@@ -170,7 +170,7 @@ void TimeZoneModel::update()
     }
     cities.sort(Qt::CaseInsensitive);
 
-    for (const QString &key : qAsConst(cities)) {
+    for (const QString &key : std::as_const(cities)) {
         const QTimeZone timeZone = zonesByCity.value(key);
         QString comment = timeZone.comment();
 
@@ -215,7 +215,7 @@ void TimeZoneModel::setSelectedTimeZones(const QStringList &selectedTimeZones)
 void TimeZoneModel::selectLocalTimeZone()
 {
     m_data[0].checked = true;
-    Q_EMIT dataChanged(index(0, 0), index(0, 0), QVector<int>{CheckedRole});
+    Q_EMIT dataChanged(index(0, 0), index(0, 0), QList<int>{CheckedRole});
 }
 
 QString TimeZoneModel::localTimeZoneCity()
