@@ -65,13 +65,14 @@ void IconApplet::configChanged()
 
 void IconApplet::populate()
 {
-    m_url = config().readEntry(QStringLiteral("url"), QUrl());
+    const QString entryName = QStringLiteral("url");
+    m_url = config().readEntry(entryName, QUrl());
 
     if (!m_url.isValid()) {
         // the old applet that used a QML plugin and stored its url
         // in plasmoid.configuration.url had its entries stored in [Configuration][General]
         // so we look here as well to provide an upgrade path
-        m_url = config().group("General").readEntry(QStringLiteral("url"), QUrl());
+        m_url = config().group("General").readEntry(entryName, QUrl());
     }
 
     // our backing desktop file already exists? just read all the things from it
@@ -96,7 +97,7 @@ void IconApplet::populate()
     setBusy(true); // unset in populateFromDesktopFile where we'll end up in if all goes well
 
     auto *statJob = KIO::stat(m_url, KIO::HideProgressInfo);
-    connect(statJob, &KIO::StatJob::finished, this, [=] {
+    connect(statJob, &KIO::StatJob::finished, this, [=, this] {
         QString desiredDesktopFileName = m_url.fileName();
 
         // in doubt, just encode the entire URL, e.g. https://www.kde.org/ has no filename
@@ -316,50 +317,15 @@ bool IconApplet::isValid() const
     return !m_localPath.isEmpty();
 }
 
-QList<QAction *> IconApplet::contextualActions()
+QList<QAction *> IconApplet::extraActions()
 {
-    QList<QAction *> actions;
+    QList<QAction *> actions = Applet::contextualActions();
     if (m_localPath.isEmpty()) {
         return actions;
     }
 
     KDesktopFile desktopFile(m_localPath);
 
-    if (m_jumpListActions.isEmpty()) {
-        const KService service(m_localPath);
-
-        const auto jumpListActions = service.actions();
-        for (const KServiceAction &serviceAction : jumpListActions) {
-            if (serviceAction.noDisplay()) {
-                continue;
-            }
-
-            QAction *action = new QAction(QIcon::fromTheme(serviceAction.icon()), serviceAction.text(), this);
-            if (serviceAction.isSeparator()) {
-                action->setSeparator(true);
-            }
-
-            connect(action, &QAction::triggered, this, [serviceAction]() {
-                auto *job = new KIO::ApplicationLauncherJob(serviceAction);
-                auto *delegate = new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled);
-                job->setUiDelegate(delegate);
-                job->start();
-            });
-
-            m_jumpListActions << action;
-        }
-    }
-
-    actions << m_jumpListActions;
-
-    if (!actions.isEmpty()) {
-        if (!m_separatorAction) {
-            m_separatorAction = new QAction(this);
-            m_separatorAction->setSeparator(true);
-        }
-        actions << m_separatorAction;
-    }
-
     if (desktopFile.hasLinkType()) {
         const QUrl linkUrl = QUrl(desktopFile.readUrl());
 
@@ -388,10 +354,44 @@ QList<QAction *> IconApplet::contextualActions()
                     });
                 }
             }
+
+            actions << m_openWithActions;
         }
+    } else {
+        if (m_jumpListActions.isEmpty()) {
+            const KService service(m_localPath);
+
+            const auto jumpListActions = service.actions();
+            for (const KServiceAction &serviceAction : jumpListActions) {
+                if (serviceAction.noDisplay()) {
+                    continue;
+                }
+
+                QAction *action = new QAction(QIcon::fromTheme(serviceAction.icon()), serviceAction.text(), this);
+                if (serviceAction.isSeparator()) {
+                    action->setSeparator(true);
+                }
+
+                connect(action, &QAction::triggered, this, [serviceAction]() {
+                    auto *job = new KIO::ApplicationLauncherJob(serviceAction);
+                    auto *delegate = new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled);
+                    job->setUiDelegate(delegate);
+                    job->start();
+                });
+
+                m_jumpListActions << action;
+            }
+        }
+        actions << m_jumpListActions;
     }
 
-    actions << m_openWithActions;
+    if (!actions.isEmpty()) {
+        if (!m_separatorAction) {
+            m_separatorAction = new QAction(this);
+            m_separatorAction->setSeparator(true);
+        }
+        actions << m_separatorAction;
+    }
 
     if (m_openContainingFolderAction) {
         actions << m_openContainingFolderAction;
