@@ -16,7 +16,6 @@
 #include <QStandardPaths>
 
 #include <KApplicationTrader>
-#include <KDesktopFileActions>
 #include <KFileUtils>
 #include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
@@ -147,14 +146,12 @@ QVariantList createAddLauncherActionList(QObject *appletInterface, const KServic
         actionList << addToDesktopAction;
     }
 
-    if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Panel)) {
-        QVariantMap addToPanelAction = Kicker::createActionItem(i18n("Add to Panel (Widget)"), QStringLiteral("list-add"), QStringLiteral("addToPanel"));
-        actionList << addToPanelAction;
-    }
-
-    if (service && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, Kicker::resolvedServiceEntryPath(service))) {
+    if (service && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, service->entryPath())) {
         QVariantMap addToTaskManagerAction = Kicker::createActionItem(i18n("Pin to Task Manager"), QStringLiteral("pin"), QStringLiteral("addToTaskManager"));
         actionList << addToTaskManagerAction;
+    } else if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Panel)) {
+        QVariantMap addToPanelAction = Kicker::createActionItem(i18n("Add to Panel (Widget)"), QStringLiteral("list-add"), QStringLiteral("addToPanel"));
+        actionList << addToPanelAction;
     }
 
     return actionList;
@@ -168,17 +165,17 @@ bool handleAddLauncherAction(const QString &actionId, QObject *appletInterface,
 
     if (actionId == QLatin1String("addToDesktop")) {
         if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Desktop)) {
-            ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::Desktop, Kicker::resolvedServiceEntryPath(service));
+            ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::Desktop, service->entryPath());
         }
         return true;
     } else if (actionId == QLatin1String("addToPanel")) {
         if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Panel)) {
-            ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::Panel, Kicker::resolvedServiceEntryPath(service));
+            ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::Panel, service->entryPath());
         }
         return true;
     } else if (actionId == QLatin1String("addToTaskManager")) {
-        if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, Kicker::resolvedServiceEntryPath(service))) {
-            ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::TaskManager, Kicker::resolvedServiceEntryPath(service));
+        if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, service->entryPath())) {
+            ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::TaskManager, service->entryPath());
         }
         return true;
     }
@@ -246,7 +243,7 @@ QVariantList systemSettingsActions()
         return list;
     }
 
-    for (const QString &id : qAsConst(ids)) {
+    for (const QString &id : std::as_const(ids)) {
         KService::Ptr service = KService::serviceByStorageId(id);
         if (!service || !service->isValid()) {
             continue;
@@ -447,7 +444,7 @@ bool handleAppstreamActions(const QString &actionId, const KService::Ptr &servic
     }
 
     const auto components =
-        appstreamPool->componentsByLaunchable(AppStream::Launchable::KindDesktopId, service->desktopEntryName() + QLatin1String(".desktop"));
+        appstreamPool->componentsByLaunchable(AppStream::Launchable::KindDesktopId, service->desktopEntryName() + QLatin1String(".desktop")).toList();
     if (components.empty()) {
         return false;
     }
@@ -465,9 +462,9 @@ static QList<KServiceAction> additionalActions(const KService::Ptr &service)
     const auto files = KFileUtils::findAllUniqueFiles(locations);
     for (const auto &file : files) {
         KService actionsService(file);
-        const auto filter = actionsService.property(QStringLiteral("X-KDE-OnlyForAppIds"), QMetaType::QStringList).toStringList();
+        const auto filter = actionsService.property<QStringList>(QStringLiteral("X-KDE-OnlyForAppIds"));
         if (filter.empty() || filter.contains(storageIdFromService(service))) {
-            actions.append(KDesktopFileActions::userDefinedServices(actionsService, true));
+            actions.append(actionsService.actions());
         }
     }
     return actions;
@@ -498,21 +495,9 @@ bool handleAdditionalAppActions(const QString &actionId, const KService::Ptr &se
         return false;
     }
     auto *job = new KIO::ApplicationLauncherJob(*action);
-    job->setUrls({QUrl::fromLocalFile(resolvedServiceEntryPath(service))});
+    job->setUrls({QUrl::fromLocalFile(service->entryPath())});
     job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
     job->start();
     return true;
 }
-
-QString resolvedServiceEntryPath(const KService::Ptr &service)
-{
-    QString path = service->entryPath();
-    if (!QDir::isAbsolutePath(path)) {
-        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + path);
-    }
-    return path;
 }
-
-}
-
-Q_DECLARE_METATYPE(KServiceAction)
