@@ -8,7 +8,6 @@
 #include "kastatsfavoritesmodel.h"
 #include "actionlist.h"
 #include "appentry.h"
-#include "contactentry.h"
 #include "debug.h"
 #include "fileentry.h"
 
@@ -20,6 +19,7 @@
 #include <KLocalizedString>
 #include <KProtocolInfo>
 #include <KSharedConfig>
+#include <KStringHandler>
 #include <KSycoca>
 
 #include <KActivities/Consumer>
@@ -28,22 +28,21 @@
 #include <KActivities/Stats/ResultWatcher>
 #include <KActivities/Stats/Terms>
 
+#include "config-KDECI_BUILD.h"
+
 namespace KAStats = KActivities::Stats;
 
 using namespace KAStats;
 using namespace KAStats::Terms;
 
 #define AGENT_APPLICATIONS QStringLiteral("org.kde.plasma.favorites.applications")
-#define AGENT_CONTACTS QStringLiteral("org.kde.plasma.favorites.contacts")
 #define AGENT_DOCUMENTS QStringLiteral("org.kde.plasma.favorites.documents")
 
 QString agentForUrl(const QString &url)
 {
     QUrl u(url);
     // clang-format off
-    return url.startsWith(QLatin1String("ktp:"))
-                ? AGENT_CONTACTS
-         : url.startsWith(QLatin1String("preferred:"))
+    return url.startsWith(QLatin1String("preferred:"))
                 ? AGENT_APPLICATIONS
          : url.startsWith(QLatin1String("applications:"))
                 ? AGENT_APPLICATIONS
@@ -73,7 +72,7 @@ public:
             if (id.isEmpty())
                 return;
 
-            QSharedPointer<AbstractEntry> entry = nullptr;
+            std::shared_ptr<AbstractEntry> entry = nullptr;
 
             if (parent->m_itemEntries.contains(id)) {
                 entry = parent->m_itemEntries[id];
@@ -84,7 +83,7 @@ public:
             }
 
             if (!entry || !entry->isValid()) {
-                qCWarning(KICKER_DEBUG) << "Entry is not valid" << id << entry;
+                qCWarning(KICKER_DEBUG) << "Entry is not valid" << id << entry.get();
                 m_id = id;
                 return;
             }
@@ -100,7 +99,7 @@ public:
             }
 
             // If this is an application, use the applications:-format url
-            auto appEntry = dynamic_cast<AppEntry *>(entry.data());
+            auto appEntry = dynamic_cast<AppEntry *>(entry.get());
             if (appEntry && !appEntry->menuId().isEmpty()) {
                 m_id = QLatin1String("applications:") + appEntry->menuId();
                 return;
@@ -144,16 +143,13 @@ public:
         return NormalizedId(this, id);
     }
 
-    QSharedPointer<AbstractEntry> entryForResource(const QString &resource, const QString &mimeType = QString()) const
+    std::shared_ptr<AbstractEntry> entryForResource(const QString &resource, const QString &mimeType = QString()) const
     {
-        using SP = QSharedPointer<AbstractEntry>;
+        using SP = std::shared_ptr<AbstractEntry>;
 
         const auto agent = agentForUrl(resource);
 
-        if (agent == AGENT_CONTACTS) {
-            return SP(new ContactEntry(q, resource));
-
-        } else if (agent == AGENT_DOCUMENTS) {
+        if (agent == AGENT_DOCUMENTS) {
             if (resource.startsWith(QLatin1String("/"))) {
                 return SP(new FileEntry(q, QUrl::fromLocalFile(resource), mimeType));
             } else {
@@ -174,8 +170,7 @@ public:
 
     Private(KAStatsFavoritesModel *parent, const QString &clientId)
         : q(parent)
-        , m_query(LinkedResources | Agent{AGENT_APPLICATIONS, AGENT_CONTACTS, AGENT_DOCUMENTS} | Type::any() | Activity::current() | Activity::global()
-                  | Limit::all())
+        , m_query(LinkedResources | Agent{AGENT_APPLICATIONS, AGENT_DOCUMENTS} | Type::any() | Activity::current() | Activity::global() | Limit(100))
         , m_watcher(m_query)
         , m_clientId(clientId)
     {
@@ -297,7 +292,7 @@ public:
         });
 
         // Debugging:
-        QVector<QString> itemStrings(m_items.size());
+        QList<QString> itemStrings(m_items.size());
         std::transform(m_items.cbegin(), m_items.cend(), itemStrings.begin(), [](const NormalizedId &item) {
             return item.value();
         });
@@ -382,7 +377,7 @@ public:
         m_items.removeAt(index);
 
         // Removing the entry from the cache
-        QMutableHashIterator<QString, QSharedPointer<AbstractEntry>> i(m_itemEntries);
+        QMutableHashIterator<QString, std::shared_ptr<AbstractEntry>> i(m_itemEntries);
         while (i.hasNext()) {
             i.next();
             if (i.value() == entry) {
@@ -414,6 +409,7 @@ public:
         // clang-format off
         return entry == nullptr ? QVariant()
              : role == Qt::DisplayRole ? entry->name()
+             : role == Kicker::DisplayWrappedRole ? KStringHandler::preProcessWrap(entry->name())
              : role == Qt::DecorationRole ? entry->icon()
              : role == Kicker::DescriptionRole ? entry->description()
              : role == Kicker::FavoriteIdRole ? entry->id()
@@ -472,7 +468,7 @@ public:
     {
         QStringList ids;
 
-        for (const auto &item : qAsConst(m_items)) {
+        for (const auto &item : std::as_const(m_items)) {
             ids << item.value();
         }
 
@@ -505,8 +501,8 @@ public:
     ResultWatcher m_watcher;
     QString m_clientId;
 
-    QVector<NormalizedId> m_items;
-    QHash<QString, QSharedPointer<AbstractEntry>> m_itemEntries;
+    QList<NormalizedId> m_items;
+    QHash<QString, std::shared_ptr<AbstractEntry>> m_itemEntries;
     QStringList m_ignoredItems;
 };
 
@@ -594,10 +590,23 @@ bool KAStatsFavoritesModel::isFavorite(const QString &id) const
     return d && d->m_itemEntries.contains(id);
 }
 
+#if BUILD_TESTING
+void KAStatsFavoritesModel::portOldFavorites(const QStringList &_ids)
+#else
 void KAStatsFavoritesModel::portOldFavorites(const QStringList &ids)
+#endif
 {
     if (!d)
         return;
+
+#if BUILD_TESTING
+    const QStringList ids = qEnvironmentVariableIsSet("KDECI_BUILD") ? QStringList{
+        QLatin1String("org.kde.plasma.emojier.desktop"),
+        QLatin1String("linguist5.desktop"),
+        QLatin1String("org.qt.linguist6.desktop"),
+    } : _ids;
+#endif
+
     qCDebug(KICKER_DEBUG) << "portOldFavorites" << ids;
 
     const QString activityId = QStringLiteral(":global");
@@ -670,16 +679,17 @@ void KAStatsFavoritesModel::removeFavoriteFrom(const QString &id, const Activity
     if (!d || id.isEmpty())
         return;
 
-    const auto url = d->normalizedId(id).value();
-
     Q_ASSERT(!activity.values.isEmpty());
 
-    qCDebug(KICKER_DEBUG) << "removeFavoriteFrom" << id << activity << url << " (actual)";
+    qCDebug(KICKER_DEBUG) << "removeFavoriteFrom" << id << activity;
 
-    if (url.isEmpty())
+    if (!isFavorite(id)) {
         return;
+    }
 
-    d->m_watcher.unlinkFromActivity(QUrl(url), activity, Agent(agentForUrl(url)));
+    QUrl url = QUrl(id);
+
+    d->m_watcher.unlinkFromActivity(url, activity, Agent(agentForUrl(id)));
 }
 
 void KAStatsFavoritesModel::setFavoriteOn(const QString &id, const QString &activityId)
@@ -749,7 +759,7 @@ QStringList KAStatsFavoritesModel::linkedActivitiesFor(const QString &id) const
         return {};
     }
 
-    auto query = LinkedResources | Agent{AGENT_APPLICATIONS, AGENT_CONTACTS, AGENT_DOCUMENTS} | Type::any() | Activity::any() | Url(url) | Limit::all();
+    auto query = LinkedResources | Agent{AGENT_APPLICATIONS, AGENT_DOCUMENTS} | Type::any() | Activity::any() | Url(url) | Limit(100);
 
     ResultSet results(query);
 
