@@ -14,12 +14,12 @@
 
 #include <QApplication>
 #include <QDir>
-#include <QIcon>
 #include <QMimeDatabase>
 #include <QQmlEngine>
 #include <QTimer>
 
 #include <KActivities/ResourceInstance>
+#include <KApplicationTrader>
 #include <KFileItem>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/JobUiDelegate>
@@ -28,7 +28,6 @@
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
-#include <KService/KApplicationTrader>
 #include <KService>
 
 #include <KActivities/Stats/Cleaning>
@@ -196,7 +195,7 @@ QVariant RecentUsageModel::appData(const QString &resource, int role) const
 
     QStringList allowedTypes({QLatin1String("Service"), QLatin1String("Application")});
 
-    if (!service || !allowedTypes.contains(service->property(QLatin1String("Type")).toString()) || service->exec().isEmpty()) {
+    if (!service || !allowedTypes.contains(service->property<QString>(QLatin1String("Type"))) || service->exec().isEmpty()) {
         return QVariant();
     }
 
@@ -293,7 +292,7 @@ QVariant RecentUsageModel::docData(const QString &resource, int role, const QStr
         if (index.isValid()) {
             return m_placesModel->icon(index);
         }
-        return QIcon::fromTheme(fileItem.iconName(), QIcon::fromTheme(QStringLiteral("unknown")));
+        return fileItem.iconName();
     } else if (role == Kicker::GroupRole) {
         return i18n("Files");
     } else if (role == Kicker::FavoriteIdRole || role == Kicker::UrlRole) {
@@ -558,5 +557,3 @@ void RecentUsageModel::refresh()
 
     setSourceModel(model);
 }
-
-Q_DECLARE_METATYPE(KServiceAction)
