@@ -10,7 +10,7 @@
 #include "runnermodel.h"
 
 #include <QAction>
-#include <QIcon>
+#include <QPluginLoader>
 #include <QUrlQuery>
 
 #include <KIO/ApplicationLauncherJob>
@@ -18,30 +18,45 @@
 #include <KNotificationJobUiDelegate>
 #include <KRunner/RunnerManager>
 
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <Plasma/Plasma>
 
-RunnerMatchesModel::RunnerMatchesModel(const QString &runnerId, const QString &name, Plasma::RunnerManager *manager, QObject *parent)
-    : AbstractModel(parent)
+RunnerMatchesModel::RunnerMatchesModel(const QString &runnerId, const std::optional<QString> &name, QObject *parent)
+    : KRunner::ResultsModel(KSharedConfig::openConfig(QStringLiteral("krunnerrc"))->group("Plugins"),
+                            KSharedConfig::openStateConfig()->group("KickerRunnerManager"),
+                            parent)
     , m_runnerId(runnerId)
-    , m_name(name)
-    , m_runnerManager(manager)
 {
-    connect(m_runnerManager, &Plasma::RunnerManager::setSearchTerm, this, &RunnerMatchesModel::requestUpdateQueryString);
-}
+    connect(this, &RunnerMatchesModel::rowsInserted, this, &RunnerMatchesModel::countChanged);
+    connect(this, &RunnerMatchesModel::rowsRemoved, this, &RunnerMatchesModel::countChanged);
+    connect(this, &RunnerMatchesModel::modelReset, this, &RunnerMatchesModel::countChanged);
 
-QString RunnerMatchesModel::description() const
-{
-    return m_name;
+    if (name.has_value()) {
+        m_name = name.value();
+    } else {
+        Q_ASSERT(!runnerId.isEmpty());
+        runnerManager()->setAllowedRunners({runnerId});
+
+        const static auto availableRunners = KRunner::RunnerManager::runnerMetaDataList();
+        for (const KPluginMetaData &runner : availableRunners) {
+            if (runner.pluginId() == runnerId) {
+                auto instance = runnerManager()->loadRunner(runner);
+                m_name = instance ? instance->name() : QString();
+            }
+        }
+    }
+    connect(runnerManager(), &KRunner::RunnerManager::requestUpdateQueryString, this, &RunnerMatchesModel::requestUpdateQueryString);
 }
 
 QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid() || index.row() >= m_matches.count()) {
+    KRunner::QueryMatch match = getQueryMatch(index);
+    if (!match.isValid()) {
         return QVariant();
     }
 
-    Plasma::QueryMatch match = m_matches.at(index.row());
-
+    // Since we have different enums than the KRunner model, we have to implement reading all the data manually
     if (role == Qt::DisplayRole) {
         return match.text();
     } else if (role == Qt::DecorationRole) {
@@ -53,27 +68,26 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
     } else if (role == Kicker::DescriptionRole) {
         return match.subtext();
     } else if (role == Kicker::FavoriteIdRole) {
-        if (match.runner()->id() == QLatin1String("services")) {
+        if (match.runner()->id() == QLatin1String("krunner_services")) {
             return match.data().toString();
         }
     } else if (role == Kicker::UrlRole) {
         const QList<QUrl> urls = match.urls();
-
         if (!urls.isEmpty()) {
             return urls.first();
         }
     } else if (role == Kicker::HasActionListRole) {
-        return match.runner()->id() == QLatin1String("services") || !match.runner()->findChildren<QAction *>().isEmpty();
+        return match.runner()->id() == QLatin1String("krunner_services") || !match.runner()->findChildren<QAction *>().isEmpty();
     } else if (role == Kicker::IsMultilineTextRole) {
         return match.isMultiLine();
     } else if (role == Kicker::ActionListRole) {
         QVariantList actionList;
-        const QList<QAction *> actions = m_runnerManager->actionsForMatch(match);
-        for (QAction *action : actions) {
-            QVariantMap item = Kicker::createActionItem(action->text(), //
-                                                        action->icon().name(),
+        const auto actions = match.actions();
+        for (auto action : actions) {
+            QVariantMap item = Kicker::createActionItem(action.text(), //
+                                                        action.iconSource(),
                                                         QStringLiteral("runnerAction"),
-                                                        QVariant::fromValue<QObject *>(action));
+                                                        QVariant::fromValue(action));
 
             actionList << item;
         }
@@ -82,7 +96,7 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
         // that any other runner returns something we want to turn into a KService is
         // unsafe, e.g. files from the Baloo runner might match a storageId just by
         // accident, creating a dangerous false positive.
-        if (match.runner()->id() != QLatin1String("services") && match.runner()->id() != QLatin1String("krunner_systemsettings")) {
+        if (match.runner()->id() != QLatin1String("krunner_services") && match.runner()->id() != QLatin1String("krunner_systemsettings")) {
             return actionList;
         }
 
@@ -159,19 +173,12 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
-int RunnerMatchesModel::rowCount(const QModelIndex &parent) const
-{
-    return parent.isValid() ? 0 : m_matches.count();
-}
-
 bool RunnerMatchesModel::trigger(int row, const QString &actionId, const QVariant &argument)
 {
-    if (row < 0 || row >= m_matches.count()) {
+    const KRunner::QueryMatch match = getQueryMatch(index(row, 0));
+    if (!match.isValid()) {
         return false;
     }
-
-    Plasma::QueryMatch match = m_matches.at(row);
-
     if (!match.isEnabled()) {
         return false;
     }
@@ -179,21 +186,13 @@ bool RunnerMatchesModel::trigger(int row, const QString &actionId, const QVarian
     // BUG 442970: Skip creating KService if there is no actionId, or the action is from a runner.
     if (actionId.isEmpty() || actionId == QLatin1String("runnerAction")) {
         if (!actionId.isEmpty()) {
-            QObject *obj = argument.value<QObject *>();
-
-            if (!obj) {
-                return false;
+            if (auto action = argument.value<KRunner::Action>()) {
+                return runnerManager()->run(match, action);
             }
-
-            QAction *action = qobject_cast<QAction *>(obj);
-
-            if (!action) {
-                return false;
-            }
-            match.setSelectedAction(action);
+            return false;
         }
 
-        return m_runnerManager->runMatch(match);
+        return runnerManager()->run(match);
     }
 
     QObject *appletInterface = static_cast<RunnerModel *>(parent())->appletInterface();
@@ -222,50 +221,3 @@ bool RunnerMatchesModel::trigger(int row, const QString &actionId, const QVarian
 
     return false;
 }
-
-void RunnerMatchesModel::setMatches(const QList<Plasma::QueryMatch> &matches)
-{
-    int oldCount = m_matches.count();
-    int newCount = matches.count();
-
-    bool emitCountChange = (oldCount != newCount);
-
-    int ceiling = qMin(oldCount, newCount);
-    bool emitDataChange = false;
-
-    for (int row = 0; row < ceiling; ++row) {
-        if (!(m_matches.at(row) == matches.at(row))) {
-            emitDataChange = true;
-            m_matches[row] = matches.at(row);
-        }
-    }
-
-    if (emitDataChange) {
-        Q_EMIT dataChanged(index(0, 0), index(ceiling - 1, 0));
-    }
-
-    if (newCount > oldCount) {
-        beginInsertRows(QModelIndex(), oldCount, newCount - 1);
-
-        m_matches = matches;
-
-        endInsertRows();
-    } else if (newCount < oldCount) {
-        beginRemoveRows(QModelIndex(), newCount, oldCount - 1);
-
-        m_matches = matches;
-
-        endRemoveRows();
-    }
-
-    if (emitCountChange) {
-        Q_EMIT countChanged();
-    }
-}
-
-AbstractModel *RunnerMatchesModel::favoritesModel()
-{
-    return static_cast<RunnerModel *>(parent())->favoritesModel();
-}
-
-Q_DECLARE_METATYPE(KServiceAction)
