@@ -12,6 +12,7 @@
 
 #include <Plasma/Containment>
 #include <Plasma/Corona>
+#include <PlasmaQuick/AppletQuickItem>
 
 PanelSpacer::PanelSpacer(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Applet(parent, data, args)
@@ -22,7 +23,7 @@ PlasmaQuick::AppletQuickItem *PanelSpacer::containmentGraphicObject() const
 {
     if (!containment())
         return nullptr; // Return nothing if there is no containment to prevent a Segmentation Fault
-    return containment()->property("_plasma_graphicObject").value<PlasmaQuick::AppletQuickItem *>();
+    return PlasmaQuick::AppletQuickItem::itemForApplet(containment());
 }
 
 K_PLUGIN_CLASS(PanelSpacer)
