@@ -11,16 +11,15 @@
 #include <QQuickWindow>
 #include <QStandardPaths>
 #include <QWindow>
-#include <QtQml>
 
 #include <sensors/SensorQuery.h>
 
 #include <KConfigLoader>
-#include <KDeclarative/QmlObjectSharedEngine>
 #include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
-#include <KNotifications/KNotificationJobUiDelegate>
+#include <KNotificationJobUiDelegate>
 #include <KService>
+#include <PlasmaQuick/SharedQmlEngine>
 
 SystemMonitor::SystemMonitor(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Applet(parent, data, args)
@@ -28,8 +27,8 @@ SystemMonitor::SystemMonitor(QObject *parent, const KPluginMetaData &data, const
     setHasConfigurationInterface(true);
 
     // Don't set the preset right now as we can't write on the config here because we don't have a Corona yet
-    if (args.count() > 2 && args.mid(3).length() > 0) {
-        const QString preset = args.mid(3).constFirst().toString();
+    if (args.count() == 2) {
+        const QString preset = args.at(1).toString();
         if (!preset.isEmpty()) {
             m_pendingStartupPreset = preset;
         }
@@ -43,9 +42,9 @@ void SystemMonitor::init()
     configChanged();
 
     // FIXME HACK: better way to get the engine At least AppletQuickItem should have an engine() getter
-    KDeclarative::QmlObjectSharedEngine *qmlObject = new KDeclarative::QmlObjectSharedEngine();
+    auto qmlObject = new PlasmaQuick::SharedQmlEngine();
     KConfigGroup cg = config();
-    m_sensorFaceController = new KSysGuard::SensorFaceController(cg, qmlObject->engine());
+    m_sensorFaceController = new KSysGuard::SensorFaceController(cg, qmlObject->engine().get());
     qmlObject->deleteLater();
 
     if (!m_pendingStartupPreset.isNull()) {
