@@ -8,6 +8,7 @@
 #include "debug.h"
 
 #include <Plasma/Corona>
+#include <PlasmaQuick/AppletQuickItem>
 #include <QAction>
 #include <kactioncollection.h>
 
@@ -80,10 +81,14 @@ void SystemTrayContainer::ensureSystrayExists()
 
     m_innerContainment->setLocation(location());
 
-    m_internalSystray = m_innerContainment->property("_plasma_graphicObject").value<QQuickItem *>();
-    Q_EMIT internalSystrayChanged();
+    auto oldInternalSystray = m_internalSystray;
+    m_internalSystray = PlasmaQuick::AppletQuickItem::itemForApplet(m_innerContainment);
 
-    actions()->addAction("configure", m_innerContainment->actions()->action("configure"));
+    if (m_internalSystray != oldInternalSystray) {
+        Q_EMIT internalSystrayChanged();
+    }
+
+    setInternalAction("configure", m_innerContainment->internalAction("configure"));
     connect(m_innerContainment.data(), &Plasma::Containment::configureRequested, this, [this](Plasma::Applet *applet) {
         Q_EMIT containment()->configureRequested(applet);
     });
@@ -94,7 +99,7 @@ void SystemTrayContainer::ensureSystrayExists()
     }
 
     // replace internal remove action with ours
-    m_innerContainment->actions()->addAction("remove", actions()->action("remove"));
+    m_innerContainment->setInternalAction("remove", internalAction("remove"));
 
     // Sync the display hints
     m_innerContainment->setContainmentDisplayHints(containmentDisplayHints() | Plasma::Types::ContainmentDrawsPlasmoidHeading
@@ -105,15 +110,15 @@ void SystemTrayContainer::ensureSystrayExists()
     });
 }
 
-void SystemTrayContainer::constraintsEvent(Plasma::Types::Constraints constraints)
+void SystemTrayContainer::constraintsEvent(Plasma::Applet::Constraints constraints)
 {
-    if (constraints & Plasma::Types::LocationConstraint) {
+    if (constraints & Plasma::Applet::LocationConstraint) {
         if (m_innerContainment) {
             m_innerContainment->setLocation(location());
         }
     }
 
-    if (constraints & Plasma::Types::FormFactorConstraint) {
+    if (constraints & Plasma::Applet::FormFactorConstraint) {
         if (m_innerContainment) {
             if (formFactor() == Plasma::Types::Horizontal || formFactor() == Plasma::Types::Vertical) {
                 m_innerContainment->setFormFactor(formFactor());
@@ -123,7 +128,7 @@ void SystemTrayContainer::constraintsEvent(Plasma::Types::Constraints constraint
         }
     }
 
-    if (constraints & Plasma::Types::UiReadyConstraint) {
+    if (constraints & Plasma::Applet::UiReadyConstraint) {
         ensureSystrayExists();
     }
 }
