@@ -181,7 +181,7 @@ QString StatusNotifierItemSource::windowId() const
     return m_windowId;
 }
 
-Plasma::Service *StatusNotifierItemSource::createService()
+Plasma5Support::Service *StatusNotifierItemSource::createService()
 {
     return new StatusNotifierItemService(this);
 }
@@ -267,7 +267,7 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
             // add app dir requires an app name, though this is completely unused in this context
             m_customIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
 
-            connect(m_customIconLoader, &KIconLoader::iconChanged, this, [=] {
+            connect(m_customIconLoader, &KIconLoader::iconChanged, this, [=, this] {
                 m_customIconLoader->reconfigure(appName, QStringList(path));
                 m_customIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
             });
@@ -417,7 +417,7 @@ QPixmap StatusNotifierItemSource::KDbusImageStructToPixmap(const KDbusImageStruc
             delete static_cast<QByteArray *>(ptr);
         },
         dataRef);
-    return QPixmap::fromImage(iconImage);
+    return QPixmap::fromImage(std::move(iconImage));
 }
 
 QIcon StatusNotifierItemSource::imageVectorToPixmap(const KDbusImageVector &vector) const
