@@ -15,6 +15,7 @@
 #include "systemtraymodel.h"
 #include "systemtraysettings.h"
 
+#include <QGuiApplication>
 #include <QMenu>
 #include <QMetaMethod>
 #include <QMetaObject>
@@ -26,80 +27,17 @@
 
 #include <Plasma/Applet>
 #include <Plasma/PluginLoader>
-#include <Plasma/ServiceJob>
+#include <Plasma5Support/ServiceJob>
 
 #include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KSharedConfig>
 #include <KWindowSystem>
 
-#if HAVE_WaylandProtocols
-#include "qwayland-fractional-scale-v1.h"
-#include <QtWaylandClient/qwaylandclientextension.h>
-#include <qpa/qplatformnativeinterface.h>
-#endif
-
-#if HAVE_WaylandProtocols // TODO Qt6: check window()->devicePixelRatio() is usable
-class FractionalScaleManagerV1 : public QWaylandClientExtensionTemplate<FractionalScaleManagerV1>, public QtWayland::wp_fractional_scale_manager_v1
-{
-public:
-    FractionalScaleManagerV1()
-        : QWaylandClientExtensionTemplate<FractionalScaleManagerV1>(1)
-        , QtWayland::wp_fractional_scale_manager_v1()
-    {
-    }
-
-    ~FractionalScaleManagerV1() override
-    {
-        QtWayland::wp_fractional_scale_manager_v1::destroy();
-    }
-};
-
-class FractionalScaleV1 : public QtWayland::wp_fractional_scale_v1
-{
-public:
-    FractionalScaleV1(struct ::wp_fractional_scale_v1 *object)
-        : QtWayland::wp_fractional_scale_v1(object)
-    {
-    }
-
-    ~FractionalScaleV1() override
-    {
-        QtWayland::wp_fractional_scale_v1::destroy();
-    }
-
-    double devicePixelRatio()
-    {
-        return m_preferredScale.value_or(120) / 120.0;
-    }
-
-    void ensureReady()
-    {
-        if (m_preferredScale.has_value()) {
-            return;
-        }
-
-        QPlatformNativeInterface *const native = qGuiApp->platformNativeInterface();
-        const auto display = static_cast<struct wl_display *>(native->nativeResourceForIntegration("wl_display"));
-        wl_display_roundtrip(display);
-    }
-
-protected:
-    void wp_fractional_scale_v1_preferred_scale(uint32_t scale) override
-    {
-        m_preferredScale = scale;
-    }
-
-private:
-    std::optional<unsigned> m_preferredScale;
-};
-#endif
-
 SystemTray::SystemTray(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Containment(parent, data, args)
 {
     setHasConfigurationInterface(true);
-    setContainmentType(Plasma::Types::CustomEmbeddedContainment);
     setContainmentDisplayHints(Plasma::Types::ContainmentDrawsPlasmoidHeading | Plasma::Types::ContainmentForcesSquarePlasmoids);
 }
 
@@ -126,10 +64,7 @@ void SystemTray::init()
         disconnect(applet, &Applet::activated, this, &Applet::activated);
     });
 
-#if HAVE_WaylandProtocols
     if (KWindowSystem::isPlatformWayland()) {
-        m_fractionalScaleManagerV1.reset(new FractionalScaleManagerV1);
-
         auto config = KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::NoGlobals);
         KConfigGroup kscreenGroup = config->group("KScreen");
         m_xwaylandClientsScale = kscreenGroup.readEntry("XwaylandClientsScale", true);
@@ -141,7 +76,6 @@ void SystemTray::init()
             }
         });
     }
-#endif
 }
 
 void SystemTray::restoreContents(KConfigGroup &group)
@@ -215,13 +149,8 @@ void SystemTray::showPlasmoidMenu(QQuickItem *appletInterface, int x, int y)
         }
     }
 
-    QAction *runAssociatedApplication = applet->actions()->action(QStringLiteral("run associated application"));
-    if (runAssociatedApplication && runAssociatedApplication->isEnabled()) {
-        desktopMenu->addAction(runAssociatedApplication);
-    }
-
-    if (applet->actions()->action(QStringLiteral("configure"))) {
-        desktopMenu->addAction(applet->actions()->action(QStringLiteral("configure")));
+    if (applet->internalAction(QStringLiteral("configure"))) {
+        desktopMenu->addAction(applet->internalAction(QStringLiteral("configure")));
     }
 
     if (desktopMenu->isEmpty()) {
@@ -252,7 +181,7 @@ void SystemTray::showStatusNotifierContextMenu(KJob *job, QQuickItem *statusNoti
         return;
     }
 
-    Plasma::ServiceJob *sjob = qobject_cast<Plasma::ServiceJob *>(job);
+    Plasma5Support::ServiceJob *sjob = qobject_cast<Plasma5Support::ServiceJob *>(job);
     if (!sjob) {
         return;
     }
@@ -342,23 +271,7 @@ QPointF SystemTray::popupPosition(QQuickItem *visualParent, int x, int y)
                 return pos;
             }
 
-            qreal devicePixelRatio = 1.0;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
-            devicePixelRatio = window->devicePixelRatio();
-#elif HAVE_WaylandProtocols
-            if (m_fractionalScaleManagerV1->isActive()) {
-                QPlatformNativeInterface *const native = qGuiApp->platformNativeInterface();
-                Q_ASSERT(native);
-                const auto surface = reinterpret_cast<struct wl_surface *>(native->nativeResourceForWindow(QByteArrayLiteral("surface"), window));
-                if (surface) {
-                    const auto scale = std::make_unique<FractionalScaleV1>(m_fractionalScaleManagerV1->get_fractional_scale(surface));
-                    if (scale->isInitialized()) {
-                        scale->ensureReady();
-                        devicePixelRatio = scale->devicePixelRatio();
-                    }
-                }
-            }
-#endif
+            const qreal devicePixelRatio = window->devicePixelRatio();
 
             if (QGuiApplication::screens().size() == 1) {
                 return pos * devicePixelRatio;
