@@ -7,13 +7,12 @@
 #pragma once
 
 #include <QAbstractItemModel>
+#include <QPointer>
 
 #include <KConfigWatcher>
 
 #include <Plasma/Containment>
 
-#include "config-WaylandProtocols.h"
-
 class QDBusPendingCallWatcher;
 class QDBusServiceWatcher;
 class QQuickItem;
@@ -98,10 +97,7 @@ private Q_SLOTS:
 private:
     SystemTrayModel *systemTrayModel();
 
-#if HAVE_WaylandProtocols
-    std::unique_ptr<class FractionalScaleManagerV1> m_fractionalScaleManagerV1;
     KConfigWatcher::Ptr m_configWatcher;
-#endif
     bool m_xwaylandClientsScale = true;
 
     QPointer<SystemTraySettings> m_settings;
