@@ -9,17 +9,17 @@
 #include "containmentlayoutmanager_debug.h"
 #include "gridlayoutmanager.h"
 
+#include <QGuiApplication>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QStyleHints>
 #include <QTimer>
 
 // Plasma
-#include <Containment>
-#include <Corona>
+#include <Plasma/Containment>
+#include <Plasma/Corona>
 #include <PlasmaQuick/AppletQuickItem>
 #include <chrono>
-#include <plasma/containment.h>
 
 using namespace std::chrono_literals;
 
@@ -108,39 +108,41 @@ AppletsLayout::~AppletsLayout()
 {
 }
 
-PlasmaQuick::AppletQuickItem *AppletsLayout::containment() const
+Plasma::Containment *AppletsLayout::containment() const
 {
-    return m_containmentItem;
+    return m_containment;
 }
 
-void AppletsLayout::setContainment(PlasmaQuick::AppletQuickItem *containmentItem)
+void AppletsLayout::setContainment(Plasma::Containment *containment)
 {
-    // Forbid changing containmentItem at runtime
-    if (m_containmentItem || containmentItem == m_containmentItem || !containmentItem->applet() || !containmentItem->applet()->isContainment()) {
+    // Forbid changing containment at runtime
+    if (m_containment || !containment->isContainment()) {
         qCWarning(CONTAINMENTLAYOUTMANAGER_DEBUG) << "Error: cannot change the containment to AppletsLayout";
         return;
     }
 
-    // Can't assign containments that aren't parents
-    QQuickItem *candidate = parentItem();
-    while (candidate) {
-        if (candidate == m_containmentItem) {
-            break;
-        }
-        candidate = candidate->parentItem();
-    }
-    if (candidate != m_containmentItem) {
+    m_containment = containment;
+
+    connect(m_containment, &Plasma::Containment::appletAdded, this, &AppletsLayout::appletAdded);
+    connect(m_containment, &Plasma::Containment::appletRemoved, this, &AppletsLayout::appletRemoved);
+
+    Q_EMIT containmentChanged();
+}
+
+PlasmaQuick::AppletQuickItem *AppletsLayout::containmentItem() const
+{
+    return m_containmentItem;
+}
+
+void AppletsLayout::setContainmentItem(PlasmaQuick::AppletQuickItem *containmentItem)
+{
+    if (containmentItem == m_containmentItem) {
         return;
     }
 
     m_containmentItem = containmentItem;
-    m_containment = static_cast<Plasma::Containment *>(m_containmentItem->applet());
 
-    connect(m_containmentItem, SIGNAL(appletAdded(QObject *, int, int)), this, SLOT(appletAdded(QObject *, int, int)));
-
-    connect(m_containmentItem, SIGNAL(appletRemoved(QObject *)), this, SLOT(appletRemoved(QObject *)));
-
-    Q_EMIT containmentChanged();
+    Q_EMIT containmentItemChanged();
 }
 
 QString AppletsLayout::configKey() const
@@ -483,29 +485,17 @@ void AppletsLayout::releaseSpace(ItemContainer *item)
     m_layoutManager->releaseSpace(item);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void AppletsLayout::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
-#else
 void AppletsLayout::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
-#endif
 {
     // Ignore completely moves without resize
     if (newGeometry.size() == oldGeometry.size()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
         QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
         return;
     }
 
     // Don't care for anything happening before startup completion
     if (!m_containment || !m_containment->corona() || !m_containment->corona()->isStartupCompleted()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
         QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
         return;
     }
 
@@ -515,11 +505,7 @@ void AppletsLayout::geometryChange(const QRectF &newGeometry, const QRectF &oldG
         m_layoutChangeTimer->start();
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
     QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
 }
 
 void AppletsLayout::updatePolish()
@@ -530,7 +516,7 @@ void AppletsLayout::updatePolish()
 
 void AppletsLayout::componentComplete()
 {
-    if (!m_containment || !m_containmentItem) {
+    if (!m_containment) {
         QQuickItem::componentComplete();
         return;
     }
@@ -544,12 +530,10 @@ void AppletsLayout::componentComplete()
         }
     }
 
-    const QList<QObject *> appletObjects = m_containmentItem->property("applets").value<QList<QObject *>>();
+    for (auto *applet : m_containment->applets()) {
+        PlasmaQuick::AppletQuickItem *appletItem = PlasmaQuick::AppletQuickItem::itemForApplet(applet);
 
-    for (auto *obj : appletObjects) {
-        PlasmaQuick::AppletQuickItem *appletItem = qobject_cast<PlasmaQuick::AppletQuickItem *>(obj);
-
-        if (!obj) {
+        if (!appletItem) {
             continue;
         }
 
@@ -654,7 +638,7 @@ void AppletsLayout::mousePressEvent(QMouseEvent *event)
     }
 
     m_mouseDownWasEditMode = m_editMode;
-    m_mouseDownPosition = event->windowPos();
+    m_mouseDownPosition = event->scenePosition();
 }
 
 void AppletsLayout::mouseMoveEvent(QMouseEvent *event)
@@ -663,7 +647,7 @@ void AppletsLayout::mouseMoveEvent(QMouseEvent *event)
         return;
     }
 
-    if (!m_editMode && QPointF(event->windowPos() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
+    if (!m_editMode && QPointF(event->scenePosition() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
         m_pressAndHoldTimer->stop();
     }
 }
@@ -677,7 +661,7 @@ void AppletsLayout::mouseReleaseEvent(QMouseEvent *event)
         // touch events, as we want a different behavior between desktop
         // and tablet mode
         && (event->source() == Qt::MouseEventSynthesizedBySystem || event->source() == Qt::MouseEventSynthesizedByQt)
-        && QPointF(event->windowPos() - m_mouseDownPosition).manhattanLength() < QGuiApplication::styleHints()->startDragDistance()) {
+        && QPointF(event->scenePosition() - m_mouseDownPosition).manhattanLength() < QGuiApplication::styleHints()->startDragDistance()) {
         setEditMode(false);
     }
 
@@ -698,39 +682,40 @@ void AppletsLayout::mouseUngrabEvent()
     m_pressAndHoldTimer->stop();
 }
 
-void AppletsLayout::appletAdded(QObject *applet, int x, int y)
+void AppletsLayout::appletAdded(Plasma::Applet *applet)
 {
-    PlasmaQuick::AppletQuickItem *appletItem = qobject_cast<PlasmaQuick::AppletQuickItem *>(applet);
+    PlasmaQuick::AppletQuickItem *appletItem = PlasmaQuick::AppletQuickItem::itemForApplet(applet);
 
     // maybe even an assert?
     if (!appletItem) {
         return;
     }
 
+    QPointF pos(appletItem->x(), appletItem->y());
+
     if (m_acceptsAppletCallback.isCallable()) {
         QQmlEngine *engine = QQmlEngine::contextForObject(this)->engine();
         Q_ASSERT(engine);
         QJSValueList args;
-        args << engine->newQObject(applet) << QJSValue(x) << QJSValue(y);
+        args << engine->newQObject(applet) << QJSValue(pos.x()) << QJSValue(pos.y());
 
         if (!m_acceptsAppletCallback.call(args).toBool()) {
-            Q_EMIT appletRefused(applet, x, y);
+            Q_EMIT appletRefused(applet, pos.x(), pos.y());
             return;
         }
     }
 
     AppletContainer *container = createContainerForApplet(appletItem);
-    container->setPosition(QPointF(x, y));
+    container->setPosition(pos);
     container->setVisible(true);
 
     m_layoutManager->positionItemAndAssign(container);
 }
 
-void AppletsLayout::appletRemoved(QObject *applet)
+void AppletsLayout::appletRemoved(Plasma::Applet *applet)
 {
-    PlasmaQuick::AppletQuickItem *appletItem = qobject_cast<PlasmaQuick::AppletQuickItem *>(applet);
+    PlasmaQuick::AppletQuickItem *appletItem = PlasmaQuick::AppletQuickItem::itemForApplet(applet);
 
-    // maybe even an assert?
     if (!appletItem) {
         return;
     }
