@@ -116,7 +116,9 @@ void ItemContainer::setEditMode(bool editMode)
 
     if (m_mouseDown) {
         sendUngrabRecursive(m_contentItem);
-        grabMouse();
+        QMouseEvent ev(QEvent::MouseButtonPress, mapFromScene(m_mouseDownPosition), m_mouseDownPosition, QPointF(), Qt::LeftButton, {}, {});
+        ev.setExclusiveGrabber(ev.point(0), this);
+        QCoreApplication::sendEvent(this, &ev);
     }
 
     if (m_dragActive != editMode && m_mouseDown) {
@@ -216,6 +218,40 @@ AppletsLayout *ItemContainer::layout() const
     return m_layout;
 }
 
+void ItemContainer::onConfigOverlayComponentStatusChanged(QQmlComponent::Status status, QQmlComponent *component)
+{
+    if (status == QQmlComponent::Loading) {
+        return;
+    }
+    if (!component) {
+        component = static_cast<QQmlComponent *>(sender());
+    }
+    if (status != QQmlComponent::Ready) {
+        delete component;
+        return;
+    }
+
+    Q_ASSERT(!m_configOverlay);
+    m_configOverlay = static_cast<ConfigOverlay *>(component->beginCreate(QQmlEngine::contextForObject(this)));
+
+    m_configOverlay->setVisible(false);
+    m_configOverlay->setItemContainer(this);
+    m_configOverlay->setParentItem(this);
+    m_configOverlay->setTouchInteraction(m_mouseSynthetizedFromTouch);
+    m_configOverlay->setZ(999);
+    m_configOverlay->setPosition(QPointF(0, 0));
+    m_configOverlay->setSize(size());
+
+    component->completeCreate();
+    component->deleteLater();
+
+    connect(m_configOverlay, &ConfigOverlay::openChanged, this, &ItemContainer::configOverlayVisibleChanged);
+
+    Q_EMIT configOverlayItemChanged();
+
+    m_configOverlay->setOpen(m_configOverlayVisible);
+}
+
 void ItemContainer::syncChildItemsGeometry(const QSizeF &size)
 {
     if (m_contentItem) {
@@ -235,24 +271,27 @@ void ItemContainer::syncChildItemsGeometry(const QSizeF &size)
     }
 }
 
-QQmlComponent *ItemContainer::configOverlayComponent() const
+QUrl ItemContainer::configOverlaySource() const
 {
-    return m_configOverlayComponent;
+    return m_configOverlaySource;
 }
 
-void ItemContainer::setConfigOverlayComponent(QQmlComponent *component)
+void ItemContainer::setConfigOverlaySource(const QUrl &url)
 {
-    if (component == m_configOverlayComponent) {
+    if (url == m_configOverlaySource || !url.isValid()) {
         return;
     }
 
-    m_configOverlayComponent = component;
+    m_configOverlaySource = url;
     if (m_configOverlay) {
         m_configOverlay->deleteLater();
         m_configOverlay = nullptr;
     }
+    Q_EMIT configOverlaySourceChanged();
 
-    Q_EMIT configOverlayComponentChanged();
+    if (m_configOverlayVisible) {
+        loadConfigOverlayItem();
+    }
 }
 
 ConfigOverlay *ItemContainer::configOverlayItem() const
@@ -283,47 +322,16 @@ bool ItemContainer::configOverlayVisible() const
 
 void ItemContainer::setConfigOverlayVisible(bool visible)
 {
-    if (!m_configOverlayComponent) {
+    if (!m_configOverlaySource.isValid() || visible == m_configOverlayVisible) {
         return;
     }
 
-    if (visible == configOverlayVisible()) {
-        return;
-    }
+    m_configOverlayVisible = visible;
 
     if (visible && !m_configOverlay) {
-        QQmlContext *context = QQmlEngine::contextForObject(this);
-        Q_ASSERT(context);
-        QObject *instance = m_configOverlayComponent->beginCreate(context);
-        m_configOverlay = qobject_cast<ConfigOverlay *>(instance);
-
-        if (!m_configOverlay) {
-            qCWarning(CONTAINMENTLAYOUTMANAGER_DEBUG) << "Error: Applet configOverlay not of ConfigOverlay type";
-            if (instance) {
-                instance->deleteLater();
-            }
-            return;
-        }
-
-        m_configOverlay->setVisible(false);
-        m_configOverlay->setItemContainer(this);
-        m_configOverlay->setParentItem(this);
-        m_configOverlay->setTouchInteraction(m_mouseSynthetizedFromTouch);
-        m_configOverlay->setZ(999);
-        m_configOverlay->setPosition(QPointF(0, 0));
-        m_configOverlay->setSize(size());
-
-        m_configOverlayComponent->completeCreate();
-
-        connect(m_configOverlay, &ConfigOverlay::openChanged, this, [this]() {
-            Q_EMIT configOverlayVisibleChanged(m_configOverlay->open());
-        });
-
-        Q_EMIT configOverlayItemChanged();
-    }
-
-    if (m_configOverlay) {
-        m_configOverlay->setOpen(visible);
+        loadConfigOverlayItem();
+    } else if (m_configOverlay) {
+        m_configOverlay->setVisible(visible);
     }
 }
 
@@ -338,11 +346,7 @@ void ItemContainer::contentData_append(QQmlListProperty<QObject> *prop, QObject
     container->m_contentData.append(object);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-int ItemContainer::contentData_count(QQmlListProperty<QObject> *prop)
-#else
 qsizetype ItemContainer::contentData_count(QQmlListProperty<QObject> *prop)
-#endif
 {
     ItemContainer *container = static_cast<ItemContainer *>(prop->object);
     if (!container) {
@@ -352,11 +356,7 @@ qsizetype ItemContainer::contentData_count(QQmlListProperty<QObject> *prop)
     return container->m_contentData.count();
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-QObject *ItemContainer::contentData_at(QQmlListProperty<QObject> *prop, int index)
-#else
 QObject *ItemContainer::contentData_at(QQmlListProperty<QObject> *prop, qsizetype index)
-#endif
 {
     ItemContainer *container = static_cast<ItemContainer *>(prop->object);
     if (!container) {
@@ -384,18 +384,10 @@ QQmlListProperty<QObject> ItemContainer::contentData()
     return QQmlListProperty<QObject>(this, nullptr, contentData_append, contentData_count, contentData_at, contentData_clear);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void ItemContainer::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
-#else
 void ItemContainer::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
-#endif
 {
     syncChildItemsGeometry(newGeometry.size());
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
     QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
     Q_EMIT contentWidthChanged();
     Q_EMIT contentHeightChanged();
 }
@@ -408,7 +400,7 @@ void ItemContainer::componentComplete()
         syncChildItemsGeometry(size());
     }
 
-    for (auto *o : qAsConst(m_contentData)) {
+    for (auto *o : std::as_const(m_contentData)) {
         QQuickItem *item = qobject_cast<QQuickItem *>(o);
         if (item) {
             item->setParentItem(m_contentItem);
@@ -453,6 +445,22 @@ void ItemContainer::sendUngrabRecursive(QQuickItem *item)
     QCoreApplication::sendEvent(item, &ev);
 }
 
+void ItemContainer::loadConfigOverlayItem()
+{
+    Q_ASSERT(!m_configOverlay);
+    constexpr QQmlComponent::CompilationMode mode = QQmlComponent::Asynchronous;
+    QQmlContext *context = QQmlEngine::contextForObject(this);
+    auto component = new QQmlComponent(context->engine(), context->resolvedUrl(m_configOverlaySource), mode, this);
+    if (!component->isLoading()) {
+        onConfigOverlayComponentStatusChanged(component->status(), component);
+    } else {
+        connect(component,
+                &QQmlComponent::statusChanged,
+                this,
+                std::bind(&ItemContainer::onConfigOverlayComponentStatusChanged, this, std::placeholders::_1, nullptr));
+    }
+}
+
 bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
 {
     // Don't filter the configoverlay
@@ -482,8 +490,8 @@ bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
         } else if (m_editModeCondition == AfterPressAndHold) {
             m_editModeTimer->start(QGuiApplication::styleHints()->mousePressAndHoldInterval());
         }
-        m_lastMousePosition = me->windowPos();
-        m_mouseDownPosition = me->windowPos();
+        m_lastMousePosition = me->scenePosition();
+        m_mouseDownPosition = me->scenePosition();
 
         if (m_editMode && !wasEditMode) {
             event->accept();
@@ -493,7 +501,7 @@ bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
     } else if (event->type() == QEvent::MouseMove) {
         QMouseEvent *me = static_cast<QMouseEvent *>(event);
 
-        if (!m_editMode && QPointF(me->windowPos() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
+        if (!m_editMode && QPointF(me->scenePosition() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
             m_editModeTimer->stop();
         } else if (m_editMode) {
             event->accept();
@@ -503,7 +511,9 @@ bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
         m_editModeTimer->stop();
         m_mouseDown = false;
         m_mouseSynthetizedFromTouch = false;
-        ungrabMouse();
+        if (auto mouseEvent = static_cast<QMouseEvent *>(event); mouseEvent->exclusiveGrabber(mouseEvent->point(0)) == this) {
+            mouseEvent->setExclusiveGrabber(mouseEvent->point(0), nullptr);
+        }
         event->accept();
         m_dragActive = false;
         if (m_editMode) {
@@ -533,7 +543,7 @@ void ItemContainer::mousePressEvent(QMouseEvent *event)
     }
 
     if (m_editMode) {
-        grabMouse();
+        event->setExclusiveGrabber(event->point(0), this);
         setCursor(Qt::ClosedHandCursor);
         m_dragActive = true;
         Q_EMIT dragActiveChanged();
@@ -541,8 +551,8 @@ void ItemContainer::mousePressEvent(QMouseEvent *event)
         m_editModeTimer->start(QGuiApplication::styleHints()->mousePressAndHoldInterval());
     }
 
-    m_lastMousePosition = event->windowPos();
-    m_mouseDownPosition = event->windowPos();
+    m_lastMousePosition = event->scenePosition();
+    m_mouseDownPosition = event->scenePosition();
     event->accept();
 }
 
@@ -557,7 +567,9 @@ void ItemContainer::mouseReleaseEvent(QMouseEvent *event)
     m_mouseDown = false;
     m_mouseSynthetizedFromTouch = false;
     m_editModeTimer->stop();
-    ungrabMouse();
+    if (event->exclusiveGrabber(event->point(0)) == this) {
+        event->setExclusiveGrabber(event->point(0), nullptr);
+    }
 
     if (m_editMode && !m_layout->itemIsManaged(this)) {
         m_layout->hidePlaceHolder();
@@ -578,7 +590,7 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
         return;
     }
 
-    if (!m_editMode && QPointF(event->windowPos() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
+    if (!m_editMode && QPointF(event->scenePosition() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
         if (m_editModeCondition == AfterPress) {
             setEditMode(true);
         } else {
@@ -592,12 +604,12 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
 
     if (m_layout && m_layout->itemIsManaged(this)) {
         m_layout->releaseSpace(this);
-        grabMouse();
+        event->setExclusiveGrabber(event->point(0), this);
         m_dragActive = true;
         Q_EMIT dragActiveChanged();
 
     } else {
-        setPosition(QPointF(x() + event->windowPos().x() - m_lastMousePosition.x(), y() + event->windowPos().y() - m_lastMousePosition.y()));
+        setPosition(QPointF(x() + event->scenePosition().x() - m_lastMousePosition.x(), y() + event->scenePosition().y() - m_lastMousePosition.y()));
 
         if (m_layout) {
             m_layout->showPlaceHolderForItem(this);
@@ -605,7 +617,7 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
 
         Q_EMIT userDrag(QPointF(x(), y()), event->pos());
     }
-    m_lastMousePosition = event->windowPos();
+    m_lastMousePosition = event->scenePosition();
     event->accept();
 }
 
@@ -614,7 +626,6 @@ void ItemContainer::mouseUngrabEvent()
     m_mouseDown = false;
     m_mouseSynthetizedFromTouch = false;
     m_editModeTimer->stop();
-    ungrabMouse();
 
     if (m_layout && m_editMode && !m_layout->itemIsManaged(this)) {
         m_layout->hidePlaceHolder();
@@ -680,8 +691,9 @@ void ItemContainer::setContentItem(QQuickItem *item)
 
     m_contentItem = item;
     item->setParentItem(this);
-    m_contentItem->setPosition(QPointF(m_leftPadding, m_topPadding));
 
+    item->setVisible(true);
+    m_contentItem->setPosition(QPointF(m_leftPadding, m_topPadding));
     m_contentItem->setSize(QSizeF(width() - m_leftPadding - m_rightPadding, height() - m_topPadding - m_bottomPadding));
 
     Q_EMIT contentItemChanged();
