@@ -16,8 +16,8 @@
 #include <QDebug>
 #include <QUrl>
 
+#include <KPackage/PackageJob>
 #include <KPackage/PackageLoader>
-#include <KPackage/PackageStructure>
 
 namespace Plasma
 {
@@ -34,9 +34,7 @@ OpenWidgetAssistant::OpenWidgetAssistant(QWidget *parent)
     connect(m_fileWidget, SIGNAL(accepted()), this, SLOT(finished()));
     layout->addWidget(m_fileWidget);
 
-    m_fileWidget->setFilter(QString());
-    const QStringList mimes{QStringLiteral("application/x-plasma")};
-    m_fileWidget->setMimeFilter(mimes);
+    m_fileWidget->setFilters({KFileFilter::fromMimeType(QStringLiteral("application/x-plasma"))});
 
     m_filePage = new KPageWidgetItem(m_filePageWidget, i18n("Select Plasmoid File"));
     addPage(m_filePage);
@@ -59,11 +57,12 @@ void OpenWidgetAssistant::finished()
         return;
     }
 
-    KPackage::Package installer = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Applet"));
-
-    if (!installer.install(packageFilePath)) {
-        KMessageBox::error(this, i18n("Installing the package %1 failed.", packageFilePath), i18n("Installation Failure"));
-    }
+    auto job = KPackage::PackageJob::install(QStringLiteral("Plasma/Applet"), packageFilePath);
+    connect(job, &KJob::result, this, [packageFilePath, this](KJob *job) {
+        if (job->error()) {
+            KMessageBox::error(this, i18n("Installing the package %1 failed.", packageFilePath), i18n("Installation Failure"));
+        }
+    });
 }
 
 } // Plasma namespace
