@@ -17,7 +17,7 @@
 #include <KAuthorized>
 #include <KLazyLocalizedString>
 #include <KLocalizedString>
-#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
+#include <KNSWidgets/Dialog>
 #include <KX11Extras>
 
 #include <Plasma/Applet>
@@ -29,6 +29,7 @@
 #include <KActivities/Consumer>
 
 #include <KPackage/Package>
+#include <KPackage/PackageJob>
 #include <KPackage/PackageLoader>
 #include <KPackage/PackageStructure>
 
@@ -98,14 +99,14 @@ public:
     KCategorizedItemsViewModels::DefaultFilterModel filterModel;
     bool showSpecialFilters = true;
     DefaultItemFilterProxyModel filterItemModel;
-    static QPointer<KNS3::QtQuickDialogWrapper> newStuffDialog;
+    static QPointer<KNSWidgets::Dialog> newStuffDialog;
 
     std::unique_ptr<KActivities::Consumer> activitiesConsumer;
 };
 
-QPointer<KNS3::QtQuickDialogWrapper> WidgetExplorerPrivate::newStuffDialog;
+QPointer<KNSWidgets::Dialog> WidgetExplorerPrivate::newStuffDialog;
 
-QString readTranslatedCategory(const KPluginMetaData &data)
+QString readTranslatedCategory(const QString &category, const QString &plugin)
 {
     static const QList<KLazyLocalizedString> possibleTranslatslations{
         kli18nc("applet category", "Accessibility"),
@@ -131,12 +132,12 @@ QString readTranslatedCategory(const KPluginMetaData &data)
         kli18nc("applet category", "Clipboard"),
         kli18nc("applet category", "Tasks"),
     };
-    const auto it = std::find_if(possibleTranslatslations.begin(), possibleTranslatslations.end(), [&data](const KLazyLocalizedString &str) {
-        return data.category() == str.untranslatedText();
+    const auto it = std::find_if(possibleTranslatslations.begin(), possibleTranslatslations.end(), [&category](const KLazyLocalizedString &str) {
+        return category == str.untranslatedText();
     });
     if (it == possibleTranslatslations.cend()) {
-        qDebug() << data.category() << "from" << data.fileName() << "is not a known category that can be translated ";
-        return data.category();
+        qDebug() << category << "from" << plugin << "is not a known category that can be translated ";
+        return category;
     }
     return it->toString();
 }
@@ -162,32 +163,29 @@ void WidgetExplorerPrivate::initFilters()
         filterModel.addSeparator(i18n("Categories:"));
     }
 
-    const QSet<QString> existingCategories = itemModel.categories();
-    QSet<QString> cats;
-    const QList<KPluginMetaData> list = PluginLoader::self()->listAppletMetaData(QString());
-
-    for (const auto &plugin : list) {
-        if (!plugin.isValid()) {
-            continue;
+    struct CategoryInfo {
+        QString untranslated;
+        QString translated;
+    };
+    std::vector<CategoryInfo> categories;
+    categories.reserve(itemModel.rowCount());
+    for (int i = 0; i < itemModel.rowCount(); ++i) {
+        if (PlasmaAppletItem *p = dynamic_cast<PlasmaAppletItem *>(itemModel.item(i))) {
+            const QString translated = readTranslatedCategory(p->category(), p->pluginName());
+            if (!translated.isEmpty()) {
+                categories.push_back({p->category(), translated});
+            }
         }
-        if (plugin.rawData().value(QStringLiteral("NoDisplay")).toBool() || plugin.category() == QLatin1String("Containments") || plugin.category().isEmpty()) {
-            // we don't want to show the hidden category
-            continue;
-        }
-        const QString category = plugin.category().toLower();
-        const QString translatedCategory = readTranslatedCategory(plugin);
-        if (cats.contains(translatedCategory)) {
-            continue;
-        }
-        cats.insert(translatedCategory);
-
-        const QString lowerCaseCat = translatedCategory.toLower();
-        if (!existingCategories.contains(category)) {
-            continue;
-        }
-
-        filterModel.addFilter(translatedCategory, KCategorizedItemsViewModels::Filter(QStringLiteral("category"), category));
     }
+    std::sort(categories.begin(), categories.end(), [](const CategoryInfo &left, const CategoryInfo &right) {
+        return left.translated < right.translated;
+    });
+    auto end = std::unique(categories.begin(), categories.end(), [](const CategoryInfo left, const CategoryInfo right) {
+        return left.translated == right.translated;
+    });
+    std::for_each(categories.begin(), end, [this](const CategoryInfo &category) {
+        filterModel.addFilter(category.translated, KCategorizedItemsViewModels::Filter(QStringLiteral("category"), category.untranslated.toLower()));
+    });
 }
 
 void WidgetExplorer::classBegin()
@@ -275,7 +273,7 @@ void WidgetExplorerPrivate::initRunningApplets()
 
     const QList<Containment *> containments = c->containments();
     for (Containment *containment : containments) {
-        if (containment->containmentType() == Plasma::Types::DesktopContainment && containment->activity() != activitiesConsumer->currentActivity()) {
+        if (containment->containmentType() == Plasma::Containment::Desktop && containment->activity() != activitiesConsumer->currentActivity()) {
             continue;
         }
         if (containment->screen() != -1) {
@@ -311,8 +309,12 @@ void WidgetExplorerPrivate::screenRemoved(int screen)
 
 void WidgetExplorerPrivate::addContainment(Containment *containment)
 {
-    QObject::connect(containment, SIGNAL(appletAdded(Plasma::Applet *)), q, SLOT(appletAdded(Plasma::Applet *)));
-    QObject::connect(containment, SIGNAL(appletRemoved(Plasma::Applet *)), q, SLOT(appletRemoved(Plasma::Applet *)));
+    QObject::connect(containment, &Plasma::Containment::appletAdded, q, [this](Plasma::Applet *a, const QRectF &) {
+        appletAdded(a);
+    });
+    QObject::connect(containment, &Plasma::Containment::appletRemoved, q, [this](Plasma::Applet *a) {
+        appletRemoved(a);
+    });
 
     const QList<Applet *> applets = containment->applets();
     for (auto applet : applets) {
@@ -486,8 +488,8 @@ void WidgetExplorer::immutabilityChanged(Plasma::Types::ImmutabilityType type)
 void WidgetExplorer::downloadWidgets()
 {
     if (WidgetExplorerPrivate::newStuffDialog.isNull()) {
-        WidgetExplorerPrivate::newStuffDialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("plasmoids.knsrc"));
-        connect(WidgetExplorerPrivate::newStuffDialog, &KNS3::QtQuickDialogWrapper::closed, WidgetExplorerPrivate::newStuffDialog, &QObject::deleteLater);
+        WidgetExplorerPrivate::newStuffDialog = new KNSWidgets::Dialog(QStringLiteral("plasmoids.knsrc"));
+        connect(WidgetExplorerPrivate::newStuffDialog, &KNSWidgets::Dialog::finished, WidgetExplorerPrivate::newStuffDialog, &QObject::deleteLater);
 
         WidgetExplorerPrivate::newStuffDialog->open();
     }
@@ -516,11 +518,7 @@ void WidgetExplorer::uninstall(const QString &pluginName)
 {
     static const QString packageRoot =
         QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + PLASMA_RELATIVE_DATA_INSTALL_DIR "/plasmoids/";
-
-    KPackage::PackageStructure *structure = KPackage::PackageLoader::self()->loadPackageStructure(QStringLiteral("Plasma/Applet"));
-
-    KPackage::Package pkg(structure);
-    pkg.uninstall(pluginName, packageRoot);
+    KPackage::PackageJob::uninstall(QStringLiteral("Plasma/Applet"), pluginName, packageRoot);
 
     // FIXME: moreefficient way rather a linear scan?
     for (int i = 0; i < d->itemModel.rowCount(); ++i) {
