@@ -11,16 +11,16 @@
 #include <QDBusPendingReply>
 #include <QVBoxLayout>
 
-#include <KActionCollection>
 #include <KActivities/Consumer>
 #include <KAuthorized>
 #include <KGlobalAccel>
-#include <KIO/CommandLauncherJob>
+#include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 #include <KService>
 #include <KTerminalLauncherJob>
 #include <QDebug>
 #include <QIcon>
+#include <QQmlListProperty>
 
 #include <Plasma/Containment>
 #include <Plasma/Corona>
@@ -51,7 +51,7 @@ void ContextMenu::restore(const KConfigGroup &config)
 
     // clang-format off
     // because it really wants to mangle this nice aligned list
-    if (c->containmentType() == Plasma::Types::PanelContainment || c->containmentType() == Plasma::Types::CustomPanelContainment) {
+    if (c->containmentType() == Plasma::Containment::Panel || c->containmentType() == Plasma::Containment::CustomPanel) {
         m_actionOrder << QStringLiteral("add widgets")
                       << QStringLiteral("_context")
                       << QStringLiteral("configure")
@@ -78,13 +78,12 @@ void ContextMenu::restore(const KConfigGroup &config)
         disabled.insert(QStringLiteral("configure shortcuts"));
         disabled.insert(QStringLiteral("_open_terminal"));
         disabled.insert(QStringLiteral("_run_command"));
-        disabled.insert(QStringLiteral("run associated application"));
         disabled.insert(QStringLiteral("_lock_screen"));
         disabled.insert(QStringLiteral("_logout"));
     }
     // clang-format on
 
-    for (const QString &name : qAsConst(m_actionOrder)) {
+    for (const QString &name : std::as_const(m_actionOrder)) {
         actions.insert(name, !disabled.contains(name));
     }
 
@@ -138,29 +137,33 @@ void ContextMenu::restore(const KConfigGroup &config)
 
 QList<QAction *> ContextMenu::contextualActions()
 {
-    Plasma::Containment *c = containment();
-    Q_ASSERT(c);
+    Plasma::Containment *cont = containment();
+    Q_ASSERT(cont);
     QList<QAction *> actions;
-    foreach (const QString &name, m_actionOrder) {
+    for (const QString &name : std::as_const(m_actionOrder)) {
         if (!m_actions.value(name)) {
             continue;
         }
 
         if (name == QLatin1String("_context")) {
-            actions << c->contextualActions();
+            actions << cont->contextualActions();
         }
         if (name == QLatin1String("_wallpaper")) {
-            if (!c->wallpaper().isEmpty()) {
-                QObject *wallpaperGraphicsObject = c->property("wallpaperGraphicsObject").value<QObject *>();
+            if (!cont->wallpaperPlugin().isEmpty()) {
+                QObject *wallpaperGraphicsObject = cont->property("wallpaperGraphicsObject").value<QObject *>();
                 if (wallpaperGraphicsObject) {
-                    actions << wallpaperGraphicsObject->property("contextualActions").value<QList<QAction *>>();
+                    QQmlListProperty<QAction> l = wallpaperGraphicsObject->property("contextualActions").value<QQmlListProperty<QAction>>();
+                    int nActions = l.count(&l);
+                    for (int i = 0; i < nActions; ++i) {
+                        actions << l.at(&l, i);
+                    }
                 }
             }
         } else if (QAction *a = action(name)) {
             // Bug 364292: show "Remove this Panel" option only when panelcontroller is opened
-            if (name != QLatin1String("remove") || c->isUserConfiguring()
-                || (c->containmentType() != Plasma::Types::PanelContainment && c->containmentType() != Plasma::Types::CustomPanelContainment
-                    && c->corona()->immutability() != Plasma::Types::Mutable)) {
+            if (name != QLatin1String("remove") || cont->isUserConfiguring()
+                || (cont->containmentType() != Plasma::Containment::Panel && cont->containmentType() != Plasma::Containment::CustomPanel
+                    && cont->corona()->immutability() != Plasma::Types::Mutable)) {
                 actions << a;
             }
         }
@@ -181,7 +184,7 @@ QAction *ContextMenu::action(const QString &name)
         return m_separator3;
     } else if (name == QLatin1String("_add panel")) {
         if (c->corona() && c->corona()->immutability() == Plasma::Types::Mutable) {
-            return c->corona()->actions()->action(QStringLiteral("add panel"));
+            return c->corona()->action(QStringLiteral("add panel"));
         }
     } else if (name == QLatin1String("_run_command")) {
         if (KAuthorized::authorizeAction(QStringLiteral("run_command")) && KAuthorized::authorize(QStringLiteral("run_command"))) {
@@ -205,7 +208,7 @@ QAction *ContextMenu::action(const QString &name)
         }
     } else if (name == QLatin1String("edit mode")) {
         if (c->corona()) {
-            return c->corona()->actions()->action(QStringLiteral("edit mode"));
+            return c->corona()->action(QStringLiteral("edit mode"));
         }
     } else if (name == QLatin1String("manage activities")) {
         if (c->corona()) {
@@ -215,11 +218,11 @@ QAction *ContextMenu::action(const QString &name)
                 return nullptr;
             }
 
-            return c->corona()->actions()->action(QStringLiteral("manage activities"));
+            return c->corona()->action(QStringLiteral("manage activities"));
         }
     } else {
         // FIXME: remove action: make removal of current activity possible
-        return c->actions()->action(name);
+        return c->internalAction(name);
     }
     return nullptr;
 }
@@ -262,25 +265,12 @@ void ContextMenu::startLogout()
     }
 }
 
-// FIXME: this function contains some code copied from KCMShell::openSystemSettings()
-// which is not publicly available to C++ code right now. Eventually we should
-// move that code into KIO so it's accessible to everyone, and then call that
-// function instead of this one
 void ContextMenu::configureDisplays()
 {
-    const QString systemSettings = QStringLiteral("systemsettings");
-    const QString kscreenKCM = QStringLiteral("kcm_kscreen");
-
-    KIO::CommandLauncherJob *job = nullptr;
-
-    // Open in System Settings if it's available
-    if (KService::serviceByDesktopName(systemSettings)) {
-        job = new KIO::CommandLauncherJob(QStringLiteral("systemsettings5"), {kscreenKCM});
-        job->setDesktopName(systemSettings);
-    } else {
-        job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {kscreenKCM});
+    if (auto service = KService::serviceByDesktopName(QStringLiteral("kcm_kscreen"))) {
+        auto job = new KIO::ApplicationLauncherJob(service);
+        job->start();
     }
-    job->start();
 }
 
 QWidget *ContextMenu::createConfigurationInterface(QWidget *parent)
