@@ -16,10 +16,9 @@
 #define ACTIVITYMANAGER_SERVICE "org.kde.kactivitymanagerd"
 #define ACTIVITYRANKING_OBJECT "/ActivityRanking"
 
-ActivityEngine::ActivityEngine(QObject *parent, const QVariantList &args)
-    : Plasma::DataEngine(parent, args)
+ActivityEngine::ActivityEngine(QObject *parent)
+    : Plasma5Support::DataEngine(parent)
 {
-    Q_UNUSED(args);
     init();
 }
 
@@ -232,7 +231,7 @@ void ActivityEngine::activityStateChanged()
     setData(QStringLiteral("Status"), QStringLiteral("Running"), m_runningActivities);
 }
 
-Plasma::Service *ActivityEngine::serviceForSource(const QString &source)
+Plasma5Support::Service *ActivityEngine::serviceForSource(const QString &source)
 {
     // FIXME validate the name
     ActivityService *service = new ActivityService(m_activityController, source);
