@@ -47,7 +47,7 @@ private:
 };
 
 StatusNotifierItemSource::StatusNotifierItemSource(const QString &notifierItemId, QObject *parent)
-    : Plasma::DataContainer(parent)
+    : Plasma5Support::DataContainer(parent)
     , m_customIconLoader(nullptr)
     , m_menuImporter(nullptr)
     , m_refreshing(false)
@@ -133,7 +133,7 @@ KIconLoader *StatusNotifierItemSource::iconLoader() const
     return m_customIconLoader ? m_customIconLoader : KIconLoader::global();
 }
 
-Plasma::Service *StatusNotifierItemSource::createService()
+Plasma5Support::Service *StatusNotifierItemSource::createService()
 {
     return new StatusNotifierItemService(this);
 }
@@ -251,7 +251,7 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
             // add app dir requires an app name, though this is completely unused in this context
             m_customIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
 
-            connect(m_customIconLoader, &KIconLoader::iconChanged, this, [=] {
+            connect(m_customIconLoader, &KIconLoader::iconChanged, this, [=, this] {
                 m_customIconLoader->reconfigure(appName, QStringList(path));
                 m_customIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
             });
@@ -417,7 +417,7 @@ QPixmap StatusNotifierItemSource::KDbusImageStructToPixmap(const KDbusImageStruc
             delete static_cast<QByteArray *>(ptr);
         },
         dataRef);
-    return QPixmap::fromImage(iconImage);
+    return QPixmap::fromImage(std::move(iconImage));
 }
 
 QIcon StatusNotifierItemSource::imageVectorToPixmap(const KDbusImageVector &vector) const
