@@ -6,26 +6,26 @@
 
 #pragma once
 
-#include <Plasma/DataEngine>
+#include <Plasma5Support/DataEngine>
 
 #include <ksgrd/SensorClient.h>
 
+#include <QList>
 #include <QStringList>
-#include <QVector>
 
 class QTimer;
 
 /**
  * This class evaluates the basic expressions given in the interface.
  */
-class SystemMonitorEngine : public Plasma::DataEngine, public KSGRD::SensorClient
+class SystemMonitorEngine : public Plasma5Support::DataEngine, public KSGRD::SensorClient
 {
     Q_OBJECT
 
 public:
-    /** Inherited from Plasma::DataEngine.  Returns a list of all the sensors that ksysguardd knows about. */
+    /** Inherited from Plasma5Support::DataEngine.  Returns a list of all the sensors that ksysguardd knows about. */
     QStringList sources() const override;
-    SystemMonitorEngine(QObject *parent, const QVariantList &args);
+    SystemMonitorEngine(QObject *parent);
     ~SystemMonitorEngine() override;
 
 protected:
@@ -40,7 +40,7 @@ protected Q_SLOTS:
     void updateMonitorsList();
 
 private:
-    QVector<QString> m_sensors;
+    QList<QString> m_sensors;
     QTimer *m_timer;
     int m_waitingFor;
 };
