@@ -40,8 +40,8 @@ WeatherData::ForecastInfo::ForecastInfo()
 }
 
 // ctor, dtor
-UKMETIon::UKMETIon(QObject *parent, const QVariantList &args)
-    : IonInterface(parent, args)
+UKMETIon::UKMETIon(QObject *parent)
+    : IonInterface(parent)
 
 {
     setInitialized(true);
@@ -61,7 +61,7 @@ void UKMETIon::reset()
 
 void UKMETIon::deleteForecasts()
 {
-    // Destroy each forecast stored in a QVector
+    // Destroy each forecast stored in a QList
     QHash<QString, WeatherData>::iterator it = m_weatherData.begin(), end = m_weatherData.end();
     for (; it != end; ++it) {
         qDeleteAll(it.value().forecasts);
@@ -280,7 +280,7 @@ bool UKMETIon::updateIonSource(const QString &source)
 // Gets specific city XML data
 void UKMETIon::getXMLData(const QString &source)
 {
-    for (const QString &fetching : qAsConst(m_obsJobList)) {
+    for (const QString &fetching : std::as_const(m_obsJobList)) {
         if (fetching == source) {
             // already getting this source and awaiting the data
             return;
@@ -755,7 +755,7 @@ bool UKMETIon::readObservationXMLData(const QString &source, QXmlStreamReader &x
     }
 
     bool solarDataSourceNeedsConnect = false;
-    Plasma::DataEngine *timeEngine = dataEngine(QStringLiteral("time"));
+    Plasma5Support::DataEngine *timeEngine = dataEngine(QStringLiteral("time"));
     if (timeEngine) {
         const bool canCalculateElevation = (data.observationDateTime.isValid() && (!qIsNaN(data.stationLatitude) && !qIsNaN(data.stationLongitude)));
         if (canCalculateElevation) {
@@ -827,7 +827,7 @@ void UKMETIon::parseFiveDayForecast(const QString &source, QXmlStreamReader &xml
     Q_ASSERT(xml.isStartElement() && xml.name() == QLatin1String("item"));
 
     WeatherData &weatherData = m_weatherData[source];
-    QVector<WeatherData::ForecastInfo *> &forecasts = weatherData.forecasts;
+    QList<WeatherData::ForecastInfo *> &forecasts = weatherData.forecasts;
 
     // Flush out the old forecasts when updating.
     forecasts.clear();
@@ -902,7 +902,7 @@ void UKMETIon::validate(const QString &source)
     }
 
     QString placeList;
-    for (const QString &place : qAsConst(m_locations)) {
+    for (const QString &place : std::as_const(m_locations)) {
         const QString p = place.section(QLatin1Char('|'), 1, 1);
         placeList.append(QStringLiteral("|place|") + p + QStringLiteral("|extra|") + m_place[place].stationId);
     }
@@ -930,7 +930,7 @@ void UKMETIon::updateWeather(const QString &source)
     weatherSource.replace(QStringLiteral("bbcukmet|"), QStringLiteral("bbcukmet|weather|"));
     weatherSource.append(QLatin1Char('|') + place.sourceExtraArg);
 
-    Plasma::DataEngine::Data data;
+    Plasma5Support::DataEngine::Data data;
 
     // work-around for buggy observation RSS feed missing the station name
     QString stationName = weatherData.stationName;
@@ -997,7 +997,7 @@ void UKMETIon::updateWeather(const QString &source)
     }
 
     // 5 Day forecast info
-    const QVector<WeatherData::ForecastInfo *> &forecasts = weatherData.forecasts;
+    const QList<WeatherData::ForecastInfo *> &forecasts = weatherData.forecasts;
 
     // Set number of forecasts per day/night supported
     data.insert(QStringLiteral("Total Weather Days"), forecasts.size());
@@ -1034,7 +1034,7 @@ void UKMETIon::updateWeather(const QString &source)
     setData(weatherSource, data);
 }
 
-void UKMETIon::dataUpdated(const QString &sourceName, const Plasma::DataEngine::Data &data)
+void UKMETIon::dataUpdated(const QString &sourceName, const Plasma5Support::DataEngine::Data &data)
 {
     const bool isNight = (data.value(QStringLiteral("Corrected Elevation")).toDouble() < 0.0);
 
