@@ -10,7 +10,7 @@
 
 #include "../ion.h"
 
-#include <Plasma/DataEngineConsumer>
+#include <Plasma5Support/DataEngineConsumer>
 
 #include <QDateTime>
 #include <QXmlStreamReader>
@@ -88,8 +88,8 @@ public:
     QString windDirection;
     QString windDegrees;
 
-    QVector<WeatherData::WeatherEvent *> watches;
-    QVector<WeatherData::WeatherEvent *> warnings;
+    QList<WeatherData::WeatherEvent *> watches;
+    QList<WeatherData::WeatherEvent *> warnings;
 
     float normalHigh;
     float normalLow;
@@ -100,7 +100,7 @@ public:
     QString UVRating;
 
     // 5 day Forecast
-    QVector<WeatherData::ForecastInfo *> forecasts;
+    QList<WeatherData::ForecastInfo *> forecasts;
 
     // Historical data from previous day.
     float prevHigh;
@@ -124,19 +124,19 @@ public:
     bool isNight = false;
 };
 
-Q_DECLARE_TYPEINFO(WeatherData::WeatherEvent, Q_MOVABLE_TYPE);
-Q_DECLARE_TYPEINFO(WeatherData::ForecastInfo, Q_MOVABLE_TYPE);
-Q_DECLARE_TYPEINFO(WeatherData, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(WeatherData::WeatherEvent, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(WeatherData::ForecastInfo, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(WeatherData, Q_RELOCATABLE_TYPE);
 
 /**
  * https://weather.gc.ca/mainmenu/disclaimer_e.html
  */
-class Q_DECL_EXPORT EnvCanadaIon : public IonInterface, public Plasma::DataEngineConsumer
+class Q_DECL_EXPORT EnvCanadaIon : public IonInterface, public Plasma5Support::DataEngineConsumer
 {
     Q_OBJECT
 
 public:
-    EnvCanadaIon(QObject *parent, const QVariantList &args);
+    EnvCanadaIon(QObject *parent);
     ~EnvCanadaIon() override;
 
 public: // IonInterface API
@@ -144,7 +144,7 @@ public: // IonInterface API
 
 public Q_SLOTS:
     // for solar data pushes from the time engine
-    void dataUpdated(const QString &sourceName, const Plasma::DataEngine::Data &data);
+    void dataUpdated(const QString &sourceName, const Plasma5Support::DataEngine::Data &data);
 
 protected: // IonInterface API
     void reset() override;
