@@ -109,11 +109,7 @@ void Menu::stop(const QList<uint> &ids)
             // TODO is there a nicer algorithm for that?
             // TODO remove all m_menus also?
             m_subscriptions.erase(
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                std::remove_if(m_subscriptions.begin(), m_subscriptions.end(), std::bind(&QList<uint>::contains, m_subscriptions, std::placeholders::_1)),
-#else
                 std::remove_if(m_subscriptions.begin(), m_subscriptions.end(), std::bind(&QList<uint>::contains<uint>, m_subscriptions, std::placeholders::_1)),
-#endif
                 m_subscriptions.end());
 
             if (m_subscriptions.isEmpty()) {
@@ -197,8 +193,8 @@ void Menu::onMenuChanged(const GMenuChangeList &changes)
 {
     const bool hadMenu = !m_menus.isEmpty();
 
-    QVector<uint> dirtyMenus;
-    QVector<uint> dirtyItems;
+    QList<uint> dirtyMenus;
+    QList<uint> dirtyItems;
 
     for (const auto &change : changes) {
         auto updateSection = [&](GMenuItem &section) {
@@ -309,7 +305,7 @@ void Menu::actionsChanged(const QStringList &dirtyActions, const QString &prefix
     };
 
     // now find in which menus these actions are and Q_EMIT a change accordingly
-    QVector<uint> dirtyItems;
+    QList<uint> dirtyItems;
 
     for (const QString &action : dirtyActions) {
         const QString prefixedAction = prefix + action;
