@@ -22,14 +22,12 @@
 #include <KConfigGroup>
 #include <KDirWatch>
 #include <KSharedConfig>
+#include <KWindowInfo>
 #include <KWindowSystem>
 #include <KX11Extras>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+
 #include <xcb/xcb.h>
 
 #include "../c_ptr.h"
