@@ -219,7 +219,7 @@ void Window::initMenu()
     m_menuInited = true;
 }
 
-void Window::menuItemsChanged(const QVector<uint> &itemIds)
+void Window::menuItemsChanged(const QList<uint> &itemIds)
 {
     if (qobject_cast<Menu *>(sender()) != m_currentMenu) {
         return;
@@ -239,7 +239,7 @@ void Window::menuItemsChanged(const QVector<uint> &itemIds)
     Q_EMIT ItemsPropertiesUpdated(items, {});
 }
 
-void Window::menuChanged(const QVector<uint> &menuIds)
+void Window::menuChanged(const QList<uint> &menuIds)
 {
     if (qobject_cast<Menu *>(sender()) != m_currentMenu) {
         return;
@@ -262,7 +262,7 @@ void Window::onMenuSubscribed(uint id)
                 DBusMenuLayoutItem item;
                 uint revision = GetLayout(Utils::treeStructureToInt(id, 0, 0), 0, {}, item);
 
-                reply << revision << QVariant::fromValue(item);
+                reply << revision << QVariant::fromValue(std::move(item));
 
                 QDBusConnection::sessionBus().send(reply);
             }
@@ -506,7 +506,7 @@ uint Window::GetLayout(int parentId, int recursionDepth, const QStringList &prop
             }
 
             int aliasedCount = 0;
-            for (const auto &aliasedItem : qAsConst(items)) {
+            for (const auto &aliasedItem : std::as_const(items)) {
                 DBusMenuLayoutItem aliasedChild{
                     Utils::treeStructureToInt(originalSubscription, originalMenu, ++aliasedCount),
                     gMenuToDBusMenuProperties(aliasedItem),
@@ -588,7 +588,7 @@ QVariantMap Window::gMenuToDBusMenuProperties(const QVariantMap &source) const
             DBusMenuShortcut dbusShortcut;
             dbusShortcut.append(shortcut); // don't let it unwrap the list we append
 
-            result.insert(QStringLiteral("shortcut"), QVariant::fromValue(dbusShortcut));
+            result.insert(QStringLiteral("shortcut"), QVariant::fromValue(std::move(dbusShortcut)));
         }
     }
 
@@ -640,10 +640,10 @@ QVariantMap Window::gMenuToDBusMenuProperties(const QVariantMap &source) const
             const auto &actionState = actionStates.first();
             // assume this is a checkbox
             if (!isMenu) {
-                if (actionState.type() == QVariant::Bool) {
+                if (actionState.typeId() == QMetaType::Bool) {
                     result.insert(QStringLiteral("toggle-type"), QStringLiteral("checkbox"));
                     result.insert(QStringLiteral("toggle-state"), actionState.toBool() ? 1 : 0);
-                } else if (actionState.type() == QVariant::String) {
+                } else if (actionState.typeId() == QMetaType::QString) {
                     result.insert(QStringLiteral("toggle-type"), QStringLiteral("radio"));
                     result.insert(QStringLiteral("toggle-state"), actionState == target ? 1 : 0);
                 }
