@@ -33,7 +33,6 @@
 #include <KShell>
 #include <KStandardAction>
 #include <KTextEdit>
-#include <KTextEditor/ConfigInterface>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 #include <KToolBar>
@@ -119,10 +118,8 @@ InteractiveConsole::InteractiveConsole(ConsoleMode mode, QWidget *parent)
 
     editorLayout->addWidget(toolBar);
 
-    auto tryLoadingKatePart = [=]() -> KTextEditor::Document * {
-        const auto loadResult =
-            KPluginFactory::instantiatePlugin<KTextEditor::Document>(KPluginMetaData(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/parts/katepart")),
-                                                                     this);
+    auto tryLoadingKatePart = [=, this]() -> KTextEditor::Document * {
+        const auto loadResult = KPluginFactory::instantiatePlugin<KTextEditor::Document>(KPluginMetaData(QStringLiteral("kf6/parts/katepart")), this);
         if (!loadResult) {
             qWarning() << "Error loading katepart plugin:" << loadResult.errorString;
             return nullptr;
@@ -134,12 +131,8 @@ InteractiveConsole::InteractiveConsole(ConsoleMode mode, QWidget *parent)
 
         KTextEditor::View *view = result->createView(widget);
         view->setContextMenu(view->defaultContextMenu());
-
-        KTextEditor::ConfigInterface *config = qobject_cast<KTextEditor::ConfigInterface *>(view);
-        if (config) {
-            config->setConfigValue(QStringLiteral("line-numbers"), true);
-            config->setConfigValue(QStringLiteral("dynamic-word-wrap"), true);
-        }
+        view->setConfigValue(QStringLiteral("line-numbers"), true);
+        view->setConfigValue(QStringLiteral("dynamic-word-wrap"), true);
 
         editorLayout->addWidget(view);
         connect(result, &KTextEditor::Document::textChanged, this, &InteractiveConsole::scriptTextChanged);
@@ -205,9 +198,9 @@ InteractiveConsole::~InteractiveConsole()
 
 void InteractiveConsole::setMode(const QString &mode)
 {
-    if (mode.toLower() == QLatin1String("desktop")) {
+    if (mode.compare(QLatin1String("desktop"), Qt::CaseInsensitive) == 0) {
         m_plasmaAction->trigger();
-    } else if (mode.toLower() == QLatin1String("windowmanager")) {
+    } else if (mode.compare(QLatin1String("windowmanager"), Qt::CaseInsensitive) == 0) {
         m_kwinAction->trigger();
     }
 }
@@ -375,7 +368,7 @@ void InteractiveConsole::populateTemplatesMenu()
         return left.name() < right.name();
     });
     KPackage::Package package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LayoutTemplate"));
-    for (const auto &templateMetaData : qAsConst(templates)) {
+    for (const auto &templateMetaData : std::as_const(templates)) {
         package.setPath(templateMetaData.pluginId());
         const QString scriptFile = package.filePath("mainscript");
         if (!scriptFile.isEmpty()) {
@@ -558,10 +551,11 @@ void InteractiveConsole::evaluateScript()
             print(reply.errorMessage());
         } else {
             const int id = reply.arguments().constFirst().toInt();
-            QDBusConnection::sessionBus().connect(s_kwinService, "/" + QString::number(id), QString(), QStringLiteral("print"), this, SLOT(print(QString)));
+            QDBusConnection::sessionBus()
+                .connect(s_kwinService, "/Scripting/Script" + QString::number(id), QString(), QStringLiteral("print"), this, SLOT(print(QString)));
             QDBusConnection::sessionBus()
                 .connect(s_kwinService, "/" + QString::number(id), QString(), QStringLiteral("printError"), this, SLOT(print(QString)));
-            message = QDBusMessage::createMethodCall(s_kwinService, "/" + QString::number(id), QString(), QStringLiteral("run"));
+            message = QDBusMessage::createMethodCall(s_kwinService, "/Scripting/Script" + QString::number(id), QString(), QStringLiteral("run"));
             reply = QDBusConnection::sessionBus().call(message);
             if (reply.type() == QDBusMessage::ErrorMessage) {
                 print(reply.errorMessage());
