@@ -9,6 +9,7 @@
 
 #include <KConfigGroup>
 #include <KDesktopFile>
+#include <KSharedConfig>
 #include <KShell>
 #include <QDebug>
 #include <QQuickItem>
@@ -16,13 +17,13 @@
 #include <QStandardPaths>
 #include <QWindow>
 
+#include <QDBusMessage>
 #include <QDirIterator>
+#include <QFileIconProvider>
 #include <QFileInfo>
 #include <QMimeDatabase>
 #include <QRegularExpression>
 
-#include <set>
-
 #include <KFileItem>
 #include <KFileUtils>
 #include <KIO/CopyJob>
@@ -86,14 +87,21 @@ std::optional<AutostartEntry> AutostartModel::loadDesktopEntry(const QString &fi
 
         return AutostartEntry{targetFileName, targetScriptDir, kind, enabled, fileName, onlyInPlasma, iconName};
     }
-
     return AutostartEntry{name, name, kind, enabled, fileName, onlyInPlasma, iconName};
 }
 
+static const QString FALLBACK_ICON = QStringLiteral("application-x-executable-script");
+
 AutostartModel::AutostartModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_xdgConfigPath(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation))
     , m_xdgAutoStartPath(m_xdgConfigPath.filePath(QStringLiteral("autostart")))
+{
+    auto message = QDBusMessage::createMethodCall("org.freedesktop.systemd1", "/org/freedesktop/systemd1", "org.freedesktop.systemd1.Manager", "Subscribe");
+    QDBusConnection::sessionBus().send(message);
+}
+
+AutostartModel::~AutostartModel()
 {
 }
 
@@ -107,7 +115,7 @@ void AutostartModel::load()
     m_xdgAutoStartPath.mkpath(QStringLiteral("."));
 
     // Needed to add all script entries after application entries
-    QVector<AutostartEntry> scriptEntries;
+    QList<AutostartEntry> scriptEntries;
     const auto filesInfo = m_xdgAutoStartPath.entryInfoList(QDir::Files);
     for (const QFileInfo &fi : filesInfo) {
         if (!KDesktopFile::isDesktopFile(fi.fileName())) {
@@ -133,9 +141,45 @@ void AutostartModel::load()
 
     loadScriptsFromDir(QStringLiteral("plasma-workspace/shutdown/"), AutostartModel::AutostartEntrySource::PlasmaShutdown);
 
+    // Add unit objects for entries and set id to them
+    for (AutostartEntry &entry : m_entries) {
+        if (entry.source == AutostartModel::AutostartEntrySource::PlasmaShutdown || entry.source == AutostartModel::AutostartEntrySource::PlasmaEnvScripts) {
+            continue;
+        }
+
+        const QUrl url{entry.fileName};
+        QString actualName = url.fileName();
+        // Remove .desktop part
+        actualName.chop(8);
+        const QString serviceName = QStringLiteral("app-") + systemdEscape(actualName) + QStringLiteral("@autostart.service");
+        auto unit = new Unit(this);
+        // To show errors that occur when loading unit data in main page
+        connect(unit, &Unit::error, this, &AutostartModel::error);
+        unit->setId(serviceName);
+        entry.systemdUnit = unit;
+    }
     endResetModel();
 }
 
+// Returns if systemd is available and systemdBoot is enabled. It used to determine if the autostart entries should be clickable in qml
+bool AutostartModel::usingSystemdBoot() const
+{
+    if (!haveSystemd) {
+        return false;
+    }
+    const KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("startkderc"));
+    const KConfigGroup generalGroup(config, "General");
+    return generalGroup.readEntry("systemdBoot", true);
+}
+
+QString AutostartModel::systemdEscape(const QString &name) const
+{
+    QString newName = name;
+    newName.replace(QLatin1Char('-'), QLatin1String("\\x2d"));
+    newName.replace(QLatin1Char('/'), QLatin1String("\\xe2\\x81\\x84"));
+    return newName;
+}
+
 void AutostartModel::loadScriptsFromDir(const QString &subDir, AutostartModel::AutostartEntrySource kind)
 {
     QDir dir(m_xdgConfigPath.filePath(subDir));
@@ -145,17 +189,22 @@ void AutostartModel::loadScriptsFromDir(const QString &subDir, AutostartModel::A
     const auto autostartDirFilesInfo = dir.entryInfoList(QDir::Files);
     for (const QFileInfo &fi : autostartDirFilesInfo) {
         QString targetFileDir = fi.absoluteDir().path();
-        QString targetFilePath = fi.absoluteFilePath();
-        QString fileName = QUrl::fromLocalFile(targetFilePath).fileName();
+        QString fileName = fi.fileName();
+        QString iconName;
         const bool isSymlink = fi.isSymLink();
+
+        // logout scripts are saved as symlinks
         if (isSymlink) {
-            targetFilePath = fi.symLinkTarget();
-            QFileInfo symLinkTarget(targetFilePath);
+            QFileInfo symLinkTarget(fi.symLinkTarget());
+            iconName = m_iconProvider.icon(symLinkTarget).name();
             targetFileDir = symLinkTarget.absoluteDir().path();
             fileName = symLinkTarget.fileName();
+        } else {
+            iconName = m_iconProvider.icon(fi).name();
         }
 
-        m_entries.push_back({fileName, targetFileDir, kind, true, fi.absoluteFilePath(), false, QStringLiteral("dialog-scripts")});
+        iconName = iconName == QString("text-plain") ? FALLBACK_ICON : iconName;
+        m_entries.push_back({fileName, targetFileDir, kind, true, fi.absoluteFilePath(), false, iconName});
     }
 }
 
@@ -208,6 +257,8 @@ QVariant AutostartModel::data(const QModelIndex &index, int role) const
         return entry.iconName;
     case TargetFileDirPath:
         return entry.targetFileDirPath;
+    case SystemdUnit:
+        return QVariant::fromValue(entry.systemdUnit);
     }
 
     return QVariant();
@@ -256,18 +307,19 @@ void AutostartModel::addApplication(const KService::Ptr &service)
         newDesktopFile->sync();
     }
 
-    const QString iconName = !service->icon().isEmpty() ? service->icon() : QStringLiteral("dialog-scripts");
-
+    const QString iconName = !service->icon().isEmpty() ? service->icon() : FALLBACK_ICON;
+    Unit *unit = new Unit(this, true);
     const auto entry = AutostartEntry{service->name(),
                                       service->name(),
                                       AutostartModel::AutostartEntrySource::XdgAutoStart, // .config/autostart load desktop at startup
                                       true,
                                       desktopPath,
                                       false,
-                                      iconName};
+                                      iconName,
+                                      unit};
 
     int lastApplication = -1;
-    for (const AutostartEntry &e : qAsConst(m_entries)) {
+    for (const AutostartEntry &e : std::as_const(m_entries)) {
         if (e.source == AutostartModel::AutostartEntrySource::XdgScripts) {
             break;
         }
@@ -342,7 +394,7 @@ void AutostartModel::addScript(const QUrl &url, AutostartModel::AutostartEntrySo
 
     if (kind == AutostartModel::AutostartEntrySource::XdgScripts) {
         int lastLoginScript = -1;
-        for (const AutostartEntry &e : qAsConst(m_entries)) {
+        for (const AutostartEntry &e : std::as_const(m_entries)) {
             if (e.source == AutostartModel::AutostartEntrySource::PlasmaShutdown) {
                 break;
             }
@@ -352,6 +404,8 @@ void AutostartModel::addScript(const QUrl &url, AutostartModel::AutostartEntrySo
         // path of the desktop file that is about to be created
         const QString newFilePath = m_xdgAutoStartPath.absoluteFilePath(fileName + QStringLiteral(".desktop"));
 
+        QIcon icon = m_iconProvider.icon(file);
+        QString iconName = icon.name() == QString("text-plain") ? FALLBACK_ICON : icon.name();
         if (QFileInfo::exists(newFilePath)) {
             const QUrl baseUrl = QUrl::fromLocalFile(m_xdgAutoStartPath.path());
             fileName = suggestName(baseUrl, fileName + QStringLiteral(".desktop"));
@@ -359,7 +413,7 @@ void AutostartModel::addScript(const QUrl &url, AutostartModel::AutostartEntrySo
             // remove the .desktop part from String
             fileName.chop(8);
         }
-        AutostartScriptDesktopFile desktopFile(fileName, KShell::quoteArg(file.filePath()));
+        AutostartScriptDesktopFile desktopFile(fileName, KShell::quoteArg(file.filePath()), iconName);
         insertScriptEntry(lastLoginScript + 1, file.fileName(), file.absoluteDir().path(), desktopFile.fileName(), kind);
 
     } else if (kind == AutostartModel::AutostartEntrySource::PlasmaShutdown) {
@@ -396,8 +450,19 @@ void AutostartModel::addScript(const QUrl &url, AutostartModel::AutostartEntrySo
 void AutostartModel::insertScriptEntry(int index, const QString &name, const QString &targetFileDirPath, const QString &path, AutostartEntrySource kind)
 {
     beginInsertRows(QModelIndex(), index, index);
+    QFileInfo targetFile{QDir(targetFileDirPath).filePath(name)};
+    const QIcon icon = m_iconProvider.icon(targetFile);
+    const QString iconName = icon.name() == QString("text-plain") ? FALLBACK_ICON : icon.name();
 
-    AutostartEntry entry = AutostartEntry{name, targetFileDirPath, kind, true, path, false, QStringLiteral("dialog-scripts")};
+    Unit *unit = new Unit(this, true);
+
+    // Plasma shutdown and Plasma env scripts don't have units
+    if (kind == AutostartModel::AutostartEntrySource::PlasmaShutdown || kind == AutostartModel::AutostartEntrySource::PlasmaEnvScripts) {
+        delete unit;
+        unit = nullptr;
+    }
+
+    AutostartEntry entry = AutostartEntry{name, targetFileDirPath, kind, true, path, false, iconName, unit};
 
     m_entries.insert(index, entry);
 
@@ -418,6 +483,7 @@ void AutostartModel::removeEntry(int row)
 
         beginRemoveRows(QModelIndex(), row, row);
         m_entries.remove(row);
+        delete entry.systemdUnit;
 
         endRemoveRows();
     });
@@ -436,6 +502,7 @@ QHash<int, QByteArray> AutostartModel::roleNames() const
     roleNames.insert(OnlyInPlasma, QByteArrayLiteral("onlyInPlasma"));
     roleNames.insert(IconName, QByteArrayLiteral("iconName"));
     roleNames.insert(TargetFileDirPath, QByteArrayLiteral("targetFileDirPath"));
+    roleNames.insert(SystemdUnit, QByteArrayLiteral("systemdUnit"));
 
     return roleNames;
 }
