@@ -10,9 +10,9 @@
 #pragma once
 
 #include <QAbstractListModel>
+#include <QList>
 #include <QPalette>
 #include <QString>
-#include <QVector>
 
 struct ColorsModelData {
     QString display;
@@ -26,7 +26,7 @@ struct ColorsModelData {
     bool tints;
     qreal tintFactor;
 };
-Q_DECLARE_TYPEINFO(ColorsModelData, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(ColorsModelData, Q_RELOCATABLE_TYPE);
 
 class ColorsModel : public QAbstractListModel
 {
@@ -78,5 +78,5 @@ Q_SIGNALS:
 private:
     QString m_selectedScheme;
 
-    QVector<ColorsModelData> m_data;
+    QList<ColorsModelData> m_data;
 };
