@@ -7,13 +7,11 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
+
 #include <QDir>
+#include <QLoggingCategory>
 #include <QRegularExpression>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 #include "thememodel.h"
 #include "xcursortheme.h"
@@ -27,6 +25,8 @@
 #define XCURSOR_LIB_MINOR XCURSOR_MINOR
 #endif
 
+Q_LOGGING_CATEGORY(KCM_CURSORTHEME, "kcm_cursortheme", QtWarningMsg)
+
 CursorThemeModel::CursorThemeModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -162,6 +162,7 @@ const QStringList CursorThemeModel::searchPaths()
 #else
     // Get the search path from Xcursor
     QString path = XcursorLibraryPath();
+    qCDebug(KCM_CURSORTHEME) << "XcursorLibraryPath:" << path;
 #endif
 
     // Separate the paths
@@ -262,6 +263,7 @@ bool CursorThemeModel::handleDefault(const QDir &themeDir)
 
 void CursorThemeModel::processThemeDir(const QDir &themeDir)
 {
+    qCDebug(KCM_CURSORTHEME) << "Searching in" << themeDir;
     bool haveCursors = themeDir.exists(QStringLiteral("cursors"));
 
     // Special case handling of "default", since it's usually either a
@@ -310,13 +312,15 @@ void CursorThemeModel::processThemeDir(const QDir &themeDir)
 void CursorThemeModel::insertThemes()
 {
     // Scan each base dir for Xcursor themes and add them to the list.
-    foreach (const QString &baseDir, searchPaths()) {
+    const QStringList paths{searchPaths()};
+    qCDebug(KCM_CURSORTHEME) << "searchPaths:" << paths;
+    for (const QString &baseDir : paths) {
         QDir dir(baseDir);
         if (!dir.exists())
             continue;
 
         // Process each subdir in the directory
-        foreach (const QString &name, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
+        for (const auto list{dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)}; const QString &name : list) {
             // Don't process the theme if a theme with the same name already exists
             // in the list. Xcursor will pick the first one it finds in that case,
             // and since we use the same search order, the one Xcursor picks should
