@@ -23,7 +23,7 @@ int main(int argc, char **argv)
     QCoreApplication::setApplicationName(QStringLiteral("plasma-apply-desktoptheme"));
     QCoreApplication::setApplicationVersion(QStringLiteral("1.0"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
-    KLocalizedString::setApplicationDomain("plasma-apply-desktoptheme");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("plasma-apply-desktoptheme"));
 
     QCommandLineParser *parser = new QCommandLineParser;
     parser->addHelpOption();
