@@ -263,7 +263,6 @@ FontsAASettings::FontsAASettings(QObject *parent)
     addItemInternal("subPixel", defaultSubPixel(), &FontsAASettings::subPixelChanged);
     addItemInternal("hinting", defaultHinting(), &FontsAASettings::hintingChanged);
 
-    connect(this, &FontsAASettings::forceFontDPIWaylandChanged, this, &FontsAASettings::dpiChanged);
     connect(this, &FontsAASettings::forceFontDPIChanged, this, &FontsAASettings::dpiChanged);
 }
 
@@ -327,7 +326,7 @@ void FontsAASettings::setAntiAliasing(bool enabled)
 
 int FontsAASettings::dpi() const
 {
-    return KWindowSystem::isPlatformWayland() ? forceFontDPIWayland() : forceFontDPI();
+    return forceFontDPI();
 }
 
 void FontsAASettings::setDpi(int newDPI)
@@ -336,11 +335,7 @@ void FontsAASettings::setDpi(int newDPI)
         return;
     }
 
-    if (KWindowSystem::isPlatformWayland()) {
-        setForceFontDPIWayland(newDPI);
-    } else {
-        setForceFontDPI(newDPI);
-    }
+    setForceFontDPI(newDPI);
     Q_EMIT dpiChanged();
 }
 
