@@ -6,11 +6,13 @@
 #include "Viewer.h"
 #include "KfiConstants.h"
 #include "config-workspace.h"
+#include "kfontview_debug.h"
+
 #include <KAboutData>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KDBusService>
-#include <KParts/BrowserExtension>
+#include <KParts/NavigationExtension>
 #include <KPluginFactory>
 #include <KSharedConfig>
 #include <KShortcutsDialog>
@@ -26,10 +28,10 @@ namespace KFI
 {
 CViewer::CViewer()
 {
-    const auto result = KPluginFactory::instantiatePlugin<KParts::ReadOnlyPart>(KPluginMetaData(QStringLiteral("kf5/parts/kfontviewpart")), this);
+    const auto result = KPluginFactory::instantiatePlugin<KParts::ReadOnlyPart>(KPluginMetaData(QStringLiteral("kf6/parts/kfontviewpart")), this);
 
     if (!result) {
-        qWarning() << "Error loading kfontviewpart:" << result.errorString;
+        qCWarning(KFONTVIEW_DEBUG) << "Error loading kfontviewpart:" << result.errorString;
         exit(1);
     }
 
@@ -46,8 +48,8 @@ CViewer::CViewer()
 
     m_printAct->setEnabled(false);
 
-    if (m_preview->browserExtension()) {
-        connect(m_preview->browserExtension(), &KParts::BrowserExtension::enableAction, this, &CViewer::enableAction);
+    if (m_preview->navigationExtension()) {
+        connect(m_preview->navigationExtension(), &KParts::NavigationExtension::enableAction, this, &CViewer::enableAction);
     }
 
     setCentralWidget(m_preview->widget());
@@ -140,7 +142,6 @@ private:
 
 int main(int argc, char **argv)
 {
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     KFI::ViewerApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain(KFI_CATALOGUE);
