@@ -37,7 +37,7 @@ static constexpr int constReconfigTimeout = 10;
 class KIOPluginForMetaData : public QObject
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.fonts" FILE "fonts.json")
+    Q_PLUGIN_METADATA(IID "org.kde.kio.worker.fonts" FILE "fonts.json")
 };
 
 extern "C" {
@@ -51,9 +51,9 @@ Q_DECL_EXPORT int kdemain(int argc, char **argv)
 
     QCoreApplication app(argc, argv);
     QCoreApplication::setApplicationName("kio_" KFI_KIO_FONTS_PROTOCOL);
-    KFI::CKioFonts slave(argv[2], argv[3]);
+    KFI::CKioFonts worker(argv[2], argv[3]);
 
-    slave.dispatchLoop();
+    worker.dispatchLoop();
 
     return 0;
 }
@@ -144,7 +144,7 @@ static QString removeKnownExtension(const QUrl &url)
 }
 
 CKioFonts::CKioFonts(const QByteArray &pool, const QByteArray &app)
-    : KIO::SlaveBase(KFI_KIO_FONTS_PROTOCOL, pool, app)
+    : KIO::WorkerBase(KFI_KIO_FONTS_PROTOCOL, pool, app)
     , m_interface(new FontInstInterface())
     , m_tempDir(nullptr)
 {
@@ -156,7 +156,7 @@ CKioFonts::~CKioFonts()
     delete m_tempDir;
 }
 
-void CKioFonts::listDir(const QUrl &url)
+KIO::WorkerResult CKioFonts::listDir(const QUrl &url)
 {
     qCDebug(KCM_KFONTINST_KIO) << url;
 
@@ -192,25 +192,25 @@ void CKioFonts::listDir(const QUrl &url)
     }
 
     if (FOLDER_UNKNOWN != folder) {
-        finished();
+        return KIO::WorkerResult::pass();
     } else {
-        error(KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
+        return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
     }
 }
 
-void CKioFonts::put(const QUrl &url, int /*permissions*/, KIO::JobFlags /*flags*/)
+KIO::WorkerResult CKioFonts::put(const QUrl &url, int /*permissions*/, KIO::JobFlags /*flags*/)
 {
     qCDebug(KCM_KFONTINST_KIO) << url;
     QStringList pathList(url.adjusted(QUrl::StripTrailingSlash).path().split(QLatin1Char('/'), Qt::SkipEmptyParts));
     EFolder folder(getFolder(pathList));
 
     if (!Misc::root() && FOLDER_ROOT == folder) {
-        error(KIO::ERR_WORKER_DEFINED, i18n("Can only install fonts to either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Can only install fonts to either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
     } else if (Misc::isPackage(url.fileName())) {
-        error(KIO::ERR_WORKER_DEFINED,
-              i18n("You cannot install a fonts package directly.\n"
-                   "Please extract %1, and install the components individually.",
-                   url.toDisplayString()));
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED,
+                                       i18n("You cannot install a fonts package directly.\n"
+                                            "Please extract %1, and install the components individually.",
+                                            url.toDisplayString()));
     } else {
         if (!m_tempDir) {
             m_tempDir = new QTemporaryDir(QDir::tempPath() + QString::fromLatin1("/kio_fonts_") + QString::number(getpid()));
@@ -229,31 +229,26 @@ void CKioFonts::put(const QUrl &url, int /*permissions*/, KIO::JobFlags /*flags*
                 dataReq(); // Request for data
                 result = readData(buffer);
                 if (result > 0 && !writeAll(dest.handle(), buffer.constData(), buffer.size())) {
+                    dest.close();
                     if (ENOSPC == errno) // disk full
                     {
-                        error(KIO::ERR_DISK_FULL, dest.fileName());
-                        result = -2; // means: remove dest file
-                    } else {
-                        error(KIO::ERR_CANNOT_WRITE, dest.fileName());
-                        result = -1;
+                        return KIO::WorkerResult::fail(KIO::ERR_DISK_FULL, dest.fileName());
                     }
+                    return KIO::WorkerResult::fail(KIO::ERR_CANNOT_WRITE, dest.fileName());
                 }
             } while (result > 0);
 
-            if (result < 0) {
-                dest.close();
-                ::exit(255);
-            }
-
-            handleResp(m_interface->install(tempFile, Misc::root() || FOLDER_SYS == folder), url.fileName(), tempFile, FOLDER_SYS == folder);
+            const int resp = m_interface->install(tempFile, Misc::root() || FOLDER_SYS == folder);
             QFile::remove(tempFile);
+            return handleResp(resp, url.fileName(), tempFile, FOLDER_SYS == folder);
         } else {
-            error(EACCES == errno ? KIO::ERR_WRITE_ACCESS_DENIED : KIO::ERR_CANNOT_OPEN_FOR_WRITING, dest.fileName());
+            return KIO::WorkerResult::fail(EACCES == errno ? KIO::ERR_WRITE_ACCESS_DENIED : KIO::ERR_CANNOT_OPEN_FOR_WRITING, dest.fileName());
         }
     }
+    return KIO::WorkerResult::pass();
 }
 
-void CKioFonts::get(const QUrl &url)
+KIO::WorkerResult CKioFonts::get(const QUrl &url)
 {
     qCDebug(KCM_KFONTINST_KIO) << url;
     QStringList pathList(url.adjusted(QUrl::StripTrailingSlash).path().split(QLatin1Char('/'), Qt::SkipEmptyParts));
@@ -315,9 +310,8 @@ void CKioFonts::get(const QUrl &url)
             processedSize(array.size());
             data(QByteArray());
             processedSize(array.size());
-            finished();
             qCDebug(KCM_KFONTINST_KIO) << "Finished thumbnail...";
-            return;
+            return KIO::WorkerResult::pass();
         }
 
         QSet<QString> files;
@@ -369,19 +363,19 @@ void CKioFonts::get(const QUrl &url)
         qCDebug(KCM_KFONTINST_KIO) << "real: " << realPathC;
 
         if (-2 == QT_STAT(realPathC.constData(), &buff)) {
-            error(EACCES == errno ? KIO::ERR_ACCESS_DENIED : KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
+            return KIO::WorkerResult::fail(EACCES == errno ? KIO::ERR_ACCESS_DENIED : KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
         } else if (S_ISDIR(buff.st_mode)) {
-            error(KIO::ERR_IS_DIRECTORY, url.toDisplayString());
+            return KIO::WorkerResult::fail(KIO::ERR_IS_DIRECTORY, url.toDisplayString());
         } else if (!S_ISREG(buff.st_mode)) {
-            error(KIO::ERR_CANNOT_OPEN_FOR_READING, url.toDisplayString());
+            return KIO::WorkerResult::fail(KIO::ERR_CANNOT_OPEN_FOR_READING, url.toDisplayString());
         } else {
             int fd = QT_OPEN(realPathC.constData(), O_RDONLY);
 
             if (fd < 0) {
-                error(KIO::ERR_CANNOT_OPEN_FOR_READING, url.toDisplayString());
+                return KIO::WorkerResult::fail(KIO::ERR_CANNOT_OPEN_FOR_READING, url.toDisplayString());
             } else {
                 // Determine the mimetype of the file to be retrieved, and Q_EMIT it.
-                // This is mandatory in all slaves (for KRun/BrowserRun to work).
+                // This is mandatory in all workers (for KRun/BrowserRun to work).
                 // This code can be optimized by using QFileInfo instead of buff above
                 // and passing it to mimeTypeForFile() instead of realPath.
                 QMimeDatabase db;
@@ -401,12 +395,11 @@ void CKioFonts::get(const QUrl &url)
                             continue;
                         }
 
-                        error(KIO::ERR_CANNOT_READ, url.toDisplayString());
                         ::close(fd);
                         if (multiple) {
                             ::unlink(realPathC);
                         }
-                        return;
+                        return KIO::WorkerResult::fail(KIO::ERR_CANNOT_READ, url.toDisplayString());
                     }
                     if (0 == n) {
                         break; // Finished
@@ -423,28 +416,29 @@ void CKioFonts::get(const QUrl &url)
                 data(QByteArray());
                 ::close(fd);
                 processedSize(buff.st_size);
-                finished();
+                return KIO::WorkerResult::pass();
             }
         }
         if (multiple) {
             ::unlink(realPathC);
         }
     } else {
-        error(KIO::ERR_CANNOT_READ, url.toDisplayString());
+        return KIO::WorkerResult::fail(KIO::ERR_CANNOT_READ, url.toDisplayString());
     }
+    return KIO::WorkerResult::pass();
 }
 
-void CKioFonts::copy(const QUrl &, const QUrl &, int, KIO::JobFlags)
+KIO::WorkerResult CKioFonts::copy(const QUrl &, const QUrl &, int, KIO::JobFlags)
 {
-    error(KIO::ERR_WORKER_DEFINED, i18n("Cannot copy fonts"));
+    return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Cannot copy fonts"));
 }
 
-void CKioFonts::rename(const QUrl &, const QUrl &, KIO::JobFlags)
+KIO::WorkerResult CKioFonts::rename(const QUrl &, const QUrl &, KIO::JobFlags)
 {
-    error(KIO::ERR_WORKER_DEFINED, i18n("Cannot move fonts"));
+    return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Cannot move fonts"));
 }
 
-void CKioFonts::del(const QUrl &url, bool isFile)
+KIO::WorkerResult CKioFonts::del(const QUrl &url, bool isFile)
 {
     qCDebug(KCM_KFONTINST_KIO) << url;
     QStringList pathList(url.adjusted(QUrl::StripTrailingSlash).path().split(QLatin1Char('/'), Qt::SkipEmptyParts));
@@ -452,18 +446,19 @@ void CKioFonts::del(const QUrl &url, bool isFile)
     QString name(removeKnownExtension(url));
 
     if (!isFile) {
-        error(KIO::ERR_WORKER_DEFINED, i18n("Only fonts may be deleted."));
-    } else if (!Misc::root() && FOLDER_ROOT == folder) {
-        error(KIO::ERR_WORKER_DEFINED,
-              i18n("Can only remove fonts from either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
-    } else if (!name.isEmpty()) {
-        handleResp(m_interface->uninstall(name, Misc::root() || FOLDER_SYS == folder), name);
-    } else {
-        error(KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Only fonts may be deleted."));
     }
+    if (!Misc::root() && FOLDER_ROOT == folder) {
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Can only remove fonts from either \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
+    }
+    if (!name.isEmpty()) {
+        return handleResp(m_interface->uninstall(name, Misc::root() || FOLDER_SYS == folder), name);
+    }
+
+    return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
 }
 
-void CKioFonts::stat(const QUrl &url)
+KIO::WorkerResult CKioFonts::stat(const QUrl &url)
 {
     qCDebug(KCM_KFONTINST_KIO) << url;
 
@@ -482,8 +477,7 @@ void CKioFonts::stat(const QUrl &url)
         } else if (FOLDER_SYS == folder || FOLDER_USER == folder) {
             createUDSEntry(entry, folder);
         } else {
-            error(KIO::ERR_WORKER_DEFINED, i18n("Please specify \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
-            return;
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Please specify \"%1\" or \"%2\".", KFI_KIO_FONTS_USER.toString(), KFI_KIO_FONTS_SYS.toString()));
         }
         break;
     default:
@@ -492,20 +486,20 @@ void CKioFonts::stat(const QUrl &url)
 
     if (ok) {
         statEntry(entry);
-        finished();
+        return KIO::WorkerResult::pass();
     } else {
-        error(KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
-        return;
+        return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.toDisplayString());
     }
 }
 
-void CKioFonts::special(const QByteArray &a)
+KIO::WorkerResult CKioFonts::special(const QByteArray &a)
 {
     if (!a.isEmpty()) {
-        error(KIO::ERR_UNSUPPORTED_ACTION, i18n("No special methods supported."));
+        return KIO::WorkerResult::fail(KIO::ERR_UNSUPPORTED_ACTION, i18n("No special methods supported."));
     } else {
         setTimeoutSpecialCommand(-1);
         m_interface->reconfigure();
+        return KIO::WorkerResult::pass();
     }
 }
 
@@ -701,41 +695,30 @@ Family CKioFonts::getFont(const QUrl &url, EFolder folder)
     return m_interface->statFont(name, FOLDER_SYS == folder);
 }
 
-void CKioFonts::handleResp(int resp, const QString &file, const QString &tempFile, bool destIsSystem)
+KIO::WorkerResult CKioFonts::handleResp(int resp, const QString &file, const QString &tempFile, bool destIsSystem)
 {
     switch (resp) {
     case FontInst::STATUS_NO_SYS_CONNECTION:
-        error(KIO::ERR_WORKER_DEFINED, i18n("Failed to start the system daemon"));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Failed to start the system daemon"));
     case FontInst::STATUS_SERVICE_DIED:
-        error(KIO::ERR_WORKER_DEFINED, i18n("Backend died"));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Backend died"));
     case FontInst::STATUS_BITMAPS_DISABLED:
-        error(KIO::ERR_WORKER_DEFINED, i18n("%1 is a bitmap font, and these have been disabled on your system.", file));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("%1 is a bitmap font, and these have been disabled on your system.", file));
     case FontInst::STATUS_ALREADY_INSTALLED:
-        error(KIO::ERR_WORKER_DEFINED, i18n("%1 contains the font <b>%2</b>, which is already installed on your system.", file, FC::getName(tempFile)));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("%1 contains the font <b>%2</b>, which is already installed on your system.", file, FC::getName(tempFile)));
     case FontInst::STATUS_NOT_FONT_FILE:
-        error(KIO::ERR_WORKER_DEFINED, i18n("%1 is not a font.", file));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("%1 is not a font.", file));
     case FontInst::STATUS_PARTIAL_DELETE:
-        error(KIO::ERR_WORKER_DEFINED, i18n("Could not remove all files associated with %1", file));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Could not remove all files associated with %1", file));
     case KIO::ERR_FILE_ALREADY_EXIST: {
         QString name(Misc::modifyName(file)), destFolder(Misc::getDestFolder(m_interface->folderName(destIsSystem), name));
-        error(KIO::ERR_WORKER_DEFINED, i18n("<i>%1</i> already exists.", destFolder + name));
-        break;
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("<i>%1</i> already exists.", destFolder + name));
     }
     case FontInst::STATUS_OK:
-        finished();
-        break;
-    default:
-        error(resp, file);
-    }
-
-    if (FontInst::STATUS_OK == resp) {
         setTimeoutSpecialCommand(constReconfigTimeout);
+        return KIO::WorkerResult::pass();
+    default:
+        return KIO::WorkerResult::fail(resp, file);
     }
 }
 }
