@@ -1,21 +1,21 @@
 /*
-    KRDB - puts current KDE color scheme into preprocessor statements
-    cats specially written application default files and uses xrdb -merge to
-    write to RESOURCE_MANAGER. Thus it gives a  simple way to make non-KDE
-    applications fit in with the desktop
+   KRDB - puts current KDE color scheme into preprocessor statements
+   cats specially written application default files and uses xrdb -merge to
+   write to RESOURCE_MANAGER. Thus it gives a  simple way to make non-KDE
+   applications fit in with the desktop
 
-    SPDX-FileCopyrightText: 1998 Mark Donohoe
-    SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
-    SPDX-FileCopyrightText: 2002 Karol Szwed <gallium@kde.org>
-    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
+   SPDX-FileCopyrightText: 1998 Mark Donohoe
+   SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
+   SPDX-FileCopyrightText: 2002 Karol Szwed <gallium@kde.org>
+   SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
-    reworked for KDE 2.0:
-    SPDX-FileCopyrightText: 1999 Dirk A. Mueller
+   reworked for KDE 2.0:
+   SPDX-FileCopyrightText: 1999 Dirk A. Mueller
 
-    add support for GTK applications:
-    SPDX-FileCopyrightText: 2001 Matthias Ettrich
+   add support for GTK applications:
+   SPDX-FileCopyrightText: 2001 Matthias Ettrich
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-X11.h>
@@ -48,16 +48,12 @@
 #include <KProcess>
 #include <KWindowSystem>
 
-#include <updatelaunchenvjob.h>
+#include <KUpdateLaunchEnvironmentJob>
 
 #include "krdb.h"
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 #include <X11/Xlib.h>
+#include <private/qtx11extras_p.h>
 #endif
 
 #include <filesystem>
@@ -126,7 +122,9 @@ static void applyGtkStyles(int version)
 
     // Pass env. var to kdeinit.
     const QString value = list.join(QLatin1Char(':'));
-    UpdateLaunchEnvJob(varName, value);
+    QProcessEnvironment newEnv;
+    newEnv.insert(varName, value);
+    new KUpdateLaunchEnvironmentJob(newEnv);
 }
 
 // -----------------------------------------------------------------------------
@@ -326,20 +324,19 @@ static void createGtkrc(const QPalette &cg, bool exportGtkTheme, const QString &
 int xftDpi()
 {
     KConfig cfg(QStringLiteral("kcmfonts"));
-    KConfigGroup fontsCfg(&cfg, "General");
+    int dpi = 0;
 
-    int defaultDpi = 0;
-    const bool isWayland = KWindowSystem::isPlatformWayland();
-
-    if (isWayland) {
+    if (KWindowSystem::isPlatformWayland()) {
         KConfig cfg(QStringLiteral("kwinrc"));
         KConfigGroup xwaylandGroup = cfg.group("Xwayland");
         qreal scale = xwaylandGroup.readEntry("Scale", 1.0);
-        defaultDpi = scale * 96;
+        dpi = scale * 96;
+    } else {
+        KConfigGroup fontsCfg(&cfg, "General");
+        dpi = fontsCfg.readEntry(QStringLiteral("forceFontDPI"), 96);
     }
 
-    QString fontDpiKey = isWayland ? QStringLiteral("forceFontDPIWayland") : QStringLiteral("forceFontDPI");
-    return fontsCfg.readEntry(fontDpiKey, defaultDpi);
+    return dpi;
 }
 
 void runRdb(unsigned int flags)
@@ -384,14 +381,17 @@ void runRdb(unsigned int flags)
     // Export the Xcursor theme & size settings
     KConfigGroup mousecfg(KSharedConfig::openConfig(QStringLiteral("kcminputrc")), "Mouse");
     QString theme = mousecfg.readEntry("cursorTheme", QStringLiteral("breeze_cursors"));
-    QString size = mousecfg.readEntry("cursorSize", QStringLiteral("24"));
+    int cursorSize = mousecfg.readEntry("cursorSize", 24);
+
+    if (KWindowSystem::isPlatformWayland()) {
+        KConfig kwinConfig(QStringLiteral("kwinrc"));
+        KConfigGroup xwaylandGroup(&kwinConfig, "Xwayland");
+        cursorSize *= xwaylandGroup.readEntry("Scale", 1.0);
+    }
+
     QString contents;
-
-    if (!theme.isNull())
-        contents = "Xcursor.theme: " + theme + '\n';
-
-    if (!size.isNull())
-        contents += "Xcursor.size: " + size + '\n';
+    contents += "Xcursor.theme: " + theme + '\n';
+    contents += "Xcursor.size: " + QString::number(cursorSize) + '\n';
 
     if (exportXftSettings) {
         contents += QLatin1String("Xft.antialias: ");
