@@ -10,9 +10,10 @@
 // Qt
 #include <KJob>
 #include <KPackage/Package>
-#include <KPackage/PackageLoader>
+#include <KPackage/PackageJob>
 #include <KSycoca>
-#include <QtTest>
+#include <QSignalSpy>
+#include <QTest>
 
 class KcmTest : public QObject
 {
@@ -35,7 +36,6 @@ private Q_SLOTS:
     void testSplashScreen();
     void testLockScreen();
     void testWindowSwitcher();
-    void testDesktopSwitcher();
     void testKCMSave();
 
 private:
@@ -64,20 +64,21 @@ void KcmTest::initTestCase()
     f.close();
 
     const QString packagePath = QFINDTESTDATA("lookandfeel");
-
-    KPackage::Package p = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
-    p.setPath(packagePath);
-    QVERIFY(p.isValid());
-
     const QString packageRoot = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/plasma/look-and-feel/";
-    auto installJob = p.install(packagePath, packageRoot);
-    installJob->exec();
+    auto installJob = KPackage::PackageJob::install(QStringLiteral("Plasma/LookAndFeel"), packagePath, packageRoot);
+    connect(installJob, &KJob::result, this, [installJob]() {
+        QCOMPARE(installJob->errorText(), QString());
+        QCOMPARE(installJob->error(), KJob::NoError);
+        QVERIFY(installJob->package().isValid());
+    });
+    QSignalSpy spy(installJob, &KPackage::PackageJob::finished);
+    spy.wait();
 
     KConfig config(QStringLiteral("kdeglobals"));
     KConfigGroup cg(&config, "KDE");
     cg.writeEntry("LookAndFeelPackage", "org.kde.test");
     cg.sync();
-    m_KCMLookandFeel = new KCMLookandFeel(nullptr, KPluginMetaData(), QVariantList());
+    m_KCMLookandFeel = new KCMLookandFeel(nullptr, KPluginMetaData());
     m_KCMLookandFeel->load();
 }
 
@@ -89,17 +90,21 @@ void KcmTest::cleanupTestCase()
 
 void KcmTest::testWidgetStyle()
 {
+    // We have to use an actual theme name here because setWidgetStyle checks
+    // if the theme can actually be used before it changes the config
     m_KCMLookandFeel->lookAndFeel()->setWidgetStyle(QStringLiteral("Fusion"));
 
     KConfig config(QStringLiteral("kdeglobals"));
     KConfigGroup cg(&config, "KDE");
-    // We have to use an actual theme name here because setWidgetStyle checks
-    // if the theme can actually be used before it changes the config
     QCOMPARE(cg.readEntry("widgetStyle", QString()), QString());
 
     KConfig configDefault(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/kdedefaults/kdeglobals", KConfig::SimpleConfig);
     KConfigGroup cgd(&configDefault, "KDE");
     QCOMPARE(cgd.readEntry("widgetStyle", QString()), QStringLiteral("Fusion"));
+
+    // Test that a fake style is not actually written to config
+    m_KCMLookandFeel->lookAndFeel()->setWidgetStyle(QStringLiteral("customStyle"));
+    QCOMPARE(cgd.readEntry("widgetStyle", QString()), QStringLiteral("Fusion"));
 }
 
 void KcmTest::testColors()
@@ -196,23 +201,15 @@ void KcmTest::testWindowSwitcher()
     QCOMPARE(cgd.readEntry("LayoutName", QString()), QStringLiteral("customTestValue"));
 }
 
-void KcmTest::testDesktopSwitcher()
-{
-    m_KCMLookandFeel->lookAndFeel()->setDesktopSwitcher(QStringLiteral("customTestValue"));
-
-    KConfig config(QStringLiteral("kwinrc"));
-    KConfigGroup cg(&config, "TabBox");
-    QCOMPARE(cg.readEntry("DesktopLayout", QString()), QString());
-    QCOMPARE(cg.readEntry("DesktopListLayout", QString()), QString());
-
-    KConfig configDefault(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/kdedefaults/kwinrc", KConfig::SimpleConfig);
-    KConfigGroup cgd(&configDefault, "TabBox");
-    QCOMPARE(cgd.readEntry("DesktopLayout", QString()), QStringLiteral("customTestValue"));
-    QCOMPARE(cgd.readEntry("DesktopListLayout", QString()), QStringLiteral("customTestValue"));
-}
-
 void KcmTest::testKCMSave()
 {
+    // TODO: Previous bussiness code was effectively filtering every item from
+    // getting save, so the values would remain those set in the previous tests.
+    // This is the simpler fix to emulate the old behavior.
+    // Ideally we would test for the real items in the default theme or better,
+    // in a custom-made test package.
+    m_KCMLookandFeel->setSelectedContents(LookAndFeelManager::Empty);
+
     m_KCMLookandFeel->save();
 
     // On real setup we read entries from kdedefaults directory (XDG_CONFIG_DIRS is modified but not in test scenario)
@@ -272,11 +269,7 @@ void KcmTest::testKCMSave()
     cg = KConfigGroup(&kwinConfig, "TabBox");
     cgd = KConfigGroup(&kwinConfigDefault, "TabBox");
     QCOMPARE(cg.readEntry("LayoutName", QString()), QString());
-    QCOMPARE(cg.readEntry("DesktopLayout", QString()), QString());
-    QCOMPARE(cg.readEntry("DesktopListLayout", QString()), QString());
     QCOMPARE(cgd.readEntry("LayoutName", QString()), QStringLiteral("customTestValue"));
-    QCOMPARE(cgd.readEntry("DesktopLayout", QString()), QStringLiteral("customTestValue"));
-    QCOMPARE(cgd.readEntry("DesktopListLayout", QString()), QStringLiteral("customTestValue"));
 }
 
 QTEST_MAIN(KcmTest)
