@@ -4,6 +4,7 @@
     SPDX-FileCopyrightText: 2019 Cyril Rossi <cyril.rossi@enioka.com>
     SPDX-FileCopyrightText: 2021 Benjamin Port <benjamin.port@enioka.com>
     SPDX-FileCopyrightText: 2022 Dominic Hayes <ferenosdev@outlook.com>
+    SPDX-FileCopyrightText: 2023 Ismael Asensio <isma.af@gmail.com>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -15,20 +16,52 @@
 #include "lookandfeeldata.h"
 #include "lookandfeelsettings.h"
 #include <KIO/CommandLauncherJob>
+#include <KPackage/PackageLoader>
 #include <KSharedConfig>
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <QGuiApplication>
+#include <QStyle>
+#include <QStyleFactory>
 
 #ifdef HAVE_XCURSOR
 #include "../cursortheme/xcursor/xcursortheme.h"
 #include <X11/Xcursor/Xcursor.h>
 #endif
 
+namespace
+{
+// Helper methods to read or check entries from a nested group within a config
+
+QString configValue(KSharedConfigPtr config, const QString &groupPath, const QString &entry)
+{
+    // Navigate through the group hierarchy
+    QStringList groups = groupPath.split(QLatin1Char('/'));
+    KConfigGroup cg(config, groups.takeAt(0));
+    for (const QString &group : groups) {
+        cg = KConfigGroup(&cg, group);
+    }
+
+    return cg.readEntry(entry, QString());
+}
+
+bool configProvides(KSharedConfigPtr config, const QString &groupPath, const QStringList &entries)
+{
+    return std::any_of(entries.cbegin(), entries.cend(), [config, groupPath](const QString &entry) {
+        return !configValue(config, groupPath, entry).isEmpty();
+    });
+}
+
+bool configProvides(KSharedConfigPtr config, const QString &groupPath, const QString &entry)
+{
+    return !configValue(config, groupPath, entry).isEmpty();
+}
+
+} // Anonymouse namespace
+
 LookAndFeelManager::LookAndFeelManager(QObject *parent)
     : QObject(parent)
     , m_data(new LookAndFeelData(this))
-    , m_appearanceToApply(LookAndFeelManager::AppearanceToApply(LookAndFeelManager::AppearanceSettings))
-    , m_layoutToApply(LookAndFeelManager::LayoutToApply(LookAndFeelManager::LayoutSettings))
     , m_plasmashellChanged(false)
     , m_fontsChanged(false)
 {
@@ -40,32 +73,51 @@ LookAndFeelSettings *LookAndFeelManager::settings() const
     return m_data->settings();
 }
 
-void LookAndFeelManager::setAppearanceToApply(AppearanceToApply items)
+LookAndFeelManager::Contents LookAndFeelManager::packageContents(const KPackage::Package &pkg) const
 {
-    if (m_appearanceToApply == items) {
-        return;
+    Contents contents = Empty;
+
+    contents.setFlag(SplashScreen, !pkg.filePath("splashmainscript").isEmpty());
+    contents.setFlag(LockScreen, !pkg.filePath("lockscreenmainscript").isEmpty());
+
+    contents.setFlag(DesktopLayout, !pkg.filePath("layouts").isEmpty());
+
+    // TODO: Those seem unused... are deprecated?
+    contents.setFlag(RunCommand, !pkg.filePath("runcommandmainscript").isEmpty());
+    contents.setFlag(LogOutScript, !pkg.filePath("logoutmainscript").isEmpty());
+
+    if (!pkg.filePath("layoutdefaults").isEmpty()) {
+        KSharedConfigPtr conf = KSharedConfig::openConfig(pkg.filePath("layoutdefaults"));
+        contents.setFlag(TitlebarLayout, configProvides(conf, "kwinrc/org.kde.kdecoration2", {"ButtonsOnLeft", "ButtonsOnRight"}));
     }
-    m_appearanceToApply = items;
-    Q_EMIT appearanceToApplyChanged();
-}
 
-LookAndFeelManager::AppearanceToApply LookAndFeelManager::appearanceToApply() const
-{
-    return m_appearanceToApply;
-}
+    if (!pkg.filePath("defaults").isEmpty()) {
+        KSharedConfigPtr conf = KSharedConfig::openConfig(pkg.filePath("defaults"));
 
-void LookAndFeelManager::setLayoutToApply(LayoutToApply items)
-{
-    if (m_layoutToApply == items) {
-        return;
+        contents.setFlag(Colors, configProvides(conf, "kdeglobals/General", "ColorScheme") || !pkg.filePath("colors").isEmpty());
+        contents.setFlag(WidgetStyle, configProvides(conf, "kdeglobals/KDE", "widgetStyle"));
+        contents.setFlag(Icons, configProvides(conf, "kdeglobals/Icons", "Theme"));
+
+        contents.setFlag(PlasmaTheme, configProvides(conf, "plasmarc/Theme", "name"));
+        contents.setFlag(Wallpaper, configProvides(conf, "Wallpaper", "Image"));
+        contents.setFlag(Cursors, configProvides(conf, "kcminputrc/Mouse", "cursorTheme"));
+
+        contents.setFlag(WindowSwitcher, configProvides(conf, "kwinrc/WindowSwitcher", "LayoutName"));
+        contents.setFlag(WindowDecoration, configProvides(conf, "kwinrc/org.kde.kdecoration2", {"library", "NoPlugin"}));
+        contents.setFlag(BorderSize, configProvides(conf, "kwinrc/org.kde.kdecoration2", "BorderSize"));
+
+        contents.setFlag(Fonts,
+                         configProvides(conf, "kdeglobals/WM", {"font", "fixed", "smallestReadableFont", "toolBarFont", "menuFont"})
+                             || configProvides(conf, "kdeglobals/General", "activeFont"));
+
+        contents.setFlag(WindowPlacement, configProvides(conf, "kwinrc/Windows", "Placement"));
+        contents.setFlag(ShellPackage, configProvides(conf, "plasmashellrc/Shell", "ShellPackage"));
+
+        // TODO: Currently managed together within the "DesktopLayout" content
+        // contents.setFlag(Autostart, configProvides(conf, "Autostart", "Services"));
     }
-    m_layoutToApply = items;
-    Q_EMIT layoutToApplyChanged();
-}
 
-LookAndFeelManager::LayoutToApply LookAndFeelManager::layoutToApply() const
-{
-    return m_layoutToApply;
+    return contents;
 }
 
 void LookAndFeelManager::setSplashScreen(const QString &theme)
@@ -102,21 +154,6 @@ void LookAndFeelManager::setWindowSwitcher(const QString &theme)
     writeNewDefaults(QStringLiteral("kwinrc"), QStringLiteral("TabBox"), QStringLiteral("LayoutName"), theme);
 }
 
-void LookAndFeelManager::setDesktopSwitcher(const QString &theme)
-{
-    if (theme.isEmpty()) {
-        return;
-    }
-
-    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kwinrc"));
-    KConfigGroup group(config, QStringLiteral("TabBox"));
-
-    KConfig configDefault(configDefaults(QStringLiteral("kwinrc")));
-    KConfigGroup defaultGroup(&configDefault, QStringLiteral("TabBox"));
-    writeNewDefaults(group, defaultGroup, QStringLiteral("DesktopLayout"), theme);
-    writeNewDefaults(group, defaultGroup, QStringLiteral("DesktopListLayout"), theme);
-}
-
 void LookAndFeelManager::setWindowPlacement(const QString &value)
 {
     if (value.isEmpty()) {
@@ -162,6 +199,15 @@ void LookAndFeelManager::setTitlebarLayout(const QString &leftbtns, const QStrin
     writeNewDefaults(QStringLiteral("kwinrc"), QStringLiteral("org.kde.kdecoration2"), QStringLiteral("ButtonsOnRight"), rightbtns, KConfig::Notify);
 }
 
+void LookAndFeelManager::setBorderSize(const QString &size)
+{
+    if (size.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kwinrc"), QStringLiteral("org.kde.kdecoration2"), QStringLiteral("BorderSize"), size, KConfig::Notify);
+}
+
 void LookAndFeelManager::setBorderlessMaximized(const QString &value)
 {
     if (value.isEmpty()) { // Turn borderless off for unsupported LNFs to prevent issues
@@ -178,6 +224,15 @@ void LookAndFeelManager::setWidgetStyle(const QString &style)
         return;
     }
 
+    if (qobject_cast<QGuiApplication *>(QCoreApplication::instance())) {
+        // Some global themes use styles that may not be installed.
+        // Test if style can be installed before updating the config.
+        std::unique_ptr<QStyle> testStyle(QStyleFactory::create(style));
+        if (!testStyle) {
+            return;
+        }
+    }
+
     writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("KDE"), QStringLiteral("widgetStyle"), style, KConfig::Notify);
     Q_EMIT styleChanged(style);
 }
@@ -378,9 +433,12 @@ QString LookAndFeelManager::colorSchemeFile(const QString &schemeName) const
     return QString();
 }
 
-void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::Package &previousPackage)
+void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::Package &previousPackage, Contents applyMask)
 {
-    if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopLayout) && m_mode == Mode::Apply) {
+    // The items to apply are the package contents filtered with the user selection mask
+    const Contents itemsToApply = packageContents(package) & applyMask;
+
+    if (itemsToApply.testFlag(DesktopLayout) && m_mode == Mode::Apply) {
         QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
                                                               QStringLiteral("/PlasmaShell"),
                                                               QStringLiteral("org.kde.PlasmaShell"),
@@ -401,11 +459,11 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
     if (!package.filePath("layoutdefaults").isEmpty()) {
         KSharedConfigPtr conf = KSharedConfig::openConfig(package.filePath("layoutdefaults"));
         KConfigGroup group(conf, "kwinrc");
-        if (m_layoutToApply.testFlag(LookAndFeelManager::TitlebarLayout)) {
+        if (itemsToApply.testFlag(TitlebarLayout)) {
             group = KConfigGroup(&group, "org.kde.kdecoration2");
             setTitlebarLayout(group.readEntry("ButtonsOnLeft", QString()), group.readEntry("ButtonsOnRight", QString()));
         }
-        if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopLayout) && m_mode == Mode::Apply) {
+        if (itemsToApply.testFlag(DesktopLayout) && m_mode == Mode::Apply) {
             group = KConfigGroup(conf, "kwinrc");
             group = KConfigGroup(&group, "Windows");
             setBorderlessMaximized(group.readEntry("BorderlessMaximizedWindows", QString()));
@@ -415,7 +473,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
         KSharedConfigPtr conf = KSharedConfig::openConfig(package.filePath("defaults"));
         KConfigGroup group(conf, "kdeglobals");
         group = KConfigGroup(&group, "KDE");
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::WidgetStyle)) {
+        if (itemsToApply.testFlag(WidgetStyle)) {
             QString widgetStyle = group.readEntry("widgetStyle", QString());
             // Some global themes refer to breeze's widgetStyle with a lowercase b.
             if (widgetStyle == QStringLiteral("breeze")) {
@@ -425,7 +483,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
             setWidgetStyle(widgetStyle);
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::Colors)) {
+        if (itemsToApply.testFlag(Colors)) {
             QString colorsFile = package.filePath("colors");
             KConfigGroup group(conf, "kdeglobals");
             group = KConfigGroup(&group, "General");
@@ -445,49 +503,43 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
             }
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::Icons)) {
+        if (itemsToApply.testFlag(Icons)) {
             group = KConfigGroup(conf, "kdeglobals");
             group = KConfigGroup(&group, "Icons");
             setIcons(group.readEntry("Theme", QString()));
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::PlasmaTheme)) {
+        if (itemsToApply.testFlag(PlasmaTheme)) {
             group = KConfigGroup(conf, "plasmarc");
             group = KConfigGroup(&group, "Theme");
             setPlasmaTheme(group.readEntry("name", QString()));
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::Cursors)) {
+        if (itemsToApply.testFlag(Cursors)) {
             group = KConfigGroup(conf, "kcminputrc");
             group = KConfigGroup(&group, "Mouse");
             setCursorTheme(group.readEntry("cursorTheme", QString()));
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::WindowSwitcher)) {
+        if (itemsToApply.testFlag(WindowSwitcher)) {
             group = KConfigGroup(conf, "kwinrc");
             group = KConfigGroup(&group, "WindowSwitcher");
             setWindowSwitcher(group.readEntry("LayoutName", QString()));
         }
 
-        if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopSwitcher)) {
-            group = KConfigGroup(conf, "kwinrc");
-            group = KConfigGroup(&group, "DesktopSwitcher");
-            setDesktopSwitcher(group.readEntry("LayoutName", QString()));
-        }
-
-        if (m_layoutToApply.testFlag(LookAndFeelManager::WindowPlacement)) {
+        if (itemsToApply.testFlag(WindowPlacement)) {
             group = KConfigGroup(conf, "kwinrc");
             group = KConfigGroup(&group, "Windows");
             setWindowPlacement(group.readEntry("Placement", QStringLiteral("Centered")));
         }
 
-        if (m_layoutToApply.testFlag(LookAndFeelManager::ShellPackage)) {
+        if (itemsToApply.testFlag(ShellPackage)) {
             group = KConfigGroup(conf, "plasmashellrc");
             group = KConfigGroup(&group, "Shell");
             setShellPackage(group.readEntry("ShellPackage", QString()));
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::WindowDecoration)) {
+        if (itemsToApply.testFlag(WindowDecoration)) {
             group = KConfigGroup(conf, "kwinrc");
             group = KConfigGroup(&group, "org.kde.kdecoration2");
 
@@ -502,7 +554,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
 #endif
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::Fonts)) {
+        if (itemsToApply.testFlag(Fonts)) {
             group = KConfigGroup(conf, "kdeglobals");
             group = KConfigGroup(&group, "General");
             setGeneralFont(group.readEntry("font", QString()));
@@ -519,7 +571,13 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
             }
         }
 
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::SplashScreen)) {
+        if (itemsToApply.testFlag(BorderSize)) {
+            group = KConfigGroup(conf, "kwinrc");
+            group = KConfigGroup(&group, "org.kde.kdecoration2");
+            setBorderSize(group.readEntry("BorderSize", QString()));
+        }
+
+        if (itemsToApply.testFlag(SplashScreen)) {
             group = KConfigGroup(conf, "ksplashrc");
             group = KConfigGroup(&group, "KSplash");
             QString splashScreen = (group.readEntry("Theme", QString()));
@@ -529,7 +587,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
                 setSplashScreen(m_data->settings()->lookAndFeelPackage());
             }
         }
-        if (m_appearanceToApply.testFlag(LookAndFeelManager::LockScreen)) {
+        if (itemsToApply.testFlag(LockScreen)) {
             setLockScreen(m_data->settings()->lookAndFeelPackage());
         }
 
@@ -548,7 +606,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
         }
 
         // autostart
-        if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopLayout)) {
+        if (itemsToApply.testFlag(DesktopLayout)) {
             QStringList toStop;
             KService::List toStart;
             // remove all the old package to autostart
@@ -562,7 +620,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
                         KService service(serviceFile + QStringLiteral(".desktop"));
                         PlasmaAutostart as(serviceFile);
                         as.setAutostarts(false);
-                        QString serviceName = service.property(QStringLiteral("X-DBUS-ServiceName")).toString();
+                        QString serviceName = service.property<QString>(QStringLiteral("X-DBUS-ServiceName"));
                         toStop.append(serviceName);
                     }
                 }
@@ -577,7 +635,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
                     PlasmaAutostart as(serviceFile);
                     as.setCommand(service->exec());
                     as.setAutostarts(true);
-                    const QString serviceName = service->property(QStringLiteral("X-DBUS-ServiceName")).toString();
+                    const QString serviceName = service->property<QString>(QStringLiteral("X-DBUS-ServiceName"));
                     toStop.removeAll(serviceName);
                     if (qEnvironmentVariableIsSet("KDE_FULL_SESSION")) {
                         toStart += service;
@@ -588,14 +646,97 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
         }
     }
     // Reload KWin if something changed, but only once.
-    if (m_appearanceToApply.testFlag(LookAndFeelManager::WindowSwitcher) || m_layoutToApply.testFlag(LookAndFeelManager::DesktopSwitcher)
-        || m_appearanceToApply.testFlag(LookAndFeelManager::WindowDecoration) || m_layoutToApply.testFlag(LookAndFeelManager::WindowPlacement)
-        || m_layoutToApply.testFlag(LookAndFeelManager::WindowPlacement) || m_layoutToApply.testFlag(LookAndFeelManager::TitlebarLayout)) {
+    if (itemsToApply & KWinSettings) {
         QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KWin"), QStringLiteral("org.kde.KWin"), QStringLiteral("reloadConfig"));
         QDBusConnection::sessionBus().send(message);
     }
 }
 
+bool LookAndFeelManager::remove(const KPackage::Package &package, LookAndFeelManager::Contents contentsMask)
+{
+    QDir packageRootDir(package.path());
+    if (!packageRootDir.isReadable()) {
+        // Permission denied
+        return false;
+    }
+
+    const Contents itemsToRemove = packageContents(package) & contentsMask;
+
+    // Remove package dependencies
+    auto config = KSharedConfig::openConfig(package.filePath("defaults"), KConfig::NoGlobals);
+
+    // WidgetStyle
+    if (itemsToRemove.testFlag(WidgetStyle)) {
+        const QString widgetStyle = configValue(config, "kdeglobals/KDE", "widgetStyle");
+
+        const QDir widgetStyleDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + QStringLiteral("kstyle")
+                                  + QDir::separator() + QStringLiteral("themes"));
+        if (widgetStyleDir.exists()) {
+            // Read config to get style name
+            const QStringList styleFileList = widgetStyleDir.entryList({QStringLiteral("*.themerc")}, QDir::Files | QDir::NoDotAndDotDot);
+            for (const QString &path : styleFileList) {
+                auto widgetStyleConfig = KSharedConfig::openConfig(widgetStyleDir.absoluteFilePath(path), KConfig::SimpleConfig);
+                KConfigGroup widgetStyleKDEGroup(widgetStyleConfig, "KDE");
+                if (widgetStyleKDEGroup.exists() && widgetStyleKDEGroup.hasKey("WidgetStyle")) {
+                    if (widgetStyleKDEGroup.readEntry("WidgetStyle", "") == widgetStyle) {
+                        QFile(widgetStyleDir.absoluteFilePath(path)).remove();
+                        break;
+                    }
+                }
+            }
+        }
+    }
+
+    // Color scheme
+    if (itemsToRemove.testFlag(Colors)) {
+        const QString colorScheme = configValue(config, "kdeglobals/General", "ColorScheme");
+        QFile schemeFile(colorSchemeFile(colorScheme));
+        if (schemeFile.exists()) {
+            schemeFile.remove();
+        }
+    }
+
+    // Desktop Theme and Icon (Icons are in the theme folder). Only remove if both selected
+    // TODO: Remove separately
+    if (itemsToRemove.testFlag(PlasmaTheme) && itemsToRemove.testFlag(Icons)) {
+        const QString themeName = configValue(config, "plasmarc/Theme", "name");
+        QDir themeDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + QStringLiteral("plasma") + QDir::separator()
+                      + QStringLiteral("desktoptheme") + QDir::separator() + themeName);
+        if (themeDir.exists()) {
+            themeDir.removeRecursively();
+        }
+    }
+
+    // Wallpaper
+    if (itemsToRemove.testFlag(Wallpaper)) {
+        const QString image = configValue(config, "Wallpaper", "Image");
+        const QDir wallpaperDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + QStringLiteral("wallpapers"));
+        if (wallpaperDir.exists()) {
+            QFileInfo wallpaperFile(wallpaperDir.absoluteFilePath(image));
+            if (wallpaperFile.isFile()) {
+                // Single file, use QFile to remove
+                QFile(wallpaperFile.absoluteFilePath()).remove();
+            } else if (wallpaperFile.isDir()) {
+                // A package, use QDir to remove the folder
+                QDir(wallpaperFile.absoluteFilePath()).removeRecursively();
+            }
+        }
+    }
+
+    if (itemsToRemove.testFlag(WindowSwitcher)) {
+        const QString layoutName = configValue(config, "kwinrc/WindowSwitcher", "LayoutName");
+        const auto windowSwitcherPackages =
+            KPackage::PackageLoader::self()->findPackages(QStringLiteral("KWin/WindowSwitcher"), QString(), [&layoutName](const KPluginMetaData &meta) {
+                return meta.pluginId() == layoutName;
+            });
+        for (const auto &meta : windowSwitcherPackages) {
+            QFileInfo(meta.fileName()).absoluteDir().removeRecursively();
+        }
+    }
+
+    return packageRootDir.removeRecursively();
+}
+
 void LookAndFeelManager::setCursorTheme(const QString themeName)
 {
     // TODO: use pieces of cursor kcm when moved to plasma-desktop
@@ -607,7 +748,7 @@ void LookAndFeelManager::setCursorTheme(const QString themeName)
     Q_EMIT cursorsChanged(themeName);
 }
 
-void LookAndFeelManager::setMode(LookAndFeelManager::Mode mode)
+void LookAndFeelManager::setMode(Mode mode)
 {
     m_mode = mode;
 }
