@@ -6,10 +6,10 @@
 
 #include "kcm.h"
 
-#include <QIcon>
-#include <QStandardPaths>
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <QIcon>
+#include <QStandardPaths>
 
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -20,15 +20,13 @@ namespace ColorCorrect
 {
 K_PLUGIN_FACTORY_WITH_JSON(KCMNightColorFactory, "kcm_nightcolor.json", registerPlugin<KCMNightColor>(); registerPlugin<NightColorData>();)
 
-KCMNightColor::KCMNightColor(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, data, args)
+KCMNightColor::KCMNightColor(QObject *parent, const KPluginMetaData &data)
+    : KQuickManagedConfigModule(parent, data)
     , m_data(new NightColorData(this))
 {
     qmlRegisterAnonymousType<NightColorSettings>("org.kde.private.kcms.nightcolor", 1);
     qmlRegisterUncreatableMetaObject(ColorCorrect::staticMetaObject, "org.kde.private.kcms.nightcolor", 1, 0, "NightColorMode", "Error: only enums");
 
-    worldMapFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/nightcolor/worldmap.png"), QStandardPaths::LocateFile);
-
     minDayTemp = nightColorSettings()->findItem("DayTemperature")->minValue().toInt();
     maxDayTemp = nightColorSettings()->findItem("DayTemperature")->maxValue().toInt();
     minNightTemp = nightColorSettings()->findItem("NightTemperature")->minValue().toInt();
@@ -51,16 +49,16 @@ bool KCMNightColor::isIconThemeBreeze()
 
 void KCMNightColor::save()
 {
-    KQuickAddons::ManagedConfigModule::save();
+    KQuickManagedConfigModule::save();
 
     // load/unload colorcorrectlocationupdater based on whether user set it to automatic location
     QDBusConnection dbus = QDBusConnection::sessionBus();
 
     bool enableUpdater = (nightColorSettings()->mode() == NightColorMode::Automatic);
 
-    QDBusMessage loadMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+    QDBusMessage loadMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded6"),
                                                           QStringLiteral("/kded"),
-                                                          QStringLiteral("org.kde.kded5"),
+                                                          QStringLiteral("org.kde.kded6"),
                                                           (enableUpdater ? QStringLiteral("loadModule") : QStringLiteral("unloadModule")));
     loadMsg.setArguments({QVariant(QStringLiteral("colorcorrectlocationupdater"))});
     dbus.call(loadMsg, QDBus::NoBlock);
