@@ -3,6 +3,7 @@
     SPDX-FileCopyrightText: 2007 Jeremy Whiting <jpwhiting@kde.org>
     SPDX-FileCopyrightText: 2016 Olivier Churlaud <olivier@churlaud.com>
     SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2023 Ismael Asensio <isma.af@gmail.com>
 
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -25,6 +26,7 @@
 #include <algorithm>
 
 static const QString s_plasmaWorkspaceNotifyRcName = QStringLiteral("plasma_workspace");
+static const QRegularExpression s_eventGroupRegExp(QStringLiteral("^Event/([^/]*)$"));
 
 SourcesModel::SourcesModel(QObject *parent)
     : QAbstractItemModel(parent)
@@ -92,17 +94,41 @@ QVariant SourcesModel::data(const QModelIndex &index, int role) const
     }
 
     if (index.internalId()) { // event
-        const auto &event = m_data.at(index.internalId() - 1).events.at(index.row());
+        const auto &events = m_data.at(index.internalId() - 1).events;
+        const auto event = events.at(index.row());
 
         switch (role) {
         case Qt::DisplayRole:
-            return event.name;
+            return event->name();
         case Qt::DecorationRole:
-            return event.iconName;
-        case EventIdRole:
-            return event.eventId;
+            return event->iconName();
+        case CommentRole:
+            return event->comment();
         case ActionsRole:
-            return event.actions;
+            return event->action().split(QLatin1Char('|'), Qt::SkipEmptyParts);
+        case SoundRole:
+            return event->sound();
+        case DefaultActionsRole: {
+            // Weird KConfigSkeleton API to get the cascaded default values
+            event->useDefaults(true);
+            const QStringList defaultActions = event->action().split(QLatin1Char('|'), Qt::SkipEmptyParts);
+            event->useDefaults(false);
+            return defaultActions;
+        }
+        case DefaultSoundRole: {
+            // Weird KConfigSkeleton API to get the cascaded default values
+            event->useDefaults(true);
+            const QString defaultSound = event->sound();
+            event->useDefaults(false);
+            return defaultSound;
+        }
+        case IsDefaultRole:
+            return event->isDefaults();
+        case ShowIconsRole:
+            // We show the icons when at least one of the events specifies an icon name
+            return std::any_of(events.cbegin(), events.cend(), [](auto *event) {
+                return !event->iconName().isEmpty();
+            });
         }
 
         return QVariant();
@@ -122,7 +148,9 @@ QVariant SourcesModel::data(const QModelIndex &index, int role) const
     case DesktopEntryRole:
         return source.desktopEntry;
     case IsDefaultRole:
-        return source.isDefault;
+        return source.isDefault && std::all_of(source.events.cbegin(), source.events.cend(), [this](auto event) {
+                   return event->isDefaults();
+               });
     }
 
     return QVariant();
@@ -134,39 +162,61 @@ bool SourcesModel::setData(const QModelIndex &index, const QVariant &value, int
         return false;
     }
 
-    bool dirty = false;
+    if (!index.internalId()) { // source
+        auto &source = m_data[index.row()];
 
-    if (index.internalId()) { // event
-        auto &event = m_data[index.internalId() - 1].events[index.row()];
         switch (role) {
-        case ActionsRole: {
-            const QStringList newActions = value.toStringList();
-            if (event.actions != newActions) {
-                event.actions = newActions;
-                dirty = true;
+        case IsDefaultRole: {
+            if (source.isDefault != value.toBool()) {
+                source.isDefault = value.toBool();
+                Q_EMIT dataChanged(index, index, {role});
+                return true;
             }
             break;
         }
         }
+        return false;
     }
 
-    auto &source = m_data[index.row()];
+    NotificationManager::EventSettings *event = m_data[index.internalId() - 1].events[index.row()];
+
+    const bool wasDefault = event->isDefaults();
+    QList<int> changedRoles;
 
     switch (role) {
-    case IsDefaultRole: {
-        if (source.isDefault != value.toBool()) {
-            source.isDefault = value.toBool();
-            dirty = true;
+    case ActionsRole: {
+        const QString newAction = value.toStringList().join(QLatin1Char('|'));
+        if (event->action() != newAction) {
+            event->setAction(newAction);
+            changedRoles << role;
+        }
+        break;
+    }
+    case SoundRole: {
+        const QString newSound = value.toString();
+        if (event->sound() != newSound) {
+            event->setSound(newSound);
+            changedRoles << role;
         }
         break;
     }
     }
 
-    if (dirty) {
-        Q_EMIT dataChanged(index, index, {role});
+    if (event->isDefaults() != wasDefault) {
+        changedRoles << IsDefaultRole;
     }
 
-    return dirty;
+    if (changedRoles.isEmpty()) {
+        return false;
+    }
+
+    Q_EMIT dataChanged(index, index, changedRoles);
+    // Also notify the possible defaults change in the parent source index
+    if (changedRoles.contains(IsDefaultRole)) {
+        const QModelIndex sourceIndex = this->index(index.internalId() - 1, 0, QModelIndex());
+        Q_EMIT dataChanged(sourceIndex, sourceIndex, {IsDefaultRole});
+    }
+    return true;
 }
 
 QModelIndex SourcesModel::index(int row, int column, const QModelIndex &parent) const
@@ -202,14 +252,20 @@ QModelIndex SourcesModel::parent(const QModelIndex &child) const
 
 QHash<int, QByteArray> SourcesModel::roleNames() const
 {
-    return {{Qt::DisplayRole, QByteArrayLiteral("display")},
-            {Qt::DecorationRole, QByteArrayLiteral("decoration")},
-            {SourceTypeRole, QByteArrayLiteral("sourceType")},
-            {NotifyRcNameRole, QByteArrayLiteral("notifyRcName")},
-            {DesktopEntryRole, QByteArrayLiteral("desktopEntry")},
-            {IsDefaultRole, QByteArrayLiteral("isDefault")},
-            {EventIdRole, QByteArrayLiteral("eventId")},
-            {ActionsRole, QByteArrayLiteral("actions")}};
+    return {
+        {Qt::DisplayRole, QByteArrayLiteral("display")},
+        {Qt::DecorationRole, QByteArrayLiteral("decoration")},
+        {SourceTypeRole, QByteArrayLiteral("sourceType")},
+        {NotifyRcNameRole, QByteArrayLiteral("notifyRcName")},
+        {DesktopEntryRole, QByteArrayLiteral("desktopEntry")},
+        {IsDefaultRole, QByteArrayLiteral("isDefault")},
+        {CommentRole, QByteArrayLiteral("comment")},
+        {ShowIconsRole, QByteArrayLiteral("showIcons")},
+        {ActionsRole, QByteArrayLiteral("actions")},
+        {SoundRole, QByteArrayLiteral("sound")},
+        {DefaultActionsRole, QByteArrayLiteral("defaultActions")},
+        {DefaultSoundRole, QByteArrayLiteral("defaultSound")},
+    };
 }
 
 void SourcesModel::load()
@@ -220,31 +276,28 @@ void SourcesModel::load()
 
     QCollator collator;
 
-    QVector<SourceData> appsData;
-    QVector<SourceData> servicesData;
+    QList<SourceData> appsData;
+    QList<SourceData> servicesData;
 
     QStringList notifyRcFiles;
     QStringList desktopEntries;
 
-    // old code did KGlobal::dirs()->findAllResources("data", QStringLiteral("*/*.notifyrc")) but in KF5
-    // only notifyrc files in knotifications5/ folder are supported
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("knotifications5"), QStandardPaths::LocateDirectory);
+    // Search for notifyrc files in `/knotifications6` folders first, but also in `/knotifications5` for compatibility with KF5 applications
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("knotifications6"), QStandardPaths::LocateDirectory)
+        + QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("knotifications5"), QStandardPaths::LocateDirectory);
     for (const QString &dir : dirs) {
-        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.notifyrc"));
+        const QDir dirInfo(dir);
+        const QStringList fileNames = dirInfo.entryList(QStringList() << QStringLiteral("*.notifyrc"));
         for (const QString &file : fileNames) {
             if (notifyRcFiles.contains(file)) {
                 continue;
             }
-
             notifyRcFiles.append(file);
 
-            KConfig config(file, KConfig::NoGlobals);
-            config.addConfigSources(QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("knotifications5/") + file));
+            KSharedConfig::Ptr config = KSharedConfig::openConfig(file, KConfig::NoGlobals);
+            config->addConfigSources(QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("%2/%1").arg(file).arg(dirInfo.dirName())));
 
-            KConfigGroup globalGroup(&config, QLatin1String("Global"));
-
-            const QRegularExpression regExp(QStringLiteral("^Event/([^/]*)$"));
-            const QStringList groups = config.groupList().filter(regExp);
+            KConfigGroup globalGroup(config, QLatin1String("Global"));
 
             const QString notifyRcName = file.section(QLatin1Char('.'), 0, -2);
             const QString desktopEntry = globalGroup.readEntry(QStringLiteral("DesktopEntry"));
@@ -252,7 +305,6 @@ void SourcesModel::load()
                 if (desktopEntries.contains(desktopEntry)) {
                     continue;
                 }
-
                 desktopEntries.append(desktopEntry);
             }
 
@@ -261,36 +313,27 @@ void SourcesModel::load()
                 // any user settings and just used user-specific files for actions config
                 // I'm pretty sure there's a readEntry equivalent that does that without
                 // reading the config stuff twice, assuming we care about this to begin with
-                globalGroup.readEntry(QStringLiteral("Name")),
-                globalGroup.readEntry(QStringLiteral("Comment")),
-                globalGroup.readEntry(QStringLiteral("IconName")),
-                true,
-                notifyRcName,
-                desktopEntry,
-                {} // events
+                .name = globalGroup.readEntry(QStringLiteral("Name")),
+                .comment = globalGroup.readEntry(QStringLiteral("Comment")),
+                .iconName = globalGroup.readEntry(QStringLiteral("IconName")),
+                .isDefault = true,
+                .notifyRcName = notifyRcName,
+                .desktopEntry = desktopEntry,
+                .events = {},
             };
 
-            QVector<EventData> events;
+            // Add events
+            const QStringList groups = config->groupList().filter(s_eventGroupRegExp);
+
+            QList<NotificationManager::EventSettings *> events;
+            events.reserve(groups.size());
             for (const QString &group : groups) {
-                KConfigGroup cg(&config, group);
-
-                const QString eventId = regExp.match(group).captured(1);
-                // TODO context stuff
-                // TODO load defaults thing
-
-                EventData event{cg.readEntry("Name"),
-                                cg.readEntry("Comment"),
-                                cg.readEntry("IconName"),
-                                eventId,
-                                // TODO Flags?
-                                cg.readEntry("Action").split(QLatin1Char('|'))};
-                events.append(event);
+                const QString eventId = s_eventGroupRegExp.match(group).captured(1);
+                events.append(new NotificationManager::EventSettings(config, eventId, this));
             }
-
-            std::sort(events.begin(), events.end(), [&collator](const EventData &a, const EventData &b) {
-                return collator.compare(a.name, b.name) < 0;
+            std::sort(events.begin(), events.end(), [&collator](NotificationManager::EventSettings *a, NotificationManager::EventSettings *b) {
+                return collator.compare(a->name(), b->name()) < 0;
             });
-
             source.events = events;
 
             if (!source.desktopEntry.isEmpty()) {
@@ -310,7 +353,7 @@ void SourcesModel::load()
             return false;
         }
 
-        if (!app->property(QStringLiteral("X-GNOME-UsesNotifications")).toBool()) {
+        if (!app->property<bool>(QStringLiteral("X-GNOME-UsesNotifications"))) {
             return false;
         }
 
@@ -318,16 +361,7 @@ void SourcesModel::load()
     });
 
     for (const auto &service : services) {
-        SourceData source{
-            service->name(),
-            service->comment(),
-            service->icon(),
-            true,
-            QString(), // notifyRcFile
-            service->desktopEntryName(),
-            {} // events
-        };
-        appsData.append(source);
+        appsData.append(SourceData::fromService(service));
         desktopEntries.append(service->desktopEntryName());
     }
 
@@ -344,14 +378,7 @@ void SourcesModel::load()
             continue;
         }
 
-        SourceData source{service->name(),
-                          service->comment(),
-                          service->icon(),
-                          true,
-                          QString(), // notifyRcFile
-                          service->desktopEntryName(),
-                          {}};
-        appsData.append(source);
+        appsData.append(SourceData::fromService(service));
         desktopEntries.append(service->desktopEntryName());
     }
 
@@ -360,7 +387,15 @@ void SourcesModel::load()
     });
 
     // Fake entry for configuring non-identifyable applications
-    appsData << SourceData{i18n("Other Applications"), {}, QStringLiteral("applications-other"), true, QString(), QStringLiteral("@other"), {}};
+    appsData << SourceData{
+        .name = i18n("Other Applications"),
+        .comment = {},
+        .iconName = QStringLiteral("applications-other"),
+        .isDefault = true,
+        .notifyRcName = {},
+        .desktopEntry = QStringLiteral("@other"),
+        .events = {},
+    };
 
     // Sort and make sure plasma_workspace is at the beginning of the list
     std::sort(servicesData.begin(), servicesData.end(), [&collator](const SourceData &a, const SourceData &b) {
@@ -377,3 +412,75 @@ void SourcesModel::load()
 
     endResetModel();
 }
+
+void SourcesModel::loadEvents()
+{
+    beginResetModel();
+
+    for (const SourceData &source : std::as_const(m_data)) {
+        for (auto &event : source.events) {
+            event->load();
+        }
+    }
+
+    endResetModel();
+}
+
+void SourcesModel::saveEvents()
+{
+    for (const SourceData &source : std::as_const(m_data)) {
+        for (auto &event : source.events) {
+            event->save();
+        }
+    }
+}
+
+bool SourcesModel::isEventDefaults() const
+{
+    for (const SourceData &source : std::as_const(m_data)) {
+        for (const auto &event : source.events) {
+            if (!event->isDefaults()) {
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
+bool SourcesModel::isEventSaveNeeded() const
+{
+    for (const SourceData &source : std::as_const(m_data)) {
+        for (const auto &event : source.events) {
+            if (event->isSaveNeeded()) {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+void SourcesModel::setEventDefaults()
+{
+    beginResetModel();
+
+    for (const SourceData &source : std::as_const(m_data)) {
+        for (auto &event : source.events) {
+            event->setDefaults();
+        }
+    }
+
+    endResetModel();
+}
+
+SourceData SourceData::fromService(KService::Ptr service)
+{
+    return SourceData{
+        .name = service->name(),
+        .comment = service->comment(),
+        .iconName = service->icon(),
+        .isDefault = true,
+        .notifyRcName = {},
+        .desktopEntry = service->desktopEntryName(),
+        .events = {},
+    };
+}
