@@ -15,7 +15,10 @@
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusPendingCall>
+#include <QDir>
+#include <QQuickImageProvider>
 
+#include <KCountryFlagEmojiIconEngine>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KSharedConfig>
@@ -31,8 +34,30 @@ using namespace KCM_RegionAndLang;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMRegionAndLang, "kcm_regionandlang.json")
 
-KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, data, args)
+class FlagImageProvider : public QQuickImageProvider
+{
+public:
+    FlagImageProvider()
+        : QQuickImageProvider(QQuickImageProvider::Pixmap)
+    {
+    }
+
+    QPixmap requestPixmap(const QString &id, QSize *, const QSize &requestedSize) override
+    {
+        CacheContext cacheContext(id, requestedSize);
+        if (const auto it = m_pixmapCache.find(cacheContext); it != m_pixmapCache.end()) {
+            return it.value();
+        }
+        return m_pixmapCache[cacheContext] = QIcon(new KCountryFlagEmojiIconEngine(id)).pixmap(requestedSize);
+    }
+
+private:
+    using CacheContext = std::pair<QString, QSize>;
+    QHash<CacheContext, QPixmap> m_pixmapCache;
+};
+
+KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data)
+    : KQuickManagedConfigModule(parent, data)
     , m_settings(new RegionAndLangSettings(this))
     , m_optionsModel(new OptionsModel(this))
     , m_generator(LocaleGenerator::getGenerator())
@@ -51,8 +76,6 @@ KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data,
         connect(m_generator, &LocaleGeneratorBase::userHasToGenerateManually, this, &KCMRegionAndLang::takeEffectNextTime);
     }
 
-    setQuickHelp(i18n("You can configure the formats used for time, dates, money and other numbers here."));
-
     qmlRegisterAnonymousType<RegionAndLangSettings>("kcmregionandlang", 1);
     qmlRegisterAnonymousType<OptionsModel>("kcmregionandlang", 1);
     qmlRegisterAnonymousType<SelectedLanguageModel>("kcmregionandlang", 1);
@@ -61,7 +84,7 @@ KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data,
     qRegisterMetaType<KCM_RegionAndLang::SettingType>();
     qmlRegisterUncreatableMetaObject(KCM_RegionAndLang::staticMetaObject, "kcmregionandlang", 1, 0, "SettingType", "Error: SettingType is an enum");
 
-#if GLIBC_LOCALE_GENERATED
+#ifdef GLIBC_LOCALE_GENERATED
     // fedora pre generate locales, fetch available locales from localectl. /usr/share/i18n/locales is empty in fedora
     QDir glibcLocaleDir(localeFileDirPath());
     if (glibcLocaleDir.isEmpty()) {
@@ -90,7 +113,8 @@ KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data,
 QString KCMRegionAndLang::failedFindLocalesMessage()
 {
     return xi18nc("@info this will be shown as an error message",
-                 "Could not find the system's available locales using the <command>localectl</command> tool. Please file a bug report about this at <link>https://bugs.kde.org</link>");
+                  "Could not find the system's available locales using the <command>localectl</command> tool. Please file a bug report about this at "
+                  "<link>https://bugs.kde.org</link>");
 }
 
 QString KCMRegionAndLang::localeFileDirPath()
@@ -160,7 +184,7 @@ void KCMRegionAndLang::save()
 
 void KCMRegionAndLang::saveToConfigFile()
 {
-    KQuickAddons::ManagedConfigModule::save();
+    KQuickManagedConfigModule::save();
 }
 
 RegionAndLangSettings *KCMRegionAndLang::settings() const
@@ -217,17 +241,6 @@ void KCMRegionAndLang::reboot()
     QDBusConnection::sessionBus().asyncCall(method);
 }
 
-bool KCMRegionAndLang::isGlibc()
-{
-#ifdef OS_UBUNTU
-    return true;
-#elif defined(GLIBC_LOCALE)
-    return true;
-#else
-    return false;
-#endif
-}
-
 bool KCMRegionAndLang::enabled() const
 {
     return m_enabled;
@@ -350,5 +363,10 @@ std::unordered_map<QString, QString> KCMRegionAndLang::constructGlibcLocaleMap()
 }
 #endif
 
+void KCMRegionAndLang::load()
+{
+    engine()->addImageProvider("flags", new FlagImageProvider);
+}
+
 #include "kcmregionandlang.moc"
 #include "moc_kcmregionandlang.cpp"
