@@ -17,13 +17,14 @@
 #include "settingtype.h"
 
 #include <KConfigGroup>
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
+#include <QProcess>
 
 class RegionAndLangSettings;
 class OptionsModel;
 class LocaleGeneratorBase;
 
-class KCMRegionAndLang : public KQuickAddons::ManagedConfigModule
+class KCMRegionAndLang : public KQuickManagedConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(RegionAndLangSettings *settings READ settings CONSTANT)
@@ -31,19 +32,22 @@ class KCMRegionAndLang : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(bool enabled READ enabled NOTIFY enabledChanged)
 
 public:
-    explicit KCMRegionAndLang(QObject *parent, const KPluginMetaData &data, const QVariantList &list = QVariantList());
+    explicit KCMRegionAndLang(QObject *parent, const KPluginMetaData &data);
     void save() override;
 
     RegionAndLangSettings *settings() const;
 
     OptionsModel *optionsModel() const;
     bool enabled() const;
-    static bool isGlibc();
 #ifdef GLIBC_LOCALE
     std::optional<QString> toGlibcLocale(const QString &lang);
 #endif
     Q_INVOKABLE void unset(KCM_RegionAndLang::SettingType setting);
     Q_INVOKABLE void reboot();
+
+public Q_SLOTS:
+    void load() override;
+
 Q_SIGNALS:
     void saveClicked();
     void takeEffectNextTime();
@@ -65,8 +69,6 @@ private:
     static QString localeFileDirPath();
     static QString toUTF8Locale(const QString &locale);
 
-    QHash<QString, QString> m_cachedFlags;
-
     RegionAndLangSettings *m_settings;
     OptionsModel *m_optionsModel;
     LocaleGeneratorBase *m_generator = nullptr;
