@@ -62,8 +62,8 @@ Q_DECL_EXPORT void kcminit()
 }
 }
 
-KCMStyle::KCMStyle(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, data, args)
+KCMStyle::KCMStyle(QObject *parent, const KPluginMetaData &data)
+    : KQuickManagedConfigModule(parent, data)
     , m_data(new StyleData(this))
     , m_model(new StylesModel(this))
 {
@@ -222,7 +222,7 @@ bool KCMStyle::gtkConfigKdedModuleLoaded() const
 
 void KCMStyle::checkGtkConfigKdedModuleLoaded()
 {
-    org::kde::kded5 kdedInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QDBusConnection::sessionBus());
+    org::kde::kded6 kdedInterface(QStringLiteral("org.kde.kded6"), QStringLiteral("/kded"), QDBusConnection::sessionBus());
     auto call = kdedInterface.loadedModules();
     auto *watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
@@ -248,7 +248,7 @@ void KCMStyle::load()
 
     m_gtkPage->load();
 
-    ManagedConfigModule::load();
+    KQuickManagedConfigModule::load();
     m_model->load();
     m_previousStyle = styleSettings()->widgetStyle();
 
@@ -278,7 +278,7 @@ void KCMStyle::save()
         }
     }
 
-    ManagedConfigModule::save();
+    KQuickManagedConfigModule::save();
 
     // Export the changes we made to qtrc, and update all qt-only
     // applications on the fly, ensuring that we still follow the user's
@@ -318,7 +318,7 @@ void KCMStyle::defaults()
     // TODO the old code had a fallback chain but do we actually support not having Breeze for Plasma?
     // defaultStyle() -> oxygen -> plastique -> windows -> platinum -> motif
 
-    ManagedConfigModule::defaults();
+    KQuickManagedConfigModule::defaults();
 
     loadSettingsToModel();
 }
