@@ -4,6 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include <chrono>
+
+#include <KDirNotify>
 #include <KIO/FileUndoManager>
 #include <QDesktopServices>
 #include <QProcess>
@@ -15,7 +18,8 @@
 #include <kio/copyjob.h>
 #include <kio/job.h>
 
-#include "config-KDECI_BUILD.h"
+using namespace Qt::StringLiterals;
+using namespace std::chrono_literals;
 
 static void doUndo() // see FileUndoManagerTest::doUndo()
 {
@@ -37,10 +41,6 @@ public:
 private Q_SLOTS:
     void initTestCase()
     {
-#if KDECI_BUILD
-        QSKIP("Test is failing forever. Skip in Plasma/5.27 builds");
-#endif
-
         // make KIOs use test mode too
         setenv("KIOSLAVE_ENABLE_TESTMODE", "1", 1);
         QStandardPaths::setTestModeEnabled(true);
@@ -49,7 +49,11 @@ private Q_SLOTS:
         m_desktopPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
         m_testFileName = QLatin1String("kio_desktop_test_file");
         qWarning() << "We will write in the desktop folder" << m_desktopPath;
-        qWarning() << "Starting kded" << QProcess::startDetached(QStringLiteral("kded5"), {});
+        // NOTE: we must shut down kded if we started it in the CI! Do not detach!
+        m_kded.setProgram("kded6"_L1);
+        m_kded.start();
+        const auto started = m_kded.waitForStarted((1000ms).count());
+        qWarning() << "Starting kded" << started;
         cleanupTestCase();
     }
     void cleanupTestCase()
@@ -57,6 +61,7 @@ private Q_SLOTS:
         QFile::remove(m_desktopPath + '/' + m_testFileName);
         QFile::remove(m_desktopPath + '/' + m_testFileName + ".part");
         QFile::remove(m_desktopPath + '/' + m_testFileName + "_link");
+        m_kded.kill();
     }
 
     void testCopyToDesktop()
@@ -193,6 +198,7 @@ private Q_SLOTS:
 private:
     QString m_desktopPath;
     QString m_testFileName;
+    QProcess m_kded;
 };
 
 QTEST_GUILESS_MAIN(TestDesktop)
