@@ -87,7 +87,7 @@ History::~History()
 {
 }
 
-void History::insert(HistoryItemPtr item)
+void History::insert(const HistoryItemPtr &item)
 {
     if (!item)
         return;
@@ -95,7 +95,7 @@ void History::insert(HistoryItemPtr item)
     m_model->insert(item);
 }
 
-void History::clearAndBatchInsert(const QVector<HistoryItemPtr> &items)
+void History::clearAndBatchInsert(const QList<HistoryItemPtr> &items)
 {
     m_model->clearAndBatchInsert(items);
 }
