@@ -10,7 +10,6 @@
 
 #include "klipper.h"
 
-#include <unordered_set>
 #include <zlib.h>
 
 #include "klipper_debug.h"
@@ -50,15 +49,12 @@
 #include "klipperpopup.h"
 #include "klippersettings.h"
 
-#include <Prison/Prison>
+#include <Prison/Barcode>
 
 #include <config-X11.h>
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+
 #include <chrono>
 #include <xcb/xcb.h>
 
@@ -94,25 +90,6 @@ private:
 };
 }
 
-ClipboardContentTextEdit::ClipboardContentTextEdit(QWidget *parent)
-    : KTextEdit(parent)
-{
-}
-
-void ClipboardContentTextEdit::keyPressEvent(QKeyEvent *event)
-{
-    // Handle Ctrl+Enter to accept
-    const int key = event->key();
-    if (key == Qt::Key_Return || key == Qt::Key_Enter) {
-        if ((key == Qt::Key_Enter && (event->modifiers() == Qt::KeypadModifier)) || !event->modifiers()) {
-            Q_EMIT done();
-            event->accept();
-            return;
-        }
-    }
-    KTextEdit::keyPressEvent(event);
-}
-
 // config == KGlobal::config for process, otherwise applet
 Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mode)
     : QObject(parent)
@@ -130,7 +107,9 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
         setenv("KSNI_NO_DBUSMENU", "1", 1);
     }
     QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.klipper"));
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/klipper"), this, QDBusConnection::ExportScriptableSlots);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/klipper"),
+                                                 this,
+                                                 QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals);
 
     updateTimestamp(); // read initial X user time
     m_clip = KSystemClipboard::instance();
@@ -148,6 +127,7 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
     connect(m_history, &History::changed, this, &Klipper::slotHistoryChanged);
     connect(m_history, &History::changed, m_popup, &KlipperPopup::slotHistoryChanged);
     connect(m_history, &History::topIsUserSelectedSet, m_popup, &KlipperPopup::slotTopIsUserSelectedSet);
+    connect(m_history, &History::changed, this, &Klipper::clipboardHistoryUpdated);
 
     // we need that collection, otherwise KToggleAction is not happy :}
     m_collection = new KActionCollection(this);
@@ -179,11 +159,7 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
     m_saveFileTimer->setSingleShot(true);
     m_saveFileTimer->setInterval(5s);
     connect(m_saveFileTimer, &QTimer::timeout, this, [this] {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QtConcurrent::run(this, &Klipper::saveHistory, false);
-#else
         QtConcurrent::run(&Klipper::saveHistory, this, false);
-#endif
     });
     connect(m_history, &History::changed, this, [this] {
         if (m_bKeepContents) {
@@ -216,15 +192,6 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
     KGlobalAccel::setGlobalShortcut(m_repeatAction, QKeySequence(Qt::META | Qt::CTRL | Qt::Key_R));
     connect(m_repeatAction, &QAction::triggered, this, &Klipper::slotRepeatAction);
 
-    // add an edit-possibility
-    m_editAction = m_collection->addAction(QStringLiteral("edit_clipboard"));
-    m_editAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
-    m_editAction->setText(i18nc("@action:inmenu", "&Edit Contents…"));
-    KGlobalAccel::setGlobalShortcut(m_editAction, QKeySequence());
-    connect(m_editAction, &QAction::triggered, this, [this]() {
-        editData(m_history->first());
-    });
-
     // add barcode for mobile phones
     m_showBarcodeAction = m_collection->addAction(QStringLiteral("show-barcode"));
     m_showBarcodeAction->setText(i18nc("@action:inmenu", "&Show Barcode…"));
@@ -248,7 +215,7 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
 
     // Action to show items popup on mouse position
     m_showOnMousePos = m_collection->addAction(QStringLiteral("show-on-mouse-pos"));
-    m_showOnMousePos->setText(i18nc("@action:inmenu", "Show Items at Mouse Position"));
+    m_showOnMousePos->setText(i18nc("@action:inmenu", "Show Clipboard Items at Mouse Position"));
     m_showOnMousePos->setIcon(QIcon::fromTheme(QStringLiteral("view-list-text")));
     KGlobalAccel::setGlobalShortcut(m_showOnMousePos, QKeySequence(Qt::META | Qt::Key_V));
     connect(m_showOnMousePos, &QAction::triggered, this, &Klipper::slotPopupMenu);
@@ -264,7 +231,6 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config, KlipperMode mo
         m_actionsPopup->addAction(m_clearHistoryAction);
         m_actionsPopup->addAction(m_configureAction);
         m_actionsPopup->addAction(m_repeatAction);
-        m_actionsPopup->addAction(m_editAction);
         m_actionsPopup->addAction(m_showBarcodeAction);
 
         m_actionsPopup->addSeparator();
@@ -482,17 +448,9 @@ bool Klipper::loadHistory()
     history_stream >> version;
     delete[] version;
 
-    QVector<HistoryItemPtr> items;
-    std::unordered_set<QByteArray> uuidSet;
-    for (HistoryItemPtr item = HistoryItem::create(history_stream); !item.isNull(); item = HistoryItem::create(history_stream)) {
-        // BUG 466236 Due to a catastrophic bug existing in 5.27 beta and 5.27.0, there could be
-        // duplicate items in klipper's history file, so filter them out here.
-        if (uuidSet.count(item->uuid()) > 0) {
-            qCWarning(KLIPPER_LOG) << "One item in history has the same UUID with another item, ignored.";
-            continue;
-        }
+    QList<HistoryItemPtr> items;
+    for (HistoryItemPtr item = HistoryItem::create(history_stream); item; item = HistoryItem::create(history_stream)) {
         items.append(item);
-        uuidSet.insert(item->uuid());
     }
 
     history()->clearAndBatchInsert(items);
@@ -536,7 +494,7 @@ void Klipper::saveHistory(bool empty)
         HistoryItemConstPtr item = history()->first();
         if (item) {
             do {
-                history_stream << item.data();
+                history_stream << item.get();
                 item = HistoryItemConstPtr(history()->find(item->next_uuid()));
             } while (item != history()->first());
         }
@@ -631,7 +589,7 @@ void Klipper::slotPopupMenu()
 
 void Klipper::slotRepeatAction()
 {
-    auto top = qSharedPointerCast<const HistoryStringItem>(history()->first());
+    auto top = std::static_pointer_cast<const HistoryStringItem>(history()->first());
     if (top) {
         m_myURLGrabber->invokeAction(top);
     }
@@ -846,7 +804,7 @@ void Klipper::checkClipData(bool selectionMode)
     }
     QString &lastURLGrabberText = selectionMode ? m_lastURLGrabberTextSelection : m_lastURLGrabberTextClipboard;
     if (m_bURLGrabber && item && data->hasText()) {
-        m_myURLGrabber->checkNewData(qSharedPointerConstCast<const HistoryItem>(item));
+        m_myURLGrabber->checkNewData(std::const_pointer_cast<const HistoryItem>(item));
 
         // Make sure URLGrabber doesn't repeat all the time if klipper reads the same
         // text all the time (e.g. because XFixes is not available and the application
@@ -951,75 +909,30 @@ void Klipper::updateTimestamp()
 #endif
 }
 
-void Klipper::editData(const QSharedPointer<const HistoryItem> &item)
-{
-    QPointer<QDialog> dlg(new QDialog());
-    dlg->setWindowTitle(i18n("Edit Contents"));
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dlg);
-    connect(buttons, &QDialogButtonBox::accepted, dlg.data(), &QDialog::accept);
-    connect(buttons, &QDialogButtonBox::rejected, dlg.data(), &QDialog::reject);
-    connect(dlg.data(), &QDialog::finished, dlg.data(), [this, dlg, item](int result) {
-        Q_EMIT editFinished(item, result);
-        dlg->deleteLater();
-    });
-
-    ClipboardContentTextEdit *edit = new ClipboardContentTextEdit(dlg);
-    edit->setAcceptRichText(false);
-    if (item) {
-        edit->setPlainText(item->text());
-    }
-    edit->setFocus();
-    edit->setMinimumSize(300, 40);
-    QVBoxLayout *layout = new QVBoxLayout(dlg);
-    layout->addWidget(edit);
-    layout->addWidget(buttons);
-    dlg->adjustSize();
-
-    connect(edit, &ClipboardContentTextEdit::done, dlg.data(), &QDialog::accept);
-    connect(dlg.data(), &QDialog::accepted, this, [this, edit, item]() {
-        QString text = edit->toPlainText();
-        if (item) {
-            m_history->remove(item);
-        }
-        m_history->insert(HistoryItemPtr(new HistoryStringItem(text)));
-        if (m_myURLGrabber) {
-            m_myURLGrabber->checkNewData(HistoryItemConstPtr(m_history->first()));
-        }
-    });
-
-    if (m_mode == KlipperMode::Standalone) {
-        dlg->setModal(true);
-        dlg->exec();
-    } else if (m_mode == KlipperMode::DataEngine) {
-        dlg->open();
-    }
-}
-
 class BarcodeLabel : public QLabel
 {
 public:
-    BarcodeLabel(Prison::AbstractBarcode *barcode, QWidget *parent = nullptr)
+    BarcodeLabel(Prison::Barcode &&barcode, QWidget *parent = nullptr)
         : QLabel(parent)
-        , m_barcode(barcode)
+        , m_barcode(std::move(barcode))
     {
         setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-        setPixmap(QPixmap::fromImage(m_barcode->toImage(size())));
+        setPixmap(QPixmap::fromImage(m_barcode.toImage(size())));
     }
 
 protected:
     void resizeEvent(QResizeEvent *event) override
     {
         QLabel::resizeEvent(event);
-        setPixmap(QPixmap::fromImage(m_barcode->toImage(event->size())));
+        setPixmap(QPixmap::fromImage(m_barcode.toImage(event->size())));
     }
 
 private:
-    std::unique_ptr<Prison::AbstractBarcode> m_barcode;
+    Prison::Barcode m_barcode;
 };
 
-void Klipper::showBarcode(const QSharedPointer<const HistoryItem> &item)
+void Klipper::showBarcode(std::shared_ptr<const HistoryItem> item)
 {
-    using namespace Prison;
     QPointer<QDialog> dlg(new QDialog());
     dlg->setWindowTitle(i18n("Mobile Barcode"));
     QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok, dlg);
@@ -1031,22 +944,22 @@ void Klipper::showBarcode(const QSharedPointer<const HistoryItem> &item)
     QHBoxLayout *layout = new QHBoxLayout(mw);
 
     {
-        AbstractBarcode *qrCode = createBarcode(QRCode);
+        auto qrCode = Prison::Barcode::create(Prison::QRCode);
         if (qrCode) {
             if (item) {
                 qrCode->setData(item->text());
             }
-            BarcodeLabel *qrCodeLabel = new BarcodeLabel(qrCode, mw);
+            BarcodeLabel *qrCodeLabel = new BarcodeLabel(std::move(*qrCode), mw);
             layout->addWidget(qrCodeLabel);
         }
     }
     {
-        AbstractBarcode *dataMatrix = createBarcode(DataMatrix);
+        auto dataMatrix = Prison::Barcode::create(Prison::DataMatrix);
         if (dataMatrix) {
             if (item) {
                 dataMatrix->setData(item->text());
             }
-            BarcodeLabel *dataMatrixLabel = new BarcodeLabel(dataMatrix, mw);
+            BarcodeLabel *dataMatrixLabel = new BarcodeLabel(std::move(*dataMatrix), mw);
             layout->addWidget(dataMatrixLabel);
         }
     }
