@@ -44,15 +44,6 @@ enum class KlipperMode {
     DataEngine,
 };
 
-class ClipboardContentTextEdit : public KTextEdit
-{
-    Q_OBJECT
-public:
-    ClipboardContentTextEdit(QWidget *parent);
-    void keyPressEvent(QKeyEvent *event) override;
-    Q_SIGNAL void done();
-};
-
 class Klipper : public QObject
 {
     Q_OBJECT
@@ -100,8 +91,7 @@ public:
         return m_popup;
     }
 
-    void editData(const QSharedPointer<const HistoryItem> &item);
-    void showBarcode(const QSharedPointer<const HistoryItem> &item);
+    void showBarcode(std::shared_ptr<const HistoryItem> item);
 
 public Q_SLOTS:
     void saveSession();
@@ -146,7 +136,7 @@ protected:
     /**
      * Enter clipboard data in the history.
      */
-    QSharedPointer<HistoryItem> applyClipChanges(const QMimeData *data, bool selectionMode);
+    std::shared_ptr<HistoryItem> applyClipChanges(const QMimeData *data, bool selectionMode);
 
     void setClipboard(const HistoryItem &item, int mode, ClipboardUpdateReason updateReason = ClipboardUpdateReason::UpdateClipboard);
     bool ignoreClipboardChanges() const;
@@ -158,7 +148,8 @@ protected:
 
 Q_SIGNALS:
     void passivePopup(const QString &caption, const QString &text);
-    void editFinished(QSharedPointer<const HistoryItem> item, int result);
+    void editFinished(std::shared_ptr<const HistoryItem> item, int result);
+    Q_SCRIPTABLE void clipboardHistoryUpdated();
 
 public Q_SLOTS:
     void slotPopupMenu();
@@ -198,7 +189,6 @@ private:
     KToggleAction *m_toggleURLGrabAction;
     QAction *m_clearHistoryAction;
     QAction *m_repeatAction;
-    QAction *m_editAction;
     QAction *m_showBarcodeAction;
     QAction *m_configureAction;
     QAction *m_quitAction;
