@@ -21,7 +21,7 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("klipper");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("klipper"));
 
     KAboutData aboutData(QStringLiteral("klipper"),
                          i18n("Klipper"),
@@ -47,10 +47,6 @@ int main(int argc, char *argv[])
 
     KAboutData::setApplicationData(aboutData);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
-
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
     };
