@@ -20,10 +20,9 @@
 #include <KAboutData>
 #include <KAuthorized>
 #include <KDBusService>
+#include <KRunner/RunnerManager>
 
-#include <kdeclarative/qmlobject.h>
-
-#include <kworkspace.h>
+#include <iostream>
 
 #include "view.h"
 
@@ -34,22 +33,36 @@ int main(int argc, char **argv)
     QSurfaceFormat::setDefaultFormat(format);
 
     QCommandLineParser parser;
-    if (!qEnvironmentVariableIsSet("PLASMA_USE_QT_SCALING")) {
-        qunsetenv("QT_DEVICE_PIXEL_RATIO");
-        QCoreApplication::setAttribute(Qt::AA_DisableHighDpiScaling);
-    }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
+    bool usingPlasmaShellIntegration = false;
+    if (qEnvironmentVariableIsSet("WAYLAND_DISPLAY") || qEnvironmentVariableIsSet("WAYLAND_SOCKET")) {
+        qputenv("QT_WAYLAND_SHELL_INTEGRATION", "plasma-shell");
+        usingPlasmaShellIntegration = true;
+    }
+#endif
+
+    // this is needed to fake window position so Plasma Dialog sets correct borders
     qputenv("QT_WAYLAND_DISABLE_FIXED_POSITIONS", {});
-    const bool qpaVariable = qEnvironmentVariableIsSet("QT_QPA_PLATFORM");
-    KWorkSpace::detectPlatform(argc, argv);
+    // this variable controls whether to reconnect or exit if the compositor dies, given plasmashell does a lot of
+    // bespoke wayland code disable for now. Consider re-enabling when layer-shell support lands
+    qunsetenv("QT_WAYLAND_RECONNECT");
     QQuickWindow::setDefaultAlphaBuffer(true);
     QApplication app(argc, argv);
-    if (!qpaVariable) {
-        // don't leak the env variable to processes we start
-        qunsetenv("QT_QPA_PLATFORM");
-    }
     qunsetenv("QT_WAYLAND_DISABLE_FIXED_POSITIONS");
-    KLocalizedString::setApplicationDomain("krunner");
+    qputenv("QT_WAYLAND_RECONNECT", "1");
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
+    if (usingPlasmaShellIntegration) {
+        // Force qtwayland to load our plasma-shell integration plugin. qtwayland loads
+        // the shell integration plugin on demand, we need to create a window.
+        QWindow w;
+        w.create();
+        qunsetenv("QT_WAYLAND_SHELL_INTEGRATION");
+    }
+#endif
+
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("krunner"));
 
     //     TODO: Make it a QGuiApplication once we don't depend on KDELibs4Support
     //     QGuiApplication app(argc, argv);
@@ -58,14 +71,19 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(aboutData);
     app.setQuitOnLastWindowClosed(false);
+    app.setQuitLockEnabled(false);
 
     QCommandLineOption clipboardOption({QStringLiteral("c"), QStringLiteral("clipboard")}, i18n("Use the clipboard contents as query for KRunner"));
     QCommandLineOption daemonOption({QStringLiteral("d"), QStringLiteral("daemon")}, i18n("Start KRunner in the background, don't show it."));
     QCommandLineOption replaceOption({QStringLiteral("replace")}, i18n("Replace an existing instance"));
+    QCommandLineOption runnerId({QStringLiteral("runner")}, i18n("Show only results from the given plugin"), QStringLiteral("runner"));
+    QCommandLineOption listOption({QStringLiteral("list")}, i18n("List available plugins"));
 
     parser.addOption(clipboardOption);
     parser.addOption(daemonOption);
     parser.addOption(replaceOption);
+    parser.addOption(runnerId);
+    parser.addOption(listOption);
     parser.addPositionalArgument(QStringLiteral("query"), i18n("The query to run, only used if -c is not provided"));
 
     aboutData.setupCommandLine(&parser);
@@ -73,16 +91,24 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+    if (parser.isSet(listOption)) {
+        const auto runners = KRunner::RunnerManager::runnerMetaDataList();
+        const QString headline = i18nc("Header for command line output", "Available KRunner plugins, pluginId");
+        QString separator;
+        separator.fill(u'-', headline.length());
+        std::cout << qPrintable(headline) << std::endl << qPrintable(separator) << std::endl;
+        for (const auto &data : runners) {
+            std::cout << qPrintable(data.name()) << ": " << qPrintable(data.pluginId()) << std::endl;
+        }
+        return 0;
+    }
+
     if (!KAuthorized::authorize(QStringLiteral("run_command"))) {
         return -1;
     }
 
     KDBusService service(KDBusService::Unique | KDBusService::StartupOption(parser.isSet(replaceOption) ? KDBusService::Replace : 0));
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
-
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
     };
@@ -93,13 +119,20 @@ int main(int argc, char **argv)
 
     auto updateVisibility = [&]() {
         const QString query = parser.positionalArguments().value(0);
+        const bool hasSingleRunnerModeId = parser.isSet(runnerId);
 
         if (parser.isSet(daemonOption)) {
             view.setVisible(false);
         } else if (parser.isSet(clipboardOption)) {
             view.displayWithClipboardContents();
         } else if (!query.isEmpty()) {
-            view.query(query);
+            if (hasSingleRunnerModeId) {
+                view.querySingleRunner(parser.value(runnerId), query);
+            } else {
+                view.query(query);
+            }
+        } else if (hasSingleRunnerModeId) {
+            view.displaySingleRunner(parser.value(runnerId));
         } else {
             view.toggleDisplay();
         }
@@ -107,8 +140,7 @@ int main(int argc, char **argv)
 
     updateVisibility();
 
-    QObject::connect(&service, &KDBusService::activateRequested, &view, [&](const QStringList &arguments, const QString &workingDirectory) {
-        Q_UNUSED(workingDirectory)
+    QObject::connect(&service, &KDBusService::activateRequested, &view, [&](const QStringList &arguments) {
         parser.parse(arguments);
         updateVisibility();
     });
