@@ -15,11 +15,7 @@
 
 #include <QDebug>
 #include <QElapsedTimer>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 #include <config-workspace.h>
 
