@@ -84,7 +84,7 @@ bool KSMServer::closeSession()
 
     const QDBusMessage callerContext = message();
 
-    auto conn = QSharedPointer<QMetaObject::Connection>::create(QMetaObject::Connection());
+    auto conn = std::make_shared<QMetaObject::Connection>(QMetaObject::Connection());
     *conn = connect(this, &KSMServer::logoutFinished, this, [callerContext, conn](bool sessionClosed) {
         auto reply = callerContext.createReply(sessionClosed);
         QDBusConnection::sessionBus().send(reply);
@@ -125,7 +125,7 @@ void KSMServer::shutdown(KWorkSpace::ShutdownConfirm confirm, KWorkSpace::Shutdo
                                 : confirm == KWorkSpace::ShutdownConfirmNo ? true
                                                                            : !cg.readEntry("confirmLogout", true));
 
-    int shutdownType = (sdtype != KWorkSpace::ShutdownTypeDefault ? sdtype : cg.readEntry("shutdownType", (int)KWorkSpace::ShutdownType::ShutdownTypeLogout));
+    int shutdownType = (sdtype != KWorkSpace::ShutdownTypeDefault ? sdtype : cg.readEntry("shutdownType", (int)KWorkSpace::ShutdownType::ShutdownTypeHalt));
 
     if (!logoutConfirmed) {
         OrgKdeLogoutPromptInterface logoutPrompt(QStringLiteral("org.kde.LogoutPrompt"), QStringLiteral("/LogoutPrompt"), QDBusConnection::sessionBus());
@@ -337,7 +337,7 @@ void KSMServer::cancelShutdown(KSMClient *c)
         Q_EMIT subSessionCloseCanceled();
     } else {
         qCDebug(KSMSERVER) << "Client " << c->program() << " (" << c->clientId() << ") canceled shutdown.";
-        KNotification::event(QStringLiteral("cancellogout"), i18n("Logout canceled by '%1'", c->program()), QPixmap(), nullptr, KNotification::DefaultEvent);
+        KNotification::event(QStringLiteral("cancellogout"), i18n("Logout canceled by '%1'", c->program()), QPixmap(), KNotification::DefaultEvent);
         foreach (KSMClient *c, clients) {
             SmsShutdownCancelled(c->connection());
             if (c->saveYourselfDone) {
@@ -428,7 +428,7 @@ void KSMServer::completeShutdownOrCheckpoint()
 
     qCDebug(KSMSERVER) << "state is " << state;
     if (state == Shutdown) {
-        KNotification *n = KNotification::event(QStringLiteral("exitkde"), QString(), QPixmap(), nullptr, KNotification::DefaultEvent); // Plasma says good bye
+        KNotification *n = KNotification::event(QStringLiteral("exitkde"), QString(), QPixmap(), KNotification::DefaultEvent); // Plasma says good bye
         connect(n, &KNotification::closed, this, &KSMServer::startKilling);
         state = WaitingForKNotify;
         // https://bugs.kde.org/show_bug.cgi?id=228005
@@ -436,7 +436,7 @@ void KSMServer::completeShutdownOrCheckpoint()
         // backends are installed) the closed() signal never happens
         // and logoutSoundFinished() never gets called. Add this timer to make
         // sure the shutdown procedure continues even if sound system is broken.
-        QTimer::singleShot(5000, this, [=] {
+        QTimer::singleShot(5000, this, [=, this] {
             if (state == WaitingForKNotify) {
                 n->deleteLater();
                 startKilling();
@@ -507,7 +507,7 @@ void KSMServer::saveSubSession(const QString &name, QStringList saveAndClose, QS
     }
     qCDebug(KSMSERVER) << name << saveAndClose << saveOnly;
     state = ClosingSubSession;
-    saveType = SmSaveBoth; // both or local? what oes it mean?
+    saveType = SmSaveBoth; // both or local? what does it mean?
     saveSession = true;
     sessionGroup = QStringLiteral("SubSession: ") + name;
 
