@@ -21,23 +21,18 @@
 #include <KLocalizedString>
 #include <KRuntimePlatform>
 #include <KSharedConfig>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+
+#include <KSelectionOwner>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kdbusservice.h>
-#include <kmanagerselection.h>
 #include <ksmserver_debug.h>
 #include <kwindowsystem.h>
 
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QFile>
-#include <QQuickWindow>
-#include <X11/extensions/Xrender.h>
 
 static const char version[] = "0.4";
 
@@ -70,45 +65,6 @@ bool writeTest(QByteArray path)
     return true;
 }
 
-void checkComposite()
-{
-    if (qgetenv("KDE_SKIP_ARGB_VISUALS") == "1")
-        return;
-    // thanks to zack rusin and frederik for pointing me in the right direction
-    // for the following bits of X11 code
-    dpy = XOpenDisplay(nullptr); // open default display
-    if (!dpy) {
-        qCCritical(KSMSERVER) << "Cannot connect to the X server";
-        return;
-    }
-
-    int screen = DefaultScreen(dpy);
-    int eventBase, errorBase;
-
-    if (XRenderQueryExtension(dpy, &eventBase, &errorBase)) {
-        int nvi;
-        XVisualInfo templ;
-        templ.screen = screen;
-        templ.depth = 32;
-        templ.c_class = TrueColor;
-        XVisualInfo *xvi = XGetVisualInfo(dpy, VisualScreenMask | VisualDepthMask | VisualClassMask, &templ, &nvi);
-        for (int i = 0; i < nvi; ++i) {
-            XRenderPictFormat *format = XRenderFindVisualFormat(dpy, xvi[i].visual);
-            if (format->type == PictTypeDirect && format->direct.alphaMask) {
-                visual = xvi[i].visual;
-                colormap = XCreateColormap(dpy, RootWindow(dpy, screen), visual, AllocNone);
-
-                XFree(xvi);
-                return;
-            }
-        }
-
-        XFree(xvi);
-    }
-    XCloseDisplay(dpy);
-    dpy = nullptr;
-}
-
 void sanity_check(int argc, char *argv[])
 {
     QString msg;
@@ -121,7 +77,9 @@ void sanity_check(int argc, char *argv[])
         if (errno == ENOENT)
             msg = i18n("$HOME directory (%1) does not exist.", QFile::decodeName(path));
         else if (readOnly.isEmpty())
-            msg = i18n("No write access to $HOME directory (%1).", QFile::decodeName(path));
+            msg = xi18nc("@info",
+                         "No write access to $HOME directory (%1). If this is intentional, set <envar>KDE_HOME_READONLY=1</envar> in your environment.",
+                         QFile::decodeName(path));
     }
     if (msg.isEmpty() && access(path.data(), R_OK)) {
         if (errno == ENOENT)
@@ -207,16 +165,14 @@ int main(int argc, char *argv[])
 {
     sanity_check(argc, argv);
 
-    putenv((char *)"SESSION_MANAGER=");
-    checkComposite();
+    qunsetenv("SESSION_MANAGER");
 
     // force xcb QPA plugin as ksmserver is very X11 specific
     const QByteArray origQpaPlatform = qgetenv("QT_QPA_PLATFORM");
     qputenv("QT_QPA_PLATFORM", QByteArrayLiteral("xcb"));
 
-    QQuickWindow::setDefaultAlphaBuffer(true);
-    QCoreApplication::setAttribute(Qt::AA_DisableHighDpiScaling);
-    QApplication *a = new QApplication(argc, argv);
+    QCoreApplication::setQuitLockEnabled(false);
+    QGuiApplication *a = new QGuiApplication(argc, argv);
 
     // now the QPA platform is set, unset variable again to not launch apps with incorrect environment
     if (origQpaPlatform.isEmpty()) {
@@ -225,9 +181,9 @@ int main(int argc, char *argv[])
         qputenv("QT_QPA_PLATFORM", origQpaPlatform);
     }
 
-    QApplication::setApplicationName(QStringLiteral("ksmserver"));
-    QApplication::setApplicationVersion(QString::fromLatin1(version));
-    QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
+    QCoreApplication::setApplicationName(QStringLiteral("ksmserver"));
+    QCoreApplication::setApplicationVersion(QString::fromLatin1(version));
+    QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
     fcntl(ConnectionNumber(QX11Info::display()), F_SETFD, 1);
 
@@ -312,7 +268,7 @@ int main(int argc, char *argv[])
 
     server->setupShortcuts();
     int ret = a->exec();
-    kde_running.release(); // needs to be done before QApplication destruction
+    kde_running.release(); // needs to be done before QGuiApplication destruction
     delete a;
     return ret;
 }
