@@ -3,6 +3,7 @@
 
     SPDX-FileCopyrightText: 2000 Matthias Ettrich <ettrich@kde.org>
     SPDX-FileCopyrightText: 2005 Lubos Lunak <l.lunak@kde.org>
+    SPDX-FileCopyrightText: 2023 Harald Sitter <sitter@kde.org>
 
     SPDX-FileContributor: Oswald Buddenhagen <ob6@inf.tu-dresden.de>
 
@@ -26,6 +27,7 @@
 #include <config-workspace.h>
 #include <pwd.h>
 #include <sys/param.h>
+#include <sys/resource.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #ifdef HAVE_SYS_TIME_H
@@ -54,10 +56,10 @@
 #include <QFile>
 #include <QPushButton>
 #include <QRegularExpression>
-#include <QScopeGuard>
 #include <QSocketNotifier>
 #include <QStandardPaths>
 
+#include <KNotification>
 #include <KSharedConfig>
 #include <QTemporaryFile>
 #include <kactioncollection.h>
@@ -75,11 +77,8 @@
 
 #include <KScreenLocker/KsldApp>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+
 #include <krandom.h>
 #include <qstandardpaths.h>
 #include <startup_interface.h>
@@ -87,7 +86,7 @@
 #include "kscreenlocker_interface.h"
 #include "kwinsession_interface.h"
 
-#include <updatelaunchenvjob.h>
+#include <KUpdateLaunchEnvironmentJob>
 
 extern "C" {
 #include <X11/ICE/ICEmsg.h>
@@ -100,6 +99,30 @@ extern "C" {
 #undef static_assert
 #endif
 
+namespace
+{
+size_t fileNumberLimit()
+{
+    static auto limit = []() -> size_t {
+        struct rlimit limit {
+        };
+        if (getrlimit(RLIMIT_NOFILE, &limit) != 0) {
+            const auto err = errno;
+            qCWarning(KSMSERVER) << "Failed to getrlimit:" << strerror(err);
+            return std::numeric_limits<size_t>::max();
+        }
+        return limit.rlim_cur;
+    }();
+    return limit;
+}
+
+size_t perAppStartLimit()
+{
+    static auto limit = fileNumberLimit() / 4;
+    return limit;
+}
+} // namespace
+
 KSMServer *the_server = nullptr;
 
 KSMServer *KSMServer::self()
@@ -159,6 +182,15 @@ static QTemporaryFile *remTempFile = nullptr;
 
 static IceListenObj *listenObjs = nullptr;
 int numTransports = 0;
+static bool only_local = 0;
+
+static Bool HostBasedAuthProc(char * /*hostname*/)
+{
+    if (only_local)
+        return true;
+    else
+        return false;
+}
 
 Status KSMRegisterClientProc(SmsConn /* smsConn */, SmPointer managerData, char *previousId)
 {
@@ -271,9 +303,18 @@ public:
         : QSocketNotifier(IceConnectionNumber(conn), QSocketNotifier::Read)
         , iceConn(conn)
     {
+        count++;
     }
 
+    ~KSMConnection() override
+    {
+        count--;
+    }
+
+    Q_DISABLE_COPY_MOVE(KSMConnection)
+
     IceConn iceConn;
+    inline static size_t count = 0;
 };
 
 /* for printing hex digits */
@@ -288,34 +329,64 @@ static void fprintfhex(FILE *fp, unsigned int len, char *cp)
     }
 }
 
+/*
+ * We use temporary files which contain commands to add/remove entries from
+ * the .ICEauthority file.
+ */
+static void write_iceauth(FILE *addfp, FILE *removefp, IceAuthDataEntry *entry)
+{
+    fprintf(addfp, "add %s \"\" %s %s ", entry->protocol_name, entry->network_id, entry->auth_name);
+    fprintfhex(addfp, entry->auth_data_length, entry->auth_data);
+    fprintf(addfp, "\n");
+
+    fprintf(removefp, "remove protoname=%s protodata=\"\" netid=%s authname=%s\n", entry->protocol_name, entry->network_id, entry->auth_name);
+}
+
 #define MAGIC_COOKIE_LEN 16
 
+Status SetAuthentication_local(int count, IceListenObj *listenObjs)
+{
+    int i;
+    for (i = 0; i < count; i++) {
+        char *prot = IceGetListenConnectionString(listenObjs[i]);
+        if (!prot)
+            continue;
+        char *host = strchr(prot, '/');
+        char *sock = nullptr;
+        if (host) {
+            *host = 0;
+            host++;
+            sock = strchr(host, ':');
+            if (sock) {
+                *sock = 0;
+                sock++;
+            }
+        }
+        qCDebug(KSMSERVER) << "KSMServer: SetAProc_loc: conn " << (unsigned)i << ", prot=" << prot << ", file=" << sock;
+        if (sock && !strcmp(prot, "local")) {
+            chmod(sock, 0700);
+        }
+        IceSetHostBasedAuthProc(listenObjs[i], HostBasedAuthProc);
+        free(prot);
+    }
+    return 1;
+}
+
 Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry **authDataEntries)
 {
-    char *filename = IceAuthFileName();
-    FILE *fp;
+    QTemporaryFile addTempFile;
+    remTempFile = new QTemporaryFile;
 
-    if (IceLockAuthFile(filename, 10, 2, 600) != IceAuthLockSuccess) {
-        qWarning() << "Could not lock ICEAuthority file";
+    if (!addTempFile.open() || !remTempFile->open())
         return 0;
-    }
-    auto cleanup = qScopeGuard([filename]() {
-        IceUnlockAuthFile(filename);
-    });
 
-    if ((fp = fopen(filename, "ab")) == NULL) {
-        qWarning() << "Could not open ICEAuthority file";
+    if ((*authDataEntries = (IceAuthDataEntry *)malloc(count * 2 * sizeof(IceAuthDataEntry))) == nullptr)
         return 0;
-    }
 
-    if ((*authDataEntries = (IceAuthDataEntry *)malloc(count * 2 * sizeof(IceAuthDataEntry))) == nullptr) {
-        (void)fclose(fp);
-        return 0;
-    }
+    FILE *addAuthFile = fopen(QFile::encodeName(addTempFile.fileName()).constData(), "r+");
+    FILE *remAuthFile = fopen(QFile::encodeName(remTempFile->fileName()).constData(), "r+");
 
     for (int i = 0; i < numTransports * 2; i += 2) {
-        // ICE Auth Data
-
         (*authDataEntries)[i].network_id = IceGetListenConnectionString(listenObjs[i / 2]);
         (*authDataEntries)[i].protocol_name = (char *)"ICE";
         (*authDataEntries)[i].auth_name = (char *)"MIT-MAGIC-COOKIE-1";
@@ -323,25 +394,6 @@ Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry *
         (*authDataEntries)[i].auth_data = IceGenerateMagicCookie(MAGIC_COOKIE_LEN);
         (*authDataEntries)[i].auth_data_length = MAGIC_COOKIE_LEN;
 
-        // ICE Auth File
-        {
-            IceAuthFileEntry *file_entry = (IceAuthFileEntry *)malloc(sizeof(IceAuthFileEntry));
-            file_entry->protocol_name = strdup("ICE");
-            file_entry->protocol_data = NULL;
-            file_entry->protocol_data_length = 0;
-            file_entry->network_id = IceGetListenConnectionString(listenObjs[i / 2]);
-            file_entry->auth_name = strdup("MIT-MAGIC-COOKIE-1");
-            if (file_entry->auth_data = (char *)malloc(MAGIC_COOKIE_LEN)) {
-                memcpy(file_entry->auth_data, (*authDataEntries)[i].auth_data, MAGIC_COOKIE_LEN);
-            }
-            file_entry->auth_data_length = MAGIC_COOKIE_LEN;
-            if (IceWriteAuthFileEntry(fp, file_entry) == 0) {
-                qWarning("Failed to write ice auth file entry");
-            }
-            IceFreeAuthFileEntry(file_entry);
-        }
-
-        // XSMP Auth Data
         (*authDataEntries)[i + 1].network_id = IceGetListenConnectionString(listenObjs[i / 2]);
         (*authDataEntries)[i + 1].protocol_name = (char *)"XSMP";
         (*authDataEntries)[i + 1].auth_name = (char *)"MIT-MAGIC-COOKIE-1";
@@ -349,134 +401,146 @@ Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry *
         (*authDataEntries)[i + 1].auth_data = IceGenerateMagicCookie(MAGIC_COOKIE_LEN);
         (*authDataEntries)[i + 1].auth_data_length = MAGIC_COOKIE_LEN;
 
-        // XSMP Auth file
-        {
-            IceAuthFileEntry *file_entry = (IceAuthFileEntry *)malloc(sizeof(IceAuthFileEntry));
-            file_entry->protocol_name = strdup("XSMP");
-            file_entry->protocol_data = NULL;
-            file_entry->protocol_data_length = 0;
-            file_entry->network_id = IceGetListenConnectionString(listenObjs[i / 2]);
-            file_entry->auth_name = strdup("MIT-MAGIC-COOKIE-1");
-            if (file_entry->auth_data = (char *)malloc(MAGIC_COOKIE_LEN)) {
-                memcpy(file_entry->auth_data, (*authDataEntries)[i + 1].auth_data, MAGIC_COOKIE_LEN);
-            }
-            file_entry->auth_data_length = MAGIC_COOKIE_LEN;
-            if (IceWriteAuthFileEntry(fp, file_entry) == 0) {
-                qWarning("Failed to write xsmp ice auth file entry");
-            }
-            IceFreeAuthFileEntry(file_entry);
-        }
+        write_iceauth(addAuthFile, remAuthFile, &(*authDataEntries)[i]);
+        write_iceauth(addAuthFile, remAuthFile, &(*authDataEntries)[i + 1]);
 
         IceSetPaAuthData(2, &(*authDataEntries)[i]);
-    }
 
-    if (fclose(fp) != 0) {
-        qWarning() << "Could not close ICEAuthority file";
+        IceSetHostBasedAuthProc(listenObjs[i / 2], HostBasedAuthProc);
+    }
+    fclose(addAuthFile);
+    fclose(remAuthFile);
+
+    QString iceAuth = QStandardPaths::findExecutable(QStringLiteral("iceauth"));
+    if (iceAuth.isEmpty()) {
+        qCWarning(KSMSERVER, "KSMServer: could not find iceauth");
         return 0;
     }
 
+    KProcess p;
+    p << iceAuth << QStringLiteral("source") << addTempFile.fileName();
+    p.execute();
+
     return (1);
 }
 
-        /*
-         * Free up authentication data.
-         */
-        void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
-        {
-            /* Each transport has entries for ICE and XSMP */
-            for (int i = 0; i < count * 2; i++) {
-                free(authDataEntries[i].network_id);
-                free(authDataEntries[i].auth_data);
-            }
+/*
+ * Free up authentication data.
+ */
+void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
+{
+    /* Each transport has entries for ICE and XSMP */
+    if (only_local)
+        return;
 
-            free(authDataEntries);
+    for (int i = 0; i < count * 2; i++) {
+        free(authDataEntries[i].network_id);
+        free(authDataEntries[i].auth_data);
+    }
+
+    free(authDataEntries);
+
+    QString iceAuth = QStandardPaths::findExecutable(QStringLiteral("iceauth"));
+    if (iceAuth.isEmpty()) {
+        qCWarning(KSMSERVER, "KSMServer: could not find iceauth");
+        return;
+    }
+
+    if (remTempFile) {
+        KProcess p;
+        p << iceAuth << QStringLiteral("source") << remTempFile->fileName();
+        p.execute();
+    }
+
+    delete remTempFile;
+    remTempFile = nullptr;
+}
+
+static int Xio_ErrorHandler(Display *)
+{
+    qCWarning(KSMSERVER, "ksmserver: Fatal IO error: client killed");
+
+    // Don't do anything that might require the X connection
+    if (the_server) {
+        KSMServer *server = the_server;
+        the_server = nullptr;
+        server->cleanUp();
+        // Don't delete server!!
+    }
+
+    exit(0); // Don't report error, it's not our fault.
+    return 0; // Bogus return value, notreached
+}
+
+void KSMServer::setupXIOErrorHandler()
+{
+    XSetIOErrorHandler(Xio_ErrorHandler);
+}
+
+static int wake_up_socket = -1;
+static void sighandler(int sig)
+{
+    if (sig == SIGHUP) {
+        signal(SIGHUP, sighandler);
+        return;
+    }
+
+    char ch = 0;
+    (void)::write(wake_up_socket, &ch, 1);
+}
+
+void KSMWatchProc(IceConn iceConn, IcePointer client_data, Bool opening, IcePointer *watch_data)
+{
+    KSMServer *ds = (KSMServer *)client_data;
+
+    if (opening) {
+        *watch_data = (IcePointer)ds->watchConnection(iceConn);
+    } else {
+        ds->removeConnection((KSMConnection *)*watch_data);
+    }
+}
+
+static Status KSMNewClientProc(SmsConn conn, SmPointer manager_data, unsigned long *mask_ret, SmsCallbacks *cb, char **failure_reason_ret)
+{
+    *failure_reason_ret = nullptr;
+
+    void *client = ((KSMServer *)manager_data)->newClient(conn);
+    if (client == NULL) {
+        const char *errstr = "Connection rejected: ksmserver is shutting down";
+        qCWarning(KSMSERVER, "%s", errstr);
+
+        if ((*failure_reason_ret = (char *)malloc(strlen(errstr) + 1)) != NULL) {
+            strcpy(*failure_reason_ret, errstr);
         }
+        return 0;
+    }
 
-        static int Xio_ErrorHandler(Display *)
-        {
-            qCWarning(KSMSERVER, "ksmserver: Fatal IO error: client killed");
+    cb->register_client.callback = KSMRegisterClientProc;
+    cb->register_client.manager_data = client;
+    cb->interact_request.callback = KSMInteractRequestProc;
+    cb->interact_request.manager_data = client;
+    cb->interact_done.callback = KSMInteractDoneProc;
+    cb->interact_done.manager_data = client;
+    cb->save_yourself_request.callback = KSMSaveYourselfRequestProc;
+    cb->save_yourself_request.manager_data = client;
+    cb->save_yourself_phase2_request.callback = KSMSaveYourselfPhase2RequestProc;
+    cb->save_yourself_phase2_request.manager_data = client;
+    cb->save_yourself_done.callback = KSMSaveYourselfDoneProc;
+    cb->save_yourself_done.manager_data = client;
+    cb->close_connection.callback = KSMCloseConnectionProc;
+    cb->close_connection.manager_data = client;
+    cb->set_properties.callback = KSMSetPropertiesProc;
+    cb->set_properties.manager_data = client;
+    cb->delete_properties.callback = KSMDeletePropertiesProc;
+    cb->delete_properties.manager_data = client;
+    cb->get_properties.callback = KSMGetPropertiesProc;
+    cb->get_properties.manager_data = client;
 
-            // Don't do anything that might require the X connection
-            if (the_server) {
-                KSMServer *server = the_server;
-                the_server = nullptr;
-                server->cleanUp();
-                // Don't delete server!!
-            }
-
-            exit(0); // Don't report error, it's not our fault.
-            return 0; // Bogus return value, notreached
-        }
-
-        void KSMServer::setupXIOErrorHandler()
-        {
-            XSetIOErrorHandler(Xio_ErrorHandler);
-        }
-
-        static int wake_up_socket = -1;
-        static void sighandler(int sig)
-        {
-            if (sig == SIGHUP) {
-                signal(SIGHUP, sighandler);
-                return;
-            }
-
-            char ch = 0;
-            (void)::write(wake_up_socket, &ch, 1);
-        }
-
-        void KSMWatchProc(IceConn iceConn, IcePointer client_data, Bool opening, IcePointer * watch_data)
-        {
-            KSMServer *ds = (KSMServer *)client_data;
-
-            if (opening) {
-                *watch_data = (IcePointer)ds->watchConnection(iceConn);
-            } else {
-                ds->removeConnection((KSMConnection *)*watch_data);
-            }
-        }
-
-        static Status KSMNewClientProc(SmsConn conn, SmPointer manager_data, unsigned long *mask_ret, SmsCallbacks *cb, char **failure_reason_ret)
-        {
-            *failure_reason_ret = nullptr;
-
-            void *client = ((KSMServer *)manager_data)->newClient(conn);
-            if (client == NULL) {
-                const char *errstr = "Connection rejected: ksmserver is shutting down";
-                qCWarning(KSMSERVER, "%s", errstr);
-
-                if ((*failure_reason_ret = (char *)malloc(strlen(errstr) + 1)) != NULL) {
-                    strcpy(*failure_reason_ret, errstr);
-                }
-                return 0;
-            }
-
-            cb->register_client.callback = KSMRegisterClientProc;
-            cb->register_client.manager_data = client;
-            cb->interact_request.callback = KSMInteractRequestProc;
-            cb->interact_request.manager_data = client;
-            cb->interact_done.callback = KSMInteractDoneProc;
-            cb->interact_done.manager_data = client;
-            cb->save_yourself_request.callback = KSMSaveYourselfRequestProc;
-            cb->save_yourself_request.manager_data = client;
-            cb->save_yourself_phase2_request.callback = KSMSaveYourselfPhase2RequestProc;
-            cb->save_yourself_phase2_request.manager_data = client;
-            cb->save_yourself_done.callback = KSMSaveYourselfDoneProc;
-            cb->save_yourself_done.manager_data = client;
-            cb->close_connection.callback = KSMCloseConnectionProc;
-            cb->close_connection.manager_data = client;
-            cb->set_properties.callback = KSMSetPropertiesProc;
-            cb->set_properties.manager_data = client;
-            cb->delete_properties.callback = KSMDeletePropertiesProc;
-            cb->delete_properties.manager_data = client;
-            cb->get_properties.callback = KSMGetPropertiesProc;
-            cb->get_properties.manager_data = client;
-
-            *mask_ret = SmsRegisterClientProcMask | SmsInteractRequestProcMask | SmsInteractDoneProcMask | SmsSaveYourselfRequestProcMask
-                | SmsSaveYourselfP2RequestProcMask | SmsSaveYourselfDoneProcMask | SmsCloseConnectionProcMask | SmsSetPropertiesProcMask
-                | SmsDeletePropertiesProcMask | SmsGetPropertiesProcMask;
-            return 1;
-        }
+    *mask_ret = SmsRegisterClientProcMask | SmsInteractRequestProcMask | SmsInteractDoneProcMask | SmsSaveYourselfRequestProcMask
+        | SmsSaveYourselfP2RequestProcMask | SmsSaveYourselfDoneProcMask | SmsCloseConnectionProcMask | SmsSetPropertiesProcMask | SmsDeletePropertiesProcMask
+        | SmsGetPropertiesProcMask;
+    return 1;
+}
 
 #ifdef HAVE__ICETRANSNOLISTEN
 extern "C" int _IceTransNoListen(const char *protocol);
@@ -500,12 +564,6 @@ KSMServer::KSMServer(InitFlags flags)
     QSocketNotifier *n = new QSocketNotifier(sockets[1], QSocketNotifier::Read, this);
     qApp->connect(n, &QSocketNotifier::activated, &QApplication::quit);
 
-    const QString runtimeDirectory = QStandardPaths::writableLocation(QStandardPaths::RuntimeLocation);
-    iceAuthFile.setFileTemplate(runtimeDirectory + QStringLiteral("/iceauth_XXXXXX"));
-    if (!iceAuthFile.open())
-        qFatal("Failed to create ICEauthority file");
-    setenv("ICEAUTHORITY", qPrintable(iceAuthFile.fileName()), true);
-
     new KSMServerInterfaceAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KSMServer"), this);
     the_server = this;
@@ -517,14 +575,16 @@ KSMServer::KSMServer(InitFlags flags)
     clientInteracting = nullptr;
     xonCommand = config.readEntry("xonCommand", "xon");
 
+    only_local = flags.testFlag(InitFlag::OnlyLocal);
 #ifdef HAVE__ICETRANSNOLISTEN
-    if (flags.testFlag(InitFlag::OnlyLocal)) {
+    if (only_local)
         _IceTransNoListen("tcp");
-    }
+#else
+    only_local = false;
 #endif
 
     char errormsg[256];
-    if (!SmsInitialize((char *)KSMVendorString, (char *)KSMReleaseString, KSMNewClientProc, (SmPointer)this, nullptr, 256, errormsg)) {
+    if (!SmsInitialize((char *)KSMVendorString, (char *)KSMReleaseString, KSMNewClientProc, (SmPointer)this, HostBasedAuthProc, 256, errormsg)) {
         qCWarning(KSMSERVER, "KSMServer: could not register XSM protocol");
     }
 
@@ -563,16 +623,20 @@ KSMServer::KSMServer(InitFlags flags)
 
         QProcessEnvironment newEnv;
         newEnv.insert(QStringLiteral("SESSION_MANAGER"), QString::fromLatin1(session_manager));
-        newEnv.insert(QStringLiteral("ICEAUTHORITY"), iceAuthFile.fileName());
-
-        auto updateEnvJob = new UpdateLaunchEnvJob(newEnv);
-        updateEnvJob->exec();
+        auto updateEnvJob = new KUpdateLaunchEnvironmentJob(newEnv);
+        QEventLoop loop;
+        QObject::connect(updateEnvJob, &KUpdateLaunchEnvironmentJob::finished, &loop, &QEventLoop::quit);
+        loop.exec();
 
         free(session_manager);
     }
 
-    if (!SetAuthentication(numTransports, listenObjs, &authDataEntries)) {
-        qFatal("KSMSERVER: authentication setup failed.");
+    if (only_local) {
+        if (!SetAuthentication_local(numTransports, listenObjs))
+            qFatal("KSMSERVER: authentication setup failed.");
+    } else {
+        if (!SetAuthentication(numTransports, listenObjs, &authDataEntries))
+            qFatal("KSMSERVER: authentication setup failed.");
     }
 
     IceAddConnectionWatch(KSMWatchProc, (IcePointer)this);
@@ -591,7 +655,6 @@ KSMServer::KSMServer(InitFlags flags)
     signal(SIGPIPE, SIG_IGN);
 
     connect(&protectionTimer, &QTimer::timeout, this, &KSMServer::protectionTimeout);
-    connect(&restoreTimer, &QTimer::timeout, this, &KSMServer::tryRestoreNext);
     connect(this, &KSMServer::sessionRestored, this, [this]() {
         auto reply = m_restoreSessionCall.createReply();
         QDBusConnection::sessionBus().send(reply);
@@ -721,6 +784,54 @@ void KSMServer::newConnection(int /*socket*/)
     IceConn iceConn = IceAcceptConnection(((KSMListener *)sender())->listenObj, &status);
     if (iceConn == nullptr)
         return;
+
+    // This should be sufficient to hold all open file descriptors that are not connection watches. The rest we will
+    // freely use to watch ICE connections.
+    static const size_t backupFileCount = 128;
+    qCDebug(KSMSERVER) << "KSMConnection::count" << KSMConnection::count;
+    if (KSMConnection::count > (fileNumberLimit() - backupFileCount)) {
+        // https://bugs.kde.org/show_bug.cgi?id=475506
+        qCWarning(KSMSERVER) << "Too many open connections. Refusing to track any more to prevent exhaustion of open file limits.";
+        QHash<QString, size_t> consumers;
+        for (const auto &client : clients) {
+            QString program = client->program();
+            if (program.isEmpty() && !client->restartCommand().isEmpty()) {
+                program = client->restartCommand().first();
+            }
+            if (program.isEmpty()) {
+                program = i18nc("@label an unknown executable is using resources", "[unknown]");
+            }
+
+            if (!consumers.contains(program)) {
+                consumers[program] = 0;
+            }
+            consumers[program]++;
+        }
+        std::multimap<size_t, QString> ranking; // using STL container because QMultiMap has no reverse iterators
+        for (auto it = consumers.cbegin(); it != consumers.cend(); it++) {
+            ranking.emplace(it.value(), it.key());
+        }
+
+        QString consumerInfo;
+        int i = 0;
+        for (auto it = ranking.rbegin(); i != 3 && it != ranking.rend(); it++, i++) {
+            if (!consumerInfo.isEmpty()) {
+                consumerInfo += QLatin1String(", ");
+            }
+            consumerInfo += QStringLiteral("%1:%2").arg(it->second, QString::number(it->first));
+        }
+        KNotification::event(KNotification::Error,
+                             xi18nc("@label notification; %1 is a list of executables",
+                                    "Unable to manage some apps because the system's session management resources are exhausted. Here are the top three "
+                                    "consumers of session resources:\n%1",
+                                    consumerInfo),
+                             QPixmap(),
+                             KNotification::Persistent);
+
+        std::ignore = IceCloseConnection(iceConn);
+        return;
+    }
+
     IceSetShutdownNegotiation(iceConn, false);
     IceConnectStatus cstatus;
     while ((cstatus = IceConnectionStatus(iceConn)) == IceConnectPending) {
@@ -856,18 +967,31 @@ void KSMServer::setupShortcuts()
         KActionCollection *actionCollection = new KActionCollection(this);
         actionCollection->setComponentDisplayName(i18n("Session Management"));
         QAction *a;
+
+        // "With confirmation" actions
         a = actionCollection->addAction(QStringLiteral("Log Out"));
         a->setText(i18n("Log Out"));
         KGlobalAccel::self()->setGlobalShortcut(a, QList<QKeySequence>() << (Qt::ALT | Qt::CTRL | Qt::Key_Delete));
         connect(a, &QAction::triggered, this, &KSMServer::defaultLogout);
 
+        a = actionCollection->addAction(QStringLiteral("Shut Down"));
+        a->setText(i18n("Shut Down"));
+        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
+        connect(a, &QAction::triggered, this, &KSMServer::haltWithConfirmation);
+
+        a = actionCollection->addAction(QStringLiteral("Reboot"));
+        a->setText(i18n("Reboot"));
+        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
+        connect(a, &QAction::triggered, this, &KSMServer::rebootWithConfirmation);
+
+        // "Without confirmation" actions
         a = actionCollection->addAction(QStringLiteral("Log Out Without Confirmation"));
         a->setText(i18n("Log Out Without Confirmation"));
         KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
         connect(a, &QAction::triggered, this, &KSMServer::logoutWithoutConfirmation);
 
         a = actionCollection->addAction(QStringLiteral("Halt Without Confirmation"));
-        a->setText(i18n("Halt Without Confirmation"));
+        a->setText(i18n("Shut Down Without Confirmation"));
         KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
         connect(a, &QAction::triggered, this, &KSMServer::haltWithoutConfirmation);
 
@@ -920,8 +1044,6 @@ void KSMServer::restoreSession()
     setDelayedReply(true);
     m_restoreSessionCall = message();
 
-    lastAppStarted = 0;
-    lastIdStarted.clear();
     state = KSMServer::Restoring;
 
     auto reply = m_kwinInterface->loadSession(currentSession());
@@ -932,7 +1054,7 @@ void KSMServer::restoreSession()
             qWarning() << "Failed to notify kwin of current session " << reply.error().message();
         }
         restoreLegacySession(KSharedConfig::openConfig().data());
-        tryRestoreNext();
+        tryRestore();
     });
 }
 
@@ -943,59 +1065,97 @@ void KSMServer::restoreSubSession(const QString &name)
     KConfigGroup configSessionGroup(KSharedConfig::openConfig(), sessionGroup);
     int count = configSessionGroup.readEntry("count", 0);
     appsToStart = count;
-    lastAppStarted = 0;
-    lastIdStarted.clear();
 
     state = RestoringSubSession;
-    tryRestoreNext();
+    tryRestore();
 }
 
-void KSMServer::clientRegistered(const char *previousId)
+void KSMServer::clientRegistered(const char * /* previousId */)
 {
-    if (previousId && lastIdStarted == QString::fromLocal8Bit(previousId))
-        tryRestoreNext();
 }
 
-void KSMServer::tryRestoreNext()
+void KSMServer::tryRestore()
 {
     if (state != Restoring && state != RestoringSubSession)
         return;
-    restoreTimer.stop();
     KConfigGroup config(KSharedConfig::openConfig(), sessionGroup);
 
-    while (lastAppStarted < appsToStart) {
-        lastAppStarted++;
-        QString n = QString::number(lastAppStarted);
-        QString clientId = config.readEntry(QLatin1String("clientId") + n, QString());
-        bool alreadyStarted = false;
-        foreach (KSMClient *c, clients) {
-            if (QString::fromLocal8Bit(c->clientId()) == clientId) {
-                alreadyStarted = true;
-                break;
-            }
-        }
-        if (alreadyStarted)
-            continue;
+    struct DontStartEntry {
+        QString clientId;
+        QString appName;
+    };
+    QList<DontStartEntry> dontStartEntries;
+    QHash<QString, size_t> startCounter;
 
-        QStringList restartCommand = config.readEntry(QLatin1String("restartCommand") + n, QStringList());
-        if (restartCommand.isEmpty() || (config.readEntry(QStringLiteral("restartStyleHint") + n, 0) == SmRestartNever)) {
+    struct RestartEntry {
+        QString clientId;
+        QStringList restartCommand;
+        int restartStyleHint;
+        QString clientMachine;
+        QString userId;
+    };
+    QList<RestartEntry> entries;
+    entries.reserve(appsToStart);
+    for (int i = 0; i < appsToStart; i++) {
+        const auto n = QString::number(i);
+        const auto entry = entries.emplace_back(RestartEntry{
+            .clientId = config.readEntry(QLatin1String("clientId") + n, QString()),
+            .restartCommand = config.readEntry(QLatin1String("restartCommand") + n, QStringList()),
+            .restartStyleHint = config.readEntry(QLatin1String("restartStyleHint") + n, 0),
+            .clientMachine = config.readEntry(QLatin1String("clientMachine") + n, QString()),
+            .userId = config.readEntry(QLatin1String("userId") + n, QString()),
+        });
+
+        // Count how many times this command is going to be started. If it is too many we will create a DontStartEntry
+        // and consequently turn *all* restorations no-op in the actual start loop.
+        if (entry.restartCommand.isEmpty()) {
             continue;
         }
-        startApplication(restartCommand,
-                         config.readEntry(QStringLiteral("clientMachine") + n, QString()),
-                         config.readEntry(QStringLiteral("userId") + n, QString()));
-        lastIdStarted = clientId;
-        if (!lastIdStarted.isEmpty()) {
-            restoreTimer.setSingleShot(true);
-            restoreTimer.start(2000);
-            return; // we get called again from the clientRegistered handler
+        const auto appName = entry.restartCommand.first();
+        if (!startCounter.contains(appName)) {
+            startCounter[appName] = 0;
+        }
+        startCounter[appName]++;
+        if (startCounter[appName] == perAppStartLimit()) { // only insert this entry once! when the limit is hit
+            dontStartEntries.push_back(DontStartEntry{.clientId = entry.clientId, .appName = appName});
         }
     }
 
-    // all done
-    appsToStart = 0;
-    lastIdStarted.clear();
+    for (const auto &entry : dontStartEntries) {
+        qCWarning(KSMSERVER) << "Too many application starts issued for" << entry.appName << ". Not starting any more."
+                             << "Something may be broken with the application's session management.";
+        KNotification::event(KNotification::Error,
+                             xi18nc("@label notification; %1 is an executable name",
+                                    "Unable to restore <application>%1</application> because it is broken and has exhausted the system's session restoration "
+                                    "resources. Please report this to the app's developers.",
+                                    entry.appName));
+    }
 
+    for (const auto &entry : entries) {
+        // We only discard the entries here because a violating app will get all entries disabled, not just the ones in
+        // excess. So we need to loop all entries twice: once to establish the in-excess apps, and again to actually start
+        // (or not).
+        const bool dontStart = std::any_of(dontStartEntries.cbegin(), dontStartEntries.cend(), [&entry](const auto &dontStartEntry) {
+            return dontStartEntry.clientId == entry.clientId;
+        });
+        if (dontStart) {
+            continue;
+        }
+
+        const bool alreadyStarted = std::any_of(clients.cbegin(), clients.cend(), [&entry](const auto &client) {
+            return QString::fromLocal8Bit(client->clientId()) == entry.clientId;
+        });
+        if (alreadyStarted) {
+            continue;
+        }
+
+        if (entry.restartCommand.isEmpty() || entry.restartStyleHint == SmRestartNever) {
+            continue;
+        }
+        startApplication(entry.restartCommand, entry.clientMachine, entry.userId);
+    }
+
+    // all done
     if (state == Restoring) {
         Q_EMIT sessionRestored();
     } else { // subsession
@@ -1019,11 +1179,21 @@ void KSMServer::logoutWithoutConfirmation()
     shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeNone, KWorkSpace::ShutdownModeDefault);
 }
 
+void KSMServer::haltWithConfirmation()
+{
+    shutdown(KWorkSpace::ShutdownConfirmYes, KWorkSpace::ShutdownTypeHalt, KWorkSpace::ShutdownModeDefault);
+}
+
 void KSMServer::haltWithoutConfirmation()
 {
     shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeHalt, KWorkSpace::ShutdownModeDefault);
 }
 
+void KSMServer::rebootWithConfirmation()
+{
+    shutdown(KWorkSpace::ShutdownConfirmYes, KWorkSpace::ShutdownTypeReboot, KWorkSpace::ShutdownModeDefault);
+}
+
 void KSMServer::rebootWithoutConfirmation()
 {
     shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeReboot, KWorkSpace::ShutdownModeDefault);
