@@ -25,13 +25,12 @@ extern "C" {
 #include <QDBusMessage>
 #include <QObject>
 #include <QStringList>
-#include <QTemporaryFile>
 
 #include <KConfigGroup>
 #include <QMap>
 #include <QTime>
 #include <QTimer>
-#include <kmessagebox.h>
+#include <QWindow>
 #include <kworkspace.h>
 
 #define SESSION_PREVIOUS_LOGOUT "saved at previous logout"
@@ -118,7 +117,9 @@ private Q_SLOTS:
 
     void defaultLogout();
     void logoutWithoutConfirmation();
+    void haltWithConfirmation();
     void haltWithoutConfirmation();
+    void rebootWithConfirmation();
     void rebootWithoutConfirmation();
 
 private:
@@ -154,7 +155,7 @@ private:
     WId windowWmClientLeader(WId w);
     QByteArray windowSessionId(WId w, WId leader);
 
-    void tryRestoreNext();
+    void tryRestore();
     void startupDone();
 
     void runShutdownScripts();
@@ -204,12 +205,9 @@ private:
     KSMClient *clientInteracting;
     QString sessionGroup;
     QTimer protectionTimer;
-    QTimer restoreTimer;
     QString xonCommand;
     // sequential startup
     int appsToStart;
-    int lastAppStarted;
-    QString lastIdStarted;
 
     QStringList excludeApps;
 
@@ -224,6 +222,5 @@ private:
     OrgKdeKWinSessionInterface *m_kwinInterface;
 
     int sockets[2];
-    QTemporaryFile iceAuthFile;
     friend bool readFromPipe(int pipe);
 };
