@@ -25,7 +25,7 @@
 #include <KWindowSystem>
 
 SplashWindow::SplashWindow(bool testing, bool window, const QString &theme, QScreen *screen)
-    : KQuickAddons::QuickViewSharedEngine()
+    : PlasmaQuick::QuickViewSharedEngine()
     , m_stage(0)
     , m_testing(testing)
     , m_window(window)
@@ -36,7 +36,6 @@ SplashWindow::SplashWindow(bool testing, bool window, const QString &theme, QScr
             layerShellWindow->setScope(QStringLiteral("ksplashqml"));
             layerShellWindow->setLayer(LayerShellQt::Window::LayerOverlay);
             layerShellWindow->setExclusiveZone(-1);
-            layerShellWindow->setDesiredOutput(screen);
         }
     }
 
@@ -44,7 +43,7 @@ SplashWindow::SplashWindow(bool testing, bool window, const QString &theme, QScr
     setScreen(screen);
     setColor(Qt::transparent);
     setDefaultAlphaBuffer(true);
-    setResizeMode(KQuickAddons::QuickViewSharedEngine::SizeRootObjectToView);
+    setResizeMode(PlasmaQuick::QuickViewSharedEngine::SizeRootObjectToView);
 
     if (!m_window) {
         setFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
@@ -79,7 +78,7 @@ void SplashWindow::setStage(int stage)
 
 void SplashWindow::keyPressEvent(QKeyEvent *event)
 {
-    KQuickAddons::QuickViewSharedEngine::keyPressEvent(event);
+    PlasmaQuick::QuickViewSharedEngine::keyPressEvent(event);
     if (m_testing && !event->isAccepted() && event->key() == Qt::Key_Escape) {
         close();
     }
@@ -87,7 +86,7 @@ void SplashWindow::keyPressEvent(QKeyEvent *event)
 
 void SplashWindow::mousePressEvent(QMouseEvent *event)
 {
-    KQuickAddons::QuickViewSharedEngine::mousePressEvent(event);
+    PlasmaQuick::QuickViewSharedEngine::mousePressEvent(event);
     if (m_testing && !event->isAccepted()) {
         close();
     }
@@ -96,7 +95,7 @@ void SplashWindow::mousePressEvent(QMouseEvent *event)
 void SplashWindow::setGeometry(const QRect &rect)
 {
     bool oldGeometryEmpty = geometry().isNull();
-    KQuickAddons::QuickViewSharedEngine::setGeometry(rect);
+    PlasmaQuick::QuickViewSharedEngine::setGeometry(rect);
 
     if (oldGeometryEmpty) {
         KPackage::Package package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
