@@ -49,6 +49,7 @@ SessionManagement::SessionManagement(QObject *parent)
     connect(backend, &SessionBackend::canSuspendChanged, this, &SessionManagement::canSuspendChanged);
     connect(backend, &SessionBackend::canHybridSuspendChanged, this, &SessionManagement::canHybridSuspendChanged);
     connect(backend, &SessionBackend::canHibernateChanged, this, &SessionManagement::canHibernateChanged);
+    connect(backend, &SessionBackend::canSuspendThenHibernateChanged, this, &SessionManagement::canSuspendThenHibernateChanged);
     connect(backend, &SessionBackend::aboutToSuspend, this, &SessionManagement::aboutToSuspend);
     connect(backend, &SessionBackend::resumingFromSuspend, this, &SessionManagement::resumingFromSuspend);
 }
@@ -85,6 +86,11 @@ bool SessionManagement::canHibernate() const
     return SessionBackend::self()->canHibernate();
 }
 
+bool SessionManagement::canSuspendThenHibernate() const
+{
+    return SessionBackend::self()->canSuspendThenHibernate();
+}
+
 bool SessionManagement::canSwitchUser() const
 {
     return KAuthorized::authorizeAction(QStringLiteral("start_new_session"));
@@ -196,6 +202,14 @@ void SessionManagement::hibernate()
     SessionBackend::self()->hibernate();
 }
 
+void SessionManagement::suspendThenHibernate()
+{
+    if (!canSuspendThenHibernate()) {
+        return;
+    }
+    SessionBackend::self()->suspendThenHibernate();
+}
+
 void SessionManagement::lock()
 {
     if (!canLock()) {
