@@ -18,9 +18,7 @@
 
 #include "kdisplaymanager.h"
 
-#include "consolekit_manager_interface.h"
 #include "login1_manager_interface.h"
-#include "upower_interface.h"
 
 static SessionBackend *s_backend = nullptr;
 
@@ -37,8 +35,6 @@ SessionBackend *SessionBackend::self()
         s_backend = new TestSessionBackend();
     } else if (LogindSessionBackend::exists()) {
         s_backend = new LogindSessionBackend();
-    } else if (ConsoleKitSessionBackend::exists()) {
-        s_backend = new ConsoleKitSessionBackend();
     } else {
         s_backend = new DummySessionBackend();
     }
@@ -96,6 +92,11 @@ void TestSessionBackend::hibernate()
     qWarning() << "hibernate";
 }
 
+void TestSessionBackend::suspendThenHibernate()
+{
+    qWarning() << "suspendThenHibernate";
+}
+
 /*********************************************************************************/
 
 LogindSessionBackend::LogindSessionBackend()
@@ -127,6 +128,7 @@ LogindSessionBackend::LogindSessionBackend()
             Q_EMIT canRebootChanged();
             Q_EMIT canSuspendChanged();
             Q_EMIT canHibernateChanged();
+            Q_EMIT canSuspendThenHibernateChanged();
         }
     };
 
@@ -151,6 +153,10 @@ LogindSessionBackend::LogindSessionBackend()
         auto watcher = new QDBusPendingCallWatcher(m_login1->CanHibernate(), this);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, std::bind(propLoaded, std::placeholders::_1, &m_canHibernate));
     }
+    {
+        auto watcher = new QDBusPendingCallWatcher(m_login1->CanSuspendThenHibernate(), this);
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, std::bind(propLoaded, std::placeholders::_1, &m_canSuspendThenHibernate));
+    }
 
     connect(m_login1, &OrgFreedesktopLogin1ManagerInterface::PrepareForSleep, this, [this](bool sleeping) {
         if (sleeping) {
@@ -195,6 +201,11 @@ void LogindSessionBackend::hibernate()
     m_login1->Hibernate(true).waitForFinished();
 }
 
+void LogindSessionBackend::suspendThenHibernate()
+{
+    m_login1->SuspendThenHibernate(true).waitForFinished();
+}
+
 bool LogindSessionBackend::canShutdown() const
 {
     return m_canShutdown;
@@ -220,82 +231,7 @@ bool LogindSessionBackend::canHibernate() const
     return m_canHibernate;
 }
 
-/*********************************************************************************/
-
-bool ConsoleKitSessionBackend::exists()
+bool LogindSessionBackend::canSuspendThenHibernate() const
 {
-    return QDBusConnection::systemBus().interface()->isServiceRegistered(QStringLiteral("org.freedesktop.login1"));
-}
-
-ConsoleKitSessionBackend::ConsoleKitSessionBackend()
-{
-    m_ck = new OrgFreedesktopConsoleKitManagerInterface(QStringLiteral("org.freedesktop.ConsoleKit"),
-                                                        QStringLiteral("/org/freedesktop/ConsoleKit/Manager"),
-                                                        QDBusConnection::systemBus(),
-                                                        this);
-    m_upower = new OrgFreedesktopUPowerInterface(QStringLiteral("org.freedesktop.UPower"),
-                                                 QStringLiteral("/org/freedesktop/UPower"),
-                                                 QDBusConnection::systemBus(),
-                                                 this);
-
-    auto canStop = m_ck->CanStop();
-    canStop.waitForFinished();
-    m_canShutdown = canStop.value();
-
-    auto canRestart = m_ck->CanRestart();
-    canRestart.waitForFinished();
-    m_canReboot = canRestart.value();
-
-    m_canSuspend = m_upower->canSuspend();
-    m_canHibernate = m_upower->canHibernate();
-
-    connect(m_upower, &OrgFreedesktopUPowerInterface::NotifySleep, this, &SessionBackend::aboutToSuspend);
-    connect(m_upower, &OrgFreedesktopUPowerInterface::Resuming, this, &SessionBackend::resumingFromSuspend);
-
-    m_state = SessionManagement::State::Ready;
-}
-
-SessionManagement::State ConsoleKitSessionBackend::state() const
-{
-    return m_state;
-}
-
-void ConsoleKitSessionBackend::shutdown()
-{
-    m_ck->Stop();
-}
-
-void ConsoleKitSessionBackend::reboot()
-{
-    m_ck->Restart();
-}
-
-void ConsoleKitSessionBackend::suspend()
-{
-    m_upower->Suspend();
-}
-
-void ConsoleKitSessionBackend::hibernate()
-{
-    m_upower->Hibernate();
-}
-
-bool ConsoleKitSessionBackend::canShutdown() const
-{
-    return m_canShutdown;
-}
-
-bool ConsoleKitSessionBackend::canReboot() const
-{
-    return m_canReboot;
-}
-
-bool ConsoleKitSessionBackend::canSuspend() const
-{
-    return m_canSuspend;
-}
-
-bool ConsoleKitSessionBackend::canHibernate() const
-{
-    return m_canHibernate;
+    return m_canSuspendThenHibernate;
 }
