@@ -13,8 +13,6 @@
 #include "sessionmanagement.h"
 
 class OrgFreedesktopLogin1ManagerInterface;
-class OrgFreedesktopUPowerInterface;
-class OrgFreedesktopConsoleKitManagerInterface;
 
 /**
  * Performs direct system actions that could kill the session
@@ -36,12 +34,14 @@ public:
     virtual void suspend() = 0;
     virtual void hybridSuspend() = 0;
     virtual void hibernate() = 0;
+    virtual void suspendThenHibernate() = 0;
 
     virtual bool canShutdown() const = 0;
     virtual bool canReboot() const = 0;
     virtual bool canSuspend() const = 0;
     virtual bool canHybridSuspend() const = 0;
     virtual bool canHibernate() const = 0;
+    virtual bool canSuspendThenHibernate() const = 0;
 
     virtual bool canSwitchUser() const;
 
@@ -54,6 +54,7 @@ Q_SIGNALS:
     void canSuspendChanged();
     void canHybridSuspendChanged();
     void canHibernateChanged();
+    void canSuspendThenHibernateChanged();
 
     void aboutToSuspend();
     void resumingFromSuspend();
@@ -83,11 +84,13 @@ public:
     void suspend() override;
     void hybridSuspend() override;
     void hibernate() override;
+    void suspendThenHibernate() override;
     bool canShutdown() const override;
     bool canReboot() const override;
     bool canSuspend() const override;
     bool canHybridSuspend() const override;
     bool canHibernate() const override;
+    bool canSuspendThenHibernate() const override;
 
 private:
     OrgFreedesktopLogin1ManagerInterface *m_login1;
@@ -97,45 +100,7 @@ private:
     bool m_canSuspend = false;
     bool m_canHybridSuspend = false;
     bool m_canHibernate = false;
-    uint m_pendingJobs = 0;
-};
-
-/* Maybe misleadingly named, consolekit doesn't support suspend directly so it's
- * suplemented with upower where available
- */
-class ConsoleKitSessionBackend : public SessionBackend
-{
-    Q_OBJECT
-public:
-    static bool exists();
-    ConsoleKitSessionBackend();
-
-    SessionManagement::State state() const override;
-    void shutdown() override;
-    void reboot() override;
-    void suspend() override;
-    void hybridSuspend() override
-    {
-    }
-    void hibernate() override;
-    bool canShutdown() const override;
-    bool canReboot() const override;
-    bool canSuspend() const override;
-    bool canHybridSuspend() const override
-    {
-        return false;
-    }
-    bool canHibernate() const override;
-
-private:
-    OrgFreedesktopUPowerInterface *m_upower;
-    OrgFreedesktopConsoleKitManagerInterface *m_ck;
-
-    SessionManagement::State m_state = SessionManagement::State::Loading;
-    bool m_canShutdown = false;
-    bool m_canReboot = false;
-    bool m_canSuspend = false;
-    bool m_canHibernate = false;
+    bool m_canSuspendThenHibernate = false;
     uint m_pendingJobs = 0;
 };
 
@@ -164,6 +129,9 @@ public:
     void hibernate() override
     {
     }
+    void suspendThenHibernate() override
+    {
+    }
     bool canShutdown() const override
     {
         return false;
@@ -184,6 +152,10 @@ public:
     {
         return false;
     }
+    bool canSuspendThenHibernate() const override
+    {
+        return false;
+    }
 };
 
 class TestSessionBackend : public SessionBackend
@@ -201,6 +173,7 @@ public:
     void suspend() override;
     void hybridSuspend() override;
     void hibernate() override;
+    void suspendThenHibernate() override;
 
     bool canShutdown() const override
     {
@@ -222,4 +195,8 @@ public:
     {
         return true;
     }
+    bool canSuspendThenHibernate() const override
+    {
+        return true;
+    }
 };
