@@ -48,7 +48,7 @@ JobsModelPrivate::JobsModelPrivate(QObject *parent)
     connect(m_compressUpdatesTimer, &QTimer::timeout, this, [this] {
         for (auto it = m_pendingDirtyRoles.constBegin(), end = m_pendingDirtyRoles.constEnd(); it != end; ++it) {
             Job *job = it.key();
-            const QVector<int> roles = it.value();
+            const QList<int> roles = it.value();
             const int row = m_jobViews.indexOf(job);
             if (row == -1) {
                 continue;
@@ -75,7 +75,7 @@ JobsModelPrivate::~JobsModelPrivate()
 
     // Remember which services we had running and clear their progress
     QStringList desktopEntries;
-    for (Job *job : qAsConst(m_jobViews)) {
+    for (Job *job : std::as_const(m_jobViews)) {
         if (!desktopEntries.contains(job->desktopEntry())) {
             desktopEntries.append(job->desktopEntry());
         }
@@ -121,7 +121,7 @@ bool JobsModelPrivate::init()
     QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface();
 
     if (!master) {
-        connect(dbusIface, &QDBusConnectionInterface::serviceUnregistered, this, [=](const QString &serviceName) {
+        connect(dbusIface, &QDBusConnectionInterface::serviceUnregistered, this, [=, this](const QString &serviceName) {
             // Close all running jobs as we're defunct now
             if (serviceName == jobViewServerService || serviceName == kuiserverService) {
                 qCDebug(NOTIFICATIONMANAGER) << "Lost ownership of" << serviceName << "service";
