@@ -11,8 +11,10 @@
 #include <KSharedConfig>
 
 #include <QDateTime>
-#include <QScopedPointer>
 #include <QString>
+#include <memory>
+
+#include <qqmlregistration.h>
 
 #include "notificationmanager_export.h"
 
@@ -32,6 +34,7 @@ namespace NotificationManager
 class NOTIFICATIONMANAGER_EXPORT Settings : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
     /**
      * Whether to show critical notification popups in do not disturb mode.
@@ -334,7 +337,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 } // namespace NotificationManager
