@@ -25,7 +25,10 @@ AbstractWindowTasksModel::AbstractWindowTasksModel(QObject *parent)
 
     auto screenAdded = [this](const QScreen *screen) {
         connect(screen, &QScreen::geometryChanged, this, [this]() {
-            Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0), QVector<int>{ScreenGeometry});
+            if (rowCount() == 0) {
+                return;
+            }
+            Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0), QList<int>{ScreenGeometry});
         });
     };
 
