@@ -41,6 +41,12 @@ void TaskToolsTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
 
+    // Set up applications.menu so that kservice works
+    const QString menusDir = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String{"/menus"};
+    QDir(menusDir).removeRecursively();
+    QDir(menusDir).mkpath(QStringLiteral("."));
+    QFile::copy(QFINDTESTDATA("../../../menu/desktop/plasma-applications.menu"), menusDir + QLatin1String("/applications.menu"));
+
     const QString dataDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
 
     qputenv("XDG_DATA_DIRS", dataDir.toUtf8());
@@ -48,7 +54,7 @@ void TaskToolsTest::initTestCase()
     // Make sure we start with a clean dir
     QVERIFY(QDir(dataDir).removeRecursively());
     QVERIFY(QDir(dataDir).mkpath(QLatin1String("applications")));
-    QVERIFY(QDir(dataDir).mkpath(QLatin1String("kservices5")));
+    QVERIFY(QDir(dataDir).mkpath(QLatin1String("kservices6")));
 
     // Add our applications
     QFile::copy(QFINDTESTDATA("data/applications/org.kde.dolphin.desktop"), dataDir + QLatin1String("/applications/org.kde.dolphin.desktop"));
@@ -65,7 +71,7 @@ void TaskToolsTest::initTestCase()
                 dataDir + QLatin1String("/applications/brave-efmjfjelnicpmdcmfikempdhlmainjcb-Default.desktop"));
     QFile::copy(QFINDTESTDATA("data/applications/marisa..desktop"), dataDir + QLatin1String("/applications/marisa..desktop"));
 
-    QFile::copy(QFINDTESTDATA("data/applications/kcm_kdeconnect.desktop"), dataDir + QLatin1String("/kservices5/kcm_kdeconnect.desktop"));
+    QFile::copy(QFINDTESTDATA("data/applications/kcm_kdeconnect.desktop"), dataDir + QLatin1String("/kservices6/kcm_kdeconnect.desktop"));
 
     QFile::remove(KSycoca::absoluteFilePath());
     KSycoca::self()->ensureCacheValid();
@@ -178,8 +184,8 @@ void TaskToolsTest::testWindowUrlFromMetadata_data()
                                   << QUrl("applications:brave-efmjfjelnicpmdcmfikempdhlmainjcb-Default.desktop");
 
     const QString dataDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    QTest::addRow("kcm_kdeconnect") << dataDir + QLatin1String("/kservices5/kcm_kdeconnect") << QString()
-                                    << QUrl::fromLocalFile(dataDir + QLatin1String("/kservices5/kcm_kdeconnect.desktop"));
+    QTest::addRow("kcm_kdeconnect") << dataDir + QLatin1String("/kservices6/kcm_kdeconnect") << QString()
+                                    << QUrl::fromLocalFile(dataDir + QLatin1String("/kservices6/kcm_kdeconnect.desktop"));
 
     QTest::addRow("Empty appId and xWindowsWMClassName, don't match marisa..desktop") << QString() << QString() << QUrl();
 
