@@ -6,9 +6,10 @@
 
 #include <array>
 
-#include <QX11Info>
+#include <private/qtx11extras_p.h>
 
 #include <KActivities/Consumer>
+#include <KWindowInfo>
 
 #include <xcb/xcb.h>
 #include <xcb/xproto.h>
@@ -56,6 +57,7 @@ private:
 
 void XWindowTasksModelTest::initTestCase()
 {
+    TestUtils::initTestCase();
     if (!KWindowSystem::isPlatformX11()) {
         QSKIP("Test is not running on X11.");
     }
@@ -216,7 +218,7 @@ void XWindowTasksModelTest::test_modelData()
         QVERIFY(!oldWindowIcon.isNull());
         window->setIcon(QIcon(QFINDTESTDATA("data/windows/samplewidgetwindow.png")));
         QVERIFY(dataChangedSpy.wait());
-        QVERIFY(dataChangedSpy.takeLast().at(2).value<QVector<int>>().contains(Qt::DecorationRole));
+        QVERIFY(dataChangedSpy.takeLast().at(2).value<QList<int>>().contains(Qt::DecorationRole));
 
         const QIcon newWindowIcon = index.data(Qt::DecorationRole).value<QIcon>();
         QVERIFY(!newWindowIcon.isNull());
@@ -225,7 +227,7 @@ void XWindowTasksModelTest::test_modelData()
 
         window->setIcon(QIcon());
         QVERIFY(dataChangedSpy.wait());
-        QVERIFY(dataChangedSpy.takeLast().at(2).value<QVector<int>>().contains(Qt::DecorationRole));
+        QVERIFY(dataChangedSpy.takeLast().at(2).value<QList<int>>().contains(Qt::DecorationRole));
     } // END Icon
 
     const NET::Properties windowInfoFlags =
@@ -304,14 +306,14 @@ void XWindowTasksModelTest::test_isMinimized()
     dataChangedSpy.wait();
     // There can be more than one dataChanged signal being emitted due to caching
     QTRY_VERIFY(std::any_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsMinimized);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsMinimized);
     }));
     // The model doesn't notify data change stored under IsHidden role
     QTRY_VERIFY(std::none_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsHidden);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsHidden);
     }));
     QTRY_VERIFY(std::any_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsActive);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsActive);
     }));
     QTRY_VERIFY(index.data(AbstractTasksModel::IsMinimized).toBool());
     QTRY_VERIFY(index.data(AbstractTasksModel::IsHidden).toBool());
@@ -324,13 +326,13 @@ void XWindowTasksModelTest::test_isMinimized()
     window->requestActivate();
     dataChangedSpy.wait();
     QTRY_VERIFY(std::any_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsMinimized);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsMinimized);
     }));
     QVERIFY(std::none_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsHidden);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsHidden);
     }));
     QTRY_VERIFY(std::any_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsActive);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsActive);
     }));
     QTRY_VERIFY(!index.data(AbstractTasksModel::IsMinimized).toBool());
     QTRY_VERIFY(!index.data(AbstractTasksModel::IsHidden).toBool());
@@ -363,7 +365,7 @@ void XWindowTasksModelTest::test_lastActivated()
     window->showMinimized();
     dataChangedSpy.wait();
     QTRY_VERIFY(std::any_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::IsMinimized);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::IsMinimized);
     }));
     QTRY_VERIFY(index.data(AbstractTasksModel::IsMinimized).toBool());
 
@@ -376,7 +378,7 @@ void XWindowTasksModelTest::test_lastActivated()
     QTRY_VERIFY(!index.data(AbstractTasksModel::IsMinimized).toBool());
     // The model doesn't notify data change stored under LastActivated role
     QTRY_VERIFY(std::none_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [](const QVariantList &list) {
-        return list.at(2).value<QVector<int>>().contains(AbstractTasksModel::LastActivated);
+        return list.at(2).value<QList<int>>().contains(AbstractTasksModel::LastActivated);
     }));
     qDebug() << lastActivatedTime.msecsSinceStartOfDay() << index.data(AbstractTasksModel::LastActivated).toTime().msecsSinceStartOfDay();
     QVERIFY(std::abs(lastActivatedTime.msecsSinceStartOfDay() - index.data(AbstractTasksModel::LastActivated).toTime().msecsSinceStartOfDay()) < 1000);
@@ -473,7 +475,7 @@ void XWindowTasksModelTest::test_windowState()
         QCoreApplication::processEvents();
 
         QTRY_VERIFY(std::any_of(dataChangedSpy.cbegin(), dataChangedSpy.cend(), [role](const QVariantList &list) {
-            return list.at(2).value<QVector<int>>().contains(role);
+            return list.at(2).value<QList<int>>().contains(role);
         }));
         QVERIFY(!index.data(role).toBool());
         success = true;
