@@ -91,13 +91,13 @@ void LauncherTasksModel::Private::init()
         // Emit changes of all roles satisfied from app data cache.
         Q_EMIT q->dataChanged(q->index(0, 0),
                               q->index(launchersOrder.count() - 1, 0),
-                              QVector<int>{Qt::DisplayRole,
-                                           Qt::DecorationRole,
-                                           AbstractTasksModel::AppId,
-                                           AbstractTasksModel::AppName,
-                                           AbstractTasksModel::GenericName,
-                                           AbstractTasksModel::LauncherUrl,
-                                           AbstractTasksModel::LauncherUrlWithoutIcon});
+                              QList<int>{Qt::DisplayRole,
+                                         Qt::DecorationRole,
+                                         AbstractTasksModel::AppId,
+                                         AbstractTasksModel::AppName,
+                                         AbstractTasksModel::GenericName,
+                                         AbstractTasksModel::LauncherUrl,
+                                         AbstractTasksModel::LauncherUrlWithoutIcon});
     });
 
     QObject::connect(KSycoca::self(), &KSycoca::databaseChanged, q, [this]() {
@@ -330,7 +330,7 @@ QVariant LauncherTasksModel::data(const QModelIndex &index, int role) const
         return false;
     }
 
-    return QVariant();
+    return AbstractTasksModel::data(index, role);
 }
 
 int LauncherTasksModel::rowCount(const QModelIndex &parent) const
@@ -355,7 +355,7 @@ QStringList LauncherTasksModel::launcherList() const
     // Serializing the launchers
     QStringList result;
 
-    for (const auto &launcher : qAsConst(d->launchersOrder)) {
+    for (const auto &launcher : std::as_const(d->launchersOrder)) {
         const auto &activities = d->activitiesForLauncher[launcher];
 
         QString serializedLauncher;
@@ -401,7 +401,7 @@ void LauncherTasksModel::setLauncherList(const QStringList &serializedLaunchers)
             // Filter out invalid activities
             const auto allActivities = d->activitiesConsumer.activities();
             ActivitiesSet validActivities;
-            for (const auto &activity : qAsConst(activities)) {
+            for (const auto &activity : std::as_const(activities)) {
                 if (allActivities.contains(activity)) {
                     validActivities << activity;
                 }
