@@ -10,23 +10,77 @@
 
 #include <KConfigGroup>
 #include <KConfigWatcher>
-#include <KWayland/Client/connection_thread.h>
-#include <KWayland/Client/plasmawindowmanagement.h>
-#include <KWayland/Client/registry.h>
+
+#include <qwayland-plasma-window-management.h>
 
 #include <QDebug>
 #include <QTimer>
 #include <QUrl>
+#include <QtWaylandClient/QWaylandClientExtensionTemplate>
 
 namespace TaskManager
 {
+
+class PlasmaActivation : public QObject, public QtWayland::org_kde_plasma_activation
+{
+    Q_OBJECT
+public:
+    PlasmaActivation(::org_kde_plasma_activation *object)
+        : QtWayland::org_kde_plasma_activation(object)
+    {
+    }
+    ~PlasmaActivation() override
+    {
+        destroy();
+    }
+    void org_kde_plasma_activation_app_id(const QString &app_id) override
+    {
+        Q_EMIT appId(app_id);
+    }
+    void org_kde_plasma_activation_finished() override
+    {
+        Q_EMIT finished();
+    }
+Q_SIGNALS:
+    void appId(const QString &appId);
+    void finished();
+};
+class PlasmaActivationFeedback : public QWaylandClientExtensionTemplate<PlasmaActivationFeedback>, public QtWayland::org_kde_plasma_activation_feedback
+{
+    Q_OBJECT
+public:
+    PlasmaActivationFeedback()
+        : QWaylandClientExtensionTemplate(1)
+    {
+        connect(this, &QWaylandClientExtension::activeChanged, this, [this] {
+            if (!isActive()) {
+                destroy();
+            }
+        });
+    }
+    ~PlasmaActivationFeedback()
+    {
+        if (isActive()) {
+            destroy();
+        }
+    }
+Q_SIGNALS:
+    void newActivation(PlasmaActivation *activation);
+
+protected:
+    void org_kde_plasma_activation_feedback_activation(::org_kde_plasma_activation *id) override
+    {
+        Q_EMIT newActivation(new PlasmaActivation(id));
+    }
+};
+
 class Q_DECL_HIDDEN WaylandStartupTasksModel::Private
 {
 public:
     Private(WaylandStartupTasksModel *q);
 
-    void addActivation(KWayland::Client::PlasmaActivation *activation);
-    void removeActivation(KWayland::Client::PlasmaActivation *activation);
+    void addActivation(PlasmaActivation *activation);
+    void removeActivation(PlasmaActivation *activation);
 
     void init();
     void loadConfig();
@@ -36,14 +90,13 @@ public:
         QIcon icon;
         QString applicationId;
         QUrl launcherUrl;
-        KWayland::Client::PlasmaActivation *activation;
+        std::unique_ptr<PlasmaActivation> activation;
     };
 
     WaylandStartupTasksModel *q;
     KConfigWatcher::Ptr configWatcher = nullptr;
-    KWayland::Client::PlasmaActivationFeedback *feedback = nullptr;
-    KWayland::Client::Registry *registry = nullptr;
-    QVector<Startup> startups;
+    std::unique_ptr<PlasmaActivationFeedback> feedback = nullptr;
+    std::vector<Startup> startups;
     std::chrono::seconds startupTimeout = std::chrono::seconds::zero();
 };
 
@@ -67,13 +120,9 @@ void WaylandStartupTasksModel::Private::loadConfig()
     KConfigGroup feedbackConfig(configWatcher->config(), "FeedbackStyle");
 
     if (!feedbackConfig.readEntry("TaskbarButton", true)) {
-        delete feedback;
-        feedback = nullptr;
-        delete registry;
-        registry = nullptr;
-
         q->beginResetModel();
         startups.clear();
+        feedback.reset();
         q->endResetModel();
         return;
     }
@@ -81,38 +130,24 @@ void WaylandStartupTasksModel::Private::loadConfig()
     const KConfigGroup taskbarButtonConfig(configWatcher->config(), "TaskbarButtonSettings");
     startupTimeout = std::chrono::seconds(taskbarButtonConfig.readEntry("Timeout", 5));
 
-    if (!registry) {
-        using namespace KWayland::Client;
+    feedback = std::make_unique<PlasmaActivationFeedback>();
 
-        ConnectionThread *connection = ConnectionThread::fromApplication(q);
-        if (!connection) {
-            return;
+    QObject::connect(feedback.get(), &PlasmaActivationFeedback::activeChanged, q, [this] {
+        if (!feedback->isActive()) {
+            q->beginResetModel();
+            startups.clear();
+            q->endResetModel();
         }
+    });
 
-        registry = new Registry(q);
-        registry->create(connection);
-
-        QObject::connect(registry, &Registry::plasmaActivationFeedbackAnnounced, q, [this](quint32 name, quint32 version) {
-            feedback = registry->createPlasmaActivationFeedback(name, version, q);
-
-            QObject::connect(feedback, &PlasmaActivationFeedback::interfaceAboutToBeReleased, q, [this] {
-                q->beginResetModel();
-                startups.clear();
-                q->endResetModel();
-            });
-
-            QObject::connect(feedback, &PlasmaActivationFeedback::activation, q, [this](PlasmaActivation *activation) {
-                addActivation(activation);
-            });
-        });
-
-        registry->setup();
-    }
+    QObject::connect(feedback.get(), &PlasmaActivationFeedback::newActivation, q, [this](PlasmaActivation *activation) {
+        addActivation(activation);
+    });
 }
 
-void WaylandStartupTasksModel::Private::addActivation(KWayland::Client::PlasmaActivation *activation)
+void WaylandStartupTasksModel::Private::addActivation(PlasmaActivation *activation)
 {
-    QObject::connect(activation, &KWayland::Client::PlasmaActivation::applicationId, q, [this, activation](const QString &appId) {
+    QObject::connect(activation, &PlasmaActivation::appId, q, [this, activation](const QString &appId) {
         // The application id is guaranteed to be the desktop filename without ".desktop"
         const QString desktopFileName = appId + QLatin1String(".desktop");
         const QString desktopFilePath = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, desktopFileName);
@@ -124,14 +159,14 @@ void WaylandStartupTasksModel::Private::addActivation(KWayland::Client::PlasmaAc
         const QUrl launcherUrl(QStringLiteral("applications:") + desktopFileName);
         const AppData appData = appDataFromUrl(QUrl::fromLocalFile(desktopFilePath));
 
-        const int count = startups.count();
+        const int count = startups.size();
         q->beginInsertRows(QModelIndex(), count, count);
-        startups.append(Startup{
+        startups.push_back(Startup{
             .name = appData.name,
             .icon = appData.icon,
             .applicationId = appId,
             .launcherUrl = launcherUrl,
-            .activation = activation,
+            .activation = std::unique_ptr<PlasmaActivation>(activation),
         });
         q->endInsertRows();
 
@@ -144,25 +179,23 @@ void WaylandStartupTasksModel::Private::addActivation(KWayland::Client::PlasmaAc
         timeoutTimer->start(startupTimeout);
     });
 
-    QObject::connect(activation, &KWayland::Client::PlasmaActivation::finished, q, [this, activation]() {
+    QObject::connect(activation, &PlasmaActivation::finished, q, [this, activation]() {
         removeActivation(activation);
     });
 }
 
-void WaylandStartupTasksModel::Private::removeActivation(KWayland::Client::PlasmaActivation *activation)
+void WaylandStartupTasksModel::Private::removeActivation(PlasmaActivation *activation)
 {
-    int position = -1;
-    for (int i = 0; i < startups.count(); ++i) {
-        if (startups[i].activation == activation) {
-            position = i;
-            break;
-        }
-    }
-    if (position != -1) {
-        q->beginRemoveRows(QModelIndex(), position, position);
-        startups.removeAt(position);
-        q->endRemoveRows();
+    auto it = std::find_if(startups.begin(), startups.end(), [activation](const Startup &startup) {
+        return startup.activation.get() == activation;
+    });
+    if (it == startups.end()) {
+        return;
     }
+    const int position = std::distance(startups.begin(), it);
+    q->beginRemoveRows(QModelIndex(), position, position);
+    startups.erase(it);
+    q->endRemoveRows();
 }
 
 WaylandStartupTasksModel::WaylandStartupTasksModel(QObject *parent)
@@ -178,7 +211,7 @@ WaylandStartupTasksModel::~WaylandStartupTasksModel()
 
 QVariant WaylandStartupTasksModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid() || index.row() >= d->startups.count()) {
+    if (!index.isValid() || index.row() >= d->startups.size()) {
         return QVariant();
     }
 
@@ -197,14 +230,18 @@ QVariant WaylandStartupTasksModel::data(const QModelIndex &index, int role) cons
         return true;
     } else if (role == CanLaunchNewInstance) {
         return false;
+    } else if (role == IsOnAllVirtualDesktops) {
+        return true;
     }
 
-    return QVariant();
+    return AbstractTasksModel::data(index, role);
 }
 
 int WaylandStartupTasksModel::rowCount(const QModelIndex &parent) const
 {
-    return parent.isValid() ? 0 : d->startups.count();
+    return parent.isValid() ? 0 : d->startups.size();
 }
 
 } // namespace TaskManager
+
+#include "waylandstartuptasksmodel.moc"
