@@ -21,19 +21,36 @@
 #include <QBuffer>
 #include <QDir>
 #include <QFile>
+#include <QGuiApplication>
 #include <QIcon>
 #include <QSet>
 #include <QTimer>
 #include <QUrlQuery>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+
 #include <chrono>
 
+#include <X11/Xlib.h>
+
 using namespace std::chrono_literals;
 
+namespace X11Info
+{
+[[nodiscard]] inline auto display()
+{
+    return qGuiApp->nativeInterface<QNativeInterface::QX11Application>()->display();
+}
+
+[[nodiscard]] inline auto connection()
+{
+    return qGuiApp->nativeInterface<QNativeInterface::QX11Application>()->connection();
+}
+
+[[nodiscard]] inline Window appRootWindow()
+{
+    return DefaultRootWindow(display());
+}
+}
+
 namespace TaskManager
 {
 static const NET::Properties windowInfoFlags =
@@ -47,7 +64,7 @@ public:
     Private(XWindowTasksModel *q);
     ~Private();
 
-    QVector<WId> windows;
+    QList<WId> windows;
 
     // key=transient child, value=leader
     QHash<WId, WId> transients;
@@ -70,7 +87,7 @@ public:
     void removeWindow(WId window);
     void windowChanged(WId window, NET::Properties properties, NET::Properties2 properties2);
     void transientChanged(WId window, NET::Properties properties, NET::Properties2 properties2);
-    void dataChanged(WId window, const QVector<int> &roles);
+    void dataChanged(WId window, const QList<int> &roles);
 
     KWindowInfo *windowInfo(WId window);
     AppData appData(WId window);
@@ -111,14 +128,14 @@ void XWindowTasksModel::Private::init()
         // Emit changes of all roles satisfied from app data cache.
         Q_EMIT q->dataChanged(q->index(0, 0),
                               q->index(windows.count() - 1, 0),
-                              QVector<int>{Qt::DecorationRole,
-                                           AbstractTasksModel::AppId,
-                                           AbstractTasksModel::AppName,
-                                           AbstractTasksModel::GenericName,
-                                           AbstractTasksModel::LauncherUrl,
-                                           AbstractTasksModel::LauncherUrlWithoutIcon,
-                                           AbstractTasksModel::CanLaunchNewInstance,
-                                           AbstractTasksModel::SkipTaskbar});
+                              QList<int>{Qt::DecorationRole,
+                                         AbstractTasksModel::AppId,
+                                         AbstractTasksModel::AppName,
+                                         AbstractTasksModel::GenericName,
+                                         AbstractTasksModel::LauncherUrl,
+                                         AbstractTasksModel::LauncherUrlWithoutIcon,
+                                         AbstractTasksModel::CanLaunchNewInstance,
+                                         AbstractTasksModel::SkipTaskbar});
     };
 
     cachedStackingOrder = KX11Extras::stackingOrder();
@@ -177,13 +194,13 @@ void XWindowTasksModel::Private::init()
         int row = windows.indexOf(oldActiveWindow);
 
         if (row != -1) {
-            dataChanged(oldActiveWindow, QVector<int>{IsActive});
+            dataChanged(oldActiveWindow, QList<int>{IsActive});
         }
 
         row = windows.indexOf(window);
 
         if (row != -1) {
-            dataChanged(window, QVector<int>{IsActive});
+            dataChanged(window, QList<int>{IsActive});
         }
     });
 
@@ -195,7 +212,7 @@ void XWindowTasksModel::Private::init()
         cachedStackingOrder = KX11Extras::stackingOrder();
         Q_ASSERT(q->hasIndex(0, 0));
         Q_ASSERT(q->hasIndex(q->rowCount() - 1, 0));
-        Q_EMIT q->dataChanged(q->index(0, 0), q->index(q->rowCount() - 1, 0), QVector<int>{StackingOrder});
+        Q_EMIT q->dataChanged(q->index(0, 0), q->index(q->rowCount() - 1, 0), QList<int>{StackingOrder});
     });
 
     activeWindow = KX11Extras::activeWindow();
@@ -221,13 +238,13 @@ void XWindowTasksModel::Private::addWindow(WId window)
     const WId leader = info.transientFor();
 
     // Handle transient.
-    if (leader > 0 && leader != window && leader != QX11Info::appRootWindow() && !transients.contains(window) && windows.contains(leader)) {
+    if (leader > 0 && leader != window && leader != X11Info::appRootWindow() && !transients.contains(window) && windows.contains(leader)) {
         transients.insert(window, leader);
 
         // Update demands attention state for leader.
         if (info.hasState(NET::DemandsAttention) && windows.contains(leader)) {
             transientsDemandingAttention.insert(leader, window);
-            dataChanged(leader, QVector<int>{IsDemandingAttention});
+            dataChanged(leader, QList<int>{IsDemandingAttention});
         }
 
         return;
@@ -265,7 +282,7 @@ void XWindowTasksModel::Private::removeWindow(WId window)
 
             if (leader != XCB_WINDOW_NONE) {
                 transientsDemandingAttention.remove(leader, window);
-                dataChanged(leader, QVector<int>{IsDemandingAttention});
+                dataChanged(leader, QList<int>{IsDemandingAttention});
             }
         }
     }
@@ -289,10 +306,10 @@ void XWindowTasksModel::Private::transientChanged(WId window, NET::Properties pr
         if (info.hasState(NET::DemandsAttention)) {
             if (!transientsDemandingAttention.values(leader).contains(window)) {
                 transientsDemandingAttention.insert(leader, window);
-                dataChanged(leader, QVector<int>{IsDemandingAttention});
+                dataChanged(leader, QList<int>{IsDemandingAttention});
             }
         } else if (transientsDemandingAttention.remove(window)) {
-            dataChanged(leader, QVector<int>{IsDemandingAttention});
+            dataChanged(leader, QList<int>{IsDemandingAttention});
         }
         // Leader might have changed.
     } else if (properties2 & NET::WM2TransientFor) {
@@ -307,8 +324,8 @@ void XWindowTasksModel::Private::transientChanged(WId window, NET::Properties pr
                 if (leader != oldLeader) {
                     transientsDemandingAttention.remove(oldLeader, window);
                     transientsDemandingAttention.insert(leader, window);
-                    dataChanged(oldLeader, QVector<int>{IsDemandingAttention});
-                    dataChanged(leader, QVector<int>{IsDemandingAttention});
+                    dataChanged(oldLeader, QList<int>{IsDemandingAttention});
+                    dataChanged(leader, QList<int>{IsDemandingAttention});
                 }
             }
         }
@@ -324,7 +341,7 @@ void XWindowTasksModel::Private::windowChanged(WId window, NET::Properties prope
 
     bool wipeInfoCache = false;
     bool wipeAppDataCache = false;
-    QVector<int> changedRoles;
+    QList<int> changedRoles;
 
     if (properties & (NET::WMPid) || properties2 & (NET::WM2DesktopFileName | NET::WM2WindowClass)) {
         wipeInfoCache = true;
@@ -405,7 +422,7 @@ void XWindowTasksModel::Private::windowChanged(WId window, NET::Properties prope
     }
 }
 
-void XWindowTasksModel::Private::dataChanged(WId window, const QVector<int> &roles)
+void XWindowTasksModel::Private::dataChanged(WId window, const QList<int> &roles)
 {
     const int i = windows.indexOf(window);
 
@@ -675,8 +692,11 @@ QVariant XWindowTasksModel::data(const QModelIndex &index, int role) const
     } else if (role == IsOnAllVirtualDesktops) {
         return d->windowInfo(window)->onAllDesktops();
     } else if (role == Geometry) {
+        // Both the topLeft position and the size belong to the non-scaled coordinate system
         return d->windowInfo(window)->frameGeometry();
     } else if (role == ScreenGeometry) {
+        // The topLeft position belongs to the non-scaled coordinate system
+        // The size belongs to the scaled coordinate system, which means the size is already divided by DPR
         return screenGeometry(d->windowInfo(window)->frameGeometry().center());
     } else if (role == Activities) {
         return d->windowInfo(window)->activities();
@@ -705,7 +725,7 @@ QVariant XWindowTasksModel::data(const QModelIndex &index, int role) const
         return canLauchNewInstance(d->appData(window));
     }
 
-    return QVariant();
+    return AbstractTasksModel::data(index, role);
 }
 
 int XWindowTasksModel::rowCount(const QModelIndex &parent) const
@@ -733,7 +753,7 @@ void XWindowTasksModel::requestActivate(const QModelIndex &index)
             // TODO: do we need to check all the transients for shaded?"
         } else if (!d->transients.isEmpty()) {
             const auto transients = d->transients.keys(window);
-            for (const auto transient : qAsConst(transients)) {
+            for (const auto transient : std::as_const(transients)) {
                 KWindowInfo info(transient, NET::WMState, NET::WM2TransientFor);
                 if (info.valid(true) && info.hasState(NET::Shaded)) {
                     window = transient;
@@ -770,7 +790,7 @@ void XWindowTasksModel::requestClose(const QModelIndex &index)
         return;
     }
 
-    NETRootInfo ri(QX11Info::connection(), NET::CloseWindow);
+    NETRootInfo ri(X11Info::connection(), NET::CloseWindow);
     ri.closeWindowRequest(d->windows.at(index.row()));
 }
 
@@ -796,7 +816,7 @@ void XWindowTasksModel::requestMove(const QModelIndex &index)
 
     const QRect &geom = info->geometry();
 
-    NETRootInfo ri(QX11Info::connection(), NET::WMMoveResize);
+    NETRootInfo ri(X11Info::connection(), NET::WMMoveResize);
     ri.moveResizeRequest(window, geom.center().x(), geom.center().y(), NET::Move);
 }
 
@@ -822,7 +842,7 @@ void XWindowTasksModel::requestResize(const QModelIndex &index)
 
     const QRect &geom = info->geometry();
 
-    NETRootInfo ri(QX11Info::connection(), NET::WMMoveResize);
+    NETRootInfo ri(X11Info::connection(), NET::WMMoveResize);
     ri.moveResizeRequest(window, geom.bottomRight().x(), geom.bottomRight().y(), NET::BottomRight);
 }
 
@@ -873,7 +893,7 @@ void XWindowTasksModel::requestToggleMaximized(const QModelIndex &index)
         KX11Extras::unminimizeWindow(window);
     }
 
-    NETWinInfo ni(QX11Info::connection(), window, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
+    NETWinInfo ni(X11Info::connection(), window, X11Info::appRootWindow(), NET::WMState, NET::Properties2());
 
     if (restore) {
         ni.setState(NET::States(), NET::Max);
@@ -895,7 +915,7 @@ void XWindowTasksModel::requestToggleKeepAbove(const QModelIndex &index)
     const WId window = d->windows.at(index.row());
     const KWindowInfo *info = d->windowInfo(window);
 
-    NETWinInfo ni(QX11Info::connection(), window, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
+    NETWinInfo ni(X11Info::connection(), window, X11Info::appRootWindow(), NET::WMState, NET::Properties2());
 
     if (info->hasState(NET::KeepAbove)) {
         ni.setState(NET::States(), NET::KeepAbove);
@@ -913,7 +933,7 @@ void XWindowTasksModel::requestToggleKeepBelow(const QModelIndex &index)
     const WId window = d->windows.at(index.row());
     const KWindowInfo *info = d->windowInfo(window);
 
-    NETWinInfo ni(QX11Info::connection(), window, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
+    NETWinInfo ni(X11Info::connection(), window, X11Info::appRootWindow(), NET::WMState, NET::Properties2());
 
     if (info->hasState(NET::KeepBelow)) {
         ni.setState(NET::States(), NET::KeepBelow);
@@ -931,7 +951,7 @@ void XWindowTasksModel::requestToggleFullScreen(const QModelIndex &index)
     const WId window = d->windows.at(index.row());
     const KWindowInfo *info = d->windowInfo(window);
 
-    NETWinInfo ni(QX11Info::connection(), window, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
+    NETWinInfo ni(X11Info::connection(), window, X11Info::appRootWindow(), NET::WMState, NET::Properties2());
 
     if (info->hasState(NET::FullScreen)) {
         ni.setState(NET::States(), NET::FullScreen);
@@ -949,7 +969,7 @@ void XWindowTasksModel::requestToggleShaded(const QModelIndex &index)
     const WId window = d->windows.at(index.row());
     const KWindowInfo *info = d->windowInfo(window);
 
-    NETWinInfo ni(QX11Info::connection(), window, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
+    NETWinInfo ni(X11Info::connection(), window, X11Info::appRootWindow(), NET::WMState, NET::Properties2());
 
     if (info->hasState(NET::Shaded)) {
         ni.setState(NET::States(), NET::Shaded);
@@ -1015,7 +1035,7 @@ void XWindowTasksModel::requestNewVirtualDesktop(const QModelIndex &index)
         return;
     }
 
-    NETRootInfo ri(QX11Info::connection(), NET::NumberOfDesktops);
+    NETRootInfo ri(X11Info::connection(), NET::NumberOfDesktops);
     ri.setNumberOfDesktops(desktop);
 
     KX11Extras::setOnDesktop(window, desktop);
@@ -1046,7 +1066,7 @@ void XWindowTasksModel::requestPublishDelegateGeometry(const QModelIndex &index,
         return;
     }
 
-    NETWinInfo ni(QX11Info::connection(), window, QX11Info::appRootWindow(), NET::Properties(), NET::Properties2());
+    NETWinInfo ni(X11Info::connection(), window, X11Info::appRootWindow(), NET::Properties(), NET::Properties2());
     NETRect rect;
 
     if (geometry.isValid()) {
@@ -1078,17 +1098,7 @@ WId XWindowTasksModel::winIdFromMimeData(const QMimeData *mimeData, bool *ok)
     QByteArray data(mimeData->data(Private::mimeType()));
     WId id;
     if (data.size() != sizeof(WId)) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 2)
-        // Workaround for https://bugreports.qt.io/browse/QTBUG-71922
-        QString idString = QString::fromUtf8(data);
-        if (idString.startsWith(QLatin1String("strnum-"))) {
-            id = QString::fromUtf8(data).mid(7).toUInt();
-        } else {
-            return 0;
-        }
-#else
         return 0;
-#endif
     } else {
         memcpy(&id, data.data(), sizeof(WId));
     }
