@@ -23,11 +23,7 @@
 #include <QQuickView>
 #include <QStandardPaths>
 #include <QTimer>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 #include <KAuthorized>
 #include <KConfigGroup>
@@ -70,11 +66,10 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow *parent, KWorkSpace::ShutdownType sdtype,
             w->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityExclusive);
             w->setExclusiveZone(-1);
             w->setLayer(LayerShellQt::Window::LayerOverlay);
-            w->setDesiredOutput(screen);
         }
     }
 
-    setResizeMode(KQuickAddons::QuickViewSharedEngine::SizeRootObjectToView);
+    setResizeMode(PlasmaQuick::QuickViewSharedEngine::SizeRootObjectToView);
 
     // Qt doesn't set this on unmanaged windows
     // FIXME: or does it?
@@ -146,7 +141,8 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow *parent, KWorkSpace::ShutdownType sdtype,
     context->setContextProperty(QStringLiteral("rebootOptions"), rebootOptionsMap);
 
     // engine stuff
-    engine()->rootContext()->setContextObject(new KLocalizedContext(engine()));
+    engine()->rootContext()->setContextObject(new KLocalizedContext(engine().get()));
+    engine()->setProperty("_kirigamiTheme", QStringLiteral("KirigamiPlasmaStyle"));
 }
 
 void KSMShutdownDlg::init(const KPackage::Package &package)
@@ -191,7 +187,9 @@ void KSMShutdownDlg::init(const KPackage::Package &package)
     }
     requestActivate();
 
-    KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+    if (KWindowSystem::isPlatformX11()) {
+        KX11Extras::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+    }
 
     setKeyboardGrabEnabled(true);
     KWindowEffects::enableBlurBehind(this, true);
@@ -199,7 +197,7 @@ void KSMShutdownDlg::init(const KPackage::Package &package)
 
 void KSMShutdownDlg::resizeEvent(QResizeEvent *e)
 {
-    KQuickAddons::QuickViewSharedEngine::resizeEvent(e);
+    PlasmaQuick::QuickViewSharedEngine::resizeEvent(e);
 
     if (KX11Extras::compositingActive()) {
         // TODO: reenable window mask when we are without composite?
