@@ -33,11 +33,14 @@ void HolidaysEventsPlugin::loadEventsForDateRange(const QDate &startDate, const
 {
     if (!m_lastData.empty() && m_lastStartDate == startDate && m_lastEndDate == endDate) {
         Q_EMIT dataReady(m_lastData);
+        Q_EMIT subLabelReady(m_lastSubLabelData);
         return;
     }
 
     QMultiHash<QDate, CalendarEvents::EventData> data;
-    for (KHolidays::HolidayRegion *region : qAsConst(m_regions)) {
+    QHash<QDate, CalendarEvents::CalendarEventsPlugin::SubLabel> subLabelData;
+
+    for (KHolidays::HolidayRegion *region : std::as_const(m_regions)) {
         const KHolidays::Holiday::List holidays = region->rawHolidays(startDate, endDate);
 
         for (const KHolidays::Holiday &holiday : holidays) {
@@ -53,14 +56,23 @@ void HolidaysEventsPlugin::loadEventsForDateRange(const QDate &startDate, const
             for (QDate d = holiday.observedStartDate(); d <= holiday.observedEndDate(); d = d.addDays(1)) {
                 data.insert(d, eventData);
             }
+
+            if (!subLabelData.contains(holiday.observedStartDate()) && !holiday.name().isEmpty()) {
+                CalendarEvents::CalendarEventsPlugin::SubLabel sublabel;
+                sublabel.dayLabel = holiday.name();
+                sublabel.priority = CalendarEvents::CalendarEventsPlugin::SubLabelPriority::Default;
+                subLabelData.insert(holiday.observedStartDate(), sublabel);
+            }
         }
     }
 
     m_lastStartDate = startDate;
     m_lastEndDate = endDate;
     m_lastData = data;
+    m_lastSubLabelData = subLabelData;
 
     Q_EMIT dataReady(m_lastData);
+    Q_EMIT subLabelReady(m_lastSubLabelData);
 }
 
 void HolidaysEventsPlugin::updateSettings(const KConfigGroup &regionsConfig)
