@@ -6,6 +6,8 @@
 
 #include "appstreamrunner.h"
 
+#include <unordered_set>
+
 #include <AppStreamQt/icon.h>
 
 #include <QDebug>
@@ -18,27 +20,17 @@
 #include <KLocalizedString>
 #include <KSycoca>
 
-#include <set>
-
 #include "debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(InstallerRunner, "plasma-runner-appstream.json")
 
-InstallerRunner::InstallerRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, metaData, args)
+InstallerRunner::InstallerRunner(QObject *parent, const KPluginMetaData &metaData)
+    : KRunner::AbstractRunner(parent, metaData)
 {
-    setObjectName(QStringLiteral("Installation Suggestions"));
-    // We want to give the other runners time to check if there are matching applications already installed
-    setPriority(AbstractRunner::LowestPriority);
-
-    addSyntax(Plasma::RunnerSyntax(":q:", i18n("Looks for non-installed components according to :q:")));
+    addSyntax(":q:", i18n("Looks for non-installed components according to :q:"));
     setMinLetterCount(3);
 }
 
-InstallerRunner::~InstallerRunner()
-{
-}
-
 static QIcon componentIcon(const AppStream::Component &comp)
 {
     QIcon ret;
@@ -68,13 +60,11 @@ static QIcon componentIcon(const AppStream::Component &comp)
     return ret;
 }
 
-void InstallerRunner::match(Plasma::RunnerContext &context)
+void InstallerRunner::match(KRunner::RunnerContext &context)
 {
     // Give the other runners a bit of time to produce results
     QEventLoop loop;
-    QTimer::singleShot(200, &loop, [&loop]() {
-        loop.quit();
-    });
+    QTimer::singleShot(200, &loop, &QEventLoop::quit);
     loop.exec();
     if (!context.isValid()) {
         return;
@@ -82,25 +72,22 @@ void InstallerRunner::match(Plasma::RunnerContext &context)
 
     // Check if other plugins have already found an executable, if that is the case we do
     // not want to ask the user to install anything else
-    const QList<Plasma::QueryMatch> matches = context.matches();
-    for (const auto &match : matches) {
-        if (match.id().startsWith(QLatin1String("exec://"))) {
-            return;
-        }
+    const QList<KRunner::QueryMatch> matches = context.matches();
+    const bool execFound = std::any_of(matches.cbegin(), matches.cend(), [](const KRunner::QueryMatch &match) {
+        return match.id().startsWith(QLatin1String("exec://"));
+    });
+    if (execFound) {
+        return;
     }
 
-    std::set<QString> uniqueIds;
-    const auto components = findComponentsByString(context.query()).mid(0, 3);
+    std::unordered_set<QString> uniqueIds;
+    const auto components = findComponentsByString(context.query());
 
-    for (const AppStream::Component &component : components) {
-        if (component.kind() != AppStream::Component::KindDesktopApp)
+    for (auto it = components.cbegin(); it != components.cend() && uniqueIds.size() < 3; it = std::next(it)) {
+        if (it->kind() != AppStream::Component::KindDesktopApp)
             continue;
 
-        // KApplicationTrader uses KService which uses KSycoca which holds
-        // KDirWatch instances to monitor changes. We don't need this on
-        // our runner threads - let's not needlessly allocate inotify instances.
-        KSycoca::disableAutoRebuild();
-        const QString componentId = component.id();
+        const QString componentId = it->id();
         const auto servicesFound = KApplicationTrader::query([&componentId](const KService::Ptr &service) {
             if (service->exec().isEmpty())
                 return false;
@@ -112,7 +99,7 @@ void InstallerRunner::match(Plasma::RunnerContext &context)
             if (service->desktopEntryName().compare(idWithoutDesktop, Qt::CaseInsensitive) == 0)
                 return true;
 
-            const auto renamedFrom = service->property("X-Flatpak-RenamedFrom").toStringList();
+            const auto renamedFrom = service->property<QStringList>("X-Flatpak-RenamedFrom");
             if (renamedFrom.contains(componentId, Qt::CaseInsensitive) || renamedFrom.contains(idWithoutDesktop, Qt::CaseInsensitive))
                 return true;
 
@@ -126,41 +113,47 @@ void InstallerRunner::match(Plasma::RunnerContext &context)
             continue;
         }
 
-        Plasma::QueryMatch match(this);
-        match.setType(Plasma::QueryMatch::NoMatch); // Make sure it is less relavant than KCMs or apps
+        KRunner::QueryMatch match(this);
+        match.setCategoryRelevance(KRunner::QueryMatch::CategoryRelevance::Lowest); // Make sure it is less relavant than KCMs or apps
         match.setId(componentId);
-        match.setIcon(componentIcon(component));
-        match.setText(i18n("Get %1…", component.name()));
-        match.setSubtext(component.summary());
+        match.setIcon(componentIcon(*it));
+        match.setText(i18n("Get %1…", it->name()));
+        match.setSubtext(it->summary());
         match.setData(QUrl("appstream://" + componentId));
-        match.setRelevance(component.name().compare(context.query(), Qt::CaseInsensitive) == 0 ? 1. : 0.7);
+        match.setRelevance(it->name().compare(context.query(), Qt::CaseInsensitive) == 0 ? 1. : 0.7);
         context.addMatch(match);
     }
 }
 
-void InstallerRunner::run(const Plasma::RunnerContext & /*context*/, const Plasma::QueryMatch &match)
+void InstallerRunner::run(const KRunner::RunnerContext & /*context*/, const KRunner::QueryMatch &match)
 {
     const QUrl appstreamUrl = match.data().toUrl();
     if (!QDesktopServices::openUrl(appstreamUrl))
         qCWarning(RUNNER_APPSTREAM) << "couldn't open" << appstreamUrl;
 }
 
+void InstallerRunner::init()
+{
+    // KApplicationTrader uses KService which uses KSycoca which holds
+    // KDirWatch instances to monitor changes. We don't need this on
+    // our runner threads - let's not needlessly allocate inotify instances.
+    KSycoca::disableAutoRebuild();
+}
+
 QList<AppStream::Component> InstallerRunner::findComponentsByString(const QString &query)
 {
-    QMutexLocker locker(&m_appstreamMutex);
-    QString error;
     static bool warnedOnce = false;
-    static bool opened = m_db.load(&error);
+    static bool opened = m_db.load();
     if (!opened) {
         if (warnedOnce) {
-            qCDebug(RUNNER_APPSTREAM) << "Had errors when loading AppStream metadata pool" << error;
+            qCDebug(RUNNER_APPSTREAM) << "Had errors when loading AppStream metadata pool" << m_db.lastError();
         } else {
-            qCWarning(RUNNER_APPSTREAM) << "Had errors when loading AppStream metadata pool" << error;
+            qCWarning(RUNNER_APPSTREAM) << "Had errors when loading AppStream metadata pool" << m_db.lastError();
             warnedOnce = true;
         }
     }
 
-    return m_db.search(query);
+    return m_db.search(query).toList();
 }
 
 #include "appstreamrunner.moc"
