@@ -8,7 +8,6 @@
 #include "baloosearchrunner.h"
 
 #include <KLocalizedString>
-#include <QAction>
 #include <QApplication>
 #include <QDBusConnection>
 #include <QDir>
@@ -52,10 +51,6 @@ SearchRunner::SearchRunner(QObject *parent)
     QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.runners.baloo"));
 }
 
-SearchRunner::~SearchRunner()
-{
-}
-
 RemoteActions SearchRunner::Actions()
 {
     Baloo::IndexerConfig config;
@@ -84,24 +79,25 @@ RemoteMatches SearchRunner::Match(const QString &searchTerm)
     QSet<QUrl> foundUrls;
 
     RemoteMatches matches;
-    matches << matchInternal(searchTerm, QStringLiteral("Audio"), i18n("Audio"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Image"), i18n("Image"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Video"), i18n("Video"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Spreadsheet"), i18n("Spreadsheet"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Presentation"), i18n("Presentation"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Folder"), i18n("Folder"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Document"), i18n("Document"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Archive"), i18n("Archive"), foundUrls);
-    matches << matchInternal(searchTerm, QStringLiteral("Text"), i18n("Text"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Audio")), i18n("Audios"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Image")), i18n("Images"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Video")), i18n("Videos"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Spreadsheet")), i18n("Spreadsheets"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Presentation")), i18n("Presentations"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Folder")), i18n("Folders"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Document")), i18n("Documents"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Archive")), i18n("Archives"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(QStringLiteral("Text")), i18n("Texts"), foundUrls);
+    matches << matchInternal(searchTerm, QStringList(), i18n("Files"), foundUrls);
 
     return matches;
 }
 
-RemoteMatches SearchRunner::matchInternal(const QString &searchTerm, const QString &type, const QString &category, QSet<QUrl> &foundUrls)
+RemoteMatches SearchRunner::matchInternal(const QString &searchTerm, const QStringList &types, const QString &category, QSet<QUrl> &foundUrls)
 {
     Baloo::Query query;
     query.setSearchString(searchTerm);
-    query.setType(type);
+    query.setTypes(types);
     query.setLimit(10);
 
     Baloo::ResultIterator it = query.exec();
@@ -132,11 +128,12 @@ RemoteMatches SearchRunner::matchInternal(const QString &searchTerm, const QStri
         match.text = url.fileName();
         match.iconName = mimeDb.mimeTypeForFile(localUrl).iconName();
         match.relevance = relevance;
-        match.type =
-            url.fileName().compare(searchTerm, Qt::CaseInsensitive) == 0 || QFileInfo(url.fileName()).baseName().compare(searchTerm, Qt::CaseInsensitive) == 0
-            ? Plasma::QueryMatch::ExactMatch
-            : url.fileName().contains(searchTerm, Qt::CaseInsensitive) ? Plasma::QueryMatch::PossibleMatch
-                                                                       : Plasma::QueryMatch::CompletionMatch;
+        const QString baseName = QFileInfo(url.fileName()).completeBaseName();
+        bool isExactMatch = url.fileName().compare(searchTerm, Qt::CaseInsensitive) == 0 || baseName.compare(searchTerm, Qt::CaseInsensitive) == 0;
+        bool isPossibleMatch = url.fileName().contains(searchTerm, Qt::CaseInsensitive);
+        match.type = isExactMatch ? KRunner::QueryMatch::ExactMatch
+            : isPossibleMatch     ? KRunner::QueryMatch::PossibleMatch
+                                  : KRunner::QueryMatch::CompletionMatch;
         QVariantMap properties;
 
         QString folderPath = url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
