@@ -13,15 +13,12 @@
 #include <libqalculate/Unit.h>
 #include <libqalculate/Variable.h>
 
-#include <QApplication>
-#include <QClipboard>
 #include <QDebug>
 #include <QFile>
 #include <QMutex>
 
 #include <KIO/Job>
 #include <KLocalizedString>
-#include <KProtocolManager>
 
 constexpr int evaluationTimeout = 10000;
 
@@ -209,13 +206,6 @@ QString QalculateEngine::evaluate(const QString &expression, bool *isApproximate
     return m_lastResult;
 }
 
-void QalculateEngine::copyToClipboard(bool flag)
-{
-    Q_UNUSED(flag);
-
-    QApplication::clipboard()->setText(m_lastResult);
-}
-
 static const QMap<QString, int> s_commonBaseMappings = {
     {QStringLiteral("roman"), BASE_ROMAN_NUMERALS},
     {QStringLiteral("time"), BASE_TIME},
@@ -287,3 +277,8 @@ bool QalculateEngine::findPrefix(QString basePrefix, int *base, QString *customB
 #endif
     return false;
 }
+
+bool QalculateEngine::isKnownFunction(const QString &str)
+{
+    return CALCULATOR->getFunction(str.toLocal8Bit().constData()) != nullptr;
+}
