@@ -9,13 +9,13 @@
 #include <KLocalizedString>
 #include <KPluginMetaData>
 
-HelpRunner::HelpRunner(QObject *parent, const KPluginMetaData &pluginMetaData, const QVariantList &args)
-    : AbstractRunner(parent, pluginMetaData, args)
+HelpRunner::HelpRunner(QObject *parent, const KPluginMetaData &pluginMetaData)
+    : AbstractRunner(parent, pluginMetaData)
+    , m_actionList({Action(QStringLiteral("configure"), i18n("Configure plugin"), QStringLiteral("configure"))})
 {
     setTriggerWords({i18nc("this is a runner keyword", "help"), QStringLiteral("?")});
     m_manager = qobject_cast<RunnerManager *>(parent);
     Q_ASSERT(m_manager);
-    m_actionList = {new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure plugin"), this)};
 }
 
 void HelpRunner::match(RunnerContext &context)
@@ -45,8 +45,12 @@ void HelpRunner::match(RunnerContext &context)
     for (AbstractRunner *runner : std::as_const(matchingRunners)) {
         const QList<RunnerSyntax> syntaxes = runner->syntaxes();
         if (showExtendedHelp) {
+            float i = 1;
             for (const RunnerSyntax &syntax : syntaxes) {
                 QueryMatch match(this);
+                // Set relevance to preserve the original order of the syntaxes
+                match.setRelevance(1 / i);
+                i++;
                 QString matchText;
                 QString text = QLatin1String("<b>");
                 const auto exampleQueries = syntax.exampleQueries();
@@ -61,19 +65,19 @@ void HelpRunner::match(RunnerContext &context)
                 match.setData(syntax.exampleQueries().constFirst());
                 match.setMultiLine(true);
                 match.setMatchCategory(runner->name());
-                match.setIcon(runner->icon());
+                match.setIconName(runner->metadata().iconName());
                 matches << match;
             }
         } else {
             QueryMatch match(this);
             if (runner->metadata().value(QStringLiteral("X-Plasma-ShowDesciptionInOverview"), false)) {
-                match.setText(runner->description());
+                match.setText(runner->metadata().description());
             } else {
                 match.setText(syntaxes.constFirst().exampleQueries().constFirst());
-                match.setSubtext(runner->description());
+                match.setSubtext(runner->metadata().description());
             }
-            match.setIcon(runner->icon());
-            match.setType(QueryMatch::CompletionMatch);
+            match.setIconName(runner->metadata().iconName());
+            match.setCategoryRelevance(QueryMatch::CategoryRelevance::Low);
             match.setData(QVariant::fromValue(runner->metadata()));
             if (!runner->metadata().value(QStringLiteral("X-KDE-ConfigModule")).isEmpty()) {
                 match.setActions(m_actionList);
@@ -94,7 +98,7 @@ void HelpRunner::run(const RunnerContext &context, const QueryMatch &match)
             QStringLiteral("--args"),
             match.data().value<KPluginMetaData>().pluginId(),
         };
-        job = new KIO::CommandLauncherJob(QStringLiteral("systemsettings5"), args);
+        job = new KIO::CommandLauncherJob(QStringLiteral("systemsettings"), args);
         job->start();
     } else if (match.type() == QueryMatch::CompletionMatch) {
         const KPluginMetaData data = match.data().value<KPluginMetaData>();
