@@ -21,28 +21,19 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KillRunner, "plasma-runner-kill.json")
 
-KillRunner::KillRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, metaData, args)
-    , m_processes(nullptr)
+KillRunner::KillRunner(QObject *parent, const KPluginMetaData &metaData)
+    : KRunner::AbstractRunner(parent, metaData)
+    , m_processes(new KSysGuard::Processes(QString(), this))
+    , m_actionList({
+          KRunner::Action(QString::number(15), QStringLiteral("application-exit"), i18n("Send SIGTERM")),
+          KRunner::Action(QString::number(9), QStringLiteral("process-stop"), i18n("Send SIGKILL")),
+      })
 {
-    setObjectName(QStringLiteral("Kill Runner"));
-
-    auto *sigterm = new QAction(QIcon::fromTheme(QStringLiteral("application-exit")), i18n("Send SIGTERM"), this);
-    sigterm->setData(15);
-    auto *sigkill = new QAction(QIcon::fromTheme(QStringLiteral("process-stop")), i18n("Send SIGKILL"), this);
-    sigkill->setData(9);
-    m_actionList = {sigterm, sigkill};
-
-    connect(this, &Plasma::AbstractRunner::prepare, this, &KillRunner::prep);
-    connect(this, &Plasma::AbstractRunner::teardown, this, &KillRunner::cleanup);
-
-    m_delayedCleanupTimer.setInterval(50);
-    m_delayedCleanupTimer.setSingleShot(true);
-    connect(&m_delayedCleanupTimer, &QTimer::timeout, this, &KillRunner::cleanup);
+    connect(this, &KRunner::AbstractRunner::prepare, m_processes, [this]() {
+        m_needsRefresh = true;
+    });
 }
 
-KillRunner::~KillRunner() = default;
-
 void KillRunner::reloadConfiguration()
 {
     KConfigGroup grp = config();
@@ -53,8 +44,8 @@ void KillRunner::reloadConfiguration()
     m_hasTrigger = !m_triggerWord.isEmpty();
 
     m_sorting = (Sort)grp.readEntry(CONFIG_SORTING, static_cast<int>(Sort::NONE));
-    QList<Plasma::RunnerSyntax> syntaxes;
-    syntaxes << Plasma::RunnerSyntax(m_triggerWord + QStringLiteral(":q:"), i18n("Terminate running applications whose names match the query."));
+    QList<KRunner::RunnerSyntax> syntaxes;
+    syntaxes << KRunner::RunnerSyntax(m_triggerWord + QStringLiteral(":q:"), i18n("Terminate running applications whose names match the query."));
     setSyntaxes(syntaxes);
     if (m_hasTrigger) {
         setTriggerWords({m_triggerWord});
@@ -65,46 +56,20 @@ void KillRunner::reloadConfiguration()
     }
 }
 
-void KillRunner::prep()
+void KillRunner::match(KRunner::RunnerContext &context)
 {
-    m_delayedCleanupTimer.stop();
-}
-
-void KillRunner::cleanup()
-{
-    if (!m_processes) {
-        return;
-    }
-
-    if (m_prepLock.tryLockForWrite()) {
-        delete m_processes;
-        m_processes = nullptr;
-
-        m_prepLock.unlock();
-    } else {
-        m_delayedCleanupTimer.stop();
-    }
-}
-
-void KillRunner::match(Plasma::RunnerContext &context)
-{
-    QString term = context.query();
-    m_prepLock.lockForRead();
-    if (!m_processes) {
-        m_prepLock.unlock();
-        m_prepLock.lockForWrite();
-        if (!m_processes) {
-            suspendMatching(true);
-            m_processes = new KSysGuard::Processes();
-            m_processes->updateAllProcesses();
-            suspendMatching(false);
+    // Only refresh the matches when we are matching. If we were to call it in the prepare slot, we would waste resources
+    // because very likely the runner will not be used during the current match session
+    if (m_needsRefresh) {
+        m_processes->updateAllProcesses();
+        if (!context.isValid()) {
+            return;
         }
     }
-    m_prepLock.unlock();
-
+    QString term = context.query();
     term = term.right(term.length() - m_triggerWord.length());
 
-    QList<Plasma::QueryMatch> matches;
+    QList<KRunner::QueryMatch> matches;
     const QList<KSysGuard::Process *> processlist = m_processes->getAllProcesses();
     for (const KSysGuard::Process *process : processlist) {
         if (!context.isValid()) {
@@ -116,7 +81,7 @@ void KillRunner::match(Plasma::RunnerContext &context)
         }
 
         const quint64 pid = process->pid();
-        Plasma::QueryMatch match(this);
+        KRunner::QueryMatch match(this);
         match.setText(i18n("Terminate %1", name));
         match.setSubtext(i18n("Process ID: %1", QString::number(pid)));
         match.setIconName(QStringLiteral("application-exit"));
@@ -143,21 +108,12 @@ void KillRunner::match(Plasma::RunnerContext &context)
     context.addMatches(matches);
 }
 
-void KillRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
+void KillRunner::run(const KRunner::RunnerContext & /*context*/, const KRunner::QueryMatch &match)
 {
-    Q_UNUSED(context)
-
     const quint64 pid = match.data().toUInt();
+    const int signal = match.selectedAction() ? match.selectedAction().id().toInt() : 9; // default: SIGKILL
 
-    int signal;
-    if (match.selectedAction()) {
-        signal = match.selectedAction()->data().toInt();
-    } else {
-        signal = 9; // default: SIGKILL
-    }
-
-    const QStringList args = {QStringLiteral("-%1").arg(signal), QString::number(pid)};
-    int returnCode = KProcess::execute(QStringLiteral("kill"), args);
+    int returnCode = KProcess::execute(QStringLiteral("kill"), {QStringLiteral("-%1").arg(signal), QString::number(pid)});
     if (returnCode == 0) {
         return;
     }
