@@ -1,33 +1,24 @@
 /*
     SPDX-FileCopyrightText: 2009 Jan Gerrit Marker <jangerrit@weiler-marker.com>
-    SPDX-FileCopyrightText: 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
+    SPDX-FileCopyrightText: 2020-2023 Alexander Lohnau <alexander.lohnau@gmx.de>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-// Project-Includes
 #include "killrunner_config.h"
-// KDE-Includes
+
 #include "config_keys.h"
 #include <KConfigGroup>
 #include <KPluginFactory>
 #include <KSharedConfig>
 
-K_PLUGIN_FACTORY(KillRunnerConfigFactory, registerPlugin<KillRunnerConfig>();)
+K_PLUGIN_CLASS(KillRunnerConfig)
 
-KillRunnerConfigForm::KillRunnerConfigForm(QWidget *parent)
-    : QWidget(parent)
+KillRunnerConfig::KillRunnerConfig(QObject *parent)
+    : KCModule(parent)
 {
-    setupUi(this);
-}
-
-KillRunnerConfig::KillRunnerConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-{
-    m_ui = new KillRunnerConfigForm(this);
-
-    QGridLayout *layout = new QGridLayout(this);
-    layout->addWidget(m_ui, 0, 0);
+    m_ui = new Ui::KillRunnerConfigUi();
+    m_ui->setupUi(widget());
 
     m_ui->sorting->addItem(i18n("CPU usage"), CPU);
     m_ui->sorting->addItem(i18n("inverted CPU usage"), CPUI);
@@ -36,8 +27,6 @@ KillRunnerConfig::KillRunnerConfig(QWidget *parent, const QVariantList &args)
     connect(m_ui->useTriggerWord, &QCheckBox::stateChanged, this, &KillRunnerConfig::markAsChanged);
     connect(m_ui->triggerWord, &KLineEdit::textChanged, this, &KillRunnerConfig::markAsChanged);
     connect(m_ui->sorting, &QComboBox::currentIndexChanged, this, &KillRunnerConfig::markAsChanged);
-
-    load();
 }
 
 void KillRunnerConfig::load()
@@ -50,8 +39,6 @@ void KillRunnerConfig::load()
     m_ui->useTriggerWord->setChecked(grp.readEntry(CONFIG_USE_TRIGGERWORD, true));
     m_ui->triggerWord->setText(grp.readEntry(CONFIG_TRIGGERWORD, i18n("kill")));
     m_ui->sorting->setCurrentIndex(m_ui->sorting->findData(grp.readEntry<int>(CONFIG_SORTING, NONE)));
-
-    Q_EMIT changed(false);
 }
 
 void KillRunnerConfig::save()
@@ -65,8 +52,6 @@ void KillRunnerConfig::save()
     grp.writeEntry(CONFIG_TRIGGERWORD, m_ui->triggerWord->text());
     grp.writeEntry(CONFIG_SORTING, m_ui->sorting->itemData(m_ui->sorting->currentIndex()));
     grp.sync();
-
-    Q_EMIT changed(false);
 }
 
 void KillRunnerConfig::defaults()
@@ -77,7 +62,7 @@ void KillRunnerConfig::defaults()
     m_ui->triggerWord->setText(i18n("kill"));
     m_ui->sorting->setCurrentIndex(m_ui->sorting->findData((int)NONE));
 
-    markAsChanged();
+    setNeedsSave(true);
 }
 
 #include "killrunner_config.moc"
