@@ -24,20 +24,13 @@
 
 K_PLUGIN_CLASS_WITH_JSON(LocationsRunner, "plasma-runner-locations.json")
 
-LocationsRunner::LocationsRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, metaData, args)
+LocationsRunner::LocationsRunner(QObject *parent, const KPluginMetaData &metaData)
+    : KRunner::AbstractRunner(parent, metaData)
 {
-    // set the name shown after the result in krunner window
-    setObjectName(QStringLiteral("Locations"));
-    addSyntax(
-        Plasma::RunnerSyntax(QStringLiteral(":q:"), i18n("Finds local directories and files, network locations and Internet sites with paths matching :q:.")));
+    addSyntax(QStringLiteral(":q:"), i18n("Finds local directories and files, network locations and Internet sites with paths matching :q:."));
 }
 
-LocationsRunner::~LocationsRunner()
-{
-}
-
-void LocationsRunner::match(Plasma::RunnerContext &context)
+void LocationsRunner::match(KRunner::RunnerContext &context)
 {
     QString term = context.query();
     // If we have a query with an executable and optionally arguments, BUG: 433053
@@ -55,19 +48,19 @@ void LocationsRunner::match(Plasma::RunnerContext &context)
     const QFileInfo fileInfo = QFileInfo(url.toLocalFile());
 
     if (fileInfo.exists()) {
-        Plasma::QueryMatch match(this);
+        KRunner::QueryMatch match(this);
         match.setText(i18n("Open %1", context.query()));
         match.setIconName(fileInfo.isFile() ? KIO::iconNameForUrl(url) : QStringLiteral("system-file-manager"));
 
         match.setRelevance(1);
         match.setData(url);
         match.setUrls({url});
-        match.setType(Plasma::QueryMatch::ExactMatch);
+        match.setCategoryRelevance(KRunner::QueryMatch::CategoryRelevance::Highest);
         context.addMatch(match);
     } else if (!url.isLocalFile() && !url.isEmpty() && !url.scheme().isEmpty()) {
         const QString protocol = url.scheme();
-        Plasma::QueryMatch match(this);
-        match.setType(Plasma::QueryMatch::PossibleMatch);
+        KRunner::QueryMatch match(this);
+        match.setCategoryRelevance(KRunner::QueryMatch::CategoryRelevance::Low);
         match.setData(url);
         match.setUrls({url});
 
@@ -99,10 +92,8 @@ void LocationsRunner::match(Plasma::RunnerContext &context)
     }
 }
 
-void LocationsRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
+void LocationsRunner::run(const KRunner::RunnerContext & /*context*/, const KRunner::QueryMatch &match)
 {
-    Q_UNUSED(context)
-
     auto *job = new KIO::OpenUrlJob(match.data().toUrl());
     job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
     job->setRunExecutables(false);
