@@ -21,6 +21,9 @@
 #include <QUrlQuery>
 
 #include <KActivities/ResourceInstance>
+#include <KActivities/Stats/Query>
+#include <KActivities/Stats/ResultSet>
+#include <KActivities/Stats/Terms>
 #include <KApplicationTrader>
 #include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
@@ -34,8 +37,6 @@
 
 #include "debug.h"
 
-namespace
-{
 int weightedLength(const QString &query)
 {
     return KStringHandler::logicalLength(query);
@@ -57,26 +58,25 @@ inline bool contains(const QStringList &results, const QStringList &queryList)
     });
 }
 
-} // namespace
-
 /**
  * @brief Finds all KServices for a given runner query
  */
 class ServiceFinder
 {
 public:
-    ServiceFinder(ServiceRunner *runner, const QList<KService::Ptr> &list)
+    ServiceFinder(ServiceRunner *runner, const QList<KService::Ptr> &list, const QString &currentActivity)
         : m_runner(runner)
         , m_services(list)
+        , m_currentActivity(currentActivity)
     {
     }
 
-    void match(Plasma::RunnerContext &context)
+    void match(KRunner::RunnerContext &context)
     {
-        term = context.query();
+        query = context.query();
         // Splitting the query term to match using subsequences
-        queryList = term.split(QLatin1Char(' '));
-        weightedTermLength = weightedLength(term);
+        queryList = query.split(QLatin1Char(' '));
+        weightedTermLength = weightedLength(query);
 
         matchNameKeywordAndGenericName();
         matchCategories();
@@ -86,30 +86,29 @@ public:
     }
 
 private:
-    void seen(const KService::Ptr &service)
+    inline void seen(const KService::Ptr &service)
     {
-        m_seen.insert(service->storageId());
         m_seen.insert(service->exec());
     }
 
-    void seen(const KServiceAction &action)
+    inline void seen(const KServiceAction &action)
     {
         m_seen.insert(action.exec());
     }
 
-    bool hasSeen(const KService::Ptr &service)
+    inline bool hasSeen(const KService::Ptr &service)
     {
-        return m_seen.contains(service->storageId()) && m_seen.contains(service->exec());
+        return m_seen.contains(service->exec());
     }
 
-    bool hasSeen(const KServiceAction &action)
+    inline bool hasSeen(const KServiceAction &action)
     {
         return m_seen.contains(action.exec());
     }
 
     bool disqualify(const KService::Ptr &service)
     {
-        auto ret = hasSeen(service) || service->noDisplay();
+        auto ret = hasSeen(service);
         qCDebug(RUNNER_SERVICES) << service->name() << "disqualified?" << ret;
         seen(service);
         return ret;
@@ -144,26 +143,43 @@ private:
         return relevanceIncrement;
     }
 
-    void setupMatch(const KService::Ptr &service, Plasma::QueryMatch &match)
+    void setupMatch(const KService::Ptr &service, KRunner::QueryMatch &match)
     {
         const QString name = service->name();
+        const QString exec = service->exec();
 
         match.setText(name);
 
         QUrl url(service->storageId());
         url.setScheme(QStringLiteral("applications"));
         match.setData(url);
+        match.setUrls({QUrl::fromLocalFile(service->entryPath())});
 
-        QString path = service->entryPath();
-        if (!QDir::isAbsolutePath(path)) {
-            path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/") + path);
+        QString urlPath = resolvedArgs(exec);
+        if (urlPath.isEmpty()) {
+            // Otherwise we might filter out broken services. Rather than hiding them, it is better to show an error message on launch (as done by KIO's jobs)
+            urlPath = exec;
+        }
+        match.setId(QStringLiteral("exec://") + urlPath);
+        if (!service->genericName().isEmpty() && service->genericName() != name) {
+            match.setSubtext(service->genericName());
+        } else if (!service->comment().isEmpty()) {
+            match.setSubtext(service->comment());
         }
 
-        match.setUrls({QUrl::fromLocalFile(path)});
+        if (!service->icon().isEmpty()) {
+            match.setIconName(service->icon());
+        }
+    }
 
-        QString exec = service->exec();
-
-        QStringList resultingArgs = KIO::DesktopExecParser(KService(QString(), exec, QString()), {}).resultingArguments();
+    QString resolvedArgs(const QString &exec)
+    {
+        const KService syntheticService(QString(), exec, QString());
+        KIO::DesktopExecParser parser(syntheticService, {});
+        QStringList resultingArgs = parser.resultingArguments();
+        if (const auto error = parser.errorMessage(); resultingArgs.isEmpty() && !error.isEmpty()) {
+            qCWarning(RUNNER_SERVICES) << "Failed to resolve executable from service. Error:" << error;
+        }
 
         // Remove any environment variables.
         if (KIO::DesktopExecParser::executableName(exec) == QLatin1String("env")) {
@@ -175,6 +191,7 @@ private:
 
             // Now parse it again to resolve the path.
             resultingArgs = KIO::DesktopExecParser(KService(QString(), KShell::joinArgs(resultingArgs), QString()), {}).resultingArguments();
+            return resultingArgs.join(QLatin1Char(' '));
         }
 
         // Remove special arguments that have no real impact on the application.
@@ -191,17 +208,7 @@ private:
                 }
             }
         }
-
-        match.setId(QStringLiteral("exec://") + resultingArgs.join(QLatin1Char(' ')));
-        if (!service->genericName().isEmpty() && service->genericName() != name) {
-            match.setSubtext(service->genericName());
-        } else if (!service->comment().isEmpty()) {
-            match.setSubtext(service->comment());
-        }
-
-        if (!service->icon().isEmpty()) {
-            match.setIconName(service->icon());
-        }
+        return resultingArgs.join(QLatin1Char(' '));
     }
 
     void matchNameKeywordAndGenericName()
@@ -211,10 +218,14 @@ private:
             if (contains(service->name(), queryList)) {
                 return true;
             }
-            // If the term length is < 3, no real point searching the Keywords and GenericName
+            // If the term length is < 3, no real point searching the untranslated Name, Keywords and GenericName
             if (weightedTermLength < 3) {
                 return false;
             }
+            if (contains(service->untranslatedName(), queryList)) {
+                return true;
+            }
+
             // Keywords
             if (contains(service->keywords(), queryList)) {
                 return true;
@@ -240,22 +251,20 @@ private:
             const QString name = service->name();
             const QString exec = service->exec();
 
-            Plasma::QueryMatch match(m_runner);
-            match.setType(Plasma::QueryMatch::PossibleMatch);
-            setupMatch(service, match);
+            KRunner::QueryMatch::CategoryRelevance categoryRelevance = KRunner::QueryMatch::CategoryRelevance::Moderate;
             qreal relevance(0.6);
 
             // If the term was < 3 chars and NOT at the beginning of the App's name or Exec, then
             // chances are the user doesn't want that app.
             if (weightedTermLength < 3) {
-                if (name.startsWith(term, Qt::CaseInsensitive) || exec.startsWith(term, Qt::CaseInsensitive)) {
+                if (name.startsWith(query, Qt::CaseInsensitive) || exec.startsWith(query, Qt::CaseInsensitive)) {
                     relevance = 0.9;
                 } else {
                     continue;
                 }
-            } else if (name.compare(term, Qt::CaseInsensitive) == 0) {
+            } else if (name.compare(query, Qt::CaseInsensitive) == 0) {
                 relevance = 1;
-                match.setType(Plasma::QueryMatch::ExactMatch);
+                categoryRelevance = KRunner::QueryMatch::CategoryRelevance::Highest;
             } else if (name.contains(queryList[0], Qt::CaseInsensitive)) {
                 relevance = 0.8;
                 relevance += increaseMatchRelavance(service, queryList, QStringLiteral("Name"));
@@ -279,6 +288,9 @@ private:
                 }
             }
 
+            KRunner::QueryMatch match(m_runner);
+            match.setCategoryRelevance(categoryRelevance);
+            setupMatch(service, match);
             if (service->categories().contains(QLatin1String("KDE"))) {
                 qCDebug(RUNNER_SERVICES) << "found a kde thing" << id << match.subtext() << relevance;
                 relevance += .09;
@@ -287,6 +299,12 @@ private:
             qCDebug(RUNNER_SERVICES) << name << "is this relevant:" << relevance;
             match.setRelevance(relevance);
 
+            if (const auto foundIt = m_runner->m_favourites.constFind(service->desktopEntryName()); foundIt != m_runner->m_favourites.cend()) {
+                if (foundIt->isGlobal || foundIt->linkedActivities.contains(m_currentActivity)) {
+                    match.setRelevance(match.relevance() + 0.3);
+                }
+            }
+
             matches << match;
         }
     }
@@ -297,28 +315,21 @@ private:
         if (weightedTermLength < 5) {
             return;
         }
-        const auto categoriesFilter = [this](const KService::Ptr &service) {
-            return contains(service->categories(), queryList);
-        };
-
         for (const KService::Ptr &service : m_services) {
-            if (!categoriesFilter(service) || disqualify(service)) {
+            const QStringList categories = service->categories();
+            if (disqualify(service) || !contains(categories, queryList)) {
                 continue;
             }
             qCDebug(RUNNER_SERVICES) << service->name() << "is an exact match!" << service->storageId() << service->exec();
 
-            Plasma::QueryMatch match(m_runner);
-            match.setType(Plasma::QueryMatch::PossibleMatch);
+            KRunner::QueryMatch match(m_runner);
             setupMatch(service, match);
 
             qreal relevance = 0.4;
-            const QStringList categories = service->categories();
             if (std::any_of(categories.begin(), categories.end(), [this](const QString &category) {
-                    return category.compare(term, Qt::CaseInsensitive) == 0;
+                    return category.compare(query, Qt::CaseInsensitive) == 0;
                 })) {
                 relevance = 0.6;
-            } else if (service->categories().contains(QLatin1String("X-KDE-More")) || !service->showInCurrentDesktop()) {
-                relevance = 0.5;
             }
 
             if (service->isApplication()) {
@@ -335,34 +346,25 @@ private:
         if (weightedTermLength < 3) {
             return;
         }
-
-        const auto hasActionsFilter = [](const KService::Ptr &service) {
-            return !service->actions().isEmpty();
-        };
         for (const KService::Ptr &service : m_services) {
-            if (!hasActionsFilter(service) || service->noDisplay()) {
-                continue;
-            }
-
-            // Skip SystemSettings as we find KCMs already
-            if (service->storageId() == QLatin1String("systemsettings.desktop")) {
-                continue;
-            }
-
             const auto actions = service->actions();
+            // Skip SystemSettings as we find KCMs already
+            if (actions.isEmpty() || service->storageId() == QLatin1String("systemsettings.desktop")) {
+                continue;
+            }
+
             for (const KServiceAction &action : actions) {
                 if (action.text().isEmpty() || action.exec().isEmpty() || hasSeen(action)) {
                     continue;
                 }
                 seen(action);
 
-                const int matchIndex = action.text().indexOf(term, 0, Qt::CaseInsensitive);
+                const int matchIndex = action.text().indexOf(query, 0, Qt::CaseInsensitive);
                 if (matchIndex < 0) {
                     continue;
                 }
 
-                Plasma::QueryMatch match(m_runner);
-                match.setType(Plasma::QueryMatch::PossibleMatch);
+                KRunner::QueryMatch match(m_runner);
                 if (!action.icon().isEmpty()) {
                     match.setIconName(action.icon());
                 } else {
@@ -376,16 +378,16 @@ private:
                 QUrl url(service->storageId());
                 url.setScheme(QStringLiteral("applications"));
 
-                QUrlQuery query;
-                query.addQueryItem(QStringLiteral("action"), action.name());
-                url.setQuery(query);
+                QUrlQuery urlQuery;
+                urlQuery.addQueryItem(QStringLiteral("action"), action.name());
+                url.setQuery(urlQuery);
 
                 match.setData(url);
 
                 qreal relevance = 0.5;
-                if (action.text().compare(term, Qt::CaseInsensitive) == 0) {
+                if (action.text().compare(query, Qt::CaseInsensitive) == 0) {
                     relevance = 0.65;
-                    match.setType(Plasma::QueryMatch::HelperMatch); // Give it a higer match type to ensure it is shown, BUG: 455436
+                    match.setCategoryRelevance(KRunner::QueryMatch::CategoryRelevance::High); // Give it a higer match type to ensure it is shown, BUG: 455436
                 } else if (matchIndex == 0) {
                     relevance += 0.05;
                 }
@@ -400,38 +402,67 @@ private:
     ServiceRunner *m_runner;
     QSet<QString> m_seen;
     const QList<KService::Ptr> m_services;
+    const QString m_currentActivity;
 
-    QList<Plasma::QueryMatch> matches;
+    QList<KRunner::QueryMatch> matches;
     QString query;
-    QString term;
     QStringList queryList;
     int weightedTermLength = -1;
 };
 
-ServiceRunner::ServiceRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, metaData, args)
+ServiceRunner::ServiceRunner(QObject *parent, const KPluginMetaData &metaData)
+    : KRunner::AbstractRunner(parent, metaData)
+    , m_kactivitiesQuery(Terms::LinkedResources | Terms::Agent{QStringLiteral("org.kde.plasma.favorites.applications")} | Terms::Type::any()
+                         | Terms::Activity::any() | Terms::Limit(25))
+    , m_kactivitiesWatcher(m_kactivitiesQuery)
 {
-    setObjectName(QStringLiteral("Application"));
-    setPriority(AbstractRunner::HighestPriority);
+    addSyntax(QStringLiteral(":q:"), i18n("Finds applications whose name or description match :q:"));
+    connect(&m_kactivitiesWatcher, &ResultWatcher::resultLinked, [this](const QString &resource) {
+        processActivitiesResults(ResultSet(m_kactivitiesQuery | Terms::Url::contains(resource)));
+    });
 
-    addSyntax(Plasma::RunnerSyntax(QStringLiteral(":q:"), i18n("Finds applications whose name or description match :q:")));
+    connect(&m_kactivitiesWatcher, &ResultWatcher::resultUnlinked, [this](const QString &resource) {
+        m_favourites.remove(resource);
+        // In case it was only unlinked from one activity
+        processActivitiesResults(ResultSet(m_kactivitiesQuery | Terms::Url::contains(resource)));
+    });
+    processActivitiesResults(ResultSet(m_kactivitiesQuery));
+
+    // Load services once per match session. Reloading them for every character is not worth it
+    // Also filter out hidden ones since those are not relevant for matching
+    connect(this, &KRunner::AbstractRunner::prepare, this, [this]() {
+        m_services = KApplicationTrader::query([](const KService::Ptr &service) {
+            return !service->noDisplay();
+        });
+    });
+    connect(this, &KRunner::AbstractRunner::teardown, this, [this]() {
+        m_services.clear();
+    });
 }
 
-ServiceRunner::~ServiceRunner() = default;
-
-void ServiceRunner::match(Plasma::RunnerContext &context)
+void ServiceRunner::processActivitiesResults(const ResultSet &results)
 {
-    KSycoca::disableAutoRebuild();
-    ServiceFinder finder(this, KApplicationTrader::query([](const KService::Ptr &) {
-                             return true;
-                         }));
+    const static QLatin1String globalActivity(":global");
+    const static QLatin1String applicationScheme("applications");
+    for (const ResultSet::Result &result : results) {
+        if (result.url().scheme() == applicationScheme) {
+            m_favourites.insert(result.url().path().remove(QLatin1String(".desktop")),
+                                ActivityFavourite{
+                                    result.linkedActivities(),
+                                    result.linkedActivities().contains(globalActivity),
+                                });
+        }
+    }
+}
+
+void ServiceRunner::match(KRunner::RunnerContext &context)
+{
+    ServiceFinder finder(this, m_services, m_activitiesConsuer.currentActivity());
     finder.match(context);
 }
 
-void ServiceRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
+void ServiceRunner::run(const KRunner::RunnerContext & /*context*/, const KRunner::QueryMatch &match)
 {
-    Q_UNUSED(context)
-
     const QUrl dataUrl = match.data().toUrl();
 
     KService::Ptr service = KService::serviceByStorageId(dataUrl.path());
@@ -461,3 +492,7 @@ void ServiceRunner::run(const Plasma::RunnerContext &context, const Plasma::Quer
     job->setUiDelegate(delegate);
     job->start();
 }
+
+K_PLUGIN_CLASS_WITH_JSON(ServiceRunner, "plasma-runner-services.json")
+
+#include "servicerunner.moc"
