@@ -7,25 +7,23 @@
 #pragma once
 
 #include <KRunner/AbstractRunner>
+#include <KRunner/Action>
 #include <KServiceAction>
 
-class WebshortcutRunner : public Plasma::AbstractRunner
+class WebshortcutRunner : public KRunner::AbstractRunner
 {
     Q_OBJECT
 
 public:
-    WebshortcutRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
-    ~WebshortcutRunner() override;
+    WebshortcutRunner(QObject *parent, const KPluginMetaData &metaData);
 
-    void match(Plasma::RunnerContext &context) override;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
-
-private Q_SLOTS:
-    void loadSyntaxes();
-    void configurePrivateBrowsingActions();
+    void match(KRunner::RunnerContext &context) override;
+    void run(const KRunner::RunnerContext &context, const KRunner::QueryMatch &match) override;
 
 private:
-    Plasma::QueryMatch m_match;
+    Q_SLOT void loadSyntaxes();
+    void configurePrivateBrowsingActions();
+    KRunner::QueryMatch m_match;
     bool m_filterBeforeRun;
 
     QChar m_delimiter;
@@ -36,6 +34,7 @@ private:
 
     KServiceAction m_privateAction;
 
-    Plasma::RunnerContext m_lastUsedContext;
+    KRunner::RunnerContext m_lastUsedContext;
     QString m_defaultKey;
+    KRunner::Action m_action;
 };
