@@ -18,8 +18,6 @@
 #include "mockcompositor.h"
 #include "xdgoutputv1.h"
 
-#include "config-KDECI_BUILD.h"
-
 using namespace MockCompositor;
 
 class ScreenPoolTest : public QObject, DefaultCompositor
@@ -65,11 +63,9 @@ void ScreenPoolTest::initTestCase()
 
 void ScreenPoolTest::cleanupTestCase()
 {
-#if !KDECI_BUILD
     QCOMPOSITOR_COMPARE(getAll<Output>().size(), 1); // Only the default output should be left
     QTRY_COMPARE(QGuiApplication::screens().size(), 1);
     QTRY_VERIFY2(isClean(), qPrintable(dirtyMessage()));
-#endif
 
     KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("ScreenConnectors"));
     cg.deleteGroup();
@@ -82,7 +78,7 @@ void ScreenPoolTest::testScreenInsertion()
     QSignalSpy orderChangeSpy(m_screenPool, &ScreenPool::screenOrderChanged);
 
     // Add a new output
-    exec([=] {
+    exec([this] {
         OutputData data;
         data.mode.resolution = {1920, 1080};
         data.position = {1920, 0};
@@ -115,7 +111,7 @@ void ScreenPoolTest::testRedundantScreenInsertion()
     QSignalSpy addedFromAppSpy(qGuiApp, SIGNAL(screenAdded(QScreen *)));
 
     // Add a new output
-    exec([=] {
+    exec([this] {
         OutputData data;
         data.mode.resolution = {1280, 720};
         data.position = {1920, 0};
@@ -146,7 +142,7 @@ void ScreenPoolTest::testMoveOutOfRedundant()
 {
     QSignalSpy orderChangeSpy(m_screenPool, &ScreenPool::screenOrderChanged);
 
-    exec([=] {
+    exec([this] {
         auto *out = output(2);
         auto *xdgOut = xdgOutput(out);
         out->m_data.mode.resolution = {1280, 2048};
@@ -169,7 +165,7 @@ void ScreenPoolTest::testMoveInRedundant()
 {
     QSignalSpy removedSpy(m_screenPool, SIGNAL(screenRemoved(QScreen *)));
 
-    exec([=] {
+    exec([this] {
         auto *out = output(2);
         auto *xdgOut = xdgOutput(out);
         out->m_data.mode.resolution = {1280, 720};
@@ -201,7 +197,7 @@ void ScreenPoolTest::testOrderSwap()
 
     // Set a primary screen
     // TODO: "WL-2", "WL-1", "WL-3" when tests are self contained
-    exec([=] {
+    exec([this] {
         outputOrder()->setList({"WL-2", "WL-1", "WL-3"});
     });
 
@@ -230,7 +226,7 @@ void ScreenPoolTest::testPrimarySwapToRedundant()
     QSignalSpy orderChangeSpy(m_screenPool, &ScreenPool::screenOrderChanged);
 
     // Set a primary screen
-    exec([=] {
+    exec([this] {
         outputOrder()->setList({"WL-3", "WL-2", "WL-1"});
     });
 
@@ -243,7 +239,7 @@ void ScreenPoolTest::testMoveRedundantToMakePrimary()
 {
     QSignalSpy orderChangeSpy(m_screenPool, &ScreenPool::screenOrderChanged);
 
-    exec([=] {
+    exec([this] {
         auto *out = output(2);
         auto *xdgOut = xdgOutput(out);
         out->m_data.mode.resolution = {1280, 2048};
@@ -281,7 +277,7 @@ void ScreenPoolTest::testMoveInRedundantToLosePrimary()
     QCOMPARE(m_screenPool->screenOrder().size(), 3);
     QScreen *oldScreen = m_screenPool->screenOrder()[0];
 
-    exec([=] {
+    exec([this] {
         auto *out = output(2);
         auto *xdgOut = xdgOutput(out);
         xdgOut->sendLogicalSize(QSize(1280, 720));
@@ -321,7 +317,7 @@ void ScreenPoolTest::testSecondScreenRemoval()
     QCOMPARE(m_screenPool->screenOrder()[1]->name(), QStringLiteral("WL-1"));
 
     // Remove an output
-    exec([=] {
+    exec([this] {
         remove(output(1));
         outputOrder()->setList({"WL-3", "WL-1"});
     });
@@ -343,7 +339,7 @@ void ScreenPoolTest::testThirdScreenRemoval()
     QSignalSpy orderChangeSpy(m_screenPool, &ScreenPool::screenOrderChanged);
 
     // Remove an output
-    exec([=] {
+    exec([this] {
         remove(output(1));
         outputOrder()->setList({"WL-1"});
     });
@@ -370,7 +366,7 @@ void ScreenPoolTest::testLastScreenRemoval()
     QSignalSpy removedSpy(m_screenPool, SIGNAL(screenRemoved(QScreen *)));
 
     // Remove an output
-    exec([=] {
+    exec([this] {
         remove(output(0));
         outputOrder()->setList({});
     });
@@ -387,14 +383,10 @@ void ScreenPoolTest::testLastScreenRemoval()
 
 void ScreenPoolTest::testFakeToRealScreen()
 {
-#if KDECI_BUILD
-    QSKIP("testFakeToRealScreen causes assertion error in screenpool.cpp line 320");
-#endif
-
     QSignalSpy orderChangeSpy(m_screenPool, &ScreenPool::screenOrderChanged);
 
     // Add a new output
-    exec([=] {
+    exec([this] {
         OutputData data;
         data.mode.resolution = {1920, 1080};
         data.position = {0, 0};
