@@ -55,7 +55,7 @@ QScreen *ShellTest::insertScreen(const QRect &geometry, const QString &name)
 {
     QScreen *result = nullptr;
 
-    auto doTest = [=](QScreen *&res) {
+    auto doTest = [=, this](QScreen *&res) {
         int oldAppNumScreens = qApp->screens().size();
         int oldCoronaNumScreens = m_corona->numScreens();
 
@@ -70,7 +70,7 @@ QScreen *ShellTest::insertScreen(const QRect &geometry, const QString &name)
         //  QSignalSpy orderChangeSpy(m_corona->m_screenPool, &ScreenPool::screenOrderChanged);
 
         // Add a new output
-        exec([=] {
+        exec([=, this] {
             OutputData data;
             data.mode.resolution = {geometry.width(), geometry.height()};
             data.position = {geometry.x(), geometry.y()};
@@ -83,7 +83,6 @@ QScreen *ShellTest::insertScreen(const QRect &geometry, const QString &name)
         //  coronaAddedSpy.wait();
         QTRY_COMPARE(appAddedSpy.size(), 1);
         //   QTRY_COMPARE(orderChangeSpy.size(), 1);
-
         QCOMPARE(m_corona->numScreens(), oldCoronaNumScreens); // Corona has *not* been notified yer as setScreenOrder has not been called
         QCOMPARE(m_corona->m_desktopViewForScreen.count(), oldCoronaNumScreens);
         QCOMPARE(qApp->screens().size(), oldAppNumScreens + 1);
@@ -104,17 +103,19 @@ void ShellTest::setScreenOrder(const QStringList &order, bool expectOrderChanged
 {
     QSignalSpy coronaScreenOrderSpy(m_corona, &ShellCorona::screenOrderChanged);
 
-    exec([=] {
+    exec([=, this] {
         outputOrder()->setList(order);
     });
 
     if (expectOrderChanged) {
         coronaScreenOrderSpy.wait();
+        Q_ASSERT(coronaScreenOrderSpy.count() == 1);
         QCOMPARE(coronaScreenOrderSpy.count(), 1);
         auto order = coronaScreenOrderSpy.takeFirst().at(0).value<QList<QScreen *>>();
         QCOMPARE(m_corona->m_desktopViewForScreen.size(), order.size());
     } else {
         coronaScreenOrderSpy.wait(250);
+        Q_ASSERT(coronaScreenOrderSpy.count() == 0);
         QCOMPARE(coronaScreenOrderSpy.count(), 0);
     }
 
@@ -152,7 +153,7 @@ void ShellTest::initTestCase()
 
 void ShellTest::cleanupTestCase()
 {
-    exec([=] {
+    exec([this] {
         outputOrder()->setList({"WL-1"});
     });
     QCOMPOSITOR_COMPARE(getAll<Output>().size(), 1); // Only the default output should be left
@@ -176,18 +177,18 @@ void ShellTest::cleanup()
     QVERIFY(oldCoronaNumScreens <= oldNumScreens);
     QSignalSpy coronaRemovedSpy(m_corona, SIGNAL(screenRemoved(int)));
 
-    exec([=] {
+    exec([=, this] {
         for (int i = oldNumScreens - 1; i >= 0; --i) {
             remove(output(i));
         }
     });
-    setScreenOrder({""}, true);
+    setScreenOrder({}, true);
 
     QTRY_COMPARE(coronaRemovedSpy.size(), oldCoronaNumScreens);
 
     // Cleanup all the containments that were created
     for (auto *c : m_corona->containments()) {
-        if (c->containmentType() == Plasma::Types::PanelContainment || c->screen() != 0) {
+        if (c->containmentType() == Plasma::Containment::Panel || c->screen() != 0) {
             c->destroy();
         }
     }
@@ -219,9 +220,8 @@ void ShellTest::testScreenInsertion()
 void ShellTest::testPanelInsertion()
 {
     QCOMPARE(m_corona->m_panelViews.size(), 0);
-    auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.plasma.panel"));
+    auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.panel"));
     // If the panel fails to load (on ci plasma-desktop isn't here) we want the "failed" containment to be of panel type anyways
-    panelCont->setContainmentType(Plasma::Types::PanelContainment);
     QCOMPARE(m_corona->m_panelViews.size(), 1);
     QVERIFY(m_corona->m_panelViews.contains(panelCont));
     QCOMPARE(panelCont->screen(), 0);
@@ -279,7 +279,7 @@ void ShellTest::testMoveOutOfRedundant()
 
     QSignalSpy coronaAddedSpy(m_corona, SIGNAL(screenAdded(int)));
 
-    exec([=] {
+    exec([this] {
         auto *out = output(1);
         auto *xdgOut = xdgOutput(out);
         out->m_data.mode.resolution = {1280, 2048};
@@ -308,7 +308,6 @@ void ShellTest::testScreenRemoval()
 
     QCOMPARE(m_corona->m_panelViews.size(), 0);
     auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.plasma.panel"));
-    panelCont->setContainmentType(Plasma::Types::PanelContainment);
     m_corona->m_panelViews[panelCont]->setScreenToFollow(m_corona->m_screenPool->screenForId(2));
     QCOMPARE(panelCont->screen(), 2);
     QCOMPARE(m_corona->m_panelViews[panelCont]->screen(), m_corona->m_screenPool->screenForId(2));
@@ -317,7 +316,7 @@ void ShellTest::testScreenRemoval()
     QSignalSpy removedSpy(m_corona, SIGNAL(screenRemoved(int)));
 
     // Remove outputs
-    exec([=] {
+    exec([this] {
         remove(output(2));
         remove(output(1));
     });
@@ -383,7 +382,6 @@ void ShellTest::testScreenRemovalRecyclingViews()
     // Create a panel on screen 1
     QCOMPARE(m_corona->m_panelViews.size(), 0);
     auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.plasma.panel"));
-    panelCont->setContainmentType(Plasma::Types::PanelContainment);
     QCOMPARE(m_corona->m_panelViews.size(), 1);
     auto panelView = m_corona->m_panelViews[panelCont];
     panelView->setScreenToFollow(m_corona->m_screenPool->screenForId(1));
@@ -394,7 +392,7 @@ void ShellTest::testScreenRemovalRecyclingViews()
     QSignalSpy removedSpy(m_corona, SIGNAL(screenRemoved(int)));
 
     // Remove output
-    exec([=] {
+    exec([this] {
         remove(output(1));
     });
 
@@ -435,23 +433,22 @@ void ShellTest::testScreenRemovalRecyclingViews()
 
 void ShellTest::testReorderScreens_data()
 {
-    QTest::addColumn<QVector<QRect>>("geometries");
+    QTest::addColumn<QList<QRect>>("geometries");
     QTest::addColumn<QStringList>("orderBefore");
     QTest::addColumn<QStringList>("orderAfter");
 
-    QTest::newRow("twoScreens") << QVector<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}}) << QStringList({"WL-1", "DP-1"})
-                                << QStringList({"DP-1", "WL-1"});
-    QTest::newRow("3screensReorder0_1") << QVector<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}, {3840, 0, 1920, 1080}})
+    QTest::newRow("twoScreens") << QList<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}}) << QStringList({"WL-1", "DP-1"}) << QStringList({"DP-1", "WL-1"});
+    QTest::newRow("3screensReorder0_1") << QList<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}, {3840, 0, 1920, 1080}})
                                         << QStringList({"WL-1", "DP-1", "DP-2"}) << QStringList({"DP-1", "WL-1", "DP-2"});
-    QTest::newRow("3screensReorder2_3") << QVector<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}, {3840, 0, 1920, 1080}})
+    QTest::newRow("3screensReorder2_3") << QList<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}, {3840, 0, 1920, 1080}})
                                         << QStringList({"WL-1", "DP-1", "DP-2"}) << QStringList({"DP-1", "WL-1", "DP-2"});
-    QTest::newRow("3screensShuffled") << QVector<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}, {3840, 0, 1920, 1080}})
+    QTest::newRow("3screensShuffled") << QList<QRect>({{0, 0, 1920, 1080}, {1920, 0, 1920, 1080}, {3840, 0, 1920, 1080}})
                                       << QStringList({"WL-1", "DP-1", "DP-2"}) << QStringList({"DP-2", "DP-1", "WL-1"});
 }
 
 void ShellTest::testReorderScreens()
 {
-    QFETCH(QVector<QRect>, geometries);
+    QFETCH(QList<QRect>, geometries);
     QFETCH(QStringList, orderBefore);
     QFETCH(QStringList, orderAfter);
 
@@ -474,11 +471,11 @@ void ShellTest::testReorderScreens()
     }
     setScreenOrder(orderBefore, true);
 
-    QVector<DesktopView *> desktopViews;
-    QVector<PanelView *> panelViews;
-    QVector<Plasma::Containment *> desktopContainments;
-    QVector<Plasma::Containment *> panelContainments;
-    QVector<QScreen *> screens;
+    QList<DesktopView *> desktopViews;
+    QList<PanelView *> panelViews;
+    QList<Plasma::Containment *> desktopContainments;
+    QList<Plasma::Containment *> panelContainments;
+    QList<QScreen *> screens;
 
     for (int i = 0; i < orderBefore.size(); ++i) {
         auto *view = m_corona->m_desktopViewForScreen[i];
@@ -495,7 +492,6 @@ void ShellTest::testReorderScreens()
         QScreen *s = screens[i];
         auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.plasma.panel"));
         // If the panel fails to load (on ci plasma-desktop isn't here) we want the "failed" containment to be of panel type anyways
-        panelCont->setContainmentType(Plasma::Types::PanelContainment);
         QVERIFY(m_corona->m_panelViews.contains(panelCont));
         QCOMPARE(panelCont->screen(), 0);
         m_corona->m_panelViews[panelCont]->setScreenToFollow(s);
@@ -520,13 +516,13 @@ void ShellTest::testReorderScreens()
         view->screenToFollow();
     }
 
-    QVector<DesktopView *> desktopViewsAfter;
-    QVector<PanelView *> panelViewsAfter;
+    QList<DesktopView *> desktopViewsAfter;
+    QList<PanelView *> panelViewsAfter;
     panelViewsAfter.resize(orderAfter.size());
-    QVector<Plasma::Containment *> desktopContainmentsAfter;
-    QVector<Plasma::Containment *> panelContainmentsAfter;
+    QList<Plasma::Containment *> desktopContainmentsAfter;
+    QList<Plasma::Containment *> panelContainmentsAfter;
     panelContainmentsAfter.resize(orderAfter.size());
-    QVector<QScreen *> screensAfter;
+    QList<QScreen *> screensAfter;
 
     for (int i = 0; i < orderAfter.size(); ++i) {
         auto *view = m_corona->m_desktopViewForScreen[i];
@@ -574,9 +570,9 @@ void ShellTest::testReorderContainments()
     testSecondScreenInsertion();
     testPanelInsertion();
 
-    QVector<DesktopView *> desktopViews;
-    QVector<Plasma::Containment *> desktopContainments;
-    QVector<QScreen *> screens = m_corona->m_screenPool->screenOrder().toVector();
+    QList<DesktopView *> desktopViews;
+    QList<Plasma::Containment *> desktopContainments;
+    QList<QScreen *> screens = m_corona->m_screenPool->screenOrder().toVector();
     QCOMPARE(screens.size(), 3);
 
     for (int i = 0; i < screens.size(); ++i) {
