@@ -18,18 +18,13 @@
 #include <QStandardPaths>
 
 #include <KConfigLoader>
-#include <KDeclarative/KDeclarative>
+#include <KConfigPropertyMap>
 #include <KLocalizedString>
 #include <KPackage/Package>
 #include <KPackage/PackageLoader>
 #include <Plasma/ContainmentActions>
 #include <Plasma/Corona>
 #include <Plasma/PluginLoader>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KDeclarative/ConfigPropertyMap>
-#else
-#include <KConfigPropertyMap>
-#endif
 
 class WallpaperConfigModel : public PlasmaQuick::ConfigModel
 {
@@ -46,11 +41,10 @@ ContainmentConfigView::ContainmentConfigView(Plasma::Containment *cont, QWindow
     , m_containment(cont)
 {
     qmlRegisterAnonymousType<QAbstractItemModel>("QAbstractItemModel", 1);
-    rootContext()->setContextProperty(QStringLiteral("configDialog"), this);
-    setCurrentWallpaper(cont->containment()->wallpaper());
+    setCurrentWallpaper(cont->containment()->wallpaperPlugin());
 
     KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Wallpaper"));
-    pkg.setPath(m_containment->wallpaper());
+    pkg.setPath(m_containment->wallpaperPlugin());
     KConfigGroup cfg = m_containment->config();
     cfg = KConfigGroup(&cfg, "Wallpaper");
 
@@ -71,7 +65,7 @@ PlasmaQuick::ConfigModel *ContainmentConfigView::containmentActionConfigModel()
     if (!m_containmentActionConfigModel) {
         m_containmentActionConfigModel = new PlasmaQuick::ConfigModel(this);
 
-        const QVector<KPluginMetaData> actions = Plasma::PluginLoader::self()->listContainmentActionsMetaData(QString());
+        const QList<KPluginMetaData> actions = Plasma::PluginLoader::self()->listContainmentActionsMetaData(QString());
 
         KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Generic"));
 
@@ -157,61 +151,40 @@ QQmlPropertyMap *ContainmentConfigView::wallpaperConfiguration() const
 
 QString ContainmentConfigView::currentWallpaper() const
 {
-    return m_currentWallpaper;
+    return m_currentWallpaperPlugin;
 }
 
-void ContainmentConfigView::setCurrentWallpaper(const QString &wallpaper)
+void ContainmentConfigView::setCurrentWallpaper(const QString &wallpaperPlugin)
 {
-    if (m_currentWallpaper == wallpaper) {
+    if (m_currentWallpaperPlugin == wallpaperPlugin) {
         return;
     }
 
     delete m_ownWallpaperConfig;
     m_ownWallpaperConfig = nullptr;
 
-    if (m_containment->wallpaper() == wallpaper) {
+    if (m_containment->wallpaperPlugin() == wallpaperPlugin) {
         syncWallpaperObjects();
     } else {
         // we have to construct an independent ConfigPropertyMap when we want to configure wallpapers that are not the current one
         KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Generic"));
         pkg.setDefaultPackageRoot(QStringLiteral(PLASMA_RELATIVE_DATA_INSTALL_DIR "/wallpapers"));
-        pkg.setPath(wallpaper);
+        pkg.setPath(wallpaperPlugin);
         QFile file(pkg.filePath("config", QStringLiteral("main.xml")));
-        KConfigGroup cfg = m_containment->config();
-        cfg = KConfigGroup(&cfg, "Wallpaper");
-        cfg = KConfigGroup(&cfg, wallpaper);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        m_currentWallpaperConfig = m_ownWallpaperConfig = new KDeclarative::ConfigPropertyMap(new KConfigLoader(cfg, &file, this), this);
-#else
+        KConfigGroup cfg = m_containment->config().group("Wallpaper").group(wallpaperPlugin);
         m_currentWallpaperConfig = m_ownWallpaperConfig = new KConfigPropertyMap(new KConfigLoader(cfg, &file, this), this);
-#endif
     }
 
-    m_currentWallpaper = wallpaper;
+    m_currentWallpaperPlugin = wallpaperPlugin;
     Q_EMIT currentWallpaperChanged();
     Q_EMIT wallpaperConfigurationChanged();
 }
 
 void ContainmentConfigView::applyWallpaper()
 {
-    m_containment->setWallpaper(m_currentWallpaper);
-
-    syncWallpaperObjects();
-
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (m_currentWallpaperConfig && m_ownWallpaperConfig) {
-        for (const auto &key : m_ownWallpaperConfig->keys()) {
-            auto value = m_ownWallpaperConfig->value(key);
-            m_currentWallpaperConfig->insert(key, value);
-            m_currentWallpaperConfig->valueChanged(key, value);
-        }
-    }
-
-    delete m_ownWallpaperConfig;
-    m_ownWallpaperConfig = nullptr;
-#else
     static_cast<KConfigPropertyMap *>(m_currentWallpaperConfig)->writeConfig();
-#endif
+    m_containment->setWallpaperPlugin(m_currentWallpaperPlugin);
+    syncWallpaperObjects();
 
     Q_EMIT wallpaperConfigurationChanged();
 }
