@@ -16,7 +16,6 @@
 #include <QVBoxLayout>
 #include <QWindow>
 
-#include <KAboutPluginDialog>
 #include <klocalizedstring.h>
 
 #include <Plasma/Containment>
@@ -30,7 +29,7 @@ CurrentContainmentActionsModel::CurrentContainmentActionsModel(Plasma::Containme
     , m_tempConfigParent(QString(), KConfig::SimpleConfig)
 {
     m_baseCfg = KConfigGroup(m_containment->corona()->config(), "ActionPlugins");
-    m_baseCfg = KConfigGroup(&m_baseCfg, QString::number(m_containment->containmentType()));
+    m_baseCfg = KConfigGroup(&m_baseCfg, QString::number((int)m_containment->containmentType()));
 
     QHash<QString, Plasma::ContainmentActions *> actions = containment->containmentActions();
 
