@@ -17,35 +17,40 @@
 #include <QScreen>
 #include <qopenglshaderprogram.h>
 
+#include <PlasmaQuick/AppletQuickItem>
+
 #include <KAuthorized>
 #include <KStartupInfo>
+#include <KX11Extras>
 #include <kactivities/controller.h>
 #include <klocalizedstring.h>
 #include <kwindowsystem.h>
 
 #include <KPackage/Package>
 
-#include <KWayland/Client/plasmashell.h>
-#include <KWayland/Client/surface.h>
+#include <LayerShellQt/Window>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
     : PlasmaQuick::ContainmentView(corona, nullptr)
     , m_accentColor(Qt::transparent)
-    , m_windowType(Desktop)
-    , m_shellSurface(nullptr)
 {
     QObject::setParent(corona);
 
-    // Setting clear color to black makes the panel lose alpha channel on X11. This looks like
-    // a QtXCB bug, so set clear color only on Wayland to let the compositor optimize rendering.
+    setColor(Qt::black);
+    setFlags(Qt::Window | Qt::FramelessWindowHint);
+
     if (KWindowSystem::isPlatformWayland()) {
-        setColor(Qt::black);
+        m_layerWindow = LayerShellQt::Window::get(this);
+        m_layerWindow->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityOnDemand);
+        m_layerWindow->setExclusiveZone(-1);
+        m_layerWindow->setLayer(LayerShellQt::Window::LayerBackground);
+        m_layerWindow->setScope(QStringLiteral("desktop"));
+        m_layerWindow->setCloseOnDismissed(false);
+    } else {
+        KX11Extras::setType(winId(), NET::Desktop);
+        KX11Extras::setState(winId(), NET::KeepBelow);
     }
 
     if (targetScreen) {
@@ -54,7 +59,6 @@ DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
         setTitle(corona->kPackage().metadata().name());
     }
 
-    setFlags(Qt::Window | Qt::FramelessWindowHint);
     rootContext()->setContextProperty(QStringLiteral("desktop"), this);
     setSource(corona->kPackage().fileUrl("views", QStringLiteral("Desktop.qml")));
     connect(this, &ContainmentView::containmentChanged, this, &DesktopView::slotContainmentChanged);
@@ -105,6 +109,12 @@ void DesktopView::setScreenToFollow(QScreen *screen)
         return;
     }
 
+    // layer surfaces can't be moved between outputs, so hide and show the window on a new output
+    const bool remap = m_layerWindow && isVisible();
+    if (remap) {
+        setVisible(false);
+    }
+
     if (m_screenToFollow) {
         disconnect(m_screenToFollow.data(), &QScreen::geometryChanged, this, &DesktopView::screenGeometryChanged);
     }
@@ -112,6 +122,10 @@ void DesktopView::setScreenToFollow(QScreen *screen)
     setScreen(screen);
     connect(m_screenToFollow.data(), &QScreen::geometryChanged, this, &DesktopView::screenGeometryChanged);
 
+    if (remap) {
+        setVisible(true);
+    }
+
     QString rectString;
     QDebug(&rectString) << screen->geometry();
     setTitle(QStringLiteral("%1 @ %2").arg(corona()->kPackage().metadata().name()).arg(rectString));
@@ -125,16 +139,12 @@ QScreen *DesktopView::screenToFollow() const
 
 void DesktopView::adaptToScreen()
 {
-    ensureWindowType();
-
     // This happens sometimes, when shutting down the process
     if (!m_screenToFollow) {
         return;
     }
 
-    if (m_windowType == Desktop || m_windowType == WindowedDesktop) {
-        screenGeometryChanged();
-    }
+    screenGeometryChanged();
 }
 
 bool DesktopView::usedInAccentColor() const
@@ -181,78 +191,81 @@ void DesktopView::resetAccentColor()
     Q_EMIT accentColorChanged(Qt::transparent);
 }
 
-DesktopView::WindowType DesktopView::windowType() const
+#if PROJECT_VERSION_PATCH >= 80 || PROJECT_VERSION_MINOR >= 80
+bool DesktopView::showPreviewBanner() const
 {
-    return m_windowType;
+    static const bool shouldShowPreviewBanner = !KConfigGroup(KSharedConfig::openConfig("kdeglobals"), "General").readEntry("HideDesktopPreviewBanner", false);
+    return shouldShowPreviewBanner;
 }
 
-void DesktopView::setWindowType(DesktopView::WindowType type)
+QString DesktopView::previewBannerTitle() const
 {
-    if (m_windowType == type) {
-        return;
+    // Plasma 6 pre-release versions
+    if constexpr (PROJECT_VERSION_MAJOR == 5 && PROJECT_VERSION_MINOR >= 80) {
+        if constexpr (PROJECT_VERSION_PATCH == 80) {
+            // Development
+            return i18nc("@label %1 is the Plasma version", "KDE Plasma 6.0 Dev");
+        } else if constexpr (PROJECT_VERSION_MINOR == 80) {
+            // Alpha, 5.80.0
+            return i18nc("@label %1 is the Plasma version", "KDE Plasma 6.0 Alpha");
+        } else if constexpr (PROJECT_VERSION_MINOR == 90) {
+            // Beta 1, 5.90.0
+            return i18nc("@label %1 is the Plasma version", "KDE Plasma 6.0 Beta 1");
+        } else if constexpr (PROJECT_VERSION_MINOR == 91) {
+            // Beta 2, 5.91.0
+            return i18nc("@label %1 is the Plasma version", "KDE Plasma 6.0 Beta 2");
+        } else if constexpr (PROJECT_VERSION_MINOR == 92) {
+            // RC1, 5.92.0
+            return i18nc("@label %1 is the Plasma version, RC meaning Release Candidate", "KDE Plasma 6.0 RC1");
+        } else if constexpr (PROJECT_VERSION_MINOR == 93) {
+            // RC2, 5.93.0
+            return i18nc("@label %1 is the Plasma version, RC meaning Release Candidate", "KDE Plasma 6.0 RC2");
+        }
     }
 
-    m_windowType = type;
+    /*
+     * Versions are reported as follows:
+     *  Development, 5.27.80 -> KDE Plasma 6.0 Dev
+     *  Beta,        5.27.90 -> KDE Plasma 6.0 Beta
+     *  Development, 6.0.80  -> KDE Plasma 6.1 Dev
+     *  Beta,        6.0.90  -> KDE Plasma 6.1 Beta
+     *  Beta,        6.0.91  -> KDE Plasma 6.1 Beta 2
+     */
 
-    adaptToScreen();
+    // finalMajor, finalMinor is the final version in the line and
+    // should be updated after the final Plasma 6 release
+    constexpr int finalMajor = 5;
+    constexpr int finalMinor = 27;
 
-    Q_EMIT windowTypeChanged();
-}
+    // Incremented minor, which is zeroed and major incremented when
+    // we reach the final version in the major release line
+    constexpr int major = (PROJECT_VERSION_MAJOR == finalMajor && PROJECT_VERSION_MINOR == finalMinor) ? PROJECT_VERSION_MAJOR + 1 : PROJECT_VERSION_MAJOR;
+    constexpr int minor = (PROJECT_VERSION_MAJOR == finalMajor && PROJECT_VERSION_MINOR == finalMinor) ? 0 : PROJECT_VERSION_MINOR + 1;
+    const QString version = QStringLiteral("%1.%2").arg(QString::number(major), QString::number(minor));
 
-void DesktopView::ensureWindowType()
-{
-    // This happens sometimes, when shutting down the process
-    if (!screen()) {
-        return;
-    }
-
-    if (m_windowType == Window) {
-        setFlags(Qt::Window);
-        KWindowSystem::setType(winId(), NET::Normal);
-        KWindowSystem::clearState(winId(), NET::FullScreen);
-        if (m_shellSurface) {
-            m_shellSurface->setRole(KWayland::Client::PlasmaShellSurface::Role::Normal);
-            m_shellSurface->setSkipTaskbar(false);
+    if constexpr (PROJECT_VERSION_PATCH == 80) {
+        // Development version
+        return i18nc("@label %1 is the Plasma version", "KDE Plasma %1 Dev", version);
+    } else if constexpr (PROJECT_VERSION_PATCH >= 90) {
+        // Beta version
+        if constexpr (PROJECT_VERSION_PATCH == 90) {
+            return i18nc("@label %1 is the Plasma version", "KDE Plasma %1 Beta", version);
+        } else {
+            constexpr int betaNumber = PROJECT_VERSION_PATCH - 89;
+            return i18nc("@label %1 is the Plasma version, %2 is the beta release number", "KDE Plasma %1 Beta %2", version, betaNumber);
         }
-
-    } else if (m_windowType == Desktop) {
-        setFlags(Qt::Window | Qt::FramelessWindowHint);
-        KWindowSystem::setType(winId(), NET::Desktop);
-        KWindowSystem::setState(winId(), NET::KeepBelow);
-        if (m_shellSurface) {
-            m_shellSurface->setRole(KWayland::Client::PlasmaShellSurface::Role::Desktop);
-            m_shellSurface->setSkipTaskbar(true);
-        }
-
-    } else if (m_windowType == WindowedDesktop) {
-        KWindowSystem::setType(winId(), NET::Normal);
-        KWindowSystem::clearState(winId(), NET::FullScreen);
-        setFlags(Qt::FramelessWindowHint | flags());
-        if (m_shellSurface) {
-            m_shellSurface->setRole(KWayland::Client::PlasmaShellSurface::Role::Normal);
-            m_shellSurface->setSkipTaskbar(false);
-        }
-
-    } else if (m_windowType == FullScreen) {
-        setFlags(Qt::Window);
-        KWindowSystem::setType(winId(), NET::Normal);
-        KWindowSystem::setState(winId(), NET::FullScreen);
-        if (m_shellSurface) {
-            m_shellSurface->setRole(KWayland::Client::PlasmaShellSurface::Role::Normal);
-            m_shellSurface->setSkipTaskbar(false);
-        }
-    }
-}
-
-DesktopView::SessionType DesktopView::sessionType() const
-{
-    if (qobject_cast<ShellCorona *>(corona())) {
-        return ShellSession;
     } else {
-        return ApplicationSession;
+        // Unrecognised version
+        return i18nc("@label %1 is the Plasma version", "KDE Plasma %1", WORKSPACE_VERSION_STRING);
     }
 }
 
+QString DesktopView::previewBannerText() const
+{
+    return i18nc("@info:usagetip", "Visit bugs.kde.org to report issues");
+}
+#endif
+
 QVariantMap DesktopView::candidateContainmentsGraphicItems() const
 {
     QVariantMap map;
@@ -261,7 +274,7 @@ QVariantMap DesktopView::candidateContainmentsGraphicItems() const
     }
 
     for (auto cont : corona()->containmentsForScreen(containment()->screen())) {
-        map[cont->activity()] = cont->property("_plasma_graphicObject");
+        map[cont->activity()] = QVariant::fromValue(PlasmaQuick::AppletQuickItem::itemForApplet(cont));
     }
     return map;
 }
@@ -273,18 +286,7 @@ Q_INVOKABLE QString DesktopView::fileFromPackage(const QString &key, const QStri
 
 bool DesktopView::event(QEvent *e)
 {
-    if (e->type() == QEvent::PlatformSurface) {
-        switch (static_cast<QPlatformSurfaceEvent *>(e)->surfaceEventType()) {
-        case QPlatformSurfaceEvent::SurfaceCreated:
-            setupWaylandIntegration();
-            ensureWindowType();
-            break;
-        case QPlatformSurfaceEvent::SurfaceAboutToBeDestroyed:
-            delete m_shellSurface;
-            m_shellSurface = nullptr;
-            break;
-        }
-    } else if (e->type() == QEvent::FocusOut) {
+    if (e->type() == QEvent::FocusOut) {
         m_krunnerText.clear();
     }
 
@@ -369,12 +371,20 @@ void DesktopView::showConfigurationInterface(Plasma::Applet *applet)
 
     Plasma::Containment *cont = qobject_cast<Plasma::Containment *>(applet);
 
-    if (cont && cont->isContainment() && cont->containmentType() == Plasma::Types::DesktopContainment) {
+    if (cont && cont->isContainment() && cont->containmentType() == Plasma::Containment::Desktop) {
         m_configView = new ContainmentConfigView(cont);
         // if we changed containment with the config open, relaunch the config dialog but for the new containment
         // third arg is used to disconnect when the config closes
         connect(this, &ContainmentView::containmentChanged, m_configView.data(), [this]() {
-            showConfigurationInterface(containment());
+            if (containment()->property("wallpaperGraphicsObject").value<QObject *>()) {
+                showConfigurationInterface(containment());
+            } else {
+                // BUG 407619: wallpaperConfiguration is invalid after changing layout
+                connect(containment(), &Plasma::Containment::wallpaperGraphicsObjectChanged, this, [this] {
+                    disconnect(static_cast<Plasma::Containment *>(sender()), &Plasma::Containment::wallpaperGraphicsObjectChanged, this, nullptr);
+                    showConfigurationInterface(static_cast<Plasma::Containment *>(sender()));
+                });
+            }
         });
     } else {
         m_configView = new PlasmaQuick::ConfigView(applet);
@@ -417,12 +427,7 @@ void DesktopView::slotScreenChanged(int newId)
 
 void DesktopView::screenGeometryChanged()
 {
-    const QRect geo = m_screenToFollow->geometry();
-    //     qDebug() << "newGeometry" << this << geo << geometry();
-    setGeometry(geo);
-    if (m_shellSurface) {
-        m_shellSurface->setPosition(geo.topLeft());
-    }
+    setGeometry(m_screenToFollow->geometry());
     Q_EMIT geometryChanged();
 }
 
@@ -432,27 +437,6 @@ void DesktopView::coronaPackageChanged(const KPackage::Package &package)
     setSource(package.fileUrl("views", QStringLiteral("Desktop.qml")));
 }
 
-void DesktopView::setupWaylandIntegration()
-{
-    if (m_shellSurface) {
-        // already setup
-        return;
-    }
-    if (ShellCorona *c = qobject_cast<ShellCorona *>(corona())) {
-        using namespace KWayland::Client;
-        PlasmaShell *interface = c->waylandPlasmaShellInterface();
-        if (!interface) {
-            return;
-        }
-        Surface *s = Surface::fromWindow(this);
-        if (!s) {
-            return;
-        }
-        m_shellSurface = interface->createSurface(s, this);
-        m_shellSurface->setPosition(m_screenToFollow->geometry().topLeft());
-    }
-}
-
 void DesktopView::setAccentColorFromWallpaper(const QColor &accentColor)
 {
     if (!usedInAccentColor()) {
