@@ -19,11 +19,7 @@
 #include <QtWaylandClient/QtWaylandClientVersion>
 
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 #include <xcb/randr.h>
 #include <xcb/xcb_event.h>
@@ -40,11 +36,7 @@ public:
         : QWaylandClientExtensionTemplate(1)
     {
         setParent(parent);
-#if QTWAYLANDCLIENT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
         initialize();
-#else
-        QMetaObject::invokeMethod(this, "addRegistryListener");
-#endif
     }
 
 protected:
@@ -59,6 +51,10 @@ protected:
 
     void kde_output_order_v1_done() override
     {
+        // If no output arrived it means we don't have *any* usable output
+        if (m_done) {
+            m_outputOrder.clear();
+        }
         m_done = true;
         Q_EMIT outputOrderChanged(m_outputOrder);
     }
@@ -75,13 +71,7 @@ OutputOrderWatcher::OutputOrderWatcher(QObject *parent)
     : QObject(parent)
 {
     connect(qGuiApp, &QGuiApplication::screenAdded, this, &OutputOrderWatcher::refresh);
-    connect(qGuiApp, &QGuiApplication::screenRemoved, this, [this](QScreen *screen) {
-        // Are we in the special fake single screen situation?
-        if (m_outputOrder.size() == 1 && m_outputOrder.contains(screen->name())) {
-            m_outputOrder.clear();
-        }
-        refresh();
-    });
+    connect(qGuiApp, &QGuiApplication::screenRemoved, this, &OutputOrderWatcher::refresh);
 }
 
 void OutputOrderWatcher::useFallback(bool fallback)
@@ -249,11 +239,7 @@ void X11OutputOrderWatcher::refresh()
     }
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-bool X11OutputOrderWatcher::nativeEventFilter(const QByteArray &eventType, void *message, long int *result)
-#else
 bool X11OutputOrderWatcher::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result)
-#endif
 {
     Q_UNUSED(result);
     // a particular edge case: when we switch the only enabled screen
