@@ -13,17 +13,19 @@
 #include <QWindow> // For WId
 #endif
 
+#include <KSvg/FrameSvg>
+
 #include <PlasmaQuick/ConfigView>
 #include <PlasmaQuick/ContainmentView>
+#include <PlasmaQuick/PopupPlasmaWindow>
 
+class AutoHideScreenEdge;
 class ShellCorona;
+class PanelConfigView;
 
-namespace KWayland
+namespace LayerShellQt
 {
-namespace Client
-{
-class PlasmaShellSurface;
-}
+class Window;
 }
 
 class PanelView : public PlasmaQuick::ContainmentView
@@ -82,7 +84,7 @@ class PanelView : public PlasmaQuick::ContainmentView
      * The borders that should have a shadow
      * @since 5.7
      */
-    Q_PROPERTY(Plasma::FrameSvg::EnabledBorders enabledBorders READ enabledBorders NOTIFY enabledBordersChanged)
+    Q_PROPERTY(KSvg::FrameSvg::EnabledBorders enabledBorders READ enabledBorders NOTIFY enabledBordersChanged)
 
     /**
      * information about the screen in which the panel is in
@@ -101,6 +103,13 @@ class PanelView : public PlasmaQuick::ContainmentView
      */
     Q_PROPERTY(OpacityMode opacityMode READ opacityMode WRITE setOpacityMode NOTIFY opacityModeChanged)
 
+    /**
+     *  Property that determines how a panel's length behaves.
+     *
+     * @see LengthMode
+     */
+    Q_PROPERTY(LengthMode lengthMode READ lengthMode WRITE setLengthMode NOTIFY lengthModeChanged)
+
     /**
      *  Property that determines whether adaptive opacity is used.
      */
@@ -110,7 +119,7 @@ class PanelView : public PlasmaQuick::ContainmentView
      * Property that determines whether the panel is currently floating or not
      * @since 5.25
      */
-    Q_PROPERTY(int floating READ floating WRITE setFloating NOTIFY floatingChanged)
+    Q_PROPERTY(bool floating READ floating WRITE setFloating NOTIFY floatingChanged)
 
     /**
      * The minimum thickness in pixels that the panel can have.
@@ -122,8 +131,6 @@ public:
     enum VisibilityMode {
         NormalPanel = 0, /** default, always visible panel, the windowmanager reserves a places for it */
         AutoHide, /**the panel will be shownn only if the mouse cursor is on screen edges */
-        LetWindowsCover, /** always visible, windows will go over the panel, no area reserved */
-        WindowsGoBelow, /** always visible, windows will go under the panel, no area reserved */
     };
     Q_ENUM(VisibilityMode)
 
@@ -135,6 +142,14 @@ public:
     };
     Q_ENUM(OpacityMode)
 
+    /** Enumeration of possible length sizing modes. */
+    enum LengthMode {
+        FillAvailable = 0, /** The panel will always fill all the available screen width/height */
+        FitContent, /** The panel will always have the same size as its content */
+        Custom /** The panel size and offset can be set by the user */
+    };
+    Q_ENUM(LengthMode)
+
     explicit PanelView(ShellCorona *corona, QScreen *targetScreen = nullptr, QWindow *parent = nullptr);
     ~PanelView() override;
 
@@ -174,7 +189,7 @@ public:
     Plasma::Types::BackgroundHints backgroundHints() const;
     void setBackgroundHints(Plasma::Types::BackgroundHints hint);
 
-    Plasma::FrameSvg::EnabledBorders enabledBorders() const;
+    KSvg::FrameSvg::EnabledBorders enabledBorders() const;
 
     VisibilityMode visibilityMode() const;
     void setVisibilityMode(PanelView::VisibilityMode mode);
@@ -182,6 +197,8 @@ public:
     PanelView::OpacityMode opacityMode() const;
     bool adaptiveOpacityEnabled();
     void setOpacityMode(PanelView::OpacityMode mode);
+    PanelView::LengthMode lengthMode() const;
+    void setLengthMode(PanelView::LengthMode mode);
     void updateAdaptiveOpacityEnabled();
 
     /**
@@ -193,7 +210,7 @@ public:
     static KConfigGroup panelConfig(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen);
     static KConfigGroup panelConfigDefaults(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen);
 
-    void updateStruts();
+    void updateExclusiveZone();
 
     /*This is different from screen() as is always there, even if the window is
       temporarily outside the screen or if is hidden: only plasmashell will ever
@@ -221,11 +238,13 @@ Q_SIGNALS:
     void enabledBordersChanged();
     void floatingChanged();
     void minThicknessChanged();
+    void geometryChanged();
 
     // QWindow does not have a property for screen. Adding this property requires re-implementing the signal
     void screenToFollowChanged(QScreen *screen);
     void visibilityModeChanged();
     void opacityModeChanged();
+    void lengthModeChanged();
     void adaptiveOpacityEnabledChanged();
 
 protected Q_SLOTS:
@@ -257,8 +276,6 @@ private:
     void integrateScreen();
     bool containmentContainsPosition(const QPointF &point) const;
     QPointF positionAdjustedForContainment(const QPointF &point) const;
-    void setupWaylandIntegration();
-    void visibilityModeToWayland();
     bool edgeActivated() const;
     bool canSetStrut() const;
 
@@ -272,6 +289,7 @@ private:
     int m_topPadding;
     int m_leftPadding;
     int m_rightPadding;
+    float m_floatingness;
     int m_bottomFloatingPadding;
     int m_topFloatingPadding;
     int m_leftFloatingPadding;
@@ -283,19 +301,22 @@ private:
     bool m_containsMouse = false;
     bool m_fakeEventPending = false;
     Qt::Alignment m_alignment;
-    QPointer<PlasmaQuick::ConfigView> m_panelConfigView;
+    QPointer<PlasmaQuick::ConfigView> m_appletConfigView;
+    QPointer<PlasmaQuick::PopupPlasmaWindow> m_panelConfigView = 0;
     ShellCorona *m_corona;
     QTimer m_strutsTimer;
     VisibilityMode m_visibilityMode;
     OpacityMode m_opacityMode;
+    LengthMode m_lengthMode;
     Plasma::Theme m_theme;
     QTimer m_unhideTimer;
     Plasma::Types::BackgroundHints m_backgroundHints;
-    Plasma::FrameSvg::EnabledBorders m_enabledBorders = Plasma::FrameSvg::AllBorders;
-    KWayland::Client::PlasmaShellSurface *m_shellSurface;
+    KSvg::FrameSvg::EnabledBorders m_enabledBorders = KSvg::FrameSvg::AllBorders;
+    LayerShellQt::Window *m_layerWindow = nullptr;
     QPointer<QScreen> m_lastScreen;
     QPointer<QScreen> m_screenToFollow;
     QMetaObject::Connection m_transientWindowVisibleWatcher;
+    AutoHideScreenEdge *m_autoHideScreenEdge = nullptr;
 
     static const int STRUTSTIMERDELAY = 200;
 };
