@@ -156,11 +156,11 @@ QString Panel::alignment() const
 // NOTE: Alignment is the only one that reads and writes directly from panelconfig()
 void Panel::setAlignment(const QString &alignment)
 {
-    int a = Qt::AlignLeft;
-    if (alignment.compare("right", Qt::CaseInsensitive) == 0) {
+    int a = Qt::AlignCenter;
+    if (alignment.compare("left", Qt::CaseInsensitive) == 0) {
+        a = Qt::AlignLeft;
+    } else if (alignment.compare("right", Qt::CaseInsensitive) == 0) {
         a = Qt::AlignRight;
-    } else if (alignment.compare("center", Qt::CaseInsensitive) == 0) {
-        a = Qt::AlignCenter;
     }
 
     // Always prefer the view, if available
@@ -277,10 +277,6 @@ QString Panel::hiding() const
         return "none";
     case PanelView::AutoHide:
         return "autohide";
-    case PanelView::LetWindowsCover:
-        return "windowscover";
-    case PanelView::WindowsGoBelow:
-        return "windowsbelow";
     }
     return "none";
 }
@@ -290,10 +286,6 @@ void Panel::setHiding(const QString &mode)
     PanelView::VisibilityMode visibilityMode = PanelView::NormalPanel;
     if (mode.compare("autohide", Qt::CaseInsensitive) == 0) {
         visibilityMode = PanelView::AutoHide;
-    } else if (mode.compare("windowscover", Qt::CaseInsensitive) == 0) {
-        visibilityMode = PanelView::LetWindowsCover;
-    } else if (mode.compare("windowsbelow", Qt::CaseInsensitive) == 0) {
-        visibilityMode = PanelView::WindowsGoBelow;
     }
 
     if (panel()) {
@@ -303,4 +295,21 @@ void Panel::setHiding(const QString &mode)
     }
 }
 
+bool Panel::floating() const
+{
+    if (panel()) {
+        return panel()->floating();
+    } else {
+        return panelConfig().readEntry("floating", true);
+    }
+}
+
+void Panel::setFloating(bool floating)
+{
+    if (panel()) {
+        panel()->setFloating(floating);
+    } else {
+        panelConfig().writeEntry("floating", (int)floating);
+    }
+}
 }
