@@ -19,7 +19,6 @@
 #include <KLocalizedContext>
 #include <QDebug>
 #include <klocalizedstring.h>
-#include <kmimetypetrader.h>
 #include <kshell.h>
 
 #include <KPackage/Package>
@@ -30,7 +29,6 @@
 #include <qstandardpaths.h>
 
 #include "../screenpool.h"
-#include "../standaloneappcorona.h"
 #include "appinterface.h"
 #include "configgroup.h"
 #include "containment.h"
@@ -229,7 +227,7 @@ bool ScriptEngine::isPanel(const Plasma::Containment *c)
         return false;
     }
 
-    return c->containmentType() == Plasma::Types::PanelContainment || c->containmentType() == Plasma::Types::CustomPanelContainment;
+    return c->containmentType() == Plasma::Containment::Panel || c->containmentType() == Plasma::Containment::CustomPanel;
 }
 
 Plasma::Corona *ScriptEngine::corona() const
@@ -310,15 +308,8 @@ QStringList ScriptEngine::pendingUpdateScripts(Plasma::Corona *corona)
 
 QStringList ScriptEngine::availableActivities() const
 {
-    ShellCorona *sc = qobject_cast<ShellCorona *>(m_corona);
-    StandaloneAppCorona *ac = qobject_cast<StandaloneAppCorona *>(m_corona);
-    if (sc) {
-        return sc->availableActivities();
-    } else if (ac) {
-        return ac->availableActivities();
-    }
-
-    return QStringList();
+    ShellCorona *sc = static_cast<ShellCorona *>(m_corona);
+    return sc->availableActivities();
 }
 
 QList<Containment *> ScriptEngine::desktopsForActivity(const QString &id)
@@ -349,17 +340,9 @@ QList<Containment *> ScriptEngine::desktopsForActivity(const QString &id)
         // this can happen when the activity already exists but has never been activated
         // with the current shell package and layout.js is run to set up the shell for the
         // first time
-        ShellCorona *sc = qobject_cast<ShellCorona *>(m_corona);
-        StandaloneAppCorona *ac = qobject_cast<StandaloneAppCorona *>(m_corona);
-        if (sc) {
-            foreach (int i, sc->screenIds()) {
-                result << new Containment(sc->createContainmentForActivity(id, i), this);
-            }
-        } else if (ac) {
-            const int numScreens = m_corona->numScreens();
-            for (int i = 0; i < numScreens; ++i) {
-                result << new Containment(ac->createContainmentForActivity(id, i), this);
-            }
+        ShellCorona *sc = static_cast<ShellCorona *>(m_corona);
+        foreach (int i, sc->screenIds()) {
+            result << new Containment(sc->createContainmentForActivity(id, i), this);
         }
     }
 
@@ -383,13 +366,8 @@ Plasma::Containment *ScriptEngine::createContainment(const QString &type, const
 
     Plasma::Containment *c = nullptr;
     if (type == QLatin1String("Panel")) {
-        ShellCorona *sc = qobject_cast<ShellCorona *>(m_corona);
-        StandaloneAppCorona *ac = qobject_cast<StandaloneAppCorona *>(m_corona);
-        if (sc) {
-            c = sc->addPanel(plugin);
-        } else if (ac) {
-            c = ac->addPanel(plugin);
-        }
+        ShellCorona *sc = static_cast<ShellCorona *>(m_corona);
+        c = sc->addPanel(plugin);
     } else {
         c = m_corona->createContainment(plugin);
     }
@@ -404,7 +382,7 @@ Plasma::Containment *ScriptEngine::createContainment(const QString &type, const
             cg.writeEntry(QStringLiteral("lastScreen"), 0);
             c->restore(cg);
         }
-        c->updateConstraints(Plasma::Types::AllConstraints | Plasma::Types::StartupCompletedConstraint);
+        c->updateConstraints(Plasma::Applet::AllConstraints | Plasma::Applet::StartupCompletedConstraint);
         c->flushPendingConstraintsEvents();
     }
 
