@@ -138,6 +138,8 @@ public:
      */
     bool accentColorFromWallpaperEnabled() const;
 
+    Q_INVOKABLE QVariantMap wallpaper(uint screenNum = 0);
+
 Q_SIGNALS:
     void glInitializationFailed();
     // A preview for this containment has been rendered and saved to disk
@@ -147,6 +149,8 @@ Q_SIGNALS:
     // This API is used only by autotests, do we need something else?
     void screenOrderChanged(QList<QScreen *> screens);
 
+    void wallpaperChanged(uint screenNum);
+
 public Q_SLOTS:
     /**
      * Request saving applicationConfig on disk, it's event compressed, not immediate
@@ -174,6 +178,7 @@ public Q_SLOTS:
     void toggleActivityManager();
     void toggleWidgetExplorer();
     QString evaluateScript(const QString &string);
+    void setWallpaper(const QString &wallpaperPlugin, const QVariantMap &parameters, uint screenNum = 0);
     void activateLauncherMenu();
     QRgb color() const;
 
