@@ -19,7 +19,6 @@
 #include <unistd.h>
 
 #include "kcminit_interface.h"
-#include "kded_interface.h"
 #include "ksmserver_interface.h"
 
 #include <KCompositeJob>
@@ -117,7 +116,6 @@ public:
     {
         qCDebug(PLASMA_SESSION) << "Phase 2";
         addSubjob(new AutoStartAppsJob(m_autostart, 2));
-        addSubjob(new KDEDInitJob());
     }
 };
 
@@ -176,14 +174,14 @@ Startup::Startup(QObject *parent)
     }
 
     // Keep for KF5; remove in KF6 (KInit will be gone then)
-    QProcess::execute(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/start_kdeinit_wrapper"), QStringList());
+    QProcess::execute(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF6 "/start_kdeinit_wrapper"), QStringList());
 
     KJob *phase1 = nullptr;
     m_lock.reset(new QEventLoopLocker);
 
-    const QVector<KJob *> sequence = {
+    const QList<KJob *> sequence = {
         new StartProcessJob(QStringLiteral("kcminit_startup"), {}),
-        new StartServiceJob(QStringLiteral("kded5"), {}, QStringLiteral("org.kde.kded5"), {}),
+        new StartServiceJob(QStringLiteral("kded6"), {}, QStringLiteral("org.kde.kded6"), {}),
         x11WindowManagerJob,
         new StartServiceJob(QStringLiteral("ksmserver"), QCoreApplication::instance()->arguments().mid(1), QStringLiteral("org.kde.ksmserver")),
         new StartupPhase0(autostart, this),
@@ -264,23 +262,6 @@ void KCMInitJob::start()
     connect(watcher, &QDBusPendingCallWatcher::finished, watcher, &QObject::deleteLater);
 }
 
-KDEDInitJob::KDEDInitJob()
-{
-}
-
-void KDEDInitJob::start()
-{
-    qCDebug(PLASMA_SESSION());
-    org::kde::kded5 kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QDBusConnection::sessionBus());
-    auto pending = kded.loadSecondPhase();
-
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pending, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this]() {
-        emitResult();
-    });
-    connect(watcher, &QDBusPendingCallWatcher::finished, watcher, &QObject::deleteLater);
-}
-
 RestoreSessionJob::RestoreSessionJob()
     : KJob()
 {
@@ -308,7 +289,7 @@ void AutoStartAppsJob::start()
 {
     qCDebug(PLASMA_SESSION);
 
-    QTimer::singleShot(0, this, [=]() {
+    QTimer::singleShot(0, this, [this]() {
         do {
             QString serviceName = m_autoStart.startService();
             if (serviceName.isEmpty()) {
