@@ -29,7 +29,8 @@
 #include <unistd.h>
 
 #include <autostartscriptdesktopfile.h>
-#include <updatelaunchenvjob.h>
+
+#include <KUpdateLaunchEnvironmentJob>
 
 #include "startplasma.h"
 
@@ -168,22 +169,7 @@ void runStartupConfig()
     KConfig config(QStringLiteral("plasma-localerc"));
     KConfigGroup formatsConfig = KConfigGroup(&config, "Formats");
 
-    // Note: not all of these (e.g. LC_CTYPE) can currently be changed through system settings (but they can be changed by modifying
-    // plasma-localrc manually).
-    const auto lcValues = {"LANG",
-                           "LC_ADDRESS",
-                           "LC_COLLATE",
-                           "LC_CTYPE",
-                           "LC_IDENTIFICATION",
-                           "LC_MONETARY",
-                           "LC_MESSAGES",
-                           "LC_MEASUREMENT",
-                           "LC_NAME",
-                           "LC_NUMERIC",
-                           "LC_PAPER",
-                           "LC_TELEPHONE",
-                           "LC_TIME",
-                           "LC_ALL"};
+    const auto lcValues = {"LANG", "LC_NUMERIC", "LC_TIME", "LC_MONETARY", "LC_MEASUREMENT", "LC_COLLATE", "LC_CTYPE"};
     for (auto lc : lcValues) {
         const QString value = formatsConfig.readEntry(lc, QString());
         if (!value.isEmpty()) {
@@ -205,28 +191,22 @@ void runStartupConfig()
 
 void setupCursor(bool wayland)
 {
-    const KConfig cfg(QStringLiteral("kcminputrc"));
-    const KConfigGroup inputCfg = cfg.group("Mouse");
-
-    const auto kcminputrc_mouse_cursorsize = inputCfg.readEntry("cursorSize", 24);
-    const auto kcminputrc_mouse_cursortheme = inputCfg.readEntry("cursorTheme", QStringLiteral("breeze_cursors"));
-    if (!kcminputrc_mouse_cursortheme.isEmpty()) {
 #ifdef XCURSOR_PATH
-        QByteArray path(XCURSOR_PATH);
-        path.replace("$XCURSOR_PATH", qgetenv("XCURSOR_PATH"));
-        qputenv("XCURSOR_PATH", path);
+    QByteArray path(XCURSOR_PATH);
+    path.replace("$XCURSOR_PATH", qgetenv("XCURSOR_PATH"));
+    qputenv("XCURSOR_PATH", path);
 #endif
-    }
 
     // TODO: consider linking directly
-    const int applyMouseStatus =
-        wayland ? 0 : runSync(QStringLiteral("kapplymousetheme"), {kcminputrc_mouse_cursortheme, QString::number(kcminputrc_mouse_cursorsize)});
-    if (applyMouseStatus == 10) {
-        qputenv("XCURSOR_THEME", "breeze_cursors");
-    } else if (!kcminputrc_mouse_cursortheme.isEmpty()) {
-        qputenv("XCURSOR_THEME", kcminputrc_mouse_cursortheme.toUtf8());
+    if (!wayland) {
+        const KConfig cfg(QStringLiteral("kcminputrc"));
+        const KConfigGroup inputCfg = cfg.group("Mouse");
+
+        const auto cursorTheme = inputCfg.readEntry("cursorTheme", QStringLiteral("breeze_cursors"));
+        const auto cursorSize = inputCfg.readEntry("cursorSize", 24);
+
+        runSync(QStringLiteral("kapplymousetheme"), {cursorTheme, QString::number(cursorSize)});
     }
-    qputenv("XCURSOR_SIZE", QByteArray::number(kcminputrc_mouse_cursorsize));
 }
 
 std::optional<QProcessEnvironment> getSystemdEnvironment()
@@ -247,7 +227,7 @@ std::optional<QProcessEnvironment> getSystemdEnvironment()
         return std::nullopt;
     }
     auto variant = qdbus_cast<QVariant>(arguments[0]);
-    if (variant.type() != QVariant::StringList) {
+    if (variant.typeId() != QMetaType::QStringList) {
         return std::nullopt;
     }
 
@@ -350,12 +330,14 @@ void setupPlasmaEnvironment()
     qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", "0");
 
     qputenv("KDE_FULL_SESSION", "true");
-    qputenv("KDE_SESSION_VERSION", "5");
+    qputenv("KDE_SESSION_VERSION", "6");
     qputenv("KDE_SESSION_UID", QByteArray::number(getuid()));
     qputenv("XDG_CURRENT_DESKTOP", "KDE");
 
     qputenv("KDE_APPLICATIONS_AS_SCOPE", "1");
 
+    qputenv("XDG_MENU_PREFIX", "plasma-");
+
     // Add kdedefaults dir to allow config defaults overriding from a writable location
     QByteArray currentConfigDirs = qgetenv("XDG_CONFIG_DIRS");
     if (currentConfigDirs.isEmpty()) {
@@ -375,7 +357,7 @@ void setupPlasmaEnvironment()
         lnfManager.setMode(LookAndFeelManager::Mode::Defaults);
         lnfManager.save(package, KPackage::Package());
     }
-    // check if colors changed, if so apply them and discard palsma cache
+    // check if colors changed, if so apply them and discard plasma cache
     {
         LookAndFeelManager lnfManager;
         lnfManager.setMode(LookAndFeelManager::Mode::Apply);
@@ -479,8 +461,11 @@ bool syncDBusEnvironment()
     }
 
     // At this point all environment variables are set, let's send it to the DBus session server to update the activation environment
-    auto job = new UpdateLaunchEnvJob(environment);
-    return job->exec();
+    auto job = new KUpdateLaunchEnvironmentJob(environment);
+    QEventLoop e;
+    QObject::connect(job, &KUpdateLaunchEnvironmentJob::finished, &e, &QEventLoop::quit);
+    e.exec();
+    return true;
 }
 
 static bool desktopLockedAtStart = false;
@@ -607,7 +592,9 @@ static void migrateUserScriptsAutostart()
         }
 
         // Migrate autostart script to a standard .desktop autostart file
-        AutostartScriptDesktopFile desktopFile(scriptName, info.isSymLink() ? info.symLinkTarget() : scriptMovedPath);
+        AutostartScriptDesktopFile desktopFile(scriptName,
+                                               info.isSymLink() ? info.symLinkTarget() : scriptMovedPath,
+                                               QStringLiteral("application-x-executable-script"));
         qCInfo(PLASMA_STARTUP) << "Migrated legacy autostart script" << scriptPath << "to" << desktopFile.fileName();
 
         if (info.isSymLink() && QFile::remove(scriptPath)) {
@@ -744,7 +731,7 @@ void waitForKonqi()
             services = allServices(QLatin1String("org.kde.drkonqi-"));
             if (wait_drkonqi_counter.elapsed() >= wait_drkonqi_timeout) {
                 // ask remaining drkonqis to die in a graceful way
-                for (const auto &service : qAsConst(services)) {
+                for (const auto &service : std::as_const(services)) {
                     QDBusInterface iface(service, QStringLiteral("/MainApplication"));
                     iface.call(QStringLiteral("quit"));
                 }
@@ -756,7 +743,7 @@ void waitForKonqi()
 
 void playStartupSound()
 {
-    KNotifyConfig notifyConfig(QStringLiteral("plasma_workspace"), QList<QPair<QString, QString>>(), QStringLiteral("startkde"));
+    KNotifyConfig notifyConfig(QStringLiteral("plasma_workspace"), QStringLiteral("startkde"));
     const QString action = notifyConfig.readEntry(QStringLiteral("Action"));
     if (action.isEmpty() || !action.split(QLatin1Char('|')).contains(QLatin1String("Sound"))) {
         // no startup sound configured
