@@ -10,21 +10,16 @@
 #include <KAboutData>
 #include <KLocalizedString>
 
-#include <kworkspace.h>
-
 #include "ksystemactivitydialog.h"
 
 int main(int argc, char **argv)
 {
-    KWorkSpace::detectPlatform(argc, argv);
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("systemmonitor");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("systemmonitor"));
 
     KAboutData about(QStringLiteral("systemmonitor"), i18n("System Activity"));
     KAboutData::setApplicationData(about);
 
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
     QDBusConnection con = QDBusConnection::sessionBus();
     if (!con.registerService(QStringLiteral("org.kde.systemmonitor"))) {
         return 0;
