@@ -5,7 +5,9 @@
 */
 
 #include <QDebug>
-#include <QtTest>
+#include <QSignalSpy>
+#include <QStandardPaths>
+#include <QTest>
 
 #include <KIO/CopyJob>
 
@@ -42,7 +44,8 @@ private:
     QStringList m_packagePaths;
     QString m_dummyPackagePath;
     int m_modelNum = 0;
-    QSize m_targetSize;
+    QProperty<QSize> m_targetSize;
+    QProperty<bool> m_usedInConfig{false};
 };
 
 void ImageProxyModelTest::initTestCase()
@@ -51,6 +54,7 @@ void ImageProxyModelTest::initTestCase()
     m_alternateDir = QDir(QFINDTESTDATA("testdata/alternate"));
     QVERIFY(!m_dataDir.isEmpty());
     QVERIFY(!m_alternateDir.isEmpty());
+    renameBizarreFile(m_dataDir);
 
     m_wallpaperPaths << m_dataDir.absoluteFilePath(ImageBackendTestData::defaultImageFileName1);
     m_wallpaperPaths << m_dataDir.absoluteFilePath(ImageBackendTestData::defaultImageFileName2);
@@ -71,11 +75,11 @@ void ImageProxyModelTest::initTestCase()
 
 void ImageProxyModelTest::init()
 {
-    m_model = new ImageProxyModel({m_dataDir.absolutePath()}, m_targetSize, this);
+    m_model = new ImageProxyModel({m_dataDir.absolutePath()}, QBindable<QSize>(&m_targetSize), QBindable<bool>(&m_usedInConfig), this);
     m_countSpy = new QSignalSpy(m_model, &ImageProxyModel::countChanged);
     m_dataSpy = new QSignalSpy(m_model, &ImageProxyModel::dataChanged);
 
-    QVERIFY(m_model->loading());
+    QVERIFY(m_model->loading().value());
 
     // Test loading data
     for (int i = 0; i < m_modelNum; i++) {
@@ -89,7 +93,7 @@ void ImageProxyModelTest::init()
     m_countSpy->clear();
     QCOMPARE(m_model->sourceModels().size(), m_modelNum);
 
-    QVERIFY(!m_model->loading());
+    QVERIFY(!m_model->loading().value());
 
     QCOMPARE(m_model->rowCount(), ImageBackendTestData::defaultTotalCount);
     QCOMPARE(m_model->count(), m_model->rowCount());
@@ -110,6 +114,8 @@ void ImageProxyModelTest::cleanupTestCase()
     const QString standardPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/wallpapers/");
 
     QDir(standardPath).removeRecursively();
+
+    restoreBizarreFile(m_dataDir);
 }
 
 void ImageProxyModelTest::testImageProxyModelIndexOf()
@@ -243,7 +249,7 @@ void ImageProxyModelTest::testImageProxyModelDirWatch()
     const QString standardPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/wallpapers/");
     QVERIFY(QDir(standardPath).mkpath(standardPath));
 
-    m_model = new ImageProxyModel({standardPath}, m_targetSize, this);
+    m_model = new ImageProxyModel({standardPath}, QBindable<QSize>(&m_targetSize), QBindable<bool>(&m_usedInConfig), this);
     m_countSpy = new QSignalSpy(m_model, &ImageProxyModel::countChanged);
     m_dataSpy = new QSignalSpy(m_model, &ImageProxyModel::dataChanged);
 
