@@ -5,7 +5,9 @@
 */
 
 #include <QDebug>
-#include <QtTest>
+#include <QSignalSpy>
+#include <QStandardPaths>
+#include <QTest>
 
 #include "../model/imageproxymodel.h"
 #include "../slidemodel.h"
@@ -39,7 +41,8 @@ private:
     QString m_dummyWallpaperPath;
     QStringList m_packagePaths;
     QString m_dummyPackagePath;
-    QSize m_targetSize;
+    QProperty<QSize> m_targetSize;
+    QProperty<bool> m_usedInConfig{false};
 };
 
 void SlideModelTest::initTestCase()
@@ -48,6 +51,7 @@ void SlideModelTest::initTestCase()
     m_alternateDir = QDir(QFINDTESTDATA("testdata/alternate"));
     QVERIFY(!m_dataDir.isEmpty());
     QVERIFY(!m_alternateDir.isEmpty());
+    renameBizarreFile(m_dataDir);
 
     m_wallpaperPaths << m_dataDir.absoluteFilePath(ImageBackendTestData::defaultImageFileName1);
     m_wallpaperPaths << m_dataDir.absoluteFilePath(ImageBackendTestData::defaultImageFileName2);
@@ -67,7 +71,7 @@ void SlideModelTest::initTestCase()
 
 void SlideModelTest::init()
 {
-    m_model = new SlideModel(m_targetSize, this);
+    m_model = new SlideModel(QBindable<QSize>(&m_targetSize), QBindable<bool>(&m_usedInConfig), this);
     m_doneSpy = new QSignalSpy(m_model, &SlideModel::done);
     m_dataSpy = new QSignalSpy(m_model, &SlideModel::dataChanged);
 
@@ -97,6 +101,8 @@ void SlideModelTest::cleanupTestCase()
     const QString standardPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/wallpapers/");
 
     QDir(standardPath).removeRecursively();
+
+    restoreBizarreFile(m_dataDir);
 }
 
 void SlideModelTest::testSlideModelData()
