@@ -7,15 +7,46 @@
 
 #include "packagefinder.h"
 
+#include <limits>
+
 #include <QDir>
 
-#include <KLocalizedString>
 #include <KPackage/PackageLoader>
 
-#include "distance.h"
 #include "findsymlinktarget.h"
 #include "suffixcheck.h"
 
+namespace
+{
+/**
+ * Computes difference of two areas
+ */
+double distance(const QSize &size, const QSize &desired)
+{
+    const double desiredAspectRatio = (desired.height() > 0) ? desired.width() / static_cast<double>(desired.height()) : 0;
+    const double candidateAspectRatio = (size.height() > 0) ? size.width() / static_cast<double>(size.height()) : std::numeric_limits<double>::max();
+
+    double delta = size.width() - desired.width();
+    delta = delta >= 0.0 ? delta : -delta * 2; // Penalize for scaling up
+
+    return std::abs(candidateAspectRatio - desiredAspectRatio) * 25000 + delta;
+}
+
+/**
+ * @return size from the filename
+ */
+QSize resSize(QStringView str)
+{
+    const int index = str.indexOf(QLatin1Char('x'));
+
+    if (index != -1) {
+        return QSize(str.left(index).toInt(), str.mid(index + 1).toInt());
+    }
+
+    return QSize();
+}
+}
+
 PackageFinder::PackageFinder(const QStringList &paths, const QSize &targetSize, QObject *parent)
     : QObject(parent)
     , m_paths(paths)
@@ -121,7 +152,7 @@ void PackageFinder::findPreferredImageInPackage(KPackage::Package &package, cons
             return preferred;
         }
 
-        float best = std::numeric_limits<float>::max();
+        double best = std::numeric_limits<double>::max();
 
         for (const QString &entry : images) {
             QSize candidate = resSize(QFileInfo(entry).baseName());
@@ -130,7 +161,7 @@ void PackageFinder::findPreferredImageInPackage(KPackage::Package &package, cons
                 continue;
             }
 
-            const float dist = distance(candidate, tSize);
+            const double dist = distance(candidate, tSize);
 
             if (preferred.isEmpty() || dist < best) {
                 preferred = entry;
@@ -145,13 +176,11 @@ void PackageFinder::findPreferredImageInPackage(KPackage::Package &package, cons
     const QString preferredDark = findBestMatch(QByteArrayLiteral("images_dark"));
 
     package.removeDefinition("preferred");
-    package.addFileDefinition("preferred", QStringLiteral("images/") + preferred, i18n("Recommended wallpaper file"));
+    package.addFileDefinition("preferred", QStringLiteral("images/") + preferred);
 
     if (!preferredDark.isEmpty()) {
         package.removeDefinition("preferredDark");
-        package.addFileDefinition("preferredDark",
-                                  QStringLiteral("images_dark%1").arg(QDir::separator()) + preferredDark,
-                                  QStringLiteral("Recommended dark wallpaper file"));
+        package.addFileDefinition("preferredDark", QStringLiteral("images_dark%1").arg(QDir::separator()) + preferredDark);
     }
 }
 
